/* EventBus.c generated by valac 0.56.19, the Vala compiler
 * generated from EventBus.vala, do not modify */

/*
 * Copyright © 2023 Alain M. (https://github.com/alainm23/planify)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * Authored by: Alain M. <alainmh23@gmail.com>
 */

#include "planify.h"
#include <gio/gio.h>
#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <adwaita.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	SERVICES_EVENT_BUS_0_PROPERTY,
	SERVICES_EVENT_BUS_MOBILE_MODE_PROPERTY,
	SERVICES_EVENT_BUS_NUM_PROPERTIES
};
static GParamSpec* services_event_bus_properties[SERVICES_EVENT_BUS_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
enum  {
	SERVICES_EVENT_BUS_DISCONNECT_TYPING_ACCEL_SIGNAL,
	SERVICES_EVENT_BUS_CONNECT_TYPING_ACCEL_SIGNAL,
	SERVICES_EVENT_BUS_DISCONNECT_ALL_ACCELS_SIGNAL,
	SERVICES_EVENT_BUS_CONNECT_ALL_ACCELS_SIGNAL,
	SERVICES_EVENT_BUS_ESCAPE_PRESSED_SIGNAL,
	SERVICES_EVENT_BUS_THEME_CHANGED_SIGNAL,
	SERVICES_EVENT_BUS_DELETE_ROW_PROJECT_SIGNAL,
	SERVICES_EVENT_BUS_PANE_SELECTED_SIGNAL,
	SERVICES_EVENT_BUS_ITEM_SELECTED_SIGNAL,
	SERVICES_EVENT_BUS_TASK_SELECTED_SIGNAL,
	SERVICES_EVENT_BUS_AVATAR_DOWNLOADED_SIGNAL,
	SERVICES_EVENT_BUS_MAGIC_BUTTON_ACTIVATED_SIGNAL,
	SERVICES_EVENT_BUS_PROJECT_PICKER_CHANGED_SIGNAL,
	SERVICES_EVENT_BUS_SECTION_PICKER_CHANGED_SIGNAL,
	SERVICES_EVENT_BUS_PROJECT_PARENT_CHANGED_SIGNAL,
	SERVICES_EVENT_BUS_UPDATE_INSERTED_PROJECT_MAP_SIGNAL,
	SERVICES_EVENT_BUS_CHECKED_TOGGLED_SIGNAL,
	SERVICES_EVENT_BUS_FAVORITE_TOGGLED_SIGNAL,
	SERVICES_EVENT_BUS_ITEM_MOVED_SIGNAL,
	SERVICES_EVENT_BUS_UPDATE_INSERTED_ITEM_MAP_SIGNAL,
	SERVICES_EVENT_BUS_UPDATE_SECTION_SORT_FUNC_SIGNAL,
	SERVICES_EVENT_BUS_DAY_CHANGED_SIGNAL,
	SERVICES_EVENT_BUS_SECTION_SORT_ORDER_CHANGED_SIGNAL,
	SERVICES_EVENT_BUS_DRAG_N_DROP_ACTIVE_SIGNAL,
	SERVICES_EVENT_BUS_EXPAND_ALL_SIGNAL,
	SERVICES_EVENT_BUS_PROJECTS_DRAG_BEGIN_SIGNAL,
	SERVICES_EVENT_BUS_PROJECTS_DRAG_END_SIGNAL,
	SERVICES_EVENT_BUS_DRAG_ITEMS_END_SIGNAL,
	SERVICES_EVENT_BUS_UPDATE_SOURCES_POSITION_SIGNAL,
	SERVICES_EVENT_BUS_OAUTH_CALLBACK_SIGNAL,
	SERVICES_EVENT_BUS_MOBILE_MODE_CHANGE_SIGNAL,
	SERVICES_EVENT_BUS_SEND_TOAST_SIGNAL,
	SERVICES_EVENT_BUS_SEND_ERROR_TOAST_SIGNAL,
	SERVICES_EVENT_BUS_SEND_CONFLICT_TOAST_SIGNAL,
	SERVICES_EVENT_BUS_SEND_TASK_COMPLETED_TOAST_SIGNAL,
	SERVICES_EVENT_BUS_SHOW_MULTI_SELECT_SIGNAL,
	SERVICES_EVENT_BUS_SELECT_ITEM_SIGNAL,
	SERVICES_EVENT_BUS_UNSELECT_ITEM_SIGNAL,
	SERVICES_EVENT_BUS_UNSELECT_ALL_SIGNAL,
	SERVICES_EVENT_BUS_MAGIC_BUTTON_VISIBLE_SIGNAL,
	SERVICES_EVENT_BUS_OPEN_ITEM_SIGNAL,
	SERVICES_EVENT_BUS_PUSH_ITEM_SIGNAL,
	SERVICES_EVENT_BUS_CLOSE_ITEM_SIGNAL,
	SERVICES_EVENT_BUS_CLOSE_ITEM_EDIT_SIGNAL,
	SERVICES_EVENT_BUS_DIM_CONTENT_SIGNAL,
	SERVICES_EVENT_BUS_NUM_SIGNALS
};
static guint services_event_bus_signals[SERVICES_EVENT_BUS_NUM_SIGNALS] = {0};

static gpointer services_event_bus_parent_class = NULL;
static ServicesEventBus* services_event_bus__instance;
static ServicesEventBus* services_event_bus__instance = NULL;

static void g_cclosure_user_marshal_VOID__ENUM_STRING (GClosure * closure,
                                                GValue * return_value,
                                                guint n_param_values,
                                                const GValue * param_values,
                                                gpointer invocation_hint,
                                                gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__OBJECT_STRING_BOOLEAN (GClosure * closure,
                                                          GValue * return_value,
                                                          guint n_param_values,
                                                          const GValue * param_values,
                                                          gpointer invocation_hint,
                                                          gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__OBJECT_STRING (GClosure * closure,
                                                  GValue * return_value,
                                                  guint n_param_values,
                                                  const GValue * param_values,
                                                  gpointer invocation_hint,
                                                  gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__OBJECT_BOOLEAN (GClosure * closure,
                                                   GValue * return_value,
                                                   guint n_param_values,
                                                   const GValue * param_values,
                                                   gpointer invocation_hint,
                                                   gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__OBJECT_STRING_STRING_STRING (GClosure * closure,
                                                                GValue * return_value,
                                                                guint n_param_values,
                                                                const GValue * param_values,
                                                                gpointer invocation_hint,
                                                                gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__OBJECT_STRING_STRING (GClosure * closure,
                                                         GValue * return_value,
                                                         guint n_param_values,
                                                         const GValue * param_values,
                                                         gpointer invocation_hint,
                                                         gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__STRING_STRING_BOOLEAN (GClosure * closure,
                                                          GValue * return_value,
                                                          guint n_param_values,
                                                          const GValue * param_values,
                                                          gpointer invocation_hint,
                                                          gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__STRING_BOOLEAN (GClosure * closure,
                                                   GValue * return_value,
                                                   guint n_param_values,
                                                   const GValue * param_values,
                                                   gpointer invocation_hint,
                                                   gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__INT_STRING (GClosure * closure,
                                               GValue * return_value,
                                               guint n_param_values,
                                               const GValue * param_values,
                                               gpointer invocation_hint,
                                               gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__BOOLEAN_STRING (GClosure * closure,
                                                   GValue * return_value,
                                                   guint n_param_values,
                                                   const GValue * param_values,
                                                   gpointer invocation_hint,
                                                   gpointer marshal_data);
static void services_event_bus_finalize (GObject * obj);
static GType services_event_bus_get_type_once (void);
static void _vala_services_event_bus_get_property (GObject * object,
                                            guint property_id,
                                            GValue * value,
                                            GParamSpec * pspec);
static void _vala_services_event_bus_set_property (GObject * object,
                                            guint property_id,
                                            const GValue * value,
                                            GParamSpec * pspec);

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

ServicesEventBus*
services_event_bus_get_default (void)
{
	ServicesEventBus* _tmp0_;
	ServicesEventBus* _tmp2_;
	ServicesEventBus* _tmp3_;
	ServicesEventBus* result;
	_tmp0_ = services_event_bus__instance;
	if (_tmp0_ == NULL) {
		ServicesEventBus* _tmp1_;
		_tmp1_ = services_event_bus_new ();
		_g_object_unref0 (services_event_bus__instance);
		services_event_bus__instance = _tmp1_;
	}
	_tmp2_ = services_event_bus__instance;
	_tmp3_ = _g_object_ref0 (_tmp2_);
	result = _tmp3_;
	return result;
}

void
services_event_bus_unfocus_item (ServicesEventBus* self)
{
	g_return_if_fail (self != NULL);
	self->item_edit_active = FALSE;
	g_signal_emit (self, services_event_bus_signals[SERVICES_EVENT_BUS_DIM_CONTENT_SIGNAL], 0, FALSE, "");
}

ServicesEventBus*
services_event_bus_construct (GType object_type)
{
	ServicesEventBus * self = NULL;
	self = (ServicesEventBus*) g_object_new (object_type, NULL);
	return self;
}

ServicesEventBus*
services_event_bus_new (void)
{
	return services_event_bus_construct (SERVICES_TYPE_EVENT_BUS);
}

gboolean
services_event_bus_get_mobile_mode (ServicesEventBus* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->_mobile_mode;
	return result;
}

void
services_event_bus_set_mobile_mode (ServicesEventBus* self,
                                    gboolean value)
{
	g_return_if_fail (self != NULL);
	self->_mobile_mode = value;
	g_signal_emit (self, services_event_bus_signals[SERVICES_EVENT_BUS_MOBILE_MODE_CHANGE_SIGNAL], 0);
	g_object_notify_by_pspec ((GObject *) self, services_event_bus_properties[SERVICES_EVENT_BUS_MOBILE_MODE_PROPERTY]);
}

static void
g_cclosure_user_marshal_VOID__ENUM_STRING (GClosure * closure,
                                           GValue * return_value,
                                           guint n_param_values,
                                           const GValue * param_values,
                                           gpointer invocation_hint,
                                           gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__ENUM_STRING) (gpointer data1, gint arg_1, const char* arg_2, gpointer data2);
	register GMarshalFunc_VOID__ENUM_STRING callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 3);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__ENUM_STRING) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_enum (param_values + 1), g_value_get_string (param_values + 2), data2);
}

static void
g_cclosure_user_marshal_VOID__OBJECT_STRING_BOOLEAN (GClosure * closure,
                                                     GValue * return_value,
                                                     guint n_param_values,
                                                     const GValue * param_values,
                                                     gpointer invocation_hint,
                                                     gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__OBJECT_STRING_BOOLEAN) (gpointer data1, gpointer arg_1, const char* arg_2, gboolean arg_3, gpointer data2);
	register GMarshalFunc_VOID__OBJECT_STRING_BOOLEAN callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 4);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__OBJECT_STRING_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_object (param_values + 1), g_value_get_string (param_values + 2), g_value_get_boolean (param_values + 3), data2);
}

static void
g_cclosure_user_marshal_VOID__OBJECT_STRING (GClosure * closure,
                                             GValue * return_value,
                                             guint n_param_values,
                                             const GValue * param_values,
                                             gpointer invocation_hint,
                                             gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__OBJECT_STRING) (gpointer data1, gpointer arg_1, const char* arg_2, gpointer data2);
	register GMarshalFunc_VOID__OBJECT_STRING callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 3);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__OBJECT_STRING) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_object (param_values + 1), g_value_get_string (param_values + 2), data2);
}

static void
g_cclosure_user_marshal_VOID__OBJECT_BOOLEAN (GClosure * closure,
                                              GValue * return_value,
                                              guint n_param_values,
                                              const GValue * param_values,
                                              gpointer invocation_hint,
                                              gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__OBJECT_BOOLEAN) (gpointer data1, gpointer arg_1, gboolean arg_2, gpointer data2);
	register GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 3);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__OBJECT_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_object (param_values + 1), g_value_get_boolean (param_values + 2), data2);
}

static void
g_cclosure_user_marshal_VOID__OBJECT_STRING_STRING_STRING (GClosure * closure,
                                                           GValue * return_value,
                                                           guint n_param_values,
                                                           const GValue * param_values,
                                                           gpointer invocation_hint,
                                                           gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__OBJECT_STRING_STRING_STRING) (gpointer data1, gpointer arg_1, const char* arg_2, const char* arg_3, const char* arg_4, gpointer data2);
	register GMarshalFunc_VOID__OBJECT_STRING_STRING_STRING callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 5);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__OBJECT_STRING_STRING_STRING) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_object (param_values + 1), g_value_get_string (param_values + 2), g_value_get_string (param_values + 3), g_value_get_string (param_values + 4), data2);
}

static void
g_cclosure_user_marshal_VOID__OBJECT_STRING_STRING (GClosure * closure,
                                                    GValue * return_value,
                                                    guint n_param_values,
                                                    const GValue * param_values,
                                                    gpointer invocation_hint,
                                                    gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__OBJECT_STRING_STRING) (gpointer data1, gpointer arg_1, const char* arg_2, const char* arg_3, gpointer data2);
	register GMarshalFunc_VOID__OBJECT_STRING_STRING callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 4);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__OBJECT_STRING_STRING) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_object (param_values + 1), g_value_get_string (param_values + 2), g_value_get_string (param_values + 3), data2);
}

static void
g_cclosure_user_marshal_VOID__STRING_STRING_BOOLEAN (GClosure * closure,
                                                     GValue * return_value,
                                                     guint n_param_values,
                                                     const GValue * param_values,
                                                     gpointer invocation_hint,
                                                     gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__STRING_STRING_BOOLEAN) (gpointer data1, const char* arg_1, const char* arg_2, gboolean arg_3, gpointer data2);
	register GMarshalFunc_VOID__STRING_STRING_BOOLEAN callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 4);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__STRING_STRING_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_string (param_values + 1), g_value_get_string (param_values + 2), g_value_get_boolean (param_values + 3), data2);
}

static void
g_cclosure_user_marshal_VOID__STRING_BOOLEAN (GClosure * closure,
                                              GValue * return_value,
                                              guint n_param_values,
                                              const GValue * param_values,
                                              gpointer invocation_hint,
                                              gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__STRING_BOOLEAN) (gpointer data1, const char* arg_1, gboolean arg_2, gpointer data2);
	register GMarshalFunc_VOID__STRING_BOOLEAN callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 3);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__STRING_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_string (param_values + 1), g_value_get_boolean (param_values + 2), data2);
}

static void
g_cclosure_user_marshal_VOID__INT_STRING (GClosure * closure,
                                          GValue * return_value,
                                          guint n_param_values,
                                          const GValue * param_values,
                                          gpointer invocation_hint,
                                          gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__INT_STRING) (gpointer data1, gint arg_1, const char* arg_2, gpointer data2);
	register GMarshalFunc_VOID__INT_STRING callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 3);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__INT_STRING) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_int (param_values + 1), g_value_get_string (param_values + 2), data2);
}

static void
g_cclosure_user_marshal_VOID__BOOLEAN_STRING (GClosure * closure,
                                              GValue * return_value,
                                              guint n_param_values,
                                              const GValue * param_values,
                                              gpointer invocation_hint,
                                              gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__BOOLEAN_STRING) (gpointer data1, gboolean arg_1, const char* arg_2, gpointer data2);
	register GMarshalFunc_VOID__BOOLEAN_STRING callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 3);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__BOOLEAN_STRING) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_boolean (param_values + 1), g_value_get_string (param_values + 2), data2);
}

static void
services_event_bus_class_init (ServicesEventBusClass * klass,
                               gpointer klass_data)
{
	services_event_bus_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_services_event_bus_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_services_event_bus_set_property;
	G_OBJECT_CLASS (klass)->finalize = services_event_bus_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERVICES_EVENT_BUS_MOBILE_MODE_PROPERTY, services_event_bus_properties[SERVICES_EVENT_BUS_MOBILE_MODE_PROPERTY] = g_param_spec_boolean ("mobile-mode", "mobile-mode", "mobile-mode", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	services_event_bus_signals[SERVICES_EVENT_BUS_DISCONNECT_TYPING_ACCEL_SIGNAL] = g_signal_new ("disconnect-typing-accel", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	services_event_bus_signals[SERVICES_EVENT_BUS_CONNECT_TYPING_ACCEL_SIGNAL] = g_signal_new ("connect-typing-accel", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	services_event_bus_signals[SERVICES_EVENT_BUS_DISCONNECT_ALL_ACCELS_SIGNAL] = g_signal_new ("disconnect-all-accels", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	services_event_bus_signals[SERVICES_EVENT_BUS_CONNECT_ALL_ACCELS_SIGNAL] = g_signal_new ("connect-all-accels", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	services_event_bus_signals[SERVICES_EVENT_BUS_ESCAPE_PRESSED_SIGNAL] = g_signal_new ("escape-pressed", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	services_event_bus_signals[SERVICES_EVENT_BUS_THEME_CHANGED_SIGNAL] = g_signal_new ("theme-changed", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	services_event_bus_signals[SERVICES_EVENT_BUS_DELETE_ROW_PROJECT_SIGNAL] = g_signal_new ("delete-row-project", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, OBJECTS_TYPE_PROJECT);
	services_event_bus_signals[SERVICES_EVENT_BUS_PANE_SELECTED_SIGNAL] = g_signal_new ("pane-selected", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__ENUM_STRING, G_TYPE_NONE, 2, TYPE_PANE_TYPE, G_TYPE_STRING);
	services_event_bus_signals[SERVICES_EVENT_BUS_ITEM_SELECTED_SIGNAL] = g_signal_new ("item-selected", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
	services_event_bus_signals[SERVICES_EVENT_BUS_TASK_SELECTED_SIGNAL] = g_signal_new ("task-selected", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
	services_event_bus_signals[SERVICES_EVENT_BUS_AVATAR_DOWNLOADED_SIGNAL] = g_signal_new ("avatar-downloaded", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	services_event_bus_signals[SERVICES_EVENT_BUS_MAGIC_BUTTON_ACTIVATED_SIGNAL] = g_signal_new ("magic-button-activated", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN, G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
	services_event_bus_signals[SERVICES_EVENT_BUS_PROJECT_PICKER_CHANGED_SIGNAL] = g_signal_new ("project-picker-changed", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
	services_event_bus_signals[SERVICES_EVENT_BUS_SECTION_PICKER_CHANGED_SIGNAL] = g_signal_new ("section-picker-changed", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
	services_event_bus_signals[SERVICES_EVENT_BUS_PROJECT_PARENT_CHANGED_SIGNAL] = g_signal_new ("project-parent-changed", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_STRING_BOOLEAN, G_TYPE_NONE, 3, OBJECTS_TYPE_PROJECT, G_TYPE_STRING, G_TYPE_BOOLEAN);
	services_event_bus_signals[SERVICES_EVENT_BUS_UPDATE_INSERTED_PROJECT_MAP_SIGNAL] = g_signal_new ("update-inserted-project-map", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_STRING, G_TYPE_NONE, 2, gtk_widget_get_type (), G_TYPE_STRING);
	services_event_bus_signals[SERVICES_EVENT_BUS_CHECKED_TOGGLED_SIGNAL] = g_signal_new ("checked-toggled", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_BOOLEAN, G_TYPE_NONE, 2, OBJECTS_TYPE_ITEM, G_TYPE_BOOLEAN);
	services_event_bus_signals[SERVICES_EVENT_BUS_FAVORITE_TOGGLED_SIGNAL] = g_signal_new ("favorite-toggled", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, OBJECTS_TYPE_PROJECT);
	services_event_bus_signals[SERVICES_EVENT_BUS_ITEM_MOVED_SIGNAL] = g_signal_new ("item-moved", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_STRING_STRING_STRING, G_TYPE_NONE, 4, OBJECTS_TYPE_ITEM, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
	services_event_bus_signals[SERVICES_EVENT_BUS_UPDATE_INSERTED_ITEM_MAP_SIGNAL] = g_signal_new ("update-inserted-item-map", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_STRING_STRING, G_TYPE_NONE, 3, gtk_widget_get_type (), G_TYPE_STRING, G_TYPE_STRING);
	services_event_bus_signals[SERVICES_EVENT_BUS_UPDATE_SECTION_SORT_FUNC_SIGNAL] = g_signal_new ("update-section-sort-func", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_STRING_BOOLEAN, G_TYPE_NONE, 3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN);
	services_event_bus_signals[SERVICES_EVENT_BUS_DAY_CHANGED_SIGNAL] = g_signal_new ("day-changed", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	services_event_bus_signals[SERVICES_EVENT_BUS_SECTION_SORT_ORDER_CHANGED_SIGNAL] = g_signal_new ("section-sort-order-changed", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
	services_event_bus_signals[SERVICES_EVENT_BUS_DRAG_N_DROP_ACTIVE_SIGNAL] = g_signal_new ("drag-n-drop-active", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_BOOLEAN, G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_BOOLEAN);
	services_event_bus_signals[SERVICES_EVENT_BUS_EXPAND_ALL_SIGNAL] = g_signal_new ("expand-all", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_BOOLEAN, G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_BOOLEAN);
	services_event_bus_signals[SERVICES_EVENT_BUS_PROJECTS_DRAG_BEGIN_SIGNAL] = g_signal_new ("projects-drag-begin", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
	services_event_bus_signals[SERVICES_EVENT_BUS_PROJECTS_DRAG_END_SIGNAL] = g_signal_new ("projects-drag-end", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
	services_event_bus_signals[SERVICES_EVENT_BUS_DRAG_ITEMS_END_SIGNAL] = g_signal_new ("drag-items-end", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
	services_event_bus_signals[SERVICES_EVENT_BUS_UPDATE_SOURCES_POSITION_SIGNAL] = g_signal_new ("update-sources-position", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	services_event_bus_signals[SERVICES_EVENT_BUS_OAUTH_CALLBACK_SIGNAL] = g_signal_new ("oauth-callback", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
	services_event_bus_signals[SERVICES_EVENT_BUS_MOBILE_MODE_CHANGE_SIGNAL] = g_signal_new ("mobile-mode-change", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	services_event_bus_signals[SERVICES_EVENT_BUS_SEND_TOAST_SIGNAL] = g_signal_new ("send-toast", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, adw_toast_get_type ());
	services_event_bus_signals[SERVICES_EVENT_BUS_SEND_ERROR_TOAST_SIGNAL] = g_signal_new ("send-error-toast", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__INT_STRING, G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_STRING);
	services_event_bus_signals[SERVICES_EVENT_BUS_SEND_CONFLICT_TOAST_SIGNAL] = g_signal_new ("send-conflict-toast", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, OBJECTS_TYPE_SOURCE);
	services_event_bus_signals[SERVICES_EVENT_BUS_SEND_TASK_COMPLETED_TOAST_SIGNAL] = g_signal_new ("send-task-completed-toast", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
	services_event_bus_signals[SERVICES_EVENT_BUS_SHOW_MULTI_SELECT_SIGNAL] = g_signal_new ("show-multi-select", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN, G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
	services_event_bus_signals[SERVICES_EVENT_BUS_SELECT_ITEM_SIGNAL] = g_signal_new ("select-item", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, gtk_widget_get_type ());
	services_event_bus_signals[SERVICES_EVENT_BUS_UNSELECT_ITEM_SIGNAL] = g_signal_new ("unselect-item", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, gtk_widget_get_type ());
	services_event_bus_signals[SERVICES_EVENT_BUS_UNSELECT_ALL_SIGNAL] = g_signal_new ("unselect-all", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	services_event_bus_signals[SERVICES_EVENT_BUS_MAGIC_BUTTON_VISIBLE_SIGNAL] = g_signal_new ("magic-button-visible", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN, G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
	services_event_bus_signals[SERVICES_EVENT_BUS_OPEN_ITEM_SIGNAL] = g_signal_new ("open-item", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, OBJECTS_TYPE_ITEM);
	services_event_bus_signals[SERVICES_EVENT_BUS_PUSH_ITEM_SIGNAL] = g_signal_new ("push-item", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, OBJECTS_TYPE_ITEM);
	services_event_bus_signals[SERVICES_EVENT_BUS_CLOSE_ITEM_SIGNAL] = g_signal_new ("close-item", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	services_event_bus_signals[SERVICES_EVENT_BUS_CLOSE_ITEM_EDIT_SIGNAL] = g_signal_new ("close-item-edit", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	services_event_bus_signals[SERVICES_EVENT_BUS_DIM_CONTENT_SIGNAL] = g_signal_new ("dim-content", SERVICES_TYPE_EVENT_BUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__BOOLEAN_STRING, G_TYPE_NONE, 2, G_TYPE_BOOLEAN, G_TYPE_STRING);
}

static void
services_event_bus_instance_init (ServicesEventBus * self,
                                  gpointer klass)
{
	ServicesSettings* _tmp0_;
	ServicesSettings* _tmp1_;
	GSettings* _tmp2_;
	_tmp0_ = services_settings_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_->settings;
	self->_mobile_mode = g_settings_get_boolean (_tmp2_, "mobile-mode");
	_g_object_unref0 (_tmp1_);
	self->multi_select_enabled = FALSE;
	self->item_edit_active = FALSE;
}

static void
services_event_bus_finalize (GObject * obj)
{
	ServicesEventBus * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERVICES_TYPE_EVENT_BUS, ServicesEventBus);
	G_OBJECT_CLASS (services_event_bus_parent_class)->finalize (obj);
}

static GType
services_event_bus_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ServicesEventBusClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) services_event_bus_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ServicesEventBus), 0, (GInstanceInitFunc) services_event_bus_instance_init, NULL };
	GType services_event_bus_type_id;
	services_event_bus_type_id = g_type_register_static (G_TYPE_OBJECT, "ServicesEventBus", &g_define_type_info, 0);
	return services_event_bus_type_id;
}

GType
services_event_bus_get_type (void)
{
	static volatile gsize services_event_bus_type_id__once = 0;
	if (g_once_init_enter (&services_event_bus_type_id__once)) {
		GType services_event_bus_type_id;
		services_event_bus_type_id = services_event_bus_get_type_once ();
		g_once_init_leave (&services_event_bus_type_id__once, services_event_bus_type_id);
	}
	return services_event_bus_type_id__once;
}

static void
_vala_services_event_bus_get_property (GObject * object,
                                       guint property_id,
                                       GValue * value,
                                       GParamSpec * pspec)
{
	ServicesEventBus * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERVICES_TYPE_EVENT_BUS, ServicesEventBus);
	switch (property_id) {
		case SERVICES_EVENT_BUS_MOBILE_MODE_PROPERTY:
		g_value_set_boolean (value, services_event_bus_get_mobile_mode (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_services_event_bus_set_property (GObject * object,
                                       guint property_id,
                                       const GValue * value,
                                       GParamSpec * pspec)
{
	ServicesEventBus * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERVICES_TYPE_EVENT_BUS, ServicesEventBus);
	switch (property_id) {
		case SERVICES_EVENT_BUS_MOBILE_MODE_PROPERTY:
		services_event_bus_set_mobile_mode (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

