/* Scheduled.c generated by valac 0.56.19, the Vala compiler
 * generated from Scheduled.vala, do not modify */

/*
 * Copyright © 2023 Alain M. (https://github.com/alainm23/planify)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * Authored by: Alain M. <alainmh23@gmail.com>
 */

#include <adwaita.h>
#include <glib-object.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gtk/gtk.h>
#include "planify.h"
#include <float.h>
#include <math.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <pango/pango.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define VIEWS_SCHEDULED_TYPE_SCHEDULED (views_scheduled_scheduled_get_type ())
#define VIEWS_SCHEDULED_SCHEDULED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED, ViewsScheduledScheduled))
#define VIEWS_SCHEDULED_SCHEDULED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VIEWS_SCHEDULED_TYPE_SCHEDULED, ViewsScheduledScheduledClass))
#define VIEWS_SCHEDULED_IS_SCHEDULED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED))
#define VIEWS_SCHEDULED_IS_SCHEDULED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VIEWS_SCHEDULED_TYPE_SCHEDULED))
#define VIEWS_SCHEDULED_SCHEDULED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED, ViewsScheduledScheduledClass))

typedef struct _ViewsScheduledScheduled ViewsScheduledScheduled;
typedef struct _ViewsScheduledScheduledClass ViewsScheduledScheduledClass;
typedef struct _ViewsScheduledScheduledPrivate ViewsScheduledScheduledPrivate;

#define LAYOUTS_TYPE_ITEM_BASE (layouts_item_base_get_type ())
#define LAYOUTS_ITEM_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LAYOUTS_TYPE_ITEM_BASE, LayoutsItemBase))
#define LAYOUTS_ITEM_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LAYOUTS_TYPE_ITEM_BASE, LayoutsItemBaseClass))
#define LAYOUTS_IS_ITEM_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LAYOUTS_TYPE_ITEM_BASE))
#define LAYOUTS_IS_ITEM_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LAYOUTS_TYPE_ITEM_BASE))
#define LAYOUTS_ITEM_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LAYOUTS_TYPE_ITEM_BASE, LayoutsItemBaseClass))

typedef struct _LayoutsItemBase LayoutsItemBase;
typedef struct _LayoutsItemBaseClass LayoutsItemBaseClass;

#define LAYOUTS_TYPE_ITEM_ROW (layouts_item_row_get_type ())
#define LAYOUTS_ITEM_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LAYOUTS_TYPE_ITEM_ROW, LayoutsItemRow))
#define LAYOUTS_ITEM_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LAYOUTS_TYPE_ITEM_ROW, LayoutsItemRowClass))
#define LAYOUTS_IS_ITEM_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LAYOUTS_TYPE_ITEM_ROW))
#define LAYOUTS_IS_ITEM_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LAYOUTS_TYPE_ITEM_ROW))
#define LAYOUTS_ITEM_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LAYOUTS_TYPE_ITEM_ROW, LayoutsItemRowClass))

typedef struct _LayoutsItemRow LayoutsItemRow;
typedef struct _LayoutsItemRowClass LayoutsItemRowClass;
enum  {
	VIEWS_SCHEDULED_SCHEDULED_0_PROPERTY,
	VIEWS_SCHEDULED_SCHEDULED_NUM_PROPERTIES
};
static GParamSpec* views_scheduled_scheduled_properties[VIEWS_SCHEDULED_SCHEDULED_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define VIEWS_SCHEDULED_TYPE_SCHEDULED_SECTION (views_scheduled_scheduled_section_get_type ())
#define VIEWS_SCHEDULED_SCHEDULED_SECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED_SECTION, ViewsScheduledScheduledSection))
#define VIEWS_SCHEDULED_SCHEDULED_SECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VIEWS_SCHEDULED_TYPE_SCHEDULED_SECTION, ViewsScheduledScheduledSectionClass))
#define VIEWS_SCHEDULED_IS_SCHEDULED_SECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED_SECTION))
#define VIEWS_SCHEDULED_IS_SCHEDULED_SECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VIEWS_SCHEDULED_TYPE_SCHEDULED_SECTION))
#define VIEWS_SCHEDULED_SCHEDULED_SECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED_SECTION, ViewsScheduledScheduledSectionClass))

typedef struct _ViewsScheduledScheduledSection ViewsScheduledScheduledSection;
typedef struct _ViewsScheduledScheduledSectionClass ViewsScheduledScheduledSectionClass;

#define VIEWS_SCHEDULED_TYPE_SCHEDULED_OVERDUE (views_scheduled_scheduled_overdue_get_type ())
#define VIEWS_SCHEDULED_SCHEDULED_OVERDUE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED_OVERDUE, ViewsScheduledScheduledOverdue))
#define VIEWS_SCHEDULED_SCHEDULED_OVERDUE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VIEWS_SCHEDULED_TYPE_SCHEDULED_OVERDUE, ViewsScheduledScheduledOverdueClass))
#define VIEWS_SCHEDULED_IS_SCHEDULED_OVERDUE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED_OVERDUE))
#define VIEWS_SCHEDULED_IS_SCHEDULED_OVERDUE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VIEWS_SCHEDULED_TYPE_SCHEDULED_OVERDUE))
#define VIEWS_SCHEDULED_SCHEDULED_OVERDUE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED_OVERDUE, ViewsScheduledScheduledOverdueClass))

typedef struct _ViewsScheduledScheduledOverdue ViewsScheduledScheduledOverdue;
typedef struct _ViewsScheduledScheduledOverdueClass ViewsScheduledScheduledOverdueClass;
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))

#define VIEWS_SCHEDULED_TYPE_SCHEDULED_DAY (views_scheduled_scheduled_day_get_type ())
#define VIEWS_SCHEDULED_SCHEDULED_DAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED_DAY, ViewsScheduledScheduledDay))
#define VIEWS_SCHEDULED_SCHEDULED_DAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VIEWS_SCHEDULED_TYPE_SCHEDULED_DAY, ViewsScheduledScheduledDayClass))
#define VIEWS_SCHEDULED_IS_SCHEDULED_DAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED_DAY))
#define VIEWS_SCHEDULED_IS_SCHEDULED_DAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VIEWS_SCHEDULED_TYPE_SCHEDULED_DAY))
#define VIEWS_SCHEDULED_SCHEDULED_DAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED_DAY, ViewsScheduledScheduledDayClass))

typedef struct _ViewsScheduledScheduledDay ViewsScheduledScheduledDay;
typedef struct _ViewsScheduledScheduledDayClass ViewsScheduledScheduledDayClass;

#define VIEWS_SCHEDULED_TYPE_SCHEDULED_RANGE (views_scheduled_scheduled_range_get_type ())
#define VIEWS_SCHEDULED_SCHEDULED_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED_RANGE, ViewsScheduledScheduledRange))
#define VIEWS_SCHEDULED_SCHEDULED_RANGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VIEWS_SCHEDULED_TYPE_SCHEDULED_RANGE, ViewsScheduledScheduledRangeClass))
#define VIEWS_SCHEDULED_IS_SCHEDULED_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED_RANGE))
#define VIEWS_SCHEDULED_IS_SCHEDULED_RANGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VIEWS_SCHEDULED_TYPE_SCHEDULED_RANGE))
#define VIEWS_SCHEDULED_SCHEDULED_RANGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED_RANGE, ViewsScheduledScheduledRangeClass))

typedef struct _ViewsScheduledScheduledRange ViewsScheduledScheduledRange;
typedef struct _ViewsScheduledScheduledRangeClass ViewsScheduledScheduledRangeClass;

#define VIEWS_SCHEDULED_TYPE_SCHEDULED_MONTH (views_scheduled_scheduled_month_get_type ())
#define VIEWS_SCHEDULED_SCHEDULED_MONTH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED_MONTH, ViewsScheduledScheduledMonth))
#define VIEWS_SCHEDULED_SCHEDULED_MONTH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VIEWS_SCHEDULED_TYPE_SCHEDULED_MONTH, ViewsScheduledScheduledMonthClass))
#define VIEWS_SCHEDULED_IS_SCHEDULED_MONTH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED_MONTH))
#define VIEWS_SCHEDULED_IS_SCHEDULED_MONTH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VIEWS_SCHEDULED_TYPE_SCHEDULED_MONTH))
#define VIEWS_SCHEDULED_SCHEDULED_MONTH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VIEWS_SCHEDULED_TYPE_SCHEDULED_MONTH, ViewsScheduledScheduledMonthClass))

typedef struct _ViewsScheduledScheduledMonth ViewsScheduledScheduledMonth;
typedef struct _ViewsScheduledScheduledMonthClass ViewsScheduledScheduledMonthClass;

#define DIALOGS_TYPE_QUICK_ADD (dialogs_quick_add_get_type ())
#define DIALOGS_QUICK_ADD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_TYPE_QUICK_ADD, DialogsQuickAdd))
#define DIALOGS_QUICK_ADD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_TYPE_QUICK_ADD, DialogsQuickAddClass))
#define DIALOGS_IS_QUICK_ADD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_TYPE_QUICK_ADD))
#define DIALOGS_IS_QUICK_ADD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_TYPE_QUICK_ADD))
#define DIALOGS_QUICK_ADD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_TYPE_QUICK_ADD, DialogsQuickAddClass))

typedef struct _DialogsQuickAdd DialogsQuickAdd;
typedef struct _DialogsQuickAddClass DialogsQuickAddClass;

#define TYPE_PLANIFY (planify_get_type ())
#define PLANIFY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PLANIFY, Planify))
#define PLANIFY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PLANIFY, PlanifyClass))
#define IS_PLANIFY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PLANIFY))
#define IS_PLANIFY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PLANIFY))
#define PLANIFY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PLANIFY, PlanifyClass))

typedef struct _Planify Planify;
typedef struct _PlanifyClass PlanifyClass;
typedef struct _PlanifyPrivate PlanifyPrivate;

#define TYPE_MAIN_WINDOW (main_window_get_type ())
#define MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MAIN_WINDOW, MainWindow))
#define MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MAIN_WINDOW, MainWindowClass))
#define IS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MAIN_WINDOW))
#define IS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MAIN_WINDOW))
#define MAIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MAIN_WINDOW, MainWindowClass))

typedef struct _MainWindow MainWindow;
typedef struct _MainWindowClass MainWindowClass;
typedef struct _Block78Data Block78Data;
#define _g_free0(var) (var = (g_free (var), NULL))

#define DIALOGS_TYPE_LABEL_PICKER (dialogs_label_picker_get_type ())
#define DIALOGS_LABEL_PICKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_TYPE_LABEL_PICKER, DialogsLabelPicker))
#define DIALOGS_LABEL_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_TYPE_LABEL_PICKER, DialogsLabelPickerClass))
#define DIALOGS_IS_LABEL_PICKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_TYPE_LABEL_PICKER))
#define DIALOGS_IS_LABEL_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_TYPE_LABEL_PICKER))
#define DIALOGS_LABEL_PICKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_TYPE_LABEL_PICKER, DialogsLabelPickerClass))

typedef struct _DialogsLabelPicker DialogsLabelPicker;
typedef struct _DialogsLabelPickerClass DialogsLabelPickerClass;

#define LAYOUTS_TYPE_HEADER_BAR (layouts_header_bar_get_type ())
#define LAYOUTS_HEADER_BAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LAYOUTS_TYPE_HEADER_BAR, LayoutsHeaderBar))
#define LAYOUTS_HEADER_BAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LAYOUTS_TYPE_HEADER_BAR, LayoutsHeaderBarClass))
#define LAYOUTS_IS_HEADER_BAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LAYOUTS_TYPE_HEADER_BAR))
#define LAYOUTS_IS_HEADER_BAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LAYOUTS_TYPE_HEADER_BAR))
#define LAYOUTS_HEADER_BAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LAYOUTS_TYPE_HEADER_BAR, LayoutsHeaderBarClass))

typedef struct _LayoutsHeaderBar LayoutsHeaderBar;
typedef struct _LayoutsHeaderBarClass LayoutsHeaderBarClass;

#define WIDGETS_TYPE_FILTER_FLOW_BOX (widgets_filter_flow_box_get_type ())
#define WIDGETS_FILTER_FLOW_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_FILTER_FLOW_BOX, WidgetsFilterFlowBox))
#define WIDGETS_FILTER_FLOW_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_FILTER_FLOW_BOX, WidgetsFilterFlowBoxClass))
#define WIDGETS_IS_FILTER_FLOW_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_FILTER_FLOW_BOX))
#define WIDGETS_IS_FILTER_FLOW_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_FILTER_FLOW_BOX))
#define WIDGETS_FILTER_FLOW_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_FILTER_FLOW_BOX, WidgetsFilterFlowBoxClass))

typedef struct _WidgetsFilterFlowBox WidgetsFilterFlowBox;
typedef struct _WidgetsFilterFlowBoxClass WidgetsFilterFlowBoxClass;
typedef struct _Block79Data Block79Data;
typedef struct _WidgetsFilterFlowBoxPrivate WidgetsFilterFlowBoxPrivate;

#define WIDGETS_TYPE_MAGIC_BUTTON (widgets_magic_button_get_type ())
#define WIDGETS_MAGIC_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_MAGIC_BUTTON, WidgetsMagicButton))
#define WIDGETS_MAGIC_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_MAGIC_BUTTON, WidgetsMagicButtonClass))
#define WIDGETS_IS_MAGIC_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_MAGIC_BUTTON))
#define WIDGETS_IS_MAGIC_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_MAGIC_BUTTON))
#define WIDGETS_MAGIC_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_MAGIC_BUTTON, WidgetsMagicButtonClass))

typedef struct _WidgetsMagicButton WidgetsMagicButton;
typedef struct _WidgetsMagicButtonClass WidgetsMagicButtonClass;

struct _ViewsScheduledScheduled {
	AdwBin parent_instance;
	ViewsScheduledScheduledPrivate * priv;
	GeeHashMap* items;
};

struct _ViewsScheduledScheduledClass {
	AdwBinClass parent_class;
};

struct _ViewsScheduledScheduledPrivate {
	GtkRevealer* indicator_revealer;
	WidgetsContextMenuMenuCheckPicker* priority_filter;
	GtkListBox* listbox;
	GtkScrolledWindow* scrolled_window;
	GeeHashMap* signal_map;
};

struct _Planify {
	AdwApplication parent_instance;
	PlanifyPrivate * priv;
	MainWindow* main_window;
};

struct _PlanifyClass {
	AdwApplicationClass parent_class;
};

struct _Block78Data {
	int _ref_count_;
	ViewsScheduledScheduled* self;
	WidgetsContextMenuMenuPicker* sorted_by_item;
};

struct _Block79Data {
	int _ref_count_;
	ViewsScheduledScheduled* self;
	LayoutsHeaderBar* headerbar;
	GtkImage* title_icon;
	GtkBox* title_box;
	WidgetsFilterFlowBox* filters;
};

struct _WidgetsFilterFlowBox {
	AdwBin parent_instance;
	WidgetsFilterFlowBoxPrivate * priv;
	GtkFlowBox* flowbox;
};

struct _WidgetsFilterFlowBoxClass {
	AdwBinClass parent_class;
};

static gint ViewsScheduledScheduled_private_offset;
static gpointer views_scheduled_scheduled_parent_class = NULL;
VALA_EXTERN Planify* planify__instance;

VALA_EXTERN GType views_scheduled_scheduled_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ViewsScheduledScheduled, g_object_unref)
VALA_EXTERN GType layouts_item_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LayoutsItemBase, g_object_unref)
VALA_EXTERN GType layouts_item_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LayoutsItemRow, g_object_unref)
static void views_scheduled_scheduled_add_days (ViewsScheduledScheduled* self);
VALA_EXTERN ViewsScheduledScheduledOverdue* views_scheduled_scheduled_overdue_new (void);
VALA_EXTERN ViewsScheduledScheduledOverdue* views_scheduled_scheduled_overdue_construct (GType object_type);
VALA_EXTERN GType views_scheduled_scheduled_section_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ViewsScheduledScheduledSection, g_object_unref)
VALA_EXTERN GType views_scheduled_scheduled_overdue_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ViewsScheduledScheduledOverdue, g_object_unref)
VALA_EXTERN GType views_scheduled_scheduled_day_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ViewsScheduledScheduledDay, g_object_unref)
VALA_EXTERN ViewsScheduledScheduledDay* views_scheduled_scheduled_day_new (GDateTime* date);
VALA_EXTERN ViewsScheduledScheduledDay* views_scheduled_scheduled_day_construct (GType object_type,
                                                                     GDateTime* date);
VALA_EXTERN ViewsScheduledScheduledRange* views_scheduled_scheduled_range_new (GDateTime* start_date,
                                                                   GDateTime* end_date);
VALA_EXTERN ViewsScheduledScheduledRange* views_scheduled_scheduled_range_construct (GType object_type,
                                                                         GDateTime* start_date,
                                                                         GDateTime* end_date);
VALA_EXTERN GType views_scheduled_scheduled_range_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ViewsScheduledScheduledRange, g_object_unref)
VALA_EXTERN ViewsScheduledScheduledMonth* views_scheduled_scheduled_month_new (GDateTime* date);
VALA_EXTERN ViewsScheduledScheduledMonth* views_scheduled_scheduled_month_construct (GType object_type,
                                                                         GDateTime* date);
VALA_EXTERN GType views_scheduled_scheduled_month_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ViewsScheduledScheduledMonth, g_object_unref)
VALA_EXTERN void views_scheduled_scheduled_prepare_new_item (ViewsScheduledScheduled* self,
                                                 const gchar* content);
VALA_EXTERN GType dialogs_quick_add_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsQuickAdd, g_object_unref)
VALA_EXTERN DialogsQuickAdd* dialogs_quick_add_new (void);
VALA_EXTERN DialogsQuickAdd* dialogs_quick_add_construct (GType object_type);
VALA_EXTERN void dialogs_quick_add_update_content (DialogsQuickAdd* self,
                                       const gchar* content);
VALA_EXTERN void dialogs_quick_add_set_due (DialogsQuickAdd* self,
                                GDateTime* date);
VALA_EXTERN GType planify_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Planify, g_object_unref)
VALA_EXTERN GType main_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MainWindow, g_object_unref)
static GtkPopover* views_scheduled_scheduled_build_view_setting_popover (ViewsScheduledScheduled* self);
static Block78Data* block78_data_ref (Block78Data* _data78_);
static void block78_data_unref (void * _userdata_);
static void __lambda829_ (Block78Data* _data78_);
static void ___lambda829__g_object_notify (GObject* _sender,
                                    GParamSpec* pspec,
                                    gpointer self);
static void __lambda830_ (ViewsScheduledScheduled* self,
                   ObjectsFiltersFilterItem* filter,
                   gboolean active);
static void ___lambda830__widgets_context_menu_menu_check_picker_filter_change (WidgetsContextMenuMenuCheckPicker* _sender,
                                                                         ObjectsFiltersFilterItem* filter,
                                                                         gboolean active,
                                                                         gpointer self);
static void __lambda831_ (ViewsScheduledScheduled* self);
VALA_EXTERN GType dialogs_label_picker_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsLabelPicker, g_object_unref)
VALA_EXTERN DialogsLabelPicker* dialogs_label_picker_new (LabelPickerType picker_type);
VALA_EXTERN DialogsLabelPicker* dialogs_label_picker_construct (GType object_type,
                                                    LabelPickerType picker_type);
VALA_EXTERN void dialogs_label_picker_add_labels_list (DialogsLabelPicker* self,
                                           GeeArrayList* labels_list);
VALA_EXTERN void dialogs_label_picker_set_labels (DialogsLabelPicker* self,
                                      GeeArrayList* value);
static void __lambda832_ (ViewsScheduledScheduled* self,
                   GeeHashMap* labels);
static void ___lambda832__dialogs_label_picker_labels_changed (DialogsLabelPicker* _sender,
                                                        GeeHashMap* labels,
                                                        gpointer self);
static void ___lambda831__widgets_context_menu_menu_item_activate_item (WidgetsContextMenuMenuItem* _sender,
                                                                 gpointer self);
VALA_EXTERN void views_scheduled_scheduled_clean_up (ViewsScheduledScheduled* self);
VALA_EXTERN void views_scheduled_scheduled_section_clean_up (ViewsScheduledScheduledSection* self);
static void _g_object_unref0_ (gpointer var);
static inline void _g_list_free__g_object_unref0_ (GList* self);
VALA_EXTERN ViewsScheduledScheduled* views_scheduled_scheduled_new (void);
VALA_EXTERN ViewsScheduledScheduled* views_scheduled_scheduled_construct (GType object_type);
static GObject * views_scheduled_scheduled_constructor (GType type,
                                                 guint n_construct_properties,
                                                 GObjectConstructParam * construct_properties);
VALA_EXTERN GType layouts_header_bar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LayoutsHeaderBar, g_object_unref)
VALA_EXTERN GType widgets_filter_flow_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsFilterFlowBox, g_object_unref)
static Block79Data* block79_data_ref (Block79Data* _data79_);
static void block79_data_unref (void * _userdata_);
VALA_EXTERN LayoutsHeaderBar* layouts_header_bar_new (void);
VALA_EXTERN LayoutsHeaderBar* layouts_header_bar_construct (GType object_type);
VALA_EXTERN void layouts_header_bar_set_title (LayoutsHeaderBar* self,
                                   const gchar* value);
VALA_EXTERN void layouts_header_bar_pack_end (LayoutsHeaderBar* self,
                                  GtkWidget* widget);
VALA_EXTERN WidgetsFilterFlowBox* widgets_filter_flow_box_new (void);
VALA_EXTERN WidgetsFilterFlowBox* widgets_filter_flow_box_construct (GType object_type);
VALA_EXTERN void widgets_filter_flow_box_set_base_object (WidgetsFilterFlowBox* self,
                                              ObjectsBaseObject* value);
VALA_EXTERN GType widgets_magic_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsMagicButton, g_object_unref)
VALA_EXTERN WidgetsMagicButton* widgets_magic_button_new (void);
VALA_EXTERN WidgetsMagicButton* widgets_magic_button_construct (GType object_type);
static void _views_scheduled_scheduled___lambda833_ (ViewsScheduledScheduled* self);
static void __views_scheduled_scheduled___lambda833__widgets_magic_button_clicked (WidgetsMagicButton* _sender,
                                                                            gpointer self);
static void _views_scheduled_scheduled___lambda834_ (ViewsScheduledScheduled* self);
static void __views_scheduled_scheduled___lambda834__services_event_bus_day_changed (ServicesEventBus* _sender,
                                                                              gpointer self);
static void _views_scheduled_scheduled___lambda835_ (Block79Data* _data79_);
VALA_EXTERN void layouts_header_bar_revealer_title_box (LayoutsHeaderBar* self,
                                            gboolean reveal);
static void __views_scheduled_scheduled___lambda835__gtk_adjustment_value_changed (GtkAdjustment* _sender,
                                                                            gpointer self);
static void _views_scheduled_scheduled___lambda836_ (Block79Data* _data79_);
static void __views_scheduled_scheduled___lambda836__services_event_bus_theme_changed (ServicesEventBus* _sender,
                                                                                gpointer self);
static void _views_scheduled_scheduled___lambda837_ (Block79Data* _data79_,
                                              gboolean active,
                                              const gchar* focused_item_id);
static void __views_scheduled_scheduled___lambda837__services_event_bus_dim_content (ServicesEventBus* _sender,
                                                                              gboolean active,
                                                                              const gchar* focused_item_id,
                                                                              gpointer self);
static void views_scheduled_scheduled_finalize (GObject * obj);
static GType views_scheduled_scheduled_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
views_scheduled_scheduled_get_instance_private (ViewsScheduledScheduled* self)
{
	return G_STRUCT_MEMBER_P (self, ViewsScheduledScheduled_private_offset);
}

static void
views_scheduled_scheduled_add_days (ViewsScheduledScheduled* self)
{
	GtkListBox* _tmp0_;
	ViewsScheduledScheduledOverdue* _tmp1_;
	ViewsScheduledScheduledOverdue* _tmp2_;
	GDateTime* date = NULL;
	GDateTime* _tmp3_;
	gint month_days = 0;
	GDateTime* _tmp4_;
	GDateTime* _tmp5_;
	gint remaining_days = 0;
	GDateTime* _tmp6_;
	GDateTime* _tmp7_;
	GDateTime* _tmp8_;
	gint _tmp9_;
	gint days_to_iterate = 0;
	gboolean _tmp10_ = FALSE;
	ViewsScheduledScheduledDay* row = NULL;
	GDateTime* _tmp11_;
	ViewsScheduledScheduledDay* _tmp12_;
	GtkListBox* _tmp13_;
	ViewsScheduledScheduledDay* _tmp14_;
	GDateTime* _tmp23_;
	GDateTime* _tmp24_;
	GDateTime* _tmp25_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->listbox;
	_tmp1_ = views_scheduled_scheduled_overdue_new ();
	g_object_ref_sink (_tmp1_);
	_tmp2_ = _tmp1_;
	gtk_list_box_append (_tmp0_, (GtkWidget*) _tmp2_);
	_g_object_unref0 (_tmp2_);
	_tmp3_ = g_date_time_new_now_local ();
	date = _tmp3_;
	_tmp4_ = date;
	_tmp5_ = date;
	month_days = utils_datetime_get_days_of_month (g_date_time_get_month (_tmp4_), g_date_time_get_year (_tmp5_));
	_tmp6_ = date;
	_tmp7_ = g_date_time_add_days (_tmp6_, 7);
	_tmp8_ = _tmp7_;
	_tmp9_ = month_days - g_date_time_get_day_of_month (_tmp8_);
	_g_date_time_unref0 (_tmp8_);
	remaining_days = _tmp9_;
	days_to_iterate = 7;
	if (remaining_days >= 1) {
		_tmp10_ = remaining_days <= 3;
	} else {
		_tmp10_ = FALSE;
	}
	if (_tmp10_) {
		days_to_iterate += remaining_days;
	}
	_tmp11_ = date;
	_tmp12_ = views_scheduled_scheduled_day_new (_tmp11_);
	g_object_ref_sink (_tmp12_);
	row = _tmp12_;
	_tmp13_ = self->priv->listbox;
	_tmp14_ = row;
	gtk_list_box_append (_tmp13_, (GtkWidget*) _tmp14_);
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp15_ = FALSE;
			_tmp15_ = TRUE;
			while (TRUE) {
				GDateTime* _tmp17_;
				GDateTime* _tmp18_;
				GDateTime* _tmp19_;
				ViewsScheduledScheduledDay* _tmp20_;
				GtkListBox* _tmp21_;
				ViewsScheduledScheduledDay* _tmp22_;
				if (!_tmp15_) {
					gint _tmp16_;
					_tmp16_ = i;
					i = _tmp16_ + 1;
				}
				_tmp15_ = FALSE;
				if (!(i < days_to_iterate)) {
					break;
				}
				_tmp17_ = date;
				_tmp18_ = g_date_time_add_days (_tmp17_, 1);
				_g_date_time_unref0 (date);
				date = _tmp18_;
				_tmp19_ = date;
				_tmp20_ = views_scheduled_scheduled_day_new (_tmp19_);
				g_object_ref_sink (_tmp20_);
				_g_object_unref0 (row);
				row = _tmp20_;
				_tmp21_ = self->priv->listbox;
				_tmp22_ = row;
				gtk_list_box_append (_tmp21_, (GtkWidget*) _tmp22_);
			}
		}
	}
	_tmp23_ = date;
	_tmp24_ = date;
	month_days = utils_datetime_get_days_of_month (g_date_time_get_month (_tmp23_), g_date_time_get_year (_tmp24_));
	_tmp25_ = date;
	remaining_days = month_days - g_date_time_get_day_of_month (_tmp25_);
	if (remaining_days > 3) {
		GtkListBox* _tmp26_;
		GDateTime* _tmp27_;
		GDateTime* _tmp28_;
		GDateTime* _tmp29_;
		GDateTime* _tmp30_;
		GDateTime* _tmp31_;
		GDateTime* _tmp32_;
		ViewsScheduledScheduledRange* _tmp33_;
		ViewsScheduledScheduledRange* _tmp34_;
		_tmp26_ = self->priv->listbox;
		_tmp27_ = date;
		_tmp28_ = g_date_time_add_days (_tmp27_, 1);
		_tmp29_ = _tmp28_;
		_tmp30_ = date;
		_tmp31_ = g_date_time_add_days (_tmp30_, remaining_days);
		_tmp32_ = _tmp31_;
		_tmp33_ = views_scheduled_scheduled_range_new (_tmp29_, _tmp32_);
		g_object_ref_sink (_tmp33_);
		_tmp34_ = _tmp33_;
		gtk_list_box_append (_tmp26_, (GtkWidget*) _tmp34_);
		_g_object_unref0 (_tmp34_);
		_g_date_time_unref0 (_tmp32_);
		_g_date_time_unref0 (_tmp29_);
	}
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp35_ = FALSE;
			_tmp35_ = TRUE;
			while (TRUE) {
				GDateTime* _tmp37_;
				GDateTime* _tmp38_;
				GDateTime* first_of_month = NULL;
				GDateTime* _tmp39_;
				GDateTime* _tmp40_;
				GDateTime* _tmp41_;
				GtkListBox* _tmp42_;
				GDateTime* _tmp43_;
				ViewsScheduledScheduledMonth* _tmp44_;
				ViewsScheduledScheduledMonth* _tmp45_;
				if (!_tmp35_) {
					gint _tmp36_;
					_tmp36_ = i;
					i = _tmp36_ + 1;
				}
				_tmp35_ = FALSE;
				if (!(i < 4)) {
					break;
				}
				_tmp37_ = date;
				_tmp38_ = g_date_time_add_months (_tmp37_, 1);
				_g_date_time_unref0 (date);
				date = _tmp38_;
				_tmp39_ = date;
				_tmp40_ = date;
				_tmp41_ = g_date_time_new_local (g_date_time_get_year (_tmp39_), g_date_time_get_month (_tmp40_), 1, 0, 0, (gdouble) 0);
				first_of_month = _tmp41_;
				_tmp42_ = self->priv->listbox;
				_tmp43_ = first_of_month;
				_tmp44_ = views_scheduled_scheduled_month_new (_tmp43_);
				g_object_ref_sink (_tmp44_);
				_tmp45_ = _tmp44_;
				gtk_list_box_append (_tmp42_, (GtkWidget*) _tmp45_);
				_g_object_unref0 (_tmp45_);
				_g_date_time_unref0 (first_of_month);
			}
		}
	}
	_g_object_unref0 (row);
	_g_date_time_unref0 (date);
}

void
views_scheduled_scheduled_prepare_new_item (ViewsScheduledScheduled* self,
                                            const gchar* content)
{
	DialogsQuickAdd* dialog = NULL;
	DialogsQuickAdd* _tmp0_;
	GDateTime* _tmp1_;
	GDateTime* _tmp2_;
	GDateTime* _tmp3_;
	GDateTime* _tmp4_;
	GDateTime* _tmp5_;
	GDateTime* _tmp6_;
	Planify* _tmp7_;
	MainWindow* _tmp8_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (content != NULL);
	_tmp0_ = dialogs_quick_add_new ();
	g_object_ref_sink (_tmp0_);
	dialog = _tmp0_;
	dialogs_quick_add_update_content (dialog, content);
	_tmp1_ = g_date_time_new_now_local ();
	_tmp2_ = _tmp1_;
	_tmp3_ = g_date_time_add_days (_tmp2_, 1);
	_tmp4_ = _tmp3_;
	_tmp5_ = utils_datetime_get_date_only (_tmp4_);
	_tmp6_ = _tmp5_;
	dialogs_quick_add_set_due (dialog, _tmp6_);
	_g_date_time_unref0 (_tmp6_);
	_g_date_time_unref0 (_tmp4_);
	_g_date_time_unref0 (_tmp2_);
	_tmp7_ = planify__instance;
	_tmp8_ = _tmp7_->main_window;
	adw_dialog_present ((AdwDialog*) dialog, (GtkWidget*) _tmp8_);
	_g_object_unref0 (dialog);
}

static Block78Data*
block78_data_ref (Block78Data* _data78_)
{
	g_atomic_int_inc (&_data78_->_ref_count_);
	return _data78_;
}

static void
block78_data_unref (void * _userdata_)
{
	Block78Data* _data78_;
	_data78_ = (Block78Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data78_->_ref_count_)) {
		ViewsScheduledScheduled* self;
		self = _data78_->self;
		_g_object_unref0 (_data78_->sorted_by_item);
		_g_object_unref0 (self);
		g_slice_free (Block78Data, _data78_);
	}
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
__lambda829_ (Block78Data* _data78_)
{
	ViewsScheduledScheduled* self;
	ServicesSettings* _tmp0_;
	ServicesSettings* _tmp1_;
	GSettings* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	self = _data78_->self;
	_tmp0_ = services_settings_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_->settings;
	_tmp3_ = widgets_context_menu_menu_picker_get_selected (_data78_->sorted_by_item);
	_tmp4_ = _tmp3_;
	g_settings_set_string (_tmp2_, "scheduled-sort-order", _tmp4_);
	_g_object_unref0 (_tmp1_);
}

static void
___lambda829__g_object_notify (GObject* _sender,
                               GParamSpec* pspec,
                               gpointer self)
{
	__lambda829_ (self);
}

static void
__lambda830_ (ViewsScheduledScheduled* self,
              ObjectsFiltersFilterItem* filter,
              gboolean active)
{
	g_return_if_fail (filter != NULL);
	if (active) {
		ObjectsFiltersScheduled* _tmp0_;
		ObjectsFiltersScheduled* _tmp1_;
		_tmp0_ = objects_filters_scheduled_get_default ();
		_tmp1_ = _tmp0_;
		objects_base_object_add_filter ((ObjectsBaseObject*) _tmp1_, filter);
		_g_object_unref0 (_tmp1_);
	} else {
		ObjectsFiltersScheduled* _tmp2_;
		ObjectsFiltersScheduled* _tmp3_;
		_tmp2_ = objects_filters_scheduled_get_default ();
		_tmp3_ = _tmp2_;
		objects_base_object_remove_filter ((ObjectsBaseObject*) _tmp3_, filter);
		_g_object_unref0 (_tmp3_);
	}
}

static void
___lambda830__widgets_context_menu_menu_check_picker_filter_change (WidgetsContextMenuMenuCheckPicker* _sender,
                                                                    ObjectsFiltersFilterItem* filter,
                                                                    gboolean active,
                                                                    gpointer self)
{
	__lambda830_ ((ViewsScheduledScheduled*) self, filter, active);
}

static void
__lambda832_ (ViewsScheduledScheduled* self,
              GeeHashMap* labels)
{
	GeeArrayList* to_remove = NULL;
	GeeArrayList* _tmp21_;
	g_return_if_fail (labels != NULL);
	{
		GeeIterator* _label_it = NULL;
		GeeCollection* _tmp0_;
		GeeCollection* _tmp1_;
		GeeCollection* _tmp2_;
		GeeIterator* _tmp3_;
		GeeIterator* _tmp4_;
		_tmp0_ = gee_abstract_map_get_values ((GeeAbstractMap*) labels);
		_tmp1_ = _tmp0_;
		_tmp2_ = _tmp1_;
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
		_tmp4_ = _tmp3_;
		_g_object_unref0 (_tmp2_);
		_label_it = _tmp4_;
		while (TRUE) {
			GeeIterator* _tmp5_;
			ObjectsLabel* label = NULL;
			GeeIterator* _tmp6_;
			gpointer _tmp7_;
			ObjectsFiltersFilterItem* filter = NULL;
			ObjectsFiltersFilterItem* _tmp8_;
			ObjectsFiltersFilterItem* _tmp9_;
			ObjectsFiltersFilterItem* _tmp10_;
			ObjectsLabel* _tmp11_;
			const gchar* _tmp12_;
			const gchar* _tmp13_;
			ObjectsFiltersFilterItem* _tmp14_;
			ObjectsLabel* _tmp15_;
			const gchar* _tmp16_;
			const gchar* _tmp17_;
			ObjectsFiltersScheduled* _tmp18_;
			ObjectsFiltersScheduled* _tmp19_;
			ObjectsFiltersFilterItem* _tmp20_;
			_tmp5_ = _label_it;
			if (!gee_iterator_next (_tmp5_)) {
				break;
			}
			_tmp6_ = _label_it;
			_tmp7_ = gee_iterator_get (_tmp6_);
			label = (ObjectsLabel*) _tmp7_;
			_tmp8_ = objects_filters_filter_item_new ();
			filter = _tmp8_;
			_tmp9_ = filter;
			objects_filters_filter_item_set_filter_type (_tmp9_, FILTER_ITEM_TYPE_LABEL);
			_tmp10_ = filter;
			_tmp11_ = label;
			_tmp12_ = objects_base_object_get_name ((ObjectsBaseObject*) _tmp11_);
			_tmp13_ = _tmp12_;
			objects_filters_filter_item_set_name (_tmp10_, _tmp13_);
			_tmp14_ = filter;
			_tmp15_ = label;
			_tmp16_ = objects_base_object_get_id ((ObjectsBaseObject*) _tmp15_);
			_tmp17_ = _tmp16_;
			objects_filters_filter_item_set_value (_tmp14_, _tmp17_);
			_tmp18_ = objects_filters_scheduled_get_default ();
			_tmp19_ = _tmp18_;
			_tmp20_ = filter;
			objects_base_object_add_filter ((ObjectsBaseObject*) _tmp19_, _tmp20_);
			_g_object_unref0 (_tmp19_);
			_g_object_unref0 (filter);
			_g_object_unref0 (label);
		}
		_g_object_unref0 (_label_it);
	}
	_tmp21_ = gee_array_list_new (OBJECTS_FILTERS_TYPE_FILTER_ITEM, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
	to_remove = _tmp21_;
	{
		GeeIterator* _filter_it = NULL;
		ObjectsFiltersScheduled* _tmp22_;
		ObjectsFiltersScheduled* _tmp23_;
		GeeHashMap* _tmp24_;
		GeeCollection* _tmp25_;
		GeeCollection* _tmp26_;
		GeeCollection* _tmp27_;
		GeeIterator* _tmp28_;
		GeeIterator* _tmp29_;
		_tmp22_ = objects_filters_scheduled_get_default ();
		_tmp23_ = _tmp22_;
		_tmp24_ = ((ObjectsBaseObject*) _tmp23_)->filters;
		_tmp25_ = gee_abstract_map_get_values ((GeeAbstractMap*) _tmp24_);
		_tmp26_ = _tmp25_;
		_tmp27_ = _tmp26_;
		_tmp28_ = gee_iterable_iterator ((GeeIterable*) _tmp27_);
		_tmp29_ = _tmp28_;
		_g_object_unref0 (_tmp27_);
		_g_object_unref0 (_tmp23_);
		_filter_it = _tmp29_;
		while (TRUE) {
			GeeIterator* _tmp30_;
			ObjectsFiltersFilterItem* filter = NULL;
			GeeIterator* _tmp31_;
			gpointer _tmp32_;
			ObjectsFiltersFilterItem* _tmp33_;
			FilterItemType _tmp34_;
			FilterItemType _tmp35_;
			_tmp30_ = _filter_it;
			if (!gee_iterator_next (_tmp30_)) {
				break;
			}
			_tmp31_ = _filter_it;
			_tmp32_ = gee_iterator_get (_tmp31_);
			filter = (ObjectsFiltersFilterItem*) _tmp32_;
			_tmp33_ = filter;
			_tmp34_ = objects_filters_filter_item_get_filter_type (_tmp33_);
			_tmp35_ = _tmp34_;
			if (_tmp35_ == FILTER_ITEM_TYPE_LABEL) {
				ObjectsFiltersFilterItem* _tmp36_;
				const gchar* _tmp37_;
				const gchar* _tmp38_;
				_tmp36_ = filter;
				_tmp37_ = objects_filters_filter_item_get_value (_tmp36_);
				_tmp38_ = _tmp37_;
				if (!gee_abstract_map_has_key ((GeeAbstractMap*) labels, _tmp38_)) {
					GeeArrayList* _tmp39_;
					ObjectsFiltersFilterItem* _tmp40_;
					_tmp39_ = to_remove;
					_tmp40_ = filter;
					gee_abstract_collection_add ((GeeAbstractCollection*) _tmp39_, _tmp40_);
				}
			}
			_g_object_unref0 (filter);
		}
		_g_object_unref0 (_filter_it);
	}
	{
		GeeArrayList* _filter_list = NULL;
		GeeArrayList* _tmp41_;
		gint _filter_size = 0;
		GeeArrayList* _tmp42_;
		gint _tmp43_;
		gint _tmp44_;
		gint _filter_index = 0;
		_tmp41_ = to_remove;
		_filter_list = _tmp41_;
		_tmp42_ = _filter_list;
		_tmp43_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp42_);
		_tmp44_ = _tmp43_;
		_filter_size = _tmp44_;
		_filter_index = -1;
		while (TRUE) {
			gint _tmp45_;
			gint _tmp46_;
			ObjectsFiltersFilterItem* filter = NULL;
			GeeArrayList* _tmp47_;
			gpointer _tmp48_;
			ObjectsFiltersScheduled* _tmp49_;
			ObjectsFiltersScheduled* _tmp50_;
			ObjectsFiltersFilterItem* _tmp51_;
			_filter_index = _filter_index + 1;
			_tmp45_ = _filter_index;
			_tmp46_ = _filter_size;
			if (!(_tmp45_ < _tmp46_)) {
				break;
			}
			_tmp47_ = _filter_list;
			_tmp48_ = gee_abstract_list_get ((GeeAbstractList*) _tmp47_, _filter_index);
			filter = (ObjectsFiltersFilterItem*) _tmp48_;
			_tmp49_ = objects_filters_scheduled_get_default ();
			_tmp50_ = _tmp49_;
			_tmp51_ = filter;
			objects_base_object_remove_filter ((ObjectsBaseObject*) _tmp50_, _tmp51_);
			_g_object_unref0 (_tmp50_);
			_g_object_unref0 (filter);
		}
	}
	_g_object_unref0 (to_remove);
}

static void
___lambda832__dialogs_label_picker_labels_changed (DialogsLabelPicker* _sender,
                                                   GeeHashMap* labels,
                                                   gpointer self)
{
	__lambda832_ ((ViewsScheduledScheduled*) self, labels);
}

static void
__lambda831_ (ViewsScheduledScheduled* self)
{
	GeeArrayList* _labels = NULL;
	GeeArrayList* _tmp0_;
	DialogsLabelPicker* dialog = NULL;
	DialogsLabelPicker* _tmp22_;
	ServicesStore* _tmp23_;
	GeeArrayList* _tmp24_;
	GeeArrayList* _tmp25_;
	GeeArrayList* _tmp26_;
	GeeHashMap* _tmp27_;
	gulong _tmp28_;
	DialogsLabelPicker* _tmp29_;
	Planify* _tmp30_;
	MainWindow* _tmp31_;
	_tmp0_ = gee_array_list_new (OBJECTS_TYPE_LABEL, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
	_labels = _tmp0_;
	{
		GeeIterator* _filter_it = NULL;
		ObjectsFiltersScheduled* _tmp1_;
		ObjectsFiltersScheduled* _tmp2_;
		GeeHashMap* _tmp3_;
		GeeCollection* _tmp4_;
		GeeCollection* _tmp5_;
		GeeCollection* _tmp6_;
		GeeIterator* _tmp7_;
		GeeIterator* _tmp8_;
		_tmp1_ = objects_filters_scheduled_get_default ();
		_tmp2_ = _tmp1_;
		_tmp3_ = ((ObjectsBaseObject*) _tmp2_)->filters;
		_tmp4_ = gee_abstract_map_get_values ((GeeAbstractMap*) _tmp3_);
		_tmp5_ = _tmp4_;
		_tmp6_ = _tmp5_;
		_tmp7_ = gee_iterable_iterator ((GeeIterable*) _tmp6_);
		_tmp8_ = _tmp7_;
		_g_object_unref0 (_tmp6_);
		_g_object_unref0 (_tmp2_);
		_filter_it = _tmp8_;
		while (TRUE) {
			GeeIterator* _tmp9_;
			ObjectsFiltersFilterItem* filter = NULL;
			GeeIterator* _tmp10_;
			gpointer _tmp11_;
			ObjectsFiltersFilterItem* _tmp12_;
			FilterItemType _tmp13_;
			FilterItemType _tmp14_;
			_tmp9_ = _filter_it;
			if (!gee_iterator_next (_tmp9_)) {
				break;
			}
			_tmp10_ = _filter_it;
			_tmp11_ = gee_iterator_get (_tmp10_);
			filter = (ObjectsFiltersFilterItem*) _tmp11_;
			_tmp12_ = filter;
			_tmp13_ = objects_filters_filter_item_get_filter_type (_tmp12_);
			_tmp14_ = _tmp13_;
			if (_tmp14_ == FILTER_ITEM_TYPE_LABEL) {
				GeeArrayList* _tmp15_;
				ServicesStore* _tmp16_;
				ObjectsFiltersFilterItem* _tmp17_;
				const gchar* _tmp18_;
				const gchar* _tmp19_;
				ObjectsLabel* _tmp20_;
				ObjectsLabel* _tmp21_;
				_tmp15_ = _labels;
				_tmp16_ = services_store_instance ();
				_tmp17_ = filter;
				_tmp18_ = objects_filters_filter_item_get_value (_tmp17_);
				_tmp19_ = _tmp18_;
				_tmp20_ = services_store_get_label (_tmp16_, _tmp19_);
				_tmp21_ = _tmp20_;
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp15_, _tmp21_);
				_g_object_unref0 (_tmp21_);
			}
			_g_object_unref0 (filter);
		}
		_g_object_unref0 (_filter_it);
	}
	_tmp22_ = dialogs_label_picker_new (LABEL_PICKER_TYPE_FILTER_ONLY);
	g_object_ref_sink (_tmp22_);
	dialog = _tmp22_;
	_tmp23_ = services_store_instance ();
	_tmp24_ = services_store_get_labels (_tmp23_);
	_tmp25_ = _tmp24_;
	dialogs_label_picker_add_labels_list (dialog, _tmp25_);
	_tmp26_ = _labels;
	dialogs_label_picker_set_labels (dialog, _tmp26_);
	_tmp27_ = self->priv->signal_map;
	_tmp28_ = g_signal_connect_object (dialog, "labels-changed", (GCallback) ___lambda832__dialogs_label_picker_labels_changed, self, 0);
	_tmp29_ = dialog;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp27_, (gpointer) ((guintptr) _tmp28_), (GObject*) _tmp29_);
	_tmp30_ = planify__instance;
	_tmp31_ = _tmp30_->main_window;
	adw_dialog_present ((AdwDialog*) dialog, (GtkWidget*) _tmp31_);
	_g_object_unref0 (dialog);
	_g_object_unref0 (_labels);
}

static void
___lambda831__widgets_context_menu_menu_item_activate_item (WidgetsContextMenuMenuItem* _sender,
                                                            gpointer self)
{
	__lambda831_ ((ViewsScheduledScheduled*) self);
}

static GtkPopover*
views_scheduled_scheduled_build_view_setting_popover (ViewsScheduledScheduled* self)
{
	Block78Data* _data78_;
	ServicesSettings* _tmp0_;
	ServicesSettings* _tmp1_;
	GSettings* _tmp2_;
	gchar* _tmp3_;
	WidgetsContextMenuMenuPicker* _tmp4_ = NULL;
	WidgetsContextMenuMenuPicker* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	GeeArrayList* priority_items = NULL;
	GeeArrayList* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	ObjectsFiltersFilterItem* _tmp19_ = NULL;
	ObjectsFiltersFilterItem* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	ObjectsFiltersFilterItem* _tmp23_ = NULL;
	ObjectsFiltersFilterItem* _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	ObjectsFiltersFilterItem* _tmp27_ = NULL;
	ObjectsFiltersFilterItem* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	ObjectsFiltersFilterItem* _tmp31_ = NULL;
	ObjectsFiltersFilterItem* _tmp32_;
	WidgetsContextMenuMenuCheckPicker* _tmp33_;
	WidgetsContextMenuMenuCheckPicker* _tmp34_;
	WidgetsContextMenuMenuItem* labels_filter = NULL;
	WidgetsContextMenuMenuItem* _tmp35_ = NULL;
	GtkBox* menu_box = NULL;
	GtkBox* _tmp36_;
	WidgetsContextMenuMenuSeparator* _tmp37_;
	WidgetsContextMenuMenuSeparator* _tmp38_;
	gchar* _tmp39_;
	gchar* _tmp40_;
	gchar** _tmp41_;
	GtkLabel* _tmp42_ = NULL;
	GtkLabel* _tmp43_;
	WidgetsContextMenuMenuCheckPicker* _tmp44_;
	GtkPopover* popover = NULL;
	GtkWidget* _tmp45_;
	GtkPopover* _tmp46_ = NULL;
	GeeHashMap* _tmp47_;
	gulong _tmp48_;
	GeeHashMap* _tmp49_;
	WidgetsContextMenuMenuCheckPicker* _tmp50_;
	gulong _tmp51_;
	GeeHashMap* _tmp52_;
	GeeHashMap* _tmp53_;
	gulong _tmp54_;
	WidgetsContextMenuMenuItem* _tmp55_;
	GtkPopover* result;
	g_return_val_if_fail (self != NULL, NULL);
	_data78_ = g_slice_new0 (Block78Data);
	_data78_->_ref_count_ = 1;
	_data78_->self = g_object_ref (self);
	_tmp0_ = services_settings_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_->settings;
	_tmp3_ = g_settings_get_string (_tmp2_, "scheduled-sort-order");
	_tmp4_ = widgets_context_menu_menu_picker_new (_ ("Sorting"), "vertical-arrows-long-symbolic");
	widgets_context_menu_menu_picker_set_selected (_tmp4_, _tmp3_);
	_g_free0 (_tmp3_);
	g_object_ref_sink (_tmp4_);
	_tmp5_ = _tmp4_;
	_g_object_unref0 (_tmp1_);
	_data78_->sorted_by_item = _tmp5_;
	_tmp6_ = sorted_by_type_to_string (SORTED_BY_TYPE_NAME);
	_tmp7_ = _tmp6_;
	widgets_context_menu_menu_picker_add_item (_data78_->sorted_by_item, _ ("Alphabetically"), _tmp7_);
	_g_free0 (_tmp7_);
	_tmp8_ = sorted_by_type_to_string (SORTED_BY_TYPE_DUE_DATE);
	_tmp9_ = _tmp8_;
	widgets_context_menu_menu_picker_add_item (_data78_->sorted_by_item, _ ("Due Date"), _tmp9_);
	_g_free0 (_tmp9_);
	_tmp10_ = sorted_by_type_to_string (SORTED_BY_TYPE_ADDED_DATE);
	_tmp11_ = _tmp10_;
	widgets_context_menu_menu_picker_add_item (_data78_->sorted_by_item, _ ("Date Added"), _tmp11_);
	_g_free0 (_tmp11_);
	_tmp12_ = sorted_by_type_to_string (SORTED_BY_TYPE_UPDATED_DATE);
	_tmp13_ = _tmp12_;
	widgets_context_menu_menu_picker_add_item (_data78_->sorted_by_item, _ ("Date Modified"), _tmp13_);
	_g_free0 (_tmp13_);
	_tmp14_ = sorted_by_type_to_string (SORTED_BY_TYPE_PRIORITY);
	_tmp15_ = _tmp14_;
	widgets_context_menu_menu_picker_add_item (_data78_->sorted_by_item, _ ("Priority"), _tmp15_);
	_g_free0 (_tmp15_);
	_tmp16_ = gee_array_list_new (OBJECTS_FILTERS_TYPE_FILTER_ITEM, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
	priority_items = _tmp16_;
	_tmp17_ = g_strdup (_ ("P1"));
	_tmp18_ = g_strdup_printf ("%i", CONSTANTS_PRIORITY_1);
	_tmp19_ = objects_filters_filter_item_new ();
	objects_filters_filter_item_set_filter_type (_tmp19_, FILTER_ITEM_TYPE_PRIORITY);
	objects_filters_filter_item_set_name (_tmp19_, _tmp17_);
	_g_free0 (_tmp17_);
	objects_filters_filter_item_set_value (_tmp19_, _tmp18_);
	_g_free0 (_tmp18_);
	_tmp20_ = _tmp19_;
	gee_abstract_collection_add ((GeeAbstractCollection*) priority_items, _tmp20_);
	_g_object_unref0 (_tmp20_);
	_tmp21_ = g_strdup (_ ("P2"));
	_tmp22_ = g_strdup_printf ("%i", CONSTANTS_PRIORITY_2);
	_tmp23_ = objects_filters_filter_item_new ();
	objects_filters_filter_item_set_filter_type (_tmp23_, FILTER_ITEM_TYPE_PRIORITY);
	objects_filters_filter_item_set_name (_tmp23_, _tmp21_);
	_g_free0 (_tmp21_);
	objects_filters_filter_item_set_value (_tmp23_, _tmp22_);
	_g_free0 (_tmp22_);
	_tmp24_ = _tmp23_;
	gee_abstract_collection_add ((GeeAbstractCollection*) priority_items, _tmp24_);
	_g_object_unref0 (_tmp24_);
	_tmp25_ = g_strdup (_ ("P3"));
	_tmp26_ = g_strdup_printf ("%i", CONSTANTS_PRIORITY_3);
	_tmp27_ = objects_filters_filter_item_new ();
	objects_filters_filter_item_set_filter_type (_tmp27_, FILTER_ITEM_TYPE_PRIORITY);
	objects_filters_filter_item_set_name (_tmp27_, _tmp25_);
	_g_free0 (_tmp25_);
	objects_filters_filter_item_set_value (_tmp27_, _tmp26_);
	_g_free0 (_tmp26_);
	_tmp28_ = _tmp27_;
	gee_abstract_collection_add ((GeeAbstractCollection*) priority_items, _tmp28_);
	_g_object_unref0 (_tmp28_);
	_tmp29_ = g_strdup (_ ("P4"));
	_tmp30_ = g_strdup_printf ("%i", CONSTANTS_PRIORITY_4);
	_tmp31_ = objects_filters_filter_item_new ();
	objects_filters_filter_item_set_filter_type (_tmp31_, FILTER_ITEM_TYPE_PRIORITY);
	objects_filters_filter_item_set_name (_tmp31_, _tmp29_);
	_g_free0 (_tmp29_);
	objects_filters_filter_item_set_value (_tmp31_, _tmp30_);
	_g_free0 (_tmp30_);
	_tmp32_ = _tmp31_;
	gee_abstract_collection_add ((GeeAbstractCollection*) priority_items, _tmp32_);
	_g_object_unref0 (_tmp32_);
	_tmp33_ = widgets_context_menu_menu_check_picker_new (_ ("Priority"), "flag-outline-thick-symbolic");
	g_object_ref_sink (_tmp33_);
	_g_object_unref0 (self->priv->priority_filter);
	self->priv->priority_filter = _tmp33_;
	_tmp34_ = self->priv->priority_filter;
	widgets_context_menu_menu_check_picker_set_items (_tmp34_, priority_items);
	_tmp35_ = widgets_context_menu_menu_item_new (_ ("Filter by Labels"), "tag-outline-symbolic");
	widgets_context_menu_menu_item_set_arrow (_tmp35_, TRUE);
	g_object_ref_sink (_tmp35_);
	labels_filter = _tmp35_;
	_tmp36_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
	g_object_ref_sink (_tmp36_);
	menu_box = _tmp36_;
	gtk_widget_set_margin_bottom ((GtkWidget*) menu_box, 3);
	gtk_widget_set_margin_top ((GtkWidget*) menu_box, 3);
	gtk_box_append (menu_box, (GtkWidget*) _data78_->sorted_by_item);
	_tmp37_ = widgets_context_menu_menu_separator_new ();
	g_object_ref_sink (_tmp37_);
	_tmp38_ = _tmp37_;
	gtk_box_append (menu_box, (GtkWidget*) _tmp38_);
	_g_object_unref0 (_tmp38_);
	_tmp39_ = g_strdup ("caption");
	_tmp40_ = g_strdup ("font-bold");
	_tmp41_ = g_new0 (gchar*, 2 + 1);
	_tmp41_[0] = _tmp39_;
	_tmp41_[1] = _tmp40_;
	_tmp42_ = (GtkLabel*) gtk_label_new (_ ("Filter By"));
	gtk_widget_set_css_classes ((GtkWidget*) _tmp42_, _tmp41_);
	_tmp41_ = (_vala_array_free (_tmp41_, 2, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp42_, 6);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp42_, 6);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp42_, 6);
	gtk_widget_set_halign ((GtkWidget*) _tmp42_, GTK_ALIGN_START);
	g_object_ref_sink (_tmp42_);
	_tmp43_ = _tmp42_;
	gtk_box_append (menu_box, (GtkWidget*) _tmp43_);
	_g_object_unref0 (_tmp43_);
	_tmp44_ = self->priv->priority_filter;
	gtk_box_append (menu_box, (GtkWidget*) _tmp44_);
	gtk_box_append (menu_box, (GtkWidget*) labels_filter);
	_tmp45_ = _g_object_ref0 ((GtkWidget*) menu_box);
	_tmp46_ = (GtkPopover*) gtk_popover_new ();
	gtk_popover_set_has_arrow (_tmp46_, FALSE);
	gtk_popover_set_position (_tmp46_, GTK_POS_BOTTOM);
	gtk_popover_set_child (_tmp46_, _tmp45_);
	_g_object_unref0 (_tmp45_);
	g_object_set ((GtkWidget*) _tmp46_, "width-request", 250, NULL);
	g_object_ref_sink (_tmp46_);
	popover = _tmp46_;
	_tmp47_ = self->priv->signal_map;
	_tmp48_ = g_signal_connect_data ((GObject*) _data78_->sorted_by_item, "notify::selected", (GCallback) ___lambda829__g_object_notify, block78_data_ref (_data78_), (GClosureNotify) block78_data_unref, 0);
	gee_abstract_map_set ((GeeAbstractMap*) _tmp47_, (gpointer) ((guintptr) _tmp48_), (GObject*) _data78_->sorted_by_item);
	_tmp49_ = self->priv->signal_map;
	_tmp50_ = self->priv->priority_filter;
	_tmp51_ = g_signal_connect_object (_tmp50_, "filter-change", (GCallback) ___lambda830__widgets_context_menu_menu_check_picker_filter_change, self, 0);
	_tmp52_ = self->priv->signal_map;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp49_, (gpointer) ((guintptr) _tmp51_), (GObject*) _tmp52_);
	_tmp53_ = self->priv->signal_map;
	_tmp54_ = g_signal_connect_object (labels_filter, "activate-item", (GCallback) ___lambda831__widgets_context_menu_menu_item_activate_item, self, 0);
	_tmp55_ = labels_filter;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp53_, (gpointer) ((guintptr) _tmp54_), (GObject*) _tmp55_);
	result = popover;
	_g_object_unref0 (menu_box);
	_g_object_unref0 (labels_filter);
	_g_object_unref0 (priority_items);
	block78_data_unref (_data78_);
	_data78_ = NULL;
	return result;
}

static void
_g_object_unref0_ (gpointer var)
{
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
}

static inline void
_g_list_free__g_object_unref0_ (GList* self)
{
	g_list_free_full (self, (GDestroyNotify) _g_object_unref0_);
}

void
views_scheduled_scheduled_clean_up (ViewsScheduledScheduled* self)
{
	Util* _tmp0_;
	Util* _tmp1_;
	GtkListBox* _tmp2_;
	GList* _tmp3_;
	GList* _tmp4_;
	GeeHashMap* _tmp23_;
	g_return_if_fail (self != NULL);
	_tmp0_ = util_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = self->priv->listbox;
	_tmp3_ = util_get_children (_tmp1_, _tmp2_);
	_tmp4_ = _tmp3_;
	_g_object_unref0 (_tmp1_);
	{
		GList* row_collection = NULL;
		GList* row_it = NULL;
		row_collection = _tmp4_;
		for (row_it = row_collection; row_it != NULL; row_it = row_it->next) {
			GtkListBoxRow* _tmp5_;
			GtkListBoxRow* row = NULL;
			_tmp5_ = _g_object_ref0 ((GtkListBoxRow*) row_it->data);
			row = _tmp5_;
			{
				GtkListBoxRow* _tmp6_;
				_tmp6_ = row;
				if (VIEWS_SCHEDULED_IS_SCHEDULED_SECTION (_tmp6_)) {
					GtkListBoxRow* _tmp7_;
					_tmp7_ = row;
					views_scheduled_scheduled_section_clean_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, VIEWS_SCHEDULED_TYPE_SCHEDULED_SECTION, ViewsScheduledScheduledSection));
				}
				_g_object_unref0 (row);
			}
		}
		(row_collection == NULL) ? NULL : (row_collection = (_g_list_free__g_object_unref0_ (row_collection), NULL));
	}
	{
		GeeIterator* _entry_it = NULL;
		GeeHashMap* _tmp8_;
		GeeSet* _tmp9_;
		GeeSet* _tmp10_;
		GeeSet* _tmp11_;
		GeeIterator* _tmp12_;
		GeeIterator* _tmp13_;
		_tmp8_ = self->priv->signal_map;
		_tmp9_ = gee_abstract_map_get_entries ((GeeAbstractMap*) _tmp8_);
		_tmp10_ = _tmp9_;
		_tmp11_ = _tmp10_;
		_tmp12_ = gee_iterable_iterator ((GeeIterable*) _tmp11_);
		_tmp13_ = _tmp12_;
		_g_object_unref0 (_tmp11_);
		_entry_it = _tmp13_;
		while (TRUE) {
			GeeIterator* _tmp14_;
			GeeMapEntry* entry = NULL;
			GeeIterator* _tmp15_;
			gpointer _tmp16_;
			GeeMapEntry* _tmp17_;
			gconstpointer _tmp18_;
			gconstpointer _tmp19_;
			GeeMapEntry* _tmp20_;
			gconstpointer _tmp21_;
			gconstpointer _tmp22_;
			_tmp14_ = _entry_it;
			if (!gee_iterator_next (_tmp14_)) {
				break;
			}
			_tmp15_ = _entry_it;
			_tmp16_ = gee_iterator_get (_tmp15_);
			entry = (GeeMapEntry*) _tmp16_;
			_tmp17_ = entry;
			_tmp18_ = gee_map_entry_get_value (_tmp17_);
			_tmp19_ = _tmp18_;
			_tmp20_ = entry;
			_tmp21_ = gee_map_entry_get_key (_tmp20_);
			_tmp22_ = _tmp21_;
			g_signal_handler_disconnect ((GObject*) _tmp19_, (gulong) ((guintptr) _tmp22_));
			_g_object_unref0 (entry);
		}
		_g_object_unref0 (_entry_it);
	}
	_tmp23_ = self->priv->signal_map;
	gee_abstract_map_clear ((GeeAbstractMap*) _tmp23_);
}

ViewsScheduledScheduled*
views_scheduled_scheduled_construct (GType object_type)
{
	ViewsScheduledScheduled * self = NULL;
	self = (ViewsScheduledScheduled*) g_object_new (object_type, NULL);
	return self;
}

ViewsScheduledScheduled*
views_scheduled_scheduled_new (void)
{
	return views_scheduled_scheduled_construct (VIEWS_SCHEDULED_TYPE_SCHEDULED);
}

static Block79Data*
block79_data_ref (Block79Data* _data79_)
{
	g_atomic_int_inc (&_data79_->_ref_count_);
	return _data79_;
}

static void
block79_data_unref (void * _userdata_)
{
	Block79Data* _data79_;
	_data79_ = (Block79Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data79_->_ref_count_)) {
		ViewsScheduledScheduled* self;
		self = _data79_->self;
		_g_object_unref0 (_data79_->filters);
		_g_object_unref0 (_data79_->title_box);
		_g_object_unref0 (_data79_->title_icon);
		_g_object_unref0 (_data79_->headerbar);
		_g_object_unref0 (self);
		g_slice_free (Block79Data, _data79_);
	}
}

static void
_views_scheduled_scheduled___lambda833_ (ViewsScheduledScheduled* self)
{
	views_scheduled_scheduled_prepare_new_item (self, "");
}

static void
__views_scheduled_scheduled___lambda833__widgets_magic_button_clicked (WidgetsMagicButton* _sender,
                                                                       gpointer self)
{
	_views_scheduled_scheduled___lambda833_ ((ViewsScheduledScheduled*) self);
}

static void
_views_scheduled_scheduled___lambda834_ (ViewsScheduledScheduled* self)
{
	Util* _tmp0_;
	Util* _tmp1_;
	GtkListBox* _tmp2_;
	GList* _tmp3_;
	GList* _tmp4_;
	_tmp0_ = util_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = self->priv->listbox;
	_tmp3_ = util_get_children (_tmp1_, _tmp2_);
	_tmp4_ = _tmp3_;
	_g_object_unref0 (_tmp1_);
	{
		GList* row_collection = NULL;
		GList* row_it = NULL;
		row_collection = _tmp4_;
		for (row_it = row_collection; row_it != NULL; row_it = row_it->next) {
			GtkListBoxRow* _tmp5_;
			GtkListBoxRow* row = NULL;
			_tmp5_ = _g_object_ref0 ((GtkListBoxRow*) row_it->data);
			row = _tmp5_;
			{
				GtkListBoxRow* _tmp6_;
				GtkListBox* _tmp8_;
				GtkListBoxRow* _tmp9_;
				_tmp6_ = row;
				if (VIEWS_SCHEDULED_IS_SCHEDULED_SECTION (_tmp6_)) {
					GtkListBoxRow* _tmp7_;
					_tmp7_ = row;
					views_scheduled_scheduled_section_clean_up (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, VIEWS_SCHEDULED_TYPE_SCHEDULED_SECTION, ViewsScheduledScheduledSection));
				}
				_tmp8_ = self->priv->listbox;
				_tmp9_ = row;
				gtk_list_box_remove (_tmp8_, (GtkWidget*) _tmp9_);
				_g_object_unref0 (row);
			}
		}
		(row_collection == NULL) ? NULL : (row_collection = (_g_list_free__g_object_unref0_ (row_collection), NULL));
	}
	views_scheduled_scheduled_add_days (self);
}

static void
__views_scheduled_scheduled___lambda834__services_event_bus_day_changed (ServicesEventBus* _sender,
                                                                         gpointer self)
{
	_views_scheduled_scheduled___lambda834_ ((ViewsScheduledScheduled*) self);
}

static void
_views_scheduled_scheduled___lambda835_ (Block79Data* _data79_)
{
	ViewsScheduledScheduled* self;
	LayoutsHeaderBar* _tmp0_;
	GtkScrolledWindow* _tmp1_;
	GtkAdjustment* _tmp2_;
	GtkAdjustment* _tmp3_;
	gdouble _tmp4_;
	gdouble _tmp5_;
	self = _data79_->self;
	_tmp0_ = _data79_->headerbar;
	_tmp1_ = self->priv->scrolled_window;
	_tmp2_ = gtk_scrolled_window_get_vadjustment (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = gtk_adjustment_get_value (_tmp3_);
	_tmp5_ = _tmp4_;
	layouts_header_bar_revealer_title_box (_tmp0_, _tmp5_ >= ((gdouble) CONSTANTS_HEADERBAR_TITLE_SCROLL_THRESHOLD));
}

static void
__views_scheduled_scheduled___lambda835__gtk_adjustment_value_changed (GtkAdjustment* _sender,
                                                                       gpointer self)
{
	_views_scheduled_scheduled___lambda835_ (self);
}

static void
_views_scheduled_scheduled___lambda836_ (Block79Data* _data79_)
{
	ViewsScheduledScheduled* self;
	Util* _tmp0_;
	Util* _tmp1_;
	ObjectsFiltersScheduled* _tmp2_;
	ObjectsFiltersScheduled* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	GtkImage* _tmp6_;
	self = _data79_->self;
	_tmp0_ = util_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = objects_filters_scheduled_get_default ();
	_tmp3_ = _tmp2_;
	_tmp4_ = objects_base_object_theme_color ((ObjectsBaseObject*) _tmp3_);
	_tmp5_ = _tmp4_;
	_tmp6_ = _data79_->title_icon;
	util_set_widget_color (_tmp1_, _tmp5_, (GtkWidget*) _tmp6_);
	_g_free0 (_tmp5_);
	_g_object_unref0 (_tmp3_);
	_g_object_unref0 (_tmp1_);
}

static void
__views_scheduled_scheduled___lambda836__services_event_bus_theme_changed (ServicesEventBus* _sender,
                                                                           gpointer self)
{
	_views_scheduled_scheduled___lambda836_ (self);
}

static void
_views_scheduled_scheduled___lambda837_ (Block79Data* _data79_,
                                         gboolean active,
                                         const gchar* focused_item_id)
{
	ViewsScheduledScheduled* self;
	GtkBox* _tmp0_;
	WidgetsFilterFlowBox* _tmp1_;
	self = _data79_->self;
	g_return_if_fail (focused_item_id != NULL);
	_tmp0_ = _data79_->title_box;
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, !active);
	_tmp1_ = _data79_->filters;
	gtk_widget_set_sensitive ((GtkWidget*) _tmp1_, !active);
}

static void
__views_scheduled_scheduled___lambda837__services_event_bus_dim_content (ServicesEventBus* _sender,
                                                                         gboolean active,
                                                                         const gchar* focused_item_id,
                                                                         gpointer self)
{
	_views_scheduled_scheduled___lambda837_ (self, active, focused_item_id);
}

static GObject *
views_scheduled_scheduled_constructor (GType type,
                                       guint n_construct_properties,
                                       GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	ViewsScheduledScheduled * self;
	Block79Data* _data79_;
	GeeHashMap* _tmp0_;
	GtkGrid* indicator_grid = NULL;
	gchar* _tmp1_;
	gchar** _tmp2_;
	GtkGrid* _tmp3_ = NULL;
	GtkGrid* _tmp4_;
	GtkWidget* _tmp5_;
	GtkRevealer* _tmp6_ = NULL;
	GtkMenuButton* view_setting_button = NULL;
	GtkPopover* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar** _tmp10_;
	gchar* _tmp11_;
	GtkMenuButton* _tmp12_ = NULL;
	GtkOverlay* view_setting_overlay = NULL;
	GtkOverlay* _tmp13_;
	GtkOverlay* _tmp14_;
	GtkMenuButton* _tmp15_;
	GtkOverlay* _tmp16_;
	GtkRevealer* _tmp17_;
	ObjectsFiltersScheduled* _tmp18_;
	ObjectsFiltersScheduled* _tmp19_;
	const gchar* _tmp20_;
	const gchar* _tmp21_;
	gchar* _tmp22_;
	LayoutsHeaderBar* _tmp23_ = NULL;
	LayoutsHeaderBar* _tmp24_;
	LayoutsHeaderBar* _tmp25_;
	GtkOverlay* _tmp26_;
	GtkListBox* _tmp27_ = NULL;
	GtkListBox* _tmp28_;
	AdwBin* listbox_content = NULL;
	GtkListBox* _tmp29_;
	GtkWidget* _tmp30_;
	AdwBin* _tmp31_ = NULL;
	ObjectsFiltersScheduled* _tmp32_;
	ObjectsFiltersScheduled* _tmp33_;
	const gchar* _tmp34_;
	const gchar* _tmp35_;
	gchar* _tmp36_;
	gchar** _tmp37_;
	GtkImage* _tmp38_ = NULL;
	GtkImage* _tmp39_;
	Util* _tmp40_;
	Util* _tmp41_;
	ObjectsFiltersScheduled* _tmp42_;
	ObjectsFiltersScheduled* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	GtkImage* _tmp46_;
	GtkLabel* title_label = NULL;
	ObjectsFiltersScheduled* _tmp47_;
	ObjectsFiltersScheduled* _tmp48_;
	const gchar* _tmp49_;
	const gchar* _tmp50_;
	gchar* _tmp51_;
	gchar* _tmp52_;
	gchar** _tmp53_;
	GtkLabel* _tmp54_ = NULL;
	GtkLabel* _tmp55_;
	GtkBox* _tmp56_ = NULL;
	GtkBox* _tmp57_;
	GtkImage* _tmp58_;
	GtkBox* _tmp59_;
	GtkLabel* _tmp60_;
	ObjectsFiltersScheduled* _tmp61_;
	WidgetsFilterFlowBox* _tmp62_ = NULL;
	WidgetsFilterFlowBox* _tmp63_;
	GtkFlowBox* _tmp64_;
	WidgetsFilterFlowBox* _tmp65_;
	GtkFlowBox* _tmp66_;
	WidgetsFilterFlowBox* _tmp67_;
	GtkFlowBox* _tmp68_;
	WidgetsFilterFlowBox* _tmp69_;
	GtkFlowBox* _tmp70_;
	GtkBox* content = NULL;
	GtkBox* _tmp71_ = NULL;
	GtkBox* _tmp72_;
	GtkBox* _tmp73_;
	GtkBox* _tmp74_;
	WidgetsFilterFlowBox* _tmp75_;
	GtkBox* _tmp76_;
	AdwBin* _tmp77_;
	AdwClamp* content_clamp = NULL;
	GtkBox* _tmp78_;
	GtkWidget* _tmp79_;
	AdwClamp* _tmp80_ = NULL;
	GtkScrolledWindow* _tmp81_ = NULL;
	GtkScrolledWindow* _tmp82_;
	AdwClamp* _tmp83_;
	WidgetsMagicButton* magic_button = NULL;
	WidgetsMagicButton* _tmp84_;
	GtkOverlay* content_overlay = NULL;
	GtkScrolledWindow* _tmp85_;
	GtkWidget* _tmp86_;
	GtkOverlay* _tmp87_ = NULL;
	GtkOverlay* _tmp88_;
	WidgetsMagicButton* _tmp89_;
	AdwToolbarView* toolbar_view = NULL;
	GtkOverlay* _tmp90_;
	GtkWidget* _tmp91_;
	AdwToolbarView* _tmp92_ = NULL;
	AdwToolbarView* _tmp93_;
	LayoutsHeaderBar* _tmp94_;
	AdwToolbarView* _tmp95_;
	GeeHashMap* _tmp96_;
	WidgetsMagicButton* _tmp97_;
	gulong _tmp98_;
	WidgetsMagicButton* _tmp99_;
	GeeHashMap* _tmp100_;
	ServicesEventBus* _tmp101_;
	ServicesEventBus* _tmp102_;
	gulong _tmp103_;
	ServicesEventBus* _tmp104_;
	ServicesEventBus* _tmp105_;
	GeeHashMap* _tmp106_;
	GtkScrolledWindow* _tmp107_;
	GtkAdjustment* _tmp108_;
	GtkAdjustment* _tmp109_;
	gulong _tmp110_;
	GtkScrolledWindow* _tmp111_;
	GtkAdjustment* _tmp112_;
	GtkAdjustment* _tmp113_;
	GeeHashMap* _tmp114_;
	ServicesEventBus* _tmp115_;
	ServicesEventBus* _tmp116_;
	gulong _tmp117_;
	ServicesEventBus* _tmp118_;
	ServicesEventBus* _tmp119_;
	GeeHashMap* _tmp120_;
	ServicesEventBus* _tmp121_;
	ServicesEventBus* _tmp122_;
	gulong _tmp123_;
	ServicesEventBus* _tmp124_;
	ServicesEventBus* _tmp125_;
	parent_class = G_OBJECT_CLASS (views_scheduled_scheduled_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, VIEWS_SCHEDULED_TYPE_SCHEDULED, ViewsScheduledScheduled);
	_data79_ = g_slice_new0 (Block79Data);
	_data79_->_ref_count_ = 1;
	_data79_->self = g_object_ref (self);
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, LAYOUTS_TYPE_ITEM_ROW, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
	_g_object_unref0 (self->items);
	self->items = _tmp0_;
	_tmp1_ = g_strdup ("indicator");
	_tmp2_ = g_new0 (gchar*, 1 + 1);
	_tmp2_[0] = _tmp1_;
	_tmp3_ = (GtkGrid*) gtk_grid_new ();
	g_object_set ((GtkWidget*) _tmp3_, "width-request", 9, NULL);
	g_object_set ((GtkWidget*) _tmp3_, "height-request", 9, NULL);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp3_, 6);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp3_, 6);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp3_, _tmp2_);
	_tmp2_ = (_vala_array_free (_tmp2_, 1, (GDestroyNotify) g_free), NULL);
	g_object_ref_sink (_tmp3_);
	indicator_grid = _tmp3_;
	_tmp4_ = indicator_grid;
	_tmp5_ = _g_object_ref0 ((GtkWidget*) _tmp4_);
	_tmp6_ = (GtkRevealer*) gtk_revealer_new ();
	gtk_revealer_set_transition_type (_tmp6_, GTK_REVEALER_TRANSITION_TYPE_CROSSFADE);
	gtk_revealer_set_child (_tmp6_, _tmp5_);
	_g_object_unref0 (_tmp5_);
	gtk_widget_set_halign ((GtkWidget*) _tmp6_, GTK_ALIGN_END);
	gtk_widget_set_valign ((GtkWidget*) _tmp6_, GTK_ALIGN_START);
	gtk_widget_set_sensitive ((GtkWidget*) _tmp6_, FALSE);
	g_object_ref_sink (_tmp6_);
	_g_object_unref0 (self->priv->indicator_revealer);
	self->priv->indicator_revealer = _tmp6_;
	_tmp7_ = views_scheduled_scheduled_build_view_setting_popover (self);
	_tmp8_ = g_strdup ("view-sort-descending-rtl-symbolic");
	_tmp9_ = g_strdup ("flat");
	_tmp10_ = g_new0 (gchar*, 1 + 1);
	_tmp10_[0] = _tmp9_;
	_tmp11_ = g_strdup (_ ("View Option Menu"));
	_tmp12_ = (GtkMenuButton*) gtk_menu_button_new ();
	gtk_widget_set_valign ((GtkWidget*) _tmp12_, GTK_ALIGN_CENTER);
	gtk_widget_set_halign ((GtkWidget*) _tmp12_, GTK_ALIGN_CENTER);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp12_, 12);
	gtk_menu_button_set_popover (_tmp12_, _tmp7_);
	_g_object_unref0 (_tmp7_);
	gtk_menu_button_set_icon_name (_tmp12_, _tmp8_);
	_g_free0 (_tmp8_);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp12_, _tmp10_);
	_tmp10_ = (_vala_array_free (_tmp10_, 1, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp12_, _tmp11_);
	_g_free0 (_tmp11_);
	g_object_ref_sink (_tmp12_);
	view_setting_button = _tmp12_;
	_tmp13_ = (GtkOverlay*) gtk_overlay_new ();
	g_object_ref_sink (_tmp13_);
	view_setting_overlay = _tmp13_;
	_tmp14_ = view_setting_overlay;
	_tmp15_ = view_setting_button;
	gtk_overlay_set_child (_tmp14_, (GtkWidget*) _tmp15_);
	_tmp16_ = view_setting_overlay;
	_tmp17_ = self->priv->indicator_revealer;
	gtk_overlay_add_overlay (_tmp16_, (GtkWidget*) _tmp17_);
	_tmp18_ = objects_filters_scheduled_get_default ();
	_tmp19_ = _tmp18_;
	_tmp20_ = objects_base_object_get_name ((ObjectsBaseObject*) _tmp19_);
	_tmp21_ = _tmp20_;
	_tmp22_ = g_strdup (_tmp21_);
	_tmp23_ = layouts_header_bar_new ();
	layouts_header_bar_set_title (_tmp23_, _tmp22_);
	_g_free0 (_tmp22_);
	g_object_ref_sink (_tmp23_);
	_tmp24_ = _tmp23_;
	_g_object_unref0 (_tmp19_);
	_data79_->headerbar = _tmp24_;
	_tmp25_ = _data79_->headerbar;
	_tmp26_ = view_setting_overlay;
	layouts_header_bar_pack_end (_tmp25_, (GtkWidget*) _tmp26_);
	_tmp27_ = (GtkListBox*) gtk_list_box_new ();
	gtk_widget_set_valign ((GtkWidget*) _tmp27_, GTK_ALIGN_START);
	gtk_list_box_set_activate_on_single_click (_tmp27_, TRUE);
	gtk_list_box_set_selection_mode (_tmp27_, GTK_SELECTION_NONE);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp27_, TRUE);
	g_object_ref_sink (_tmp27_);
	_g_object_unref0 (self->priv->listbox);
	self->priv->listbox = _tmp27_;
	_tmp28_ = self->priv->listbox;
	gtk_widget_add_css_class ((GtkWidget*) _tmp28_, "listbox-background");
	_tmp29_ = self->priv->listbox;
	_tmp30_ = _g_object_ref0 ((GtkWidget*) _tmp29_);
	_tmp31_ = (AdwBin*) adw_bin_new ();
	gtk_widget_set_margin_top ((GtkWidget*) _tmp31_, 12);
	adw_bin_set_child (_tmp31_, _tmp30_);
	_g_object_unref0 (_tmp30_);
	g_object_ref_sink (_tmp31_);
	listbox_content = _tmp31_;
	_tmp32_ = objects_filters_scheduled_get_default ();
	_tmp33_ = _tmp32_;
	_tmp34_ = objects_base_object_get_icon_name ((ObjectsBaseObject*) _tmp33_);
	_tmp35_ = _tmp34_;
	_tmp36_ = g_strdup ("view-icon");
	_tmp37_ = g_new0 (gchar*, 1 + 1);
	_tmp37_[0] = _tmp36_;
	_tmp38_ = (GtkImage*) gtk_image_new_from_icon_name (_tmp35_);
	gtk_image_set_pixel_size (_tmp38_, 16);
	gtk_widget_set_valign ((GtkWidget*) _tmp38_, GTK_ALIGN_CENTER);
	gtk_widget_set_halign ((GtkWidget*) _tmp38_, GTK_ALIGN_CENTER);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp38_, _tmp37_);
	_tmp37_ = (_vala_array_free (_tmp37_, 1, (GDestroyNotify) g_free), NULL);
	g_object_ref_sink (_tmp38_);
	_tmp39_ = _tmp38_;
	_g_object_unref0 (_tmp33_);
	_data79_->title_icon = _tmp39_;
	_tmp40_ = util_get_default ();
	_tmp41_ = _tmp40_;
	_tmp42_ = objects_filters_scheduled_get_default ();
	_tmp43_ = _tmp42_;
	_tmp44_ = objects_base_object_theme_color ((ObjectsBaseObject*) _tmp43_);
	_tmp45_ = _tmp44_;
	_tmp46_ = _data79_->title_icon;
	util_set_widget_color (_tmp41_, _tmp45_, (GtkWidget*) _tmp46_);
	_g_free0 (_tmp45_);
	_g_object_unref0 (_tmp43_);
	_g_object_unref0 (_tmp41_);
	_tmp47_ = objects_filters_scheduled_get_default ();
	_tmp48_ = _tmp47_;
	_tmp49_ = objects_base_object_get_name ((ObjectsBaseObject*) _tmp48_);
	_tmp50_ = _tmp49_;
	_tmp51_ = g_strdup ("font-bold");
	_tmp52_ = g_strdup ("title-2");
	_tmp53_ = g_new0 (gchar*, 2 + 1);
	_tmp53_[0] = _tmp51_;
	_tmp53_[1] = _tmp52_;
	_tmp54_ = (GtkLabel*) gtk_label_new (_tmp50_);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp54_, _tmp53_);
	_tmp53_ = (_vala_array_free (_tmp53_, 2, (GDestroyNotify) g_free), NULL);
	gtk_label_set_ellipsize (_tmp54_, PANGO_ELLIPSIZE_END);
	gtk_widget_set_halign ((GtkWidget*) _tmp54_, GTK_ALIGN_START);
	g_object_ref_sink (_tmp54_);
	_tmp55_ = _tmp54_;
	_g_object_unref0 (_tmp48_);
	title_label = _tmp55_;
	_tmp56_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp56_, 30);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp56_, 6);
	g_object_ref_sink (_tmp56_);
	_data79_->title_box = _tmp56_;
	_tmp57_ = _data79_->title_box;
	_tmp58_ = _data79_->title_icon;
	gtk_box_append (_tmp57_, (GtkWidget*) _tmp58_);
	_tmp59_ = _data79_->title_box;
	_tmp60_ = title_label;
	gtk_box_append (_tmp59_, (GtkWidget*) _tmp60_);
	_tmp61_ = objects_filters_scheduled_get_default ();
	_tmp62_ = widgets_filter_flow_box_new ();
	gtk_widget_set_valign ((GtkWidget*) _tmp62_, GTK_ALIGN_START);
	gtk_widget_set_vexpand ((GtkWidget*) _tmp62_, FALSE);
	gtk_widget_set_vexpand_set ((GtkWidget*) _tmp62_, TRUE);
	widgets_filter_flow_box_set_base_object (_tmp62_, (ObjectsBaseObject*) _tmp61_);
	_g_object_unref0 (_tmp61_);
	g_object_ref_sink (_tmp62_);
	_data79_->filters = _tmp62_;
	_tmp63_ = _data79_->filters;
	_tmp64_ = _tmp63_->flowbox;
	gtk_widget_set_margin_start ((GtkWidget*) _tmp64_, 30);
	_tmp65_ = _data79_->filters;
	_tmp66_ = _tmp65_->flowbox;
	gtk_widget_set_margin_top ((GtkWidget*) _tmp66_, 12);
	_tmp67_ = _data79_->filters;
	_tmp68_ = _tmp67_->flowbox;
	gtk_widget_set_margin_end ((GtkWidget*) _tmp68_, 12);
	_tmp69_ = _data79_->filters;
	_tmp70_ = _tmp69_->flowbox;
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp70_, 3);
	_tmp71_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp71_, TRUE);
	gtk_widget_set_vexpand ((GtkWidget*) _tmp71_, TRUE);
	g_object_ref_sink (_tmp71_);
	content = _tmp71_;
	_tmp72_ = content;
	_tmp73_ = _data79_->title_box;
	gtk_box_append (_tmp72_, (GtkWidget*) _tmp73_);
	_tmp74_ = content;
	_tmp75_ = _data79_->filters;
	gtk_box_append (_tmp74_, (GtkWidget*) _tmp75_);
	_tmp76_ = content;
	_tmp77_ = listbox_content;
	gtk_box_append (_tmp76_, (GtkWidget*) _tmp77_);
	_tmp78_ = content;
	_tmp79_ = _g_object_ref0 ((GtkWidget*) _tmp78_);
	_tmp80_ = (AdwClamp*) adw_clamp_new ();
	adw_clamp_set_maximum_size (_tmp80_, 864);
	adw_clamp_set_tightening_threshold (_tmp80_, 600);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp80_, 64);
	adw_clamp_set_child (_tmp80_, _tmp79_);
	_g_object_unref0 (_tmp79_);
	g_object_ref_sink (_tmp80_);
	content_clamp = _tmp80_;
	_tmp81_ = (GtkScrolledWindow*) gtk_scrolled_window_new ();
	g_object_set (_tmp81_, "hscrollbar-policy", GTK_POLICY_NEVER, NULL);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp81_, TRUE);
	gtk_widget_set_vexpand ((GtkWidget*) _tmp81_, TRUE);
	g_object_ref_sink (_tmp81_);
	_g_object_unref0 (self->priv->scrolled_window);
	self->priv->scrolled_window = _tmp81_;
	_tmp82_ = self->priv->scrolled_window;
	_tmp83_ = content_clamp;
	gtk_scrolled_window_set_child (_tmp82_, (GtkWidget*) _tmp83_);
	_tmp84_ = widgets_magic_button_new ();
	g_object_ref_sink (_tmp84_);
	magic_button = _tmp84_;
	_tmp85_ = self->priv->scrolled_window;
	_tmp86_ = _g_object_ref0 ((GtkWidget*) _tmp85_);
	_tmp87_ = (GtkOverlay*) gtk_overlay_new ();
	gtk_widget_set_hexpand ((GtkWidget*) _tmp87_, TRUE);
	gtk_widget_set_vexpand ((GtkWidget*) _tmp87_, TRUE);
	gtk_overlay_set_child (_tmp87_, _tmp86_);
	_g_object_unref0 (_tmp86_);
	g_object_ref_sink (_tmp87_);
	content_overlay = _tmp87_;
	_tmp88_ = content_overlay;
	_tmp89_ = magic_button;
	gtk_overlay_add_overlay (_tmp88_, (GtkWidget*) _tmp89_);
	_tmp90_ = content_overlay;
	_tmp91_ = _g_object_ref0 ((GtkWidget*) _tmp90_);
	_tmp92_ = (AdwToolbarView*) adw_toolbar_view_new ();
	adw_toolbar_view_set_content (_tmp92_, _tmp91_);
	_g_object_unref0 (_tmp91_);
	g_object_ref_sink (_tmp92_);
	toolbar_view = _tmp92_;
	_tmp93_ = toolbar_view;
	_tmp94_ = _data79_->headerbar;
	adw_toolbar_view_add_top_bar (_tmp93_, (GtkWidget*) _tmp94_);
	_tmp95_ = toolbar_view;
	adw_bin_set_child ((AdwBin*) self, (GtkWidget*) _tmp95_);
	views_scheduled_scheduled_add_days (self);
	_tmp96_ = self->priv->signal_map;
	_tmp97_ = magic_button;
	_tmp98_ = g_signal_connect_object (_tmp97_, "clicked", (GCallback) __views_scheduled_scheduled___lambda833__widgets_magic_button_clicked, self, 0);
	_tmp99_ = magic_button;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp96_, (gpointer) ((guintptr) _tmp98_), (GObject*) _tmp99_);
	_tmp100_ = self->priv->signal_map;
	_tmp101_ = services_event_bus_get_default ();
	_tmp102_ = _tmp101_;
	_tmp103_ = g_signal_connect_object (_tmp102_, "day-changed", (GCallback) __views_scheduled_scheduled___lambda834__services_event_bus_day_changed, self, 0);
	_tmp104_ = services_event_bus_get_default ();
	_tmp105_ = _tmp104_;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp100_, (gpointer) ((guintptr) _tmp103_), (GObject*) _tmp105_);
	_g_object_unref0 (_tmp105_);
	_g_object_unref0 (_tmp102_);
	_tmp106_ = self->priv->signal_map;
	_tmp107_ = self->priv->scrolled_window;
	_tmp108_ = gtk_scrolled_window_get_vadjustment (_tmp107_);
	_tmp109_ = _tmp108_;
	_tmp110_ = g_signal_connect_data (_tmp109_, "value-changed", (GCallback) __views_scheduled_scheduled___lambda835__gtk_adjustment_value_changed, block79_data_ref (_data79_), (GClosureNotify) block79_data_unref, 0);
	_tmp111_ = self->priv->scrolled_window;
	_tmp112_ = gtk_scrolled_window_get_vadjustment (_tmp111_);
	_tmp113_ = _tmp112_;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp106_, (gpointer) ((guintptr) _tmp110_), (GObject*) _tmp113_);
	_tmp114_ = self->priv->signal_map;
	_tmp115_ = services_event_bus_get_default ();
	_tmp116_ = _tmp115_;
	_tmp117_ = g_signal_connect_data (_tmp116_, "theme-changed", (GCallback) __views_scheduled_scheduled___lambda836__services_event_bus_theme_changed, block79_data_ref (_data79_), (GClosureNotify) block79_data_unref, 0);
	_tmp118_ = services_event_bus_get_default ();
	_tmp119_ = _tmp118_;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp114_, (gpointer) ((guintptr) _tmp117_), (GObject*) _tmp119_);
	_g_object_unref0 (_tmp119_);
	_g_object_unref0 (_tmp116_);
	_tmp120_ = self->priv->signal_map;
	_tmp121_ = services_event_bus_get_default ();
	_tmp122_ = _tmp121_;
	_tmp123_ = g_signal_connect_data (_tmp122_, "dim-content", (GCallback) __views_scheduled_scheduled___lambda837__services_event_bus_dim_content, block79_data_ref (_data79_), (GClosureNotify) block79_data_unref, 0);
	_tmp124_ = services_event_bus_get_default ();
	_tmp125_ = _tmp124_;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp120_, (gpointer) ((guintptr) _tmp123_), (GObject*) _tmp125_);
	_g_object_unref0 (_tmp125_);
	_g_object_unref0 (_tmp122_);
	_g_object_unref0 (toolbar_view);
	_g_object_unref0 (content_overlay);
	_g_object_unref0 (magic_button);
	_g_object_unref0 (content_clamp);
	_g_object_unref0 (content);
	_g_object_unref0 (title_label);
	_g_object_unref0 (listbox_content);
	_g_object_unref0 (view_setting_overlay);
	_g_object_unref0 (view_setting_button);
	_g_object_unref0 (indicator_grid);
	block79_data_unref (_data79_);
	_data79_ = NULL;
	return obj;
}

static void
views_scheduled_scheduled_class_init (ViewsScheduledScheduledClass * klass,
                                      gpointer klass_data)
{
	views_scheduled_scheduled_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &ViewsScheduledScheduled_private_offset);
	G_OBJECT_CLASS (klass)->constructor = views_scheduled_scheduled_constructor;
	G_OBJECT_CLASS (klass)->finalize = views_scheduled_scheduled_finalize;
}

static void
views_scheduled_scheduled_instance_init (ViewsScheduledScheduled * self,
                                         gpointer klass)
{
	GeeHashMap* _tmp0_;
	self->priv = views_scheduled_scheduled_get_instance_private (self);
	_tmp0_ = gee_hash_map_new (G_TYPE_ULONG, NULL, NULL, G_TYPE_OBJECT, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
	self->priv->signal_map = _tmp0_;
}

static void
views_scheduled_scheduled_finalize (GObject * obj)
{
	ViewsScheduledScheduled * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, VIEWS_SCHEDULED_TYPE_SCHEDULED, ViewsScheduledScheduled);
	g_debug ("Scheduled.vala:32: Destroying - Views.Scheduled.Scheduled\n");
	_g_object_unref0 (self->priv->indicator_revealer);
	_g_object_unref0 (self->priv->priority_filter);
	_g_object_unref0 (self->priv->listbox);
	_g_object_unref0 (self->priv->scrolled_window);
	_g_object_unref0 (self->items);
	_g_object_unref0 (self->priv->signal_map);
	G_OBJECT_CLASS (views_scheduled_scheduled_parent_class)->finalize (obj);
}

static GType
views_scheduled_scheduled_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ViewsScheduledScheduledClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) views_scheduled_scheduled_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ViewsScheduledScheduled), 0, (GInstanceInitFunc) views_scheduled_scheduled_instance_init, NULL };
	GType views_scheduled_scheduled_type_id;
	views_scheduled_scheduled_type_id = g_type_register_static (adw_bin_get_type (), "ViewsScheduledScheduled", &g_define_type_info, 0);
	ViewsScheduledScheduled_private_offset = g_type_add_instance_private (views_scheduled_scheduled_type_id, sizeof (ViewsScheduledScheduledPrivate));
	return views_scheduled_scheduled_type_id;
}

GType
views_scheduled_scheduled_get_type (void)
{
	static volatile gsize views_scheduled_scheduled_type_id__once = 0;
	if (g_once_init_enter (&views_scheduled_scheduled_type_id__once)) {
		GType views_scheduled_scheduled_type_id;
		views_scheduled_scheduled_type_id = views_scheduled_scheduled_get_type_once ();
		g_once_init_leave (&views_scheduled_scheduled_type_id__once, views_scheduled_scheduled_type_id);
	}
	return views_scheduled_scheduled_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

