/* Donate.c generated by valac 0.56.19, the Vala compiler
 * generated from Donate.vala, do not modify */

/*
 * Copyright © 2023 Alain M. (https://github.com/alainm23/planify)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * Authored by: Alain M. <alainmh23@gmail.com>
 */

#include <adwaita.h>
#include <glib-object.h>
#include <gee.h>
#include <glib.h>
#include <glib/gi18n-lib.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include "planify.h"

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE (dialogs_preferences_pages_base_page_get_type ())
#define DIALOGS_PREFERENCES_PAGES_BASE_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, DialogsPreferencesPagesBasePage))
#define DIALOGS_PREFERENCES_PAGES_BASE_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, DialogsPreferencesPagesBasePageClass))
#define DIALOGS_PREFERENCES_PAGES_IS_BASE_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE))
#define DIALOGS_PREFERENCES_PAGES_IS_BASE_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE))
#define DIALOGS_PREFERENCES_PAGES_BASE_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, DialogsPreferencesPagesBasePageClass))

typedef struct _DialogsPreferencesPagesBasePage DialogsPreferencesPagesBasePage;
typedef struct _DialogsPreferencesPagesBasePageClass DialogsPreferencesPagesBasePageClass;
typedef struct _DialogsPreferencesPagesBasePagePrivate DialogsPreferencesPagesBasePagePrivate;

#define DIALOGS_PREFERENCES_PAGES_TYPE_DONATE (dialogs_preferences_pages_donate_get_type ())
#define DIALOGS_PREFERENCES_PAGES_DONATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_DONATE, DialogsPreferencesPagesDonate))
#define DIALOGS_PREFERENCES_PAGES_DONATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_DONATE, DialogsPreferencesPagesDonateClass))
#define DIALOGS_PREFERENCES_PAGES_IS_DONATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_DONATE))
#define DIALOGS_PREFERENCES_PAGES_IS_DONATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_DONATE))
#define DIALOGS_PREFERENCES_PAGES_DONATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_DONATE, DialogsPreferencesPagesDonateClass))

typedef struct _DialogsPreferencesPagesDonate DialogsPreferencesPagesDonate;
typedef struct _DialogsPreferencesPagesDonateClass DialogsPreferencesPagesDonateClass;
typedef struct _DialogsPreferencesPagesDonatePrivate DialogsPreferencesPagesDonatePrivate;
enum  {
	DIALOGS_PREFERENCES_PAGES_DONATE_0_PROPERTY,
	DIALOGS_PREFERENCES_PAGES_DONATE_NUM_PROPERTIES
};
static GParamSpec* dialogs_preferences_pages_donate_properties[DIALOGS_PREFERENCES_PAGES_DONATE_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

struct _DialogsPreferencesPagesBasePage {
	AdwNavigationPage parent_instance;
	DialogsPreferencesPagesBasePagePrivate * priv;
	GeeHashMap* signal_map;
};

struct _DialogsPreferencesPagesBasePageClass {
	AdwNavigationPageClass parent_class;
	void (*clean_up) (DialogsPreferencesPagesBasePage* self);
};

struct _DialogsPreferencesPagesDonate {
	DialogsPreferencesPagesBasePage parent_instance;
	DialogsPreferencesPagesDonatePrivate * priv;
};

struct _DialogsPreferencesPagesDonateClass {
	DialogsPreferencesPagesBasePageClass parent_class;
};

static gpointer dialogs_preferences_pages_donate_parent_class = NULL;

VALA_EXTERN GType dialogs_preferences_pages_base_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesBasePage, g_object_unref)
VALA_EXTERN GType dialogs_preferences_pages_donate_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesDonate, g_object_unref)
VALA_EXTERN void dialogs_preferences_pages_base_page_clean_up (DialogsPreferencesPagesBasePage* self);
VALA_EXTERN DialogsPreferencesPagesDonate* dialogs_preferences_pages_donate_new (AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN DialogsPreferencesPagesDonate* dialogs_preferences_pages_donate_construct (GType object_type,
                                                                           AdwPreferencesDialog* preferences_dialog);
static void dialogs_preferences_pages_donate_real_clean_up (DialogsPreferencesPagesBasePage* base);
static GObject * dialogs_preferences_pages_donate_constructor (GType type,
                                                        guint n_construct_properties,
                                                        GObjectConstructParam * construct_properties);
static void _dialogs_preferences_pages_donate___lambda424_ (DialogsPreferencesPagesDonate* self);
static void __dialogs_preferences_pages_donate___lambda424__adw_action_row_activated (AdwActionRow* _sender,
                                                                               gpointer self);
static void _dialogs_preferences_pages_donate___lambda425_ (DialogsPreferencesPagesDonate* self);
static void __dialogs_preferences_pages_donate___lambda425__adw_action_row_activated (AdwActionRow* _sender,
                                                                               gpointer self);
static void _dialogs_preferences_pages_donate___lambda426_ (DialogsPreferencesPagesDonate* self);
static void __dialogs_preferences_pages_donate___lambda426__adw_action_row_activated (AdwActionRow* _sender,
                                                                               gpointer self);
static void _dialogs_preferences_pages_donate___lambda427_ (DialogsPreferencesPagesDonate* self);
static void __dialogs_preferences_pages_donate___lambda427__adw_action_row_activated (AdwActionRow* _sender,
                                                                               gpointer self);
static void _dialogs_preferences_pages_donate___lambda428_ (DialogsPreferencesPagesDonate* self);
static void __dialogs_preferences_pages_donate___lambda428__gtk_widget_destroy (GtkWidget* _sender,
                                                                         gpointer self);
static void dialogs_preferences_pages_donate_finalize (GObject * obj);
static GType dialogs_preferences_pages_donate_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

DialogsPreferencesPagesDonate*
dialogs_preferences_pages_donate_construct (GType object_type,
                                            AdwPreferencesDialog* preferences_dialog)
{
	DialogsPreferencesPagesDonate * self = NULL;
	g_return_val_if_fail (preferences_dialog != NULL, NULL);
	self = (DialogsPreferencesPagesDonate*) g_object_new (object_type, "preferences-dialog", preferences_dialog, "title", _ ("Donate"), NULL);
	return self;
}

DialogsPreferencesPagesDonate*
dialogs_preferences_pages_donate_new (AdwPreferencesDialog* preferences_dialog)
{
	return dialogs_preferences_pages_donate_construct (DIALOGS_PREFERENCES_PAGES_TYPE_DONATE, preferences_dialog);
}

static void
dialogs_preferences_pages_donate_real_clean_up (DialogsPreferencesPagesBasePage* base)
{
	DialogsPreferencesPagesDonate * self;
	GeeHashMap* _tmp15_;
	self = (DialogsPreferencesPagesDonate*) base;
	{
		GeeIterator* _entry_it = NULL;
		GeeHashMap* _tmp0_;
		GeeSet* _tmp1_;
		GeeSet* _tmp2_;
		GeeSet* _tmp3_;
		GeeIterator* _tmp4_;
		GeeIterator* _tmp5_;
		_tmp0_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
		_tmp1_ = gee_abstract_map_get_entries ((GeeAbstractMap*) _tmp0_);
		_tmp2_ = _tmp1_;
		_tmp3_ = _tmp2_;
		_tmp4_ = gee_iterable_iterator ((GeeIterable*) _tmp3_);
		_tmp5_ = _tmp4_;
		_g_object_unref0 (_tmp3_);
		_entry_it = _tmp5_;
		while (TRUE) {
			GeeIterator* _tmp6_;
			GeeMapEntry* entry = NULL;
			GeeIterator* _tmp7_;
			gpointer _tmp8_;
			GeeMapEntry* _tmp9_;
			gconstpointer _tmp10_;
			gconstpointer _tmp11_;
			GeeMapEntry* _tmp12_;
			gconstpointer _tmp13_;
			gconstpointer _tmp14_;
			_tmp6_ = _entry_it;
			if (!gee_iterator_next (_tmp6_)) {
				break;
			}
			_tmp7_ = _entry_it;
			_tmp8_ = gee_iterator_get (_tmp7_);
			entry = (GeeMapEntry*) _tmp8_;
			_tmp9_ = entry;
			_tmp10_ = gee_map_entry_get_value (_tmp9_);
			_tmp11_ = _tmp10_;
			_tmp12_ = entry;
			_tmp13_ = gee_map_entry_get_key (_tmp12_);
			_tmp14_ = _tmp13_;
			g_signal_handler_disconnect ((GObject*) _tmp11_, (gulong) ((guintptr) _tmp14_));
			_g_object_unref0 (entry);
		}
		_g_object_unref0 (_entry_it);
	}
	_tmp15_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	gee_abstract_map_clear ((GeeAbstractMap*) _tmp15_);
}

static void
_dialogs_preferences_pages_donate___lambda424_ (DialogsPreferencesPagesDonate* self)
{
	GError* _inner_error0_ = NULL;
	{
		g_app_info_launch_default_for_uri (CONSTANTS_PATREON_URL, NULL, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp0_ = e;
		_tmp1_ = _tmp0_->message;
		g_warning ("Donate.vala:81: %s\n", _tmp1_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
__dialogs_preferences_pages_donate___lambda424__adw_action_row_activated (AdwActionRow* _sender,
                                                                          gpointer self)
{
	_dialogs_preferences_pages_donate___lambda424_ ((DialogsPreferencesPagesDonate*) self);
}

static void
_dialogs_preferences_pages_donate___lambda425_ (DialogsPreferencesPagesDonate* self)
{
	GError* _inner_error0_ = NULL;
	{
		g_app_info_launch_default_for_uri (CONSTANTS_PAYPAL_ME_URL, NULL, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp0_ = e;
		_tmp1_ = _tmp0_->message;
		g_warning ("Donate.vala:95: %s\n", _tmp1_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
__dialogs_preferences_pages_donate___lambda425__adw_action_row_activated (AdwActionRow* _sender,
                                                                          gpointer self)
{
	_dialogs_preferences_pages_donate___lambda425_ ((DialogsPreferencesPagesDonate*) self);
}

static void
_dialogs_preferences_pages_donate___lambda426_ (DialogsPreferencesPagesDonate* self)
{
	GError* _inner_error0_ = NULL;
	{
		g_app_info_launch_default_for_uri (CONSTANTS_LIBERAPAY_URL, NULL, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp0_ = e;
		_tmp1_ = _tmp0_->message;
		g_warning ("Donate.vala:109: %s\n", _tmp1_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
__dialogs_preferences_pages_donate___lambda426__adw_action_row_activated (AdwActionRow* _sender,
                                                                          gpointer self)
{
	_dialogs_preferences_pages_donate___lambda426_ ((DialogsPreferencesPagesDonate*) self);
}

static void
_dialogs_preferences_pages_donate___lambda427_ (DialogsPreferencesPagesDonate* self)
{
	GError* _inner_error0_ = NULL;
	{
		g_app_info_launch_default_for_uri (CONSTANTS_KOFI_URL, NULL, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_;
		const gchar* _tmp1_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp0_ = e;
		_tmp1_ = _tmp0_->message;
		g_warning ("Donate.vala:123: %s\n", _tmp1_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
__dialogs_preferences_pages_donate___lambda427__adw_action_row_activated (AdwActionRow* _sender,
                                                                          gpointer self)
{
	_dialogs_preferences_pages_donate___lambda427_ ((DialogsPreferencesPagesDonate*) self);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
_dialogs_preferences_pages_donate___lambda428_ (DialogsPreferencesPagesDonate* self)
{
	dialogs_preferences_pages_base_page_clean_up ((DialogsPreferencesPagesBasePage*) self);
}

static void
__dialogs_preferences_pages_donate___lambda428__gtk_widget_destroy (GtkWidget* _sender,
                                                                    gpointer self)
{
	_dialogs_preferences_pages_donate___lambda428_ ((DialogsPreferencesPagesDonate*) self);
}

static GObject *
dialogs_preferences_pages_donate_constructor (GType type,
                                              guint n_construct_properties,
                                              GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	DialogsPreferencesPagesDonate * self;
	GtkBox* content_box = NULL;
	GtkBox* _tmp0_ = NULL;
	GtkBox* hero_box = NULL;
	GtkBox* _tmp1_ = NULL;
	GtkLabel* emoji_label = NULL;
	gchar* _tmp2_;
	gchar** _tmp3_;
	GtkLabel* _tmp4_ = NULL;
	GtkLabel* hero_title = NULL;
	gchar* _tmp5_;
	gchar** _tmp6_;
	GtkLabel* _tmp7_ = NULL;
	GtkLabel* hero_description = NULL;
	gchar* _tmp8_;
	gchar** _tmp9_;
	GtkLabel* _tmp10_ = NULL;
	GtkBox* _tmp11_;
	GtkLabel* _tmp12_;
	GtkBox* _tmp13_;
	GtkLabel* _tmp14_;
	GtkBox* _tmp15_;
	GtkLabel* _tmp16_;
	GtkBox* _tmp17_;
	GtkBox* _tmp18_;
	AdwActionRow* patreon_row = NULL;
	AdwActionRow* _tmp19_;
	AdwActionRow* _tmp20_;
	AdwActionRow* _tmp21_;
	GtkImage* _tmp22_;
	GtkImage* _tmp23_;
	AdwActionRow* _tmp24_;
	AdwActionRow* _tmp25_;
	GeeHashMap* _tmp26_;
	AdwActionRow* _tmp27_;
	gulong _tmp28_;
	AdwActionRow* _tmp29_;
	AdwActionRow* paypal_row = NULL;
	AdwActionRow* _tmp30_;
	AdwActionRow* _tmp31_;
	AdwActionRow* _tmp32_;
	GtkImage* _tmp33_;
	GtkImage* _tmp34_;
	AdwActionRow* _tmp35_;
	AdwActionRow* _tmp36_;
	GeeHashMap* _tmp37_;
	AdwActionRow* _tmp38_;
	gulong _tmp39_;
	AdwActionRow* _tmp40_;
	AdwActionRow* liberapay_row = NULL;
	AdwActionRow* _tmp41_;
	AdwActionRow* _tmp42_;
	AdwActionRow* _tmp43_;
	GtkImage* _tmp44_;
	GtkImage* _tmp45_;
	AdwActionRow* _tmp46_;
	AdwActionRow* _tmp47_;
	GeeHashMap* _tmp48_;
	AdwActionRow* _tmp49_;
	gulong _tmp50_;
	AdwActionRow* _tmp51_;
	AdwActionRow* kofi_row = NULL;
	AdwActionRow* _tmp52_;
	AdwActionRow* _tmp53_;
	AdwActionRow* _tmp54_;
	GtkImage* _tmp55_;
	GtkImage* _tmp56_;
	AdwActionRow* _tmp57_;
	AdwActionRow* _tmp58_;
	GeeHashMap* _tmp59_;
	AdwActionRow* _tmp60_;
	gulong _tmp61_;
	AdwActionRow* _tmp62_;
	AdwPreferencesGroup* group = NULL;
	gchar* _tmp63_;
	AdwPreferencesGroup* _tmp64_ = NULL;
	AdwPreferencesGroup* _tmp65_;
	AdwActionRow* _tmp66_;
	AdwPreferencesGroup* _tmp67_;
	AdwActionRow* _tmp68_;
	AdwPreferencesGroup* _tmp69_;
	AdwActionRow* _tmp70_;
	AdwPreferencesGroup* _tmp71_;
	AdwActionRow* _tmp72_;
	GtkBox* _tmp73_;
	AdwPreferencesGroup* _tmp74_;
	GtkBox* thanks_box = NULL;
	gchar* _tmp75_;
	gchar** _tmp76_;
	GtkBox* _tmp77_ = NULL;
	GtkLabel* thanks_label = NULL;
	gchar* _tmp78_;
	gchar** _tmp79_;
	GtkLabel* _tmp80_ = NULL;
	GtkLabel* thanks_description = NULL;
	gchar* _tmp81_;
	gchar** _tmp82_;
	GtkLabel* _tmp83_ = NULL;
	GtkBox* _tmp84_;
	GtkLabel* _tmp85_;
	GtkBox* _tmp86_;
	GtkLabel* _tmp87_;
	GtkBox* _tmp88_;
	GtkBox* _tmp89_;
	GtkScrolledWindow* scrolled_window = NULL;
	GtkBox* _tmp90_;
	GtkWidget* _tmp91_;
	GtkScrolledWindow* _tmp92_ = NULL;
	AdwToolbarView* toolbar_view = NULL;
	AdwToolbarView* _tmp93_;
	AdwToolbarView* _tmp94_;
	AdwHeaderBar* _tmp95_;
	AdwHeaderBar* _tmp96_;
	AdwToolbarView* _tmp97_;
	GtkScrolledWindow* _tmp98_;
	AdwToolbarView* _tmp99_;
	parent_class = G_OBJECT_CLASS (dialogs_preferences_pages_donate_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DIALOGS_PREFERENCES_PAGES_TYPE_DONATE, DialogsPreferencesPagesDonate);
	_tmp0_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 18);
	gtk_widget_set_vexpand ((GtkWidget*) _tmp0_, TRUE);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp0_, TRUE);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp0_, 24);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp0_, 24);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp0_, 24);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp0_, 24);
	g_object_ref_sink (_tmp0_);
	content_box = _tmp0_;
	_tmp1_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
	gtk_widget_set_halign ((GtkWidget*) _tmp1_, GTK_ALIGN_CENTER);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp1_, 24);
	g_object_ref_sink (_tmp1_);
	hero_box = _tmp1_;
	_tmp2_ = g_strdup ("title-1");
	_tmp3_ = g_new0 (gchar*, 1 + 1);
	_tmp3_[0] = _tmp2_;
	_tmp4_ = (GtkLabel*) gtk_label_new ("💝");
	gtk_widget_set_css_classes ((GtkWidget*) _tmp4_, _tmp3_);
	_tmp3_ = (_vala_array_free (_tmp3_, 1, (GDestroyNotify) g_free), NULL);
	g_object_ref_sink (_tmp4_);
	emoji_label = _tmp4_;
	_tmp5_ = g_strdup ("title-2");
	_tmp6_ = g_new0 (gchar*, 1 + 1);
	_tmp6_[0] = _tmp5_;
	_tmp7_ = (GtkLabel*) gtk_label_new (_ ("Support Planify Development"));
	gtk_widget_set_css_classes ((GtkWidget*) _tmp7_, _tmp6_);
	_tmp6_ = (_vala_array_free (_tmp6_, 1, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_halign ((GtkWidget*) _tmp7_, GTK_ALIGN_CENTER);
	g_object_ref_sink (_tmp7_);
	hero_title = _tmp7_;
	_tmp8_ = g_strdup ("body");
	_tmp9_ = g_new0 (gchar*, 1 + 1);
	_tmp9_[0] = _tmp8_;
	_tmp10_ = (GtkLabel*) gtk_label_new (_ ("Help keep Planify free and open source! Your donations directly suppor" \
"t development, new features, and maintenance. Every contribution, no m" \
"atter the size, makes a difference."));
	gtk_label_set_wrap (_tmp10_, TRUE);
	gtk_label_set_justify (_tmp10_, GTK_JUSTIFY_CENTER);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp10_, _tmp9_);
	_tmp9_ = (_vala_array_free (_tmp9_, 1, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp10_, 12);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp10_, 12);
	g_object_ref_sink (_tmp10_);
	hero_description = _tmp10_;
	_tmp11_ = hero_box;
	_tmp12_ = emoji_label;
	gtk_box_append (_tmp11_, (GtkWidget*) _tmp12_);
	_tmp13_ = hero_box;
	_tmp14_ = hero_title;
	gtk_box_append (_tmp13_, (GtkWidget*) _tmp14_);
	_tmp15_ = hero_box;
	_tmp16_ = hero_description;
	gtk_box_append (_tmp15_, (GtkWidget*) _tmp16_);
	_tmp17_ = content_box;
	_tmp18_ = hero_box;
	gtk_box_append (_tmp17_, (GtkWidget*) _tmp18_);
	_tmp19_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp19_);
	patreon_row = _tmp19_;
	_tmp20_ = patreon_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp20_, TRUE);
	_tmp21_ = patreon_row;
	_tmp22_ = (GtkImage*) gtk_image_new_from_icon_name ("go-next-symbolic");
	g_object_ref_sink (_tmp22_);
	_tmp23_ = _tmp22_;
	adw_action_row_add_suffix (_tmp21_, (GtkWidget*) _tmp23_);
	_g_object_unref0 (_tmp23_);
	_tmp24_ = patreon_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp24_, _ ("Patreon"));
	_tmp25_ = patreon_row;
	adw_action_row_set_subtitle (_tmp25_, _ ("Monthly recurring support"));
	_tmp26_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	_tmp27_ = patreon_row;
	_tmp28_ = g_signal_connect_object (_tmp27_, "activated", (GCallback) __dialogs_preferences_pages_donate___lambda424__adw_action_row_activated, self, 0);
	_tmp29_ = patreon_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp26_, (gpointer) ((guintptr) _tmp28_), (GObject*) _tmp29_);
	_tmp30_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp30_);
	paypal_row = _tmp30_;
	_tmp31_ = paypal_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp31_, TRUE);
	_tmp32_ = paypal_row;
	_tmp33_ = (GtkImage*) gtk_image_new_from_icon_name ("go-next-symbolic");
	g_object_ref_sink (_tmp33_);
	_tmp34_ = _tmp33_;
	adw_action_row_add_suffix (_tmp32_, (GtkWidget*) _tmp34_);
	_g_object_unref0 (_tmp34_);
	_tmp35_ = paypal_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp35_, _ ("PayPal"));
	_tmp36_ = paypal_row;
	adw_action_row_set_subtitle (_tmp36_, _ ("One-time donation"));
	_tmp37_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	_tmp38_ = paypal_row;
	_tmp39_ = g_signal_connect_object (_tmp38_, "activated", (GCallback) __dialogs_preferences_pages_donate___lambda425__adw_action_row_activated, self, 0);
	_tmp40_ = paypal_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp37_, (gpointer) ((guintptr) _tmp39_), (GObject*) _tmp40_);
	_tmp41_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp41_);
	liberapay_row = _tmp41_;
	_tmp42_ = liberapay_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp42_, TRUE);
	_tmp43_ = liberapay_row;
	_tmp44_ = (GtkImage*) gtk_image_new_from_icon_name ("go-next-symbolic");
	g_object_ref_sink (_tmp44_);
	_tmp45_ = _tmp44_;
	adw_action_row_add_suffix (_tmp43_, (GtkWidget*) _tmp45_);
	_g_object_unref0 (_tmp45_);
	_tmp46_ = liberapay_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp46_, _ ("Liberapay"));
	_tmp47_ = liberapay_row;
	adw_action_row_set_subtitle (_tmp47_, _ ("Weekly recurring donations"));
	_tmp48_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	_tmp49_ = liberapay_row;
	_tmp50_ = g_signal_connect_object (_tmp49_, "activated", (GCallback) __dialogs_preferences_pages_donate___lambda426__adw_action_row_activated, self, 0);
	_tmp51_ = liberapay_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp48_, (gpointer) ((guintptr) _tmp50_), (GObject*) _tmp51_);
	_tmp52_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp52_);
	kofi_row = _tmp52_;
	_tmp53_ = kofi_row;
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp53_, TRUE);
	_tmp54_ = kofi_row;
	_tmp55_ = (GtkImage*) gtk_image_new_from_icon_name ("go-next-symbolic");
	g_object_ref_sink (_tmp55_);
	_tmp56_ = _tmp55_;
	adw_action_row_add_suffix (_tmp54_, (GtkWidget*) _tmp56_);
	_g_object_unref0 (_tmp56_);
	_tmp57_ = kofi_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp57_, _ ("Ko-fi"));
	_tmp58_ = kofi_row;
	adw_action_row_set_subtitle (_tmp58_, _ ("Buy me a coffee ☕"));
	_tmp59_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	_tmp60_ = kofi_row;
	_tmp61_ = g_signal_connect_object (_tmp60_, "activated", (GCallback) __dialogs_preferences_pages_donate___lambda427__adw_action_row_activated, self, 0);
	_tmp62_ = kofi_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp59_, (gpointer) ((guintptr) _tmp61_), (GObject*) _tmp62_);
	_tmp63_ = g_strdup (_ ("Choose Your Preferred Platform"));
	_tmp64_ = (AdwPreferencesGroup*) adw_preferences_group_new ();
	adw_preferences_group_set_title (_tmp64_, _tmp63_);
	_g_free0 (_tmp63_);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp64_, 12);
	g_object_ref_sink (_tmp64_);
	group = _tmp64_;
	_tmp65_ = group;
	_tmp66_ = patreon_row;
	adw_preferences_group_add (_tmp65_, (GtkWidget*) _tmp66_);
	_tmp67_ = group;
	_tmp68_ = paypal_row;
	adw_preferences_group_add (_tmp67_, (GtkWidget*) _tmp68_);
	_tmp69_ = group;
	_tmp70_ = liberapay_row;
	adw_preferences_group_add (_tmp69_, (GtkWidget*) _tmp70_);
	_tmp71_ = group;
	_tmp72_ = kofi_row;
	adw_preferences_group_add (_tmp71_, (GtkWidget*) _tmp72_);
	_tmp73_ = content_box;
	_tmp74_ = group;
	gtk_box_append (_tmp73_, (GtkWidget*) _tmp74_);
	_tmp75_ = g_strdup ("card");
	_tmp76_ = g_new0 (gchar*, 1 + 1);
	_tmp76_[0] = _tmp75_;
	_tmp77_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp77_, _tmp76_);
	_tmp76_ = (_vala_array_free (_tmp76_, 1, (GDestroyNotify) g_free), NULL);
	g_object_ref_sink (_tmp77_);
	thanks_box = _tmp77_;
	_tmp78_ = g_strdup ("title-4");
	_tmp79_ = g_new0 (gchar*, 1 + 1);
	_tmp79_[0] = _tmp78_;
	_tmp80_ = (GtkLabel*) gtk_label_new (_ ("Thank you for your support! 🙏"));
	gtk_widget_set_css_classes ((GtkWidget*) _tmp80_, _tmp79_);
	_tmp79_ = (_vala_array_free (_tmp79_, 1, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_halign ((GtkWidget*) _tmp80_, GTK_ALIGN_CENTER);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp80_, 12);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp80_, 6);
	g_object_ref_sink (_tmp80_);
	thanks_label = _tmp80_;
	_tmp81_ = g_strdup ("caption");
	_tmp82_ = g_new0 (gchar*, 1 + 1);
	_tmp82_[0] = _tmp81_;
	_tmp83_ = (GtkLabel*) gtk_label_new (_ ("Your contribution helps keep Planify alive and growing."));
	gtk_widget_set_css_classes ((GtkWidget*) _tmp83_, _tmp82_);
	_tmp82_ = (_vala_array_free (_tmp82_, 1, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_halign ((GtkWidget*) _tmp83_, GTK_ALIGN_CENTER);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp83_, 12);
	g_object_ref_sink (_tmp83_);
	thanks_description = _tmp83_;
	_tmp84_ = thanks_box;
	_tmp85_ = thanks_label;
	gtk_box_append (_tmp84_, (GtkWidget*) _tmp85_);
	_tmp86_ = thanks_box;
	_tmp87_ = thanks_description;
	gtk_box_append (_tmp86_, (GtkWidget*) _tmp87_);
	_tmp88_ = content_box;
	_tmp89_ = thanks_box;
	gtk_box_append (_tmp88_, (GtkWidget*) _tmp89_);
	_tmp90_ = content_box;
	_tmp91_ = _g_object_ref0 ((GtkWidget*) _tmp90_);
	_tmp92_ = (GtkScrolledWindow*) gtk_scrolled_window_new ();
	gtk_widget_set_hexpand ((GtkWidget*) _tmp92_, TRUE);
	gtk_widget_set_vexpand ((GtkWidget*) _tmp92_, TRUE);
	g_object_set (_tmp92_, "hscrollbar-policy", GTK_POLICY_NEVER, NULL);
	g_object_set (_tmp92_, "hscrollbar-policy", GTK_POLICY_NEVER, NULL);
	gtk_scrolled_window_set_child (_tmp92_, _tmp91_);
	_g_object_unref0 (_tmp91_);
	g_object_ref_sink (_tmp92_);
	scrolled_window = _tmp92_;
	_tmp93_ = (AdwToolbarView*) adw_toolbar_view_new ();
	g_object_ref_sink (_tmp93_);
	toolbar_view = _tmp93_;
	_tmp94_ = toolbar_view;
	_tmp95_ = (AdwHeaderBar*) adw_header_bar_new ();
	g_object_ref_sink (_tmp95_);
	_tmp96_ = _tmp95_;
	adw_toolbar_view_add_top_bar (_tmp94_, (GtkWidget*) _tmp96_);
	_g_object_unref0 (_tmp96_);
	_tmp97_ = toolbar_view;
	_tmp98_ = scrolled_window;
	adw_toolbar_view_set_content (_tmp97_, (GtkWidget*) _tmp98_);
	_tmp99_ = toolbar_view;
	adw_navigation_page_set_child ((AdwNavigationPage*) self, (GtkWidget*) _tmp99_);
	g_signal_connect_object ((GtkWidget*) self, "destroy", (GCallback) __dialogs_preferences_pages_donate___lambda428__gtk_widget_destroy, self, 0);
	_g_object_unref0 (toolbar_view);
	_g_object_unref0 (scrolled_window);
	_g_object_unref0 (thanks_description);
	_g_object_unref0 (thanks_label);
	_g_object_unref0 (thanks_box);
	_g_object_unref0 (group);
	_g_object_unref0 (kofi_row);
	_g_object_unref0 (liberapay_row);
	_g_object_unref0 (paypal_row);
	_g_object_unref0 (patreon_row);
	_g_object_unref0 (hero_description);
	_g_object_unref0 (hero_title);
	_g_object_unref0 (emoji_label);
	_g_object_unref0 (hero_box);
	_g_object_unref0 (content_box);
	return obj;
}

static void
dialogs_preferences_pages_donate_class_init (DialogsPreferencesPagesDonateClass * klass,
                                             gpointer klass_data)
{
	dialogs_preferences_pages_donate_parent_class = g_type_class_peek_parent (klass);
	((DialogsPreferencesPagesBasePageClass *) klass)->clean_up = (void (*) (DialogsPreferencesPagesBasePage*)) dialogs_preferences_pages_donate_real_clean_up;
	G_OBJECT_CLASS (klass)->constructor = dialogs_preferences_pages_donate_constructor;
	G_OBJECT_CLASS (klass)->finalize = dialogs_preferences_pages_donate_finalize;
}

static void
dialogs_preferences_pages_donate_instance_init (DialogsPreferencesPagesDonate * self,
                                                gpointer klass)
{
}

static void
dialogs_preferences_pages_donate_finalize (GObject * obj)
{
	DialogsPreferencesPagesDonate * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DIALOGS_PREFERENCES_PAGES_TYPE_DONATE, DialogsPreferencesPagesDonate);
	g_debug ("Donate.vala:31: Destroying - Dialogs.Preferences.Pages.Donate\n");
	G_OBJECT_CLASS (dialogs_preferences_pages_donate_parent_class)->finalize (obj);
}

static GType
dialogs_preferences_pages_donate_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (DialogsPreferencesPagesDonateClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dialogs_preferences_pages_donate_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DialogsPreferencesPagesDonate), 0, (GInstanceInitFunc) dialogs_preferences_pages_donate_instance_init, NULL };
	GType dialogs_preferences_pages_donate_type_id;
	dialogs_preferences_pages_donate_type_id = g_type_register_static (DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, "DialogsPreferencesPagesDonate", &g_define_type_info, 0);
	return dialogs_preferences_pages_donate_type_id;
}

GType
dialogs_preferences_pages_donate_get_type (void)
{
	static volatile gsize dialogs_preferences_pages_donate_type_id__once = 0;
	if (g_once_init_enter (&dialogs_preferences_pages_donate_type_id__once)) {
		GType dialogs_preferences_pages_donate_type_id;
		dialogs_preferences_pages_donate_type_id = dialogs_preferences_pages_donate_get_type_once ();
		g_once_init_leave (&dialogs_preferences_pages_donate_type_id__once, dialogs_preferences_pages_donate_type_id);
	}
	return dialogs_preferences_pages_donate_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

