/* InboxPage.c generated by valac 0.56.19, the Vala compiler
 * generated from InboxPage.vala, do not modify */

/*
 * Copyright © 2025 Alain M. (https://github.com/alainm23/planify)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * Authored by: Alain M. <alainmh23@gmail.com>
 */

#include <adwaita.h>
#include <glib-object.h>
#include <gee.h>
#include <glib.h>
#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>
#include "planify.h"
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <float.h>
#include <math.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE (dialogs_preferences_pages_base_page_get_type ())
#define DIALOGS_PREFERENCES_PAGES_BASE_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, DialogsPreferencesPagesBasePage))
#define DIALOGS_PREFERENCES_PAGES_BASE_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, DialogsPreferencesPagesBasePageClass))
#define DIALOGS_PREFERENCES_PAGES_IS_BASE_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE))
#define DIALOGS_PREFERENCES_PAGES_IS_BASE_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE))
#define DIALOGS_PREFERENCES_PAGES_BASE_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, DialogsPreferencesPagesBasePageClass))

typedef struct _DialogsPreferencesPagesBasePage DialogsPreferencesPagesBasePage;
typedef struct _DialogsPreferencesPagesBasePageClass DialogsPreferencesPagesBasePageClass;
typedef struct _DialogsPreferencesPagesBasePagePrivate DialogsPreferencesPagesBasePagePrivate;

#define DIALOGS_PREFERENCES_PAGES_TYPE_INBOX_PAGE (dialogs_preferences_pages_inbox_page_get_type ())
#define DIALOGS_PREFERENCES_PAGES_INBOX_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_INBOX_PAGE, DialogsPreferencesPagesInboxPage))
#define DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_INBOX_PAGE, DialogsPreferencesPagesInboxPageClass))
#define DIALOGS_PREFERENCES_PAGES_IS_INBOX_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_INBOX_PAGE))
#define DIALOGS_PREFERENCES_PAGES_IS_INBOX_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_INBOX_PAGE))
#define DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_INBOX_PAGE, DialogsPreferencesPagesInboxPageClass))

typedef struct _DialogsPreferencesPagesInboxPage DialogsPreferencesPagesInboxPage;
typedef struct _DialogsPreferencesPagesInboxPageClass DialogsPreferencesPagesInboxPageClass;
typedef struct _DialogsPreferencesPagesInboxPagePrivate DialogsPreferencesPagesInboxPagePrivate;
enum  {
	DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_0_PROPERTY,
	DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_NUM_PROPERTIES
};
static GParamSpec* dialogs_preferences_pages_inbox_page_properties[DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_TYPE_PROJECT_ROW (dialogs_preferences_pages_inbox_page_project_row_get_type ())
#define DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_TYPE_PROJECT_ROW, DialogsPreferencesPagesInboxPageProjectRow))
#define DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_TYPE_PROJECT_ROW, DialogsPreferencesPagesInboxPageProjectRowClass))
#define DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_IS_PROJECT_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_TYPE_PROJECT_ROW))
#define DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_IS_PROJECT_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_TYPE_PROJECT_ROW))
#define DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_TYPE_PROJECT_ROW, DialogsPreferencesPagesInboxPageProjectRowClass))

typedef struct _DialogsPreferencesPagesInboxPageProjectRow DialogsPreferencesPagesInboxPageProjectRow;
typedef struct _DialogsPreferencesPagesInboxPageProjectRowClass DialogsPreferencesPagesInboxPageProjectRowClass;
typedef struct _Block117Data Block117Data;
typedef struct _DialogsPreferencesPagesInboxPageProjectRowPrivate DialogsPreferencesPagesInboxPageProjectRowPrivate;
enum  {
	DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_0_PROPERTY,
	DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_PROJECT_PROPERTY,
	DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_GROUP_PROPERTY,
	DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_ACTIVE_PROPERTY,
	DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_NUM_PROPERTIES
};
static GParamSpec* dialogs_preferences_pages_inbox_page_project_row_properties[DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
enum  {
	DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_TOGGLED_SIGNAL,
	DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_NUM_SIGNALS
};
static guint dialogs_preferences_pages_inbox_page_project_row_signals[DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_NUM_SIGNALS] = {0};

struct _DialogsPreferencesPagesBasePage {
	AdwNavigationPage parent_instance;
	DialogsPreferencesPagesBasePagePrivate * priv;
	GeeHashMap* signal_map;
};

struct _DialogsPreferencesPagesBasePageClass {
	AdwNavigationPageClass parent_class;
	void (*clean_up) (DialogsPreferencesPagesBasePage* self);
};

struct _DialogsPreferencesPagesInboxPage {
	DialogsPreferencesPagesBasePage parent_instance;
	DialogsPreferencesPagesInboxPagePrivate * priv;
};

struct _DialogsPreferencesPagesInboxPageClass {
	DialogsPreferencesPagesBasePageClass parent_class;
};

struct _DialogsPreferencesPagesInboxPagePrivate {
	GtkBox* group_box;
};

struct _Block117Data {
	int _ref_count_;
	DialogsPreferencesPagesInboxPage* self;
	ObjectsProject* project;
	DialogsPreferencesPagesInboxPageProjectRow* row;
};

struct _DialogsPreferencesPagesInboxPageProjectRow {
	GtkListBoxRow parent_instance;
	DialogsPreferencesPagesInboxPageProjectRowPrivate * priv;
	GtkCheckButton* radio_button;
};

struct _DialogsPreferencesPagesInboxPageProjectRowClass {
	GtkListBoxRowClass parent_class;
};

struct _DialogsPreferencesPagesInboxPageProjectRowPrivate {
	ObjectsProject* _project;
};

static gint DialogsPreferencesPagesInboxPage_private_offset;
static gpointer dialogs_preferences_pages_inbox_page_parent_class = NULL;
static gint DialogsPreferencesPagesInboxPageProjectRow_private_offset;
static gpointer dialogs_preferences_pages_inbox_page_project_row_parent_class = NULL;

VALA_EXTERN GType dialogs_preferences_pages_base_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesBasePage, g_object_unref)
VALA_EXTERN GType dialogs_preferences_pages_inbox_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesInboxPage, g_object_unref)
VALA_EXTERN DialogsPreferencesPagesInboxPage* dialogs_preferences_pages_inbox_page_new (AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN DialogsPreferencesPagesInboxPage* dialogs_preferences_pages_inbox_page_construct (GType object_type,
                                                                                  AdwPreferencesDialog* preferences_dialog);
static void dialogs_preferences_pages_inbox_page_add_projects (DialogsPreferencesPagesInboxPage* self);
VALA_EXTERN GType dialogs_preferences_pages_inbox_page_project_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesInboxPageProjectRow, g_object_unref)
static Block117Data* block117_data_ref (Block117Data* _data117_);
static void block117_data_unref (void * _userdata_);
VALA_EXTERN DialogsPreferencesPagesInboxPageProjectRow* dialogs_preferences_pages_inbox_page_project_row_new (ObjectsProject* project);
VALA_EXTERN DialogsPreferencesPagesInboxPageProjectRow* dialogs_preferences_pages_inbox_page_project_row_construct (GType object_type,
                                                                                                        ObjectsProject* project);
VALA_EXTERN void dialogs_preferences_pages_inbox_page_project_row_set_active (DialogsPreferencesPagesInboxPageProjectRow* self,
                                                                  gboolean value);
VALA_EXTERN void dialogs_preferences_pages_inbox_page_project_row_set_group (DialogsPreferencesPagesInboxPageProjectRow* self,
                                                                 GtkCheckButton* value);
static void ______lambda281_ (Block117Data* _data117_);
VALA_EXTERN gboolean dialogs_preferences_pages_inbox_page_project_row_get_active (DialogsPreferencesPagesInboxPageProjectRow* self);
static void _______lambda281__dialogs_preferences_pages_inbox_page_project_row_toggled (DialogsPreferencesPagesInboxPageProjectRow* _sender,
                                                                                 gpointer self);
VALA_EXTERN ObjectsProject* dialogs_preferences_pages_inbox_page_project_row_get_project (DialogsPreferencesPagesInboxPageProjectRow* self);
static void dialogs_preferences_pages_inbox_page_project_row_set_project (DialogsPreferencesPagesInboxPageProjectRow* self,
                                                                   ObjectsProject* value);
static GObject * dialogs_preferences_pages_inbox_page_project_row_constructor (GType type,
                                                                        guint n_construct_properties,
                                                                        GObjectConstructParam * construct_properties);
static void _dialogs_preferences_pages_inbox_page_project_row___lambda279_ (DialogsPreferencesPagesInboxPageProjectRow* self);
static void __dialogs_preferences_pages_inbox_page_project_row___lambda279__gtk_gesture_click_released (GtkGestureClick* _sender,
                                                                                                 gint n_press,
                                                                                                 gdouble x,
                                                                                                 gdouble y,
                                                                                                 gpointer self);
static void _dialogs_preferences_pages_inbox_page_project_row___lambda280_ (DialogsPreferencesPagesInboxPageProjectRow* self);
static void __dialogs_preferences_pages_inbox_page_project_row___lambda280__gtk_check_button_toggled (GtkCheckButton* _sender,
                                                                                               gpointer self);
static void dialogs_preferences_pages_inbox_page_project_row_finalize (GObject * obj);
static GType dialogs_preferences_pages_inbox_page_project_row_get_type_once (void);
static void _vala_dialogs_preferences_pages_inbox_page_project_row_get_property (GObject * object,
                                                                          guint property_id,
                                                                          GValue * value,
                                                                          GParamSpec * pspec);
static void _vala_dialogs_preferences_pages_inbox_page_project_row_set_property (GObject * object,
                                                                          guint property_id,
                                                                          const GValue * value,
                                                                          GParamSpec * pspec);
static GObject * dialogs_preferences_pages_inbox_page_constructor (GType type,
                                                            guint n_construct_properties,
                                                            GObjectConstructParam * construct_properties);
static void dialogs_preferences_pages_inbox_page_finalize (GObject * obj);
static GType dialogs_preferences_pages_inbox_page_get_type_once (void);

static inline gpointer
dialogs_preferences_pages_inbox_page_get_instance_private (DialogsPreferencesPagesInboxPage* self)
{
	return G_STRUCT_MEMBER_P (self, DialogsPreferencesPagesInboxPage_private_offset);
}

DialogsPreferencesPagesInboxPage*
dialogs_preferences_pages_inbox_page_construct (GType object_type,
                                                AdwPreferencesDialog* preferences_dialog)
{
	DialogsPreferencesPagesInboxPage * self = NULL;
	g_return_val_if_fail (preferences_dialog != NULL, NULL);
	self = (DialogsPreferencesPagesInboxPage*) g_object_new (object_type, "preferences-dialog", preferences_dialog, "title", _ ("Inbox Project"), NULL);
	return self;
}

DialogsPreferencesPagesInboxPage*
dialogs_preferences_pages_inbox_page_new (AdwPreferencesDialog* preferences_dialog)
{
	return dialogs_preferences_pages_inbox_page_construct (DIALOGS_PREFERENCES_PAGES_TYPE_INBOX_PAGE, preferences_dialog);
}

static Block117Data*
block117_data_ref (Block117Data* _data117_)
{
	g_atomic_int_inc (&_data117_->_ref_count_);
	return _data117_;
}

static void
block117_data_unref (void * _userdata_)
{
	Block117Data* _data117_;
	_data117_ = (Block117Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data117_->_ref_count_)) {
		DialogsPreferencesPagesInboxPage* self;
		self = _data117_->self;
		_g_object_unref0 (_data117_->row);
		_g_object_unref0 (_data117_->project);
		_g_object_unref0 (self);
		g_slice_free (Block117Data, _data117_);
	}
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
______lambda281_ (Block117Data* _data117_)
{
	DialogsPreferencesPagesInboxPage* self;
	DialogsPreferencesPagesInboxPageProjectRow* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	self = _data117_->self;
	_tmp0_ = _data117_->row;
	_tmp1_ = dialogs_preferences_pages_inbox_page_project_row_get_active (_tmp0_);
	_tmp2_ = _tmp1_;
	if (_tmp2_) {
		ServicesSettings* _tmp3_;
		ServicesSettings* _tmp4_;
		GSettings* _tmp5_;
		ObjectsProject* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		_tmp3_ = services_settings_get_default ();
		_tmp4_ = _tmp3_;
		_tmp5_ = _tmp4_->settings;
		_tmp6_ = _data117_->project;
		_tmp7_ = objects_base_object_get_id ((ObjectsBaseObject*) _tmp6_);
		_tmp8_ = _tmp7_;
		g_settings_set_string (_tmp5_, "local-inbox-project-id", _tmp8_);
		_g_object_unref0 (_tmp4_);
	}
}

static void
_______lambda281__dialogs_preferences_pages_inbox_page_project_row_toggled (DialogsPreferencesPagesInboxPageProjectRow* _sender,
                                                                            gpointer self)
{
	______lambda281_ (self);
}

static void
dialogs_preferences_pages_inbox_page_add_projects (DialogsPreferencesPagesInboxPage* self)
{
	GtkCheckButton* fake_radio = NULL;
	GtkCheckButton* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = (GtkCheckButton*) gtk_check_button_new ();
	g_object_ref_sink (_tmp0_);
	fake_radio = _tmp0_;
	{
		GeeArrayList* _source_list = NULL;
		ServicesStore* _tmp1_;
		GeeArrayList* _tmp2_;
		GeeArrayList* _tmp3_;
		gint _source_size = 0;
		GeeArrayList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		gint _source_index = 0;
		_tmp1_ = services_store_instance ();
		_tmp2_ = services_store_get_sources (_tmp1_);
		_tmp3_ = _tmp2_;
		_source_list = _tmp3_;
		_tmp4_ = _source_list;
		_tmp5_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp4_);
		_tmp6_ = _tmp5_;
		_source_size = _tmp6_;
		_source_index = -1;
		while (TRUE) {
			gint _tmp7_;
			gint _tmp8_;
			ObjectsSource* source = NULL;
			GeeArrayList* _tmp9_;
			gpointer _tmp10_;
			LayoutsHeaderItem* source_group = NULL;
			ObjectsSource* _tmp11_;
			const gchar* _tmp12_;
			const gchar* _tmp13_;
			ObjectsSource* _tmp14_;
			gboolean _tmp15_;
			gboolean _tmp16_;
			LayoutsHeaderItem* _tmp17_ = NULL;
			GtkBox* _tmp46_;
			LayoutsHeaderItem* _tmp47_;
			_source_index = _source_index + 1;
			_tmp7_ = _source_index;
			_tmp8_ = _source_size;
			if (!(_tmp7_ < _tmp8_)) {
				break;
			}
			_tmp9_ = _source_list;
			_tmp10_ = gee_abstract_list_get ((GeeAbstractList*) _tmp9_, _source_index);
			source = (ObjectsSource*) _tmp10_;
			_tmp11_ = source;
			_tmp12_ = objects_source_get_display_name (_tmp11_);
			_tmp13_ = _tmp12_;
			_tmp14_ = source;
			_tmp15_ = objects_source_get_is_visible (_tmp14_);
			_tmp16_ = _tmp15_;
			_tmp17_ = layouts_header_item_new (_tmp13_);
			layouts_header_item_set_card (_tmp17_, TRUE);
			layouts_header_item_set_reveal (_tmp17_, _tmp16_);
			g_object_ref_sink (_tmp17_);
			source_group = _tmp17_;
			{
				GeeArrayList* _project_list = NULL;
				ServicesStore* _tmp18_;
				ObjectsSource* _tmp19_;
				const gchar* _tmp20_;
				const gchar* _tmp21_;
				GeeArrayList* _tmp22_;
				gint _project_size = 0;
				GeeArrayList* _tmp23_;
				gint _tmp24_;
				gint _tmp25_;
				gint _project_index = 0;
				_tmp18_ = services_store_instance ();
				_tmp19_ = source;
				_tmp20_ = objects_base_object_get_id ((ObjectsBaseObject*) _tmp19_);
				_tmp21_ = _tmp20_;
				_tmp22_ = services_store_get_projects_by_source (_tmp18_, _tmp21_);
				_project_list = _tmp22_;
				_tmp23_ = _project_list;
				_tmp24_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp23_);
				_tmp25_ = _tmp24_;
				_project_size = _tmp25_;
				_project_index = -1;
				while (TRUE) {
					Block117Data* _data117_;
					gint _tmp26_;
					gint _tmp27_;
					GeeArrayList* _tmp28_;
					gpointer _tmp29_;
					ObjectsProject* _tmp30_;
					gboolean _tmp31_;
					gboolean _tmp32_;
					ObjectsProject* _tmp33_;
					ObjectsProject* _tmp34_;
					gboolean _tmp35_;
					gboolean _tmp36_;
					GtkCheckButton* _tmp37_;
					GtkCheckButton* _tmp38_;
					DialogsPreferencesPagesInboxPageProjectRow* _tmp39_ = NULL;
					GeeHashMap* _tmp40_;
					DialogsPreferencesPagesInboxPageProjectRow* _tmp41_;
					gulong _tmp42_;
					DialogsPreferencesPagesInboxPageProjectRow* _tmp43_;
					LayoutsHeaderItem* _tmp44_;
					DialogsPreferencesPagesInboxPageProjectRow* _tmp45_;
					_data117_ = g_slice_new0 (Block117Data);
					_data117_->_ref_count_ = 1;
					_data117_->self = g_object_ref (self);
					_project_index = _project_index + 1;
					_tmp26_ = _project_index;
					_tmp27_ = _project_size;
					if (!(_tmp26_ < _tmp27_)) {
						block117_data_unref (_data117_);
						_data117_ = NULL;
						break;
					}
					_tmp28_ = _project_list;
					_tmp29_ = gee_abstract_list_get ((GeeAbstractList*) _tmp28_, _project_index);
					_data117_->project = (ObjectsProject*) _tmp29_;
					_tmp30_ = _data117_->project;
					_tmp31_ = objects_project_get_is_archived (_tmp30_);
					_tmp32_ = _tmp31_;
					if (_tmp32_) {
						block117_data_unref (_data117_);
						_data117_ = NULL;
						continue;
					}
					_tmp33_ = _data117_->project;
					_tmp34_ = _data117_->project;
					_tmp35_ = objects_project_get_is_inbox_project (_tmp34_);
					_tmp36_ = _tmp35_;
					_tmp37_ = fake_radio;
					_tmp38_ = _g_object_ref0 (_tmp37_);
					_tmp39_ = dialogs_preferences_pages_inbox_page_project_row_new (_tmp33_);
					dialogs_preferences_pages_inbox_page_project_row_set_active (_tmp39_, _tmp36_);
					dialogs_preferences_pages_inbox_page_project_row_set_group (_tmp39_, _tmp38_);
					_g_object_unref0 (_tmp38_);
					g_object_ref_sink (_tmp39_);
					_data117_->row = _tmp39_;
					_tmp40_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
					_tmp41_ = _data117_->row;
					_tmp42_ = g_signal_connect_data (_tmp41_, "toggled", (GCallback) _______lambda281__dialogs_preferences_pages_inbox_page_project_row_toggled, block117_data_ref (_data117_), (GClosureNotify) block117_data_unref, 0);
					_tmp43_ = _data117_->row;
					gee_abstract_map_set ((GeeAbstractMap*) _tmp40_, (gpointer) ((guintptr) _tmp42_), (GObject*) _tmp43_);
					_tmp44_ = source_group;
					_tmp45_ = _data117_->row;
					layouts_header_item_add_child (_tmp44_, (GtkWidget*) _tmp45_);
					block117_data_unref (_data117_);
					_data117_ = NULL;
				}
				_g_object_unref0 (_project_list);
			}
			_tmp46_ = self->priv->group_box;
			_tmp47_ = source_group;
			gtk_box_append (_tmp46_, (GtkWidget*) _tmp47_);
			_g_object_unref0 (source_group);
			_g_object_unref0 (source);
		}
	}
	_g_object_unref0 (fake_radio);
}

static inline gpointer
dialogs_preferences_pages_inbox_page_project_row_get_instance_private (DialogsPreferencesPagesInboxPageProjectRow* self)
{
	return G_STRUCT_MEMBER_P (self, DialogsPreferencesPagesInboxPageProjectRow_private_offset);
}

DialogsPreferencesPagesInboxPageProjectRow*
dialogs_preferences_pages_inbox_page_project_row_construct (GType object_type,
                                                            ObjectsProject* project)
{
	DialogsPreferencesPagesInboxPageProjectRow * self = NULL;
	g_return_val_if_fail (project != NULL, NULL);
	self = (DialogsPreferencesPagesInboxPageProjectRow*) g_object_new (object_type, "project", project, NULL);
	return self;
}

DialogsPreferencesPagesInboxPageProjectRow*
dialogs_preferences_pages_inbox_page_project_row_new (ObjectsProject* project)
{
	return dialogs_preferences_pages_inbox_page_project_row_construct (DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_TYPE_PROJECT_ROW, project);
}

ObjectsProject*
dialogs_preferences_pages_inbox_page_project_row_get_project (DialogsPreferencesPagesInboxPageProjectRow* self)
{
	ObjectsProject* result;
	ObjectsProject* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_project;
	result = _tmp0_;
	return result;
}

static void
dialogs_preferences_pages_inbox_page_project_row_set_project (DialogsPreferencesPagesInboxPageProjectRow* self,
                                                              ObjectsProject* value)
{
	ObjectsProject* old_value;
	g_return_if_fail (self != NULL);
	old_value = dialogs_preferences_pages_inbox_page_project_row_get_project (self);
	if (old_value != value) {
		ObjectsProject* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_project);
		self->priv->_project = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, dialogs_preferences_pages_inbox_page_project_row_properties[DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_PROJECT_PROPERTY]);
	}
}

void
dialogs_preferences_pages_inbox_page_project_row_set_group (DialogsPreferencesPagesInboxPageProjectRow* self,
                                                            GtkCheckButton* value)
{
	GtkCheckButton* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->radio_button;
	gtk_check_button_set_group (_tmp0_, value);
	g_object_notify_by_pspec ((GObject *) self, dialogs_preferences_pages_inbox_page_project_row_properties[DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_GROUP_PROPERTY]);
}

gboolean
dialogs_preferences_pages_inbox_page_project_row_get_active (DialogsPreferencesPagesInboxPageProjectRow* self)
{
	gboolean result;
	GtkCheckButton* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->radio_button;
	_tmp1_ = gtk_check_button_get_active (_tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

void
dialogs_preferences_pages_inbox_page_project_row_set_active (DialogsPreferencesPagesInboxPageProjectRow* self,
                                                             gboolean value)
{
	GtkCheckButton* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->radio_button;
	gtk_check_button_set_active (_tmp0_, value);
	g_object_notify_by_pspec ((GObject *) self, dialogs_preferences_pages_inbox_page_project_row_properties[DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_ACTIVE_PROPERTY]);
}

static void
_dialogs_preferences_pages_inbox_page_project_row___lambda279_ (DialogsPreferencesPagesInboxPageProjectRow* self)
{
	GtkCheckButton* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	_tmp0_ = self->radio_button;
	_tmp1_ = gtk_check_button_get_active (_tmp0_);
	_tmp2_ = _tmp1_;
	if (!_tmp2_) {
		GtkCheckButton* _tmp3_;
		_tmp3_ = self->radio_button;
		gtk_check_button_set_active (_tmp3_, TRUE);
		g_signal_emit (self, dialogs_preferences_pages_inbox_page_project_row_signals[DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_TOGGLED_SIGNAL], 0);
	}
}

static void
__dialogs_preferences_pages_inbox_page_project_row___lambda279__gtk_gesture_click_released (GtkGestureClick* _sender,
                                                                                            gint n_press,
                                                                                            gdouble x,
                                                                                            gdouble y,
                                                                                            gpointer self)
{
	_dialogs_preferences_pages_inbox_page_project_row___lambda279_ ((DialogsPreferencesPagesInboxPageProjectRow*) self);
}

static void
_dialogs_preferences_pages_inbox_page_project_row___lambda280_ (DialogsPreferencesPagesInboxPageProjectRow* self)
{
	GtkCheckButton* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	_tmp0_ = self->radio_button;
	_tmp1_ = gtk_check_button_get_active (_tmp0_);
	_tmp2_ = _tmp1_;
	if (_tmp2_) {
		g_signal_emit (self, dialogs_preferences_pages_inbox_page_project_row_signals[DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_TOGGLED_SIGNAL], 0);
	}
}

static void
__dialogs_preferences_pages_inbox_page_project_row___lambda280__gtk_check_button_toggled (GtkCheckButton* _sender,
                                                                                          gpointer self)
{
	_dialogs_preferences_pages_inbox_page_project_row___lambda280_ ((DialogsPreferencesPagesInboxPageProjectRow*) self);
}

static GObject *
dialogs_preferences_pages_inbox_page_project_row_constructor (GType type,
                                                              guint n_construct_properties,
                                                              GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	DialogsPreferencesPagesInboxPageProjectRow * self;
	GtkCheckButton* _tmp0_;
	AdwActionRow* action_row = NULL;
	ObjectsProject* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	AdwActionRow* _tmp5_ = NULL;
	AdwActionRow* _tmp6_;
	ObjectsProject* _tmp7_;
	ObjectsProject* _tmp8_;
	WidgetsIconColorProject* _tmp9_ = NULL;
	WidgetsIconColorProject* _tmp10_;
	AdwActionRow* _tmp11_;
	GtkCheckButton* _tmp12_;
	AdwActionRow* _tmp13_;
	GtkGestureClick* select_gesture = NULL;
	GtkGestureClick* _tmp14_;
	AdwActionRow* _tmp15_;
	GtkGestureClick* _tmp16_;
	GtkEventController* _tmp17_;
	GtkGestureClick* _tmp18_;
	GtkCheckButton* _tmp19_;
	parent_class = G_OBJECT_CLASS (dialogs_preferences_pages_inbox_page_project_row_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_TYPE_PROJECT_ROW, DialogsPreferencesPagesInboxPageProjectRow);
	gtk_widget_add_css_class ((GtkWidget*) self, "sidebar-row");
	gtk_widget_add_css_class ((GtkWidget*) self, "transition");
	gtk_widget_add_css_class ((GtkWidget*) self, "no-padding");
	_tmp0_ = (GtkCheckButton*) gtk_check_button_new ();
	g_object_ref_sink (_tmp0_);
	_g_object_unref0 (self->radio_button);
	self->radio_button = _tmp0_;
	_tmp1_ = self->priv->_project;
	_tmp2_ = objects_base_object_get_name ((ObjectsBaseObject*) _tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_strdup (_tmp3_);
	_tmp5_ = (AdwActionRow*) adw_action_row_new ();
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp5_, _tmp4_);
	_g_free0 (_tmp4_);
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp5_, TRUE);
	g_object_ref_sink (_tmp5_);
	action_row = _tmp5_;
	_tmp6_ = action_row;
	_tmp7_ = self->priv->_project;
	_tmp8_ = _g_object_ref0 (_tmp7_);
	_tmp9_ = widgets_icon_color_project_new (20);
	widgets_icon_color_project_set_project (_tmp9_, _tmp8_);
	_g_object_unref0 (_tmp8_);
	g_object_ref_sink (_tmp9_);
	_tmp10_ = _tmp9_;
	adw_action_row_add_prefix (_tmp6_, (GtkWidget*) _tmp10_);
	_g_object_unref0 (_tmp10_);
	_tmp11_ = action_row;
	_tmp12_ = self->radio_button;
	adw_action_row_add_suffix (_tmp11_, (GtkWidget*) _tmp12_);
	_tmp13_ = action_row;
	gtk_list_box_row_set_child ((GtkListBoxRow*) self, (GtkWidget*) _tmp13_);
	_tmp14_ = (GtkGestureClick*) gtk_gesture_click_new ();
	select_gesture = _tmp14_;
	_tmp15_ = action_row;
	_tmp16_ = select_gesture;
	_tmp17_ = _g_object_ref0 ((GtkEventController*) _tmp16_);
	gtk_widget_add_controller ((GtkWidget*) _tmp15_, _tmp17_);
	_tmp18_ = select_gesture;
	g_signal_connect_object (_tmp18_, "released", (GCallback) __dialogs_preferences_pages_inbox_page_project_row___lambda279__gtk_gesture_click_released, self, 0);
	_tmp19_ = self->radio_button;
	g_signal_connect_object (_tmp19_, "toggled", (GCallback) __dialogs_preferences_pages_inbox_page_project_row___lambda280__gtk_check_button_toggled, self, 0);
	_g_object_unref0 (select_gesture);
	_g_object_unref0 (action_row);
	return obj;
}

static void
dialogs_preferences_pages_inbox_page_project_row_class_init (DialogsPreferencesPagesInboxPageProjectRowClass * klass,
                                                             gpointer klass_data)
{
	dialogs_preferences_pages_inbox_page_project_row_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &DialogsPreferencesPagesInboxPageProjectRow_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_dialogs_preferences_pages_inbox_page_project_row_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_dialogs_preferences_pages_inbox_page_project_row_set_property;
	G_OBJECT_CLASS (klass)->constructor = dialogs_preferences_pages_inbox_page_project_row_constructor;
	G_OBJECT_CLASS (klass)->finalize = dialogs_preferences_pages_inbox_page_project_row_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_PROJECT_PROPERTY, dialogs_preferences_pages_inbox_page_project_row_properties[DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_PROJECT_PROPERTY] = g_param_spec_object ("project", "project", "project", OBJECTS_TYPE_PROJECT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
	g_object_class_install_property (G_OBJECT_CLASS (klass), DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_GROUP_PROPERTY, dialogs_preferences_pages_inbox_page_project_row_properties[DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_GROUP_PROPERTY] = g_param_spec_object ("group", "group", "group", gtk_check_button_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_ACTIVE_PROPERTY, dialogs_preferences_pages_inbox_page_project_row_properties[DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_ACTIVE_PROPERTY] = g_param_spec_boolean ("active", "active", "active", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	dialogs_preferences_pages_inbox_page_project_row_signals[DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_TOGGLED_SIGNAL] = g_signal_new ("toggled", DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_TYPE_PROJECT_ROW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
}

static void
dialogs_preferences_pages_inbox_page_project_row_instance_init (DialogsPreferencesPagesInboxPageProjectRow * self,
                                                                gpointer klass)
{
	self->priv = dialogs_preferences_pages_inbox_page_project_row_get_instance_private (self);
}

static void
dialogs_preferences_pages_inbox_page_project_row_finalize (GObject * obj)
{
	DialogsPreferencesPagesInboxPageProjectRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_TYPE_PROJECT_ROW, DialogsPreferencesPagesInboxPageProjectRow);
	g_debug ("InboxPage.vala:134: Destroying - ProjectRow\n");
	_g_object_unref0 (self->priv->_project);
	_g_object_unref0 (self->radio_button);
	G_OBJECT_CLASS (dialogs_preferences_pages_inbox_page_project_row_parent_class)->finalize (obj);
}

static GType
dialogs_preferences_pages_inbox_page_project_row_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (DialogsPreferencesPagesInboxPageProjectRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dialogs_preferences_pages_inbox_page_project_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DialogsPreferencesPagesInboxPageProjectRow), 0, (GInstanceInitFunc) dialogs_preferences_pages_inbox_page_project_row_instance_init, NULL };
	GType dialogs_preferences_pages_inbox_page_project_row_type_id;
	dialogs_preferences_pages_inbox_page_project_row_type_id = g_type_register_static (gtk_list_box_row_get_type (), "DialogsPreferencesPagesInboxPageProjectRow", &g_define_type_info, 0);
	DialogsPreferencesPagesInboxPageProjectRow_private_offset = g_type_add_instance_private (dialogs_preferences_pages_inbox_page_project_row_type_id, sizeof (DialogsPreferencesPagesInboxPageProjectRowPrivate));
	return dialogs_preferences_pages_inbox_page_project_row_type_id;
}

GType
dialogs_preferences_pages_inbox_page_project_row_get_type (void)
{
	static volatile gsize dialogs_preferences_pages_inbox_page_project_row_type_id__once = 0;
	if (g_once_init_enter (&dialogs_preferences_pages_inbox_page_project_row_type_id__once)) {
		GType dialogs_preferences_pages_inbox_page_project_row_type_id;
		dialogs_preferences_pages_inbox_page_project_row_type_id = dialogs_preferences_pages_inbox_page_project_row_get_type_once ();
		g_once_init_leave (&dialogs_preferences_pages_inbox_page_project_row_type_id__once, dialogs_preferences_pages_inbox_page_project_row_type_id);
	}
	return dialogs_preferences_pages_inbox_page_project_row_type_id__once;
}

static void
_vala_dialogs_preferences_pages_inbox_page_project_row_get_property (GObject * object,
                                                                     guint property_id,
                                                                     GValue * value,
                                                                     GParamSpec * pspec)
{
	DialogsPreferencesPagesInboxPageProjectRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_TYPE_PROJECT_ROW, DialogsPreferencesPagesInboxPageProjectRow);
	switch (property_id) {
		case DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_PROJECT_PROPERTY:
		g_value_set_object (value, dialogs_preferences_pages_inbox_page_project_row_get_project (self));
		break;
		case DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_ACTIVE_PROPERTY:
		g_value_set_boolean (value, dialogs_preferences_pages_inbox_page_project_row_get_active (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_dialogs_preferences_pages_inbox_page_project_row_set_property (GObject * object,
                                                                     guint property_id,
                                                                     const GValue * value,
                                                                     GParamSpec * pspec)
{
	DialogsPreferencesPagesInboxPageProjectRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_TYPE_PROJECT_ROW, DialogsPreferencesPagesInboxPageProjectRow);
	switch (property_id) {
		case DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_PROJECT_PROPERTY:
		dialogs_preferences_pages_inbox_page_project_row_set_project (self, g_value_get_object (value));
		break;
		case DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_GROUP_PROPERTY:
		dialogs_preferences_pages_inbox_page_project_row_set_group (self, g_value_get_object (value));
		break;
		case DIALOGS_PREFERENCES_PAGES_INBOX_PAGE_PROJECT_ROW_ACTIVE_PROPERTY:
		dialogs_preferences_pages_inbox_page_project_row_set_active (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static GObject *
dialogs_preferences_pages_inbox_page_constructor (GType type,
                                                  guint n_construct_properties,
                                                  GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	DialogsPreferencesPagesInboxPage * self;
	GtkLabel* description_label = NULL;
	GtkLabel* _tmp0_ = NULL;
	GtkBox* _tmp1_;
	GtkBox* _tmp2_;
	GtkLabel* _tmp3_;
	GtkBox* content_box = NULL;
	GtkBox* _tmp4_ = NULL;
	GtkBox* _tmp5_;
	GtkBox* _tmp6_;
	GtkScrolledWindow* scrolled_window = NULL;
	GtkBox* _tmp7_;
	GtkWidget* _tmp8_;
	GtkScrolledWindow* _tmp9_ = NULL;
	AdwToolbarView* toolbar_view = NULL;
	GtkScrolledWindow* _tmp10_;
	GtkWidget* _tmp11_;
	AdwToolbarView* _tmp12_ = NULL;
	AdwToolbarView* _tmp13_;
	AdwHeaderBar* _tmp14_;
	AdwHeaderBar* _tmp15_;
	AdwToolbarView* _tmp16_;
	parent_class = G_OBJECT_CLASS (dialogs_preferences_pages_inbox_page_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DIALOGS_PREFERENCES_PAGES_TYPE_INBOX_PAGE, DialogsPreferencesPagesInboxPage);
	_tmp0_ = (GtkLabel*) gtk_label_new (_ ("Your Inbox is where new tasks land by default. Based on David Allen's " \
"Getting Things Done methodology, it's your capture point for quick ide" \
"as and tasks that you'll organize later"));
	gtk_label_set_wrap (_tmp0_, TRUE);
	gtk_label_set_xalign (_tmp0_, (gfloat) 0);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp0_, 6);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp0_, 3);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp0_, 3);
	g_object_ref_sink (_tmp0_);
	description_label = _tmp0_;
	_tmp1_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
	g_object_ref_sink (_tmp1_);
	_g_object_unref0 (self->priv->group_box);
	self->priv->group_box = _tmp1_;
	_tmp2_ = self->priv->group_box;
	_tmp3_ = description_label;
	gtk_box_append (_tmp2_, (GtkWidget*) _tmp3_);
	_tmp4_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp4_, 12);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp4_, 12);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp4_, 24);
	g_object_ref_sink (_tmp4_);
	content_box = _tmp4_;
	_tmp5_ = content_box;
	_tmp6_ = self->priv->group_box;
	gtk_box_append (_tmp5_, (GtkWidget*) _tmp6_);
	_tmp7_ = content_box;
	_tmp8_ = _g_object_ref0 ((GtkWidget*) _tmp7_);
	_tmp9_ = (GtkScrolledWindow*) gtk_scrolled_window_new ();
	g_object_set (_tmp9_, "hscrollbar-policy", GTK_POLICY_NEVER, NULL);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp9_, TRUE);
	gtk_widget_set_vexpand ((GtkWidget*) _tmp9_, TRUE);
	gtk_scrolled_window_set_child (_tmp9_, _tmp8_);
	_g_object_unref0 (_tmp8_);
	g_object_ref_sink (_tmp9_);
	scrolled_window = _tmp9_;
	_tmp10_ = scrolled_window;
	_tmp11_ = _g_object_ref0 ((GtkWidget*) _tmp10_);
	_tmp12_ = (AdwToolbarView*) adw_toolbar_view_new ();
	adw_toolbar_view_set_content (_tmp12_, _tmp11_);
	_g_object_unref0 (_tmp11_);
	g_object_ref_sink (_tmp12_);
	toolbar_view = _tmp12_;
	_tmp13_ = toolbar_view;
	_tmp14_ = (AdwHeaderBar*) adw_header_bar_new ();
	g_object_ref_sink (_tmp14_);
	_tmp15_ = _tmp14_;
	adw_toolbar_view_add_top_bar (_tmp13_, (GtkWidget*) _tmp15_);
	_g_object_unref0 (_tmp15_);
	_tmp16_ = toolbar_view;
	adw_navigation_page_set_child ((AdwNavigationPage*) self, (GtkWidget*) _tmp16_);
	dialogs_preferences_pages_inbox_page_add_projects (self);
	_g_object_unref0 (toolbar_view);
	_g_object_unref0 (scrolled_window);
	_g_object_unref0 (content_box);
	_g_object_unref0 (description_label);
	return obj;
}

static void
dialogs_preferences_pages_inbox_page_class_init (DialogsPreferencesPagesInboxPageClass * klass,
                                                 gpointer klass_data)
{
	dialogs_preferences_pages_inbox_page_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &DialogsPreferencesPagesInboxPage_private_offset);
	G_OBJECT_CLASS (klass)->constructor = dialogs_preferences_pages_inbox_page_constructor;
	G_OBJECT_CLASS (klass)->finalize = dialogs_preferences_pages_inbox_page_finalize;
}

static void
dialogs_preferences_pages_inbox_page_instance_init (DialogsPreferencesPagesInboxPage * self,
                                                    gpointer klass)
{
	self->priv = dialogs_preferences_pages_inbox_page_get_instance_private (self);
}

static void
dialogs_preferences_pages_inbox_page_finalize (GObject * obj)
{
	DialogsPreferencesPagesInboxPage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DIALOGS_PREFERENCES_PAGES_TYPE_INBOX_PAGE, DialogsPreferencesPagesInboxPage);
	g_debug ("InboxPage.vala:33: Destroying Dialogs.Preferences.Pages.InboxPage\n");
	_g_object_unref0 (self->priv->group_box);
	G_OBJECT_CLASS (dialogs_preferences_pages_inbox_page_parent_class)->finalize (obj);
}

static GType
dialogs_preferences_pages_inbox_page_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (DialogsPreferencesPagesInboxPageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dialogs_preferences_pages_inbox_page_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DialogsPreferencesPagesInboxPage), 0, (GInstanceInitFunc) dialogs_preferences_pages_inbox_page_instance_init, NULL };
	GType dialogs_preferences_pages_inbox_page_type_id;
	dialogs_preferences_pages_inbox_page_type_id = g_type_register_static (DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, "DialogsPreferencesPagesInboxPage", &g_define_type_info, 0);
	DialogsPreferencesPagesInboxPage_private_offset = g_type_add_instance_private (dialogs_preferences_pages_inbox_page_type_id, sizeof (DialogsPreferencesPagesInboxPagePrivate));
	return dialogs_preferences_pages_inbox_page_type_id;
}

GType
dialogs_preferences_pages_inbox_page_get_type (void)
{
	static volatile gsize dialogs_preferences_pages_inbox_page_type_id__once = 0;
	if (g_once_init_enter (&dialogs_preferences_pages_inbox_page_type_id__once)) {
		GType dialogs_preferences_pages_inbox_page_type_id;
		dialogs_preferences_pages_inbox_page_type_id = dialogs_preferences_pages_inbox_page_get_type_once ();
		g_once_init_leave (&dialogs_preferences_pages_inbox_page_type_id__once, dialogs_preferences_pages_inbox_page_type_id);
	}
	return dialogs_preferences_pages_inbox_page_type_id__once;
}

