/* ReminderRow.c generated by valac 0.56.19, the Vala compiler
 * generated from ReminderRow.vala, do not modify */

/*
 * Copyright © 2023 Alain M. (https://github.com/alainm23/planify)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * Authored by: Alain M. <alainmh23@gmail.com>
 */

#include "planify.h"
#include <gtk/gtk.h>
#include <gee.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	WIDGETS_REMINDER_PICKER_REMINDER_ROW_0_PROPERTY,
	WIDGETS_REMINDER_PICKER_REMINDER_ROW_REMINDER_PROPERTY,
	WIDGETS_REMINDER_PICKER_REMINDER_ROW_NUM_PROPERTIES
};
static GParamSpec* widgets_reminder_picker_reminder_row_properties[WIDGETS_REMINDER_PICKER_REMINDER_ROW_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block45Data Block45Data;
enum  {
	WIDGETS_REMINDER_PICKER_REMINDER_ROW_ACTIVATED_SIGNAL,
	WIDGETS_REMINDER_PICKER_REMINDER_ROW_DELETED_SIGNAL,
	WIDGETS_REMINDER_PICKER_REMINDER_ROW_NUM_SIGNALS
};
static guint widgets_reminder_picker_reminder_row_signals[WIDGETS_REMINDER_PICKER_REMINDER_ROW_NUM_SIGNALS] = {0};

struct _WidgetsReminderPickerReminderRowPrivate {
	ObjectsReminder* _reminder;
	GtkRevealer* main_revealer;
	GeeHashMap* signal_map;
};

struct _Block45Data {
	int _ref_count_;
	WidgetsReminderPickerReminderRow* self;
	WidgetsLoadingButton* remove_button;
};

static gint WidgetsReminderPickerReminderRow_private_offset;
static gpointer widgets_reminder_picker_reminder_row_parent_class = NULL;

static gboolean __lambda236_ (WidgetsReminderPickerReminderRow* self);
static gboolean ___lambda236__gsource_func (gpointer self);
static GObject * widgets_reminder_picker_reminder_row_constructor (GType type,
                                                            guint n_construct_properties,
                                                            GObjectConstructParam * construct_properties);
static Block45Data* block45_data_ref (Block45Data* _data45_);
static void block45_data_unref (void * _userdata_);
static gboolean _widgets_reminder_picker_reminder_row___lambda237_ (WidgetsReminderPickerReminderRow* self);
static gboolean __widgets_reminder_picker_reminder_row___lambda237__gsource_func (gpointer self);
static void _widgets_reminder_picker_reminder_row___lambda238_ (WidgetsReminderPickerReminderRow* self);
static void __widgets_reminder_picker_reminder_row___lambda238__gtk_button_clicked (GtkButton* _sender,
                                                                             gpointer self);
static void _widgets_reminder_picker_reminder_row___lambda239_ (Block45Data* _data45_);
static void __widgets_reminder_picker_reminder_row___lambda239__objects_base_object_loading_change (ObjectsBaseObject* _sender,
                                                                                             gpointer self);
static void widgets_reminder_picker_reminder_row_finalize (GObject * obj);
static GType widgets_reminder_picker_reminder_row_get_type_once (void);
static void _vala_widgets_reminder_picker_reminder_row_get_property (GObject * object,
                                                              guint property_id,
                                                              GValue * value,
                                                              GParamSpec * pspec);
static void _vala_widgets_reminder_picker_reminder_row_set_property (GObject * object,
                                                              guint property_id,
                                                              const GValue * value,
                                                              GParamSpec * pspec);
static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

static inline gpointer
widgets_reminder_picker_reminder_row_get_instance_private (WidgetsReminderPickerReminderRow* self)
{
	return G_STRUCT_MEMBER_P (self, WidgetsReminderPickerReminderRow_private_offset);
}

WidgetsReminderPickerReminderRow*
widgets_reminder_picker_reminder_row_construct (GType object_type,
                                                ObjectsReminder* reminder)
{
	WidgetsReminderPickerReminderRow * self = NULL;
	g_return_val_if_fail (reminder != NULL, NULL);
	self = (WidgetsReminderPickerReminderRow*) g_object_new (object_type, "reminder", reminder, NULL);
	return self;
}

WidgetsReminderPickerReminderRow*
widgets_reminder_picker_reminder_row_new (ObjectsReminder* reminder)
{
	return widgets_reminder_picker_reminder_row_construct (WIDGETS_REMINDER_PICKER_TYPE_REMINDER_ROW, reminder);
}

WidgetsReminderPickerReminderRow*
widgets_reminder_picker_reminder_row_construct_new (GType object_type)
{
	WidgetsReminderPickerReminderRow * self = NULL;
	ObjectsReminder* reminder = NULL;
	ObjectsReminder* _tmp0_;
	_tmp0_ = objects_reminder_new ();
	reminder = _tmp0_;
	self = (WidgetsReminderPickerReminderRow*) g_object_new (object_type, "reminder", reminder, NULL);
	_g_object_unref0 (reminder);
	return self;
}

WidgetsReminderPickerReminderRow*
widgets_reminder_picker_reminder_row_new_new (void)
{
	return widgets_reminder_picker_reminder_row_construct_new (WIDGETS_REMINDER_PICKER_TYPE_REMINDER_ROW);
}

static gboolean
__lambda236_ (WidgetsReminderPickerReminderRow* self)
{
	GtkWidget* _tmp0_;
	GtkWidget* _tmp1_;
	gboolean result;
	_tmp0_ = gtk_widget_get_parent ((GtkWidget*) self);
	_tmp1_ = _tmp0_;
	gtk_list_box_remove (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_list_box_get_type (), GtkListBox), (GtkWidget*) self);
	result = G_SOURCE_REMOVE;
	return result;
}

static gboolean
___lambda236__gsource_func (gpointer self)
{
	gboolean result;
	result = __lambda236_ ((WidgetsReminderPickerReminderRow*) self);
	return result;
}

void
widgets_reminder_picker_reminder_row_hide_destroy (WidgetsReminderPickerReminderRow* self)
{
	GtkRevealer* _tmp0_;
	GtkRevealer* _tmp1_;
	guint _tmp2_;
	guint _tmp3_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->main_revealer;
	gtk_revealer_set_reveal_child (_tmp0_, FALSE);
	widgets_reminder_picker_reminder_row_clean_up (self);
	_tmp1_ = self->priv->main_revealer;
	_tmp2_ = gtk_revealer_get_transition_duration (_tmp1_);
	_tmp3_ = _tmp2_;
	g_timeout_add_full (G_PRIORITY_DEFAULT, _tmp3_, ___lambda236__gsource_func, g_object_ref (self), g_object_unref);
}

void
widgets_reminder_picker_reminder_row_clean_up (WidgetsReminderPickerReminderRow* self)
{
	GeeHashMap* _tmp15_;
	g_return_if_fail (self != NULL);
	{
		GeeIterator* _entry_it = NULL;
		GeeHashMap* _tmp0_;
		GeeSet* _tmp1_;
		GeeSet* _tmp2_;
		GeeSet* _tmp3_;
		GeeIterator* _tmp4_;
		GeeIterator* _tmp5_;
		_tmp0_ = self->priv->signal_map;
		_tmp1_ = gee_abstract_map_get_entries ((GeeAbstractMap*) _tmp0_);
		_tmp2_ = _tmp1_;
		_tmp3_ = _tmp2_;
		_tmp4_ = gee_iterable_iterator ((GeeIterable*) _tmp3_);
		_tmp5_ = _tmp4_;
		_g_object_unref0 (_tmp3_);
		_entry_it = _tmp5_;
		while (TRUE) {
			GeeIterator* _tmp6_;
			GeeMapEntry* entry = NULL;
			GeeIterator* _tmp7_;
			gpointer _tmp8_;
			GeeMapEntry* _tmp9_;
			gconstpointer _tmp10_;
			gconstpointer _tmp11_;
			GeeMapEntry* _tmp12_;
			gconstpointer _tmp13_;
			gconstpointer _tmp14_;
			_tmp6_ = _entry_it;
			if (!gee_iterator_next (_tmp6_)) {
				break;
			}
			_tmp7_ = _entry_it;
			_tmp8_ = gee_iterator_get (_tmp7_);
			entry = (GeeMapEntry*) _tmp8_;
			_tmp9_ = entry;
			_tmp10_ = gee_map_entry_get_value (_tmp9_);
			_tmp11_ = _tmp10_;
			_tmp12_ = entry;
			_tmp13_ = gee_map_entry_get_key (_tmp12_);
			_tmp14_ = _tmp13_;
			g_signal_handler_disconnect ((GObject*) _tmp11_, (gulong) ((guintptr) _tmp14_));
			_g_object_unref0 (entry);
		}
		_g_object_unref0 (_entry_it);
	}
	_tmp15_ = self->priv->signal_map;
	gee_abstract_map_clear ((GeeAbstractMap*) _tmp15_);
}

ObjectsReminder*
widgets_reminder_picker_reminder_row_get_reminder (WidgetsReminderPickerReminderRow* self)
{
	ObjectsReminder* result;
	ObjectsReminder* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_reminder;
	result = _tmp0_;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
widgets_reminder_picker_reminder_row_set_reminder (WidgetsReminderPickerReminderRow* self,
                                                   ObjectsReminder* value)
{
	ObjectsReminder* old_value;
	g_return_if_fail (self != NULL);
	old_value = widgets_reminder_picker_reminder_row_get_reminder (self);
	if (old_value != value) {
		ObjectsReminder* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_reminder);
		self->priv->_reminder = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, widgets_reminder_picker_reminder_row_properties[WIDGETS_REMINDER_PICKER_REMINDER_ROW_REMINDER_PROPERTY]);
	}
}

static Block45Data*
block45_data_ref (Block45Data* _data45_)
{
	g_atomic_int_inc (&_data45_->_ref_count_);
	return _data45_;
}

static void
block45_data_unref (void * _userdata_)
{
	Block45Data* _data45_;
	_data45_ = (Block45Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data45_->_ref_count_)) {
		WidgetsReminderPickerReminderRow* self;
		self = _data45_->self;
		_g_object_unref0 (_data45_->remove_button);
		_g_object_unref0 (self);
		g_slice_free (Block45Data, _data45_);
	}
}

static gboolean
_widgets_reminder_picker_reminder_row___lambda237_ (WidgetsReminderPickerReminderRow* self)
{
	GtkRevealer* _tmp0_;
	gboolean result;
	_tmp0_ = self->priv->main_revealer;
	gtk_revealer_set_reveal_child (_tmp0_, TRUE);
	result = G_SOURCE_REMOVE;
	return result;
}

static gboolean
__widgets_reminder_picker_reminder_row___lambda237__gsource_func (gpointer self)
{
	gboolean result;
	result = _widgets_reminder_picker_reminder_row___lambda237_ ((WidgetsReminderPickerReminderRow*) self);
	return result;
}

static void
_widgets_reminder_picker_reminder_row___lambda238_ (WidgetsReminderPickerReminderRow* self)
{
	g_signal_emit (self, widgets_reminder_picker_reminder_row_signals[WIDGETS_REMINDER_PICKER_REMINDER_ROW_DELETED_SIGNAL], 0);
}

static void
__widgets_reminder_picker_reminder_row___lambda238__gtk_button_clicked (GtkButton* _sender,
                                                                        gpointer self)
{
	_widgets_reminder_picker_reminder_row___lambda238_ ((WidgetsReminderPickerReminderRow*) self);
}

static void
_widgets_reminder_picker_reminder_row___lambda239_ (Block45Data* _data45_)
{
	WidgetsReminderPickerReminderRow* self;
	WidgetsLoadingButton* _tmp0_;
	ObjectsReminder* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	self = _data45_->self;
	_tmp0_ = _data45_->remove_button;
	_tmp1_ = self->priv->_reminder;
	_tmp2_ = objects_base_object_get_loading ((ObjectsBaseObject*) _tmp1_);
	_tmp3_ = _tmp2_;
	widgets_loading_button_set_is_loading (_tmp0_, _tmp3_);
}

static void
__widgets_reminder_picker_reminder_row___lambda239__objects_base_object_loading_change (ObjectsBaseObject* _sender,
                                                                                        gpointer self)
{
	_widgets_reminder_picker_reminder_row___lambda239_ (self);
}

static GObject *
widgets_reminder_picker_reminder_row_constructor (GType type,
                                                  guint n_construct_properties,
                                                  GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	WidgetsReminderPickerReminderRow * self;
	Block45Data* _data45_;
	GtkLabel* reminder_label = NULL;
	ObjectsReminder* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	GtkLabel* _tmp3_;
	WidgetsLoadingButton* _tmp4_ = NULL;
	WidgetsLoadingButton* _tmp5_;
	WidgetsLoadingButton* _tmp6_;
	GtkBox* reminder_box = NULL;
	GtkBox* _tmp7_ = NULL;
	GtkBox* _tmp8_;
	GtkImage* _tmp9_;
	GtkImage* _tmp10_;
	GtkBox* _tmp11_;
	GtkLabel* _tmp12_;
	GtkBox* _tmp13_;
	WidgetsLoadingButton* _tmp14_;
	GtkBox* _tmp15_;
	GtkWidget* _tmp16_;
	GtkRevealer* _tmp17_ = NULL;
	GtkRevealer* _tmp18_;
	GtkRevealer* _tmp19_;
	guint _tmp20_;
	guint _tmp21_;
	GeeHashMap* _tmp22_;
	WidgetsLoadingButton* _tmp23_;
	gulong _tmp24_;
	WidgetsLoadingButton* _tmp25_;
	GeeHashMap* _tmp26_;
	ObjectsReminder* _tmp27_;
	gulong _tmp28_;
	ObjectsReminder* _tmp29_;
	parent_class = G_OBJECT_CLASS (widgets_reminder_picker_reminder_row_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, WIDGETS_REMINDER_PICKER_TYPE_REMINDER_ROW, WidgetsReminderPickerReminderRow);
	_data45_ = g_slice_new0 (Block45Data);
	_data45_->_ref_count_ = 1;
	_data45_->self = g_object_ref (self);
	gtk_widget_add_css_class ((GtkWidget*) self, "row");
	_tmp0_ = self->priv->_reminder;
	_tmp1_ = objects_reminder_get_relative_text (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = (GtkLabel*) gtk_label_new (_tmp2_);
	g_object_ref_sink (_tmp3_);
	reminder_label = _tmp3_;
	_tmp4_ = widgets_loading_button_new_with_icon ("cross-large-circle-filled-symbolic", 16);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp4_, TRUE);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp4_, 6);
	gtk_widget_set_halign ((GtkWidget*) _tmp4_, GTK_ALIGN_END);
	g_object_ref_sink (_tmp4_);
	_data45_->remove_button = _tmp4_;
	_tmp5_ = _data45_->remove_button;
	gtk_widget_add_css_class ((GtkWidget*) _tmp5_, "flat");
	_tmp6_ = _data45_->remove_button;
	gtk_widget_add_css_class ((GtkWidget*) _tmp6_, "no-padding");
	_tmp7_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp7_, 3);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp7_, 3);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp7_, 3);
	g_object_ref_sink (_tmp7_);
	reminder_box = _tmp7_;
	_tmp8_ = reminder_box;
	_tmp9_ = (GtkImage*) gtk_image_new_from_icon_name ("alarm-symbolic");
	g_object_ref_sink (_tmp9_);
	_tmp10_ = _tmp9_;
	gtk_box_append (_tmp8_, (GtkWidget*) _tmp10_);
	_g_object_unref0 (_tmp10_);
	_tmp11_ = reminder_box;
	_tmp12_ = reminder_label;
	gtk_box_append (_tmp11_, (GtkWidget*) _tmp12_);
	_tmp13_ = reminder_box;
	_tmp14_ = _data45_->remove_button;
	gtk_box_append (_tmp13_, (GtkWidget*) _tmp14_);
	_tmp15_ = reminder_box;
	_tmp16_ = _g_object_ref0 ((GtkWidget*) _tmp15_);
	_tmp17_ = (GtkRevealer*) gtk_revealer_new ();
	gtk_revealer_set_transition_type (_tmp17_, GTK_REVEALER_TRANSITION_TYPE_SLIDE_DOWN);
	gtk_revealer_set_child (_tmp17_, _tmp16_);
	_g_object_unref0 (_tmp16_);
	g_object_ref_sink (_tmp17_);
	_g_object_unref0 (self->priv->main_revealer);
	self->priv->main_revealer = _tmp17_;
	_tmp18_ = self->priv->main_revealer;
	gtk_list_box_row_set_child ((GtkListBoxRow*) self, (GtkWidget*) _tmp18_);
	_tmp19_ = self->priv->main_revealer;
	_tmp20_ = gtk_revealer_get_transition_duration (_tmp19_);
	_tmp21_ = _tmp20_;
	g_timeout_add_full (G_PRIORITY_DEFAULT, _tmp21_, __widgets_reminder_picker_reminder_row___lambda237__gsource_func, g_object_ref (self), g_object_unref);
	_tmp22_ = self->priv->signal_map;
	_tmp23_ = _data45_->remove_button;
	_tmp24_ = g_signal_connect_object ((GtkButton*) _tmp23_, "clicked", (GCallback) __widgets_reminder_picker_reminder_row___lambda238__gtk_button_clicked, self, 0);
	_tmp25_ = _data45_->remove_button;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp22_, (gpointer) ((guintptr) _tmp24_), (GObject*) _tmp25_);
	_tmp26_ = self->priv->signal_map;
	_tmp27_ = self->priv->_reminder;
	_tmp28_ = g_signal_connect_data ((ObjectsBaseObject*) _tmp27_, "loading-change", (GCallback) __widgets_reminder_picker_reminder_row___lambda239__objects_base_object_loading_change, block45_data_ref (_data45_), (GClosureNotify) block45_data_unref, 0);
	_tmp29_ = self->priv->_reminder;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp26_, (gpointer) ((guintptr) _tmp28_), (GObject*) _tmp29_);
	_g_object_unref0 (reminder_box);
	_g_object_unref0 (reminder_label);
	block45_data_unref (_data45_);
	_data45_ = NULL;
	return obj;
}

static void
widgets_reminder_picker_reminder_row_class_init (WidgetsReminderPickerReminderRowClass * klass,
                                                 gpointer klass_data)
{
	widgets_reminder_picker_reminder_row_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &WidgetsReminderPickerReminderRow_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_widgets_reminder_picker_reminder_row_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_widgets_reminder_picker_reminder_row_set_property;
	G_OBJECT_CLASS (klass)->constructor = widgets_reminder_picker_reminder_row_constructor;
	G_OBJECT_CLASS (klass)->finalize = widgets_reminder_picker_reminder_row_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), WIDGETS_REMINDER_PICKER_REMINDER_ROW_REMINDER_PROPERTY, widgets_reminder_picker_reminder_row_properties[WIDGETS_REMINDER_PICKER_REMINDER_ROW_REMINDER_PROPERTY] = g_param_spec_object ("reminder", "reminder", "reminder", OBJECTS_TYPE_REMINDER, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
	widgets_reminder_picker_reminder_row_signals[WIDGETS_REMINDER_PICKER_REMINDER_ROW_ACTIVATED_SIGNAL] = g_signal_new ("activated", WIDGETS_REMINDER_PICKER_TYPE_REMINDER_ROW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	widgets_reminder_picker_reminder_row_signals[WIDGETS_REMINDER_PICKER_REMINDER_ROW_DELETED_SIGNAL] = g_signal_new ("deleted", WIDGETS_REMINDER_PICKER_TYPE_REMINDER_ROW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
}

static void
widgets_reminder_picker_reminder_row_instance_init (WidgetsReminderPickerReminderRow * self,
                                                    gpointer klass)
{
	GeeHashMap* _tmp0_;
	self->priv = widgets_reminder_picker_reminder_row_get_instance_private (self);
	_tmp0_ = gee_hash_map_new (G_TYPE_ULONG, NULL, NULL, G_TYPE_OBJECT, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
	self->priv->signal_map = _tmp0_;
}

static void
widgets_reminder_picker_reminder_row_finalize (GObject * obj)
{
	WidgetsReminderPickerReminderRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, WIDGETS_REMINDER_PICKER_TYPE_REMINDER_ROW, WidgetsReminderPickerReminderRow);
	g_debug ("ReminderRow.vala:47: Destroying - Widgets.Widgets.ReminderPicker.Remin" \
"derRow\n");
	_g_object_unref0 (self->priv->_reminder);
	_g_object_unref0 (self->priv->main_revealer);
	_g_object_unref0 (self->priv->signal_map);
	G_OBJECT_CLASS (widgets_reminder_picker_reminder_row_parent_class)->finalize (obj);
}

static GType
widgets_reminder_picker_reminder_row_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (WidgetsReminderPickerReminderRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) widgets_reminder_picker_reminder_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (WidgetsReminderPickerReminderRow), 0, (GInstanceInitFunc) widgets_reminder_picker_reminder_row_instance_init, NULL };
	GType widgets_reminder_picker_reminder_row_type_id;
	widgets_reminder_picker_reminder_row_type_id = g_type_register_static (gtk_list_box_row_get_type (), "WidgetsReminderPickerReminderRow", &g_define_type_info, 0);
	WidgetsReminderPickerReminderRow_private_offset = g_type_add_instance_private (widgets_reminder_picker_reminder_row_type_id, sizeof (WidgetsReminderPickerReminderRowPrivate));
	return widgets_reminder_picker_reminder_row_type_id;
}

GType
widgets_reminder_picker_reminder_row_get_type (void)
{
	static volatile gsize widgets_reminder_picker_reminder_row_type_id__once = 0;
	if (g_once_init_enter (&widgets_reminder_picker_reminder_row_type_id__once)) {
		GType widgets_reminder_picker_reminder_row_type_id;
		widgets_reminder_picker_reminder_row_type_id = widgets_reminder_picker_reminder_row_get_type_once ();
		g_once_init_leave (&widgets_reminder_picker_reminder_row_type_id__once, widgets_reminder_picker_reminder_row_type_id);
	}
	return widgets_reminder_picker_reminder_row_type_id__once;
}

static void
_vala_widgets_reminder_picker_reminder_row_get_property (GObject * object,
                                                         guint property_id,
                                                         GValue * value,
                                                         GParamSpec * pspec)
{
	WidgetsReminderPickerReminderRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, WIDGETS_REMINDER_PICKER_TYPE_REMINDER_ROW, WidgetsReminderPickerReminderRow);
	switch (property_id) {
		case WIDGETS_REMINDER_PICKER_REMINDER_ROW_REMINDER_PROPERTY:
		g_value_set_object (value, widgets_reminder_picker_reminder_row_get_reminder (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_widgets_reminder_picker_reminder_row_set_property (GObject * object,
                                                         guint property_id,
                                                         const GValue * value,
                                                         GParamSpec * pspec)
{
	WidgetsReminderPickerReminderRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, WIDGETS_REMINDER_PICKER_TYPE_REMINDER_ROW, WidgetsReminderPickerReminderRow);
	switch (property_id) {
		case WIDGETS_REMINDER_PICKER_REMINDER_ROW_REMINDER_PROPERTY:
		widgets_reminder_picker_reminder_row_set_reminder (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

