/* ProjectPicker.c generated by valac 0.56.19, the Vala compiler
 * generated from ProjectPicker.vala, do not modify */

/*
 * Copyright © 2023 Alain M. (https://github.com/alainm23/planify)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * Authored by: Alain M. <alainmh23@gmail.com>
 */

#include <adwaita.h>
#include <glib-object.h>
#include "planify.h"
#include <glib.h>
#include <glib/gi18n-lib.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define DIALOGS_PROJECT_PICKER_TYPE_PROJECT_PICKER (dialogs_project_picker_project_picker_get_type ())
#define DIALOGS_PROJECT_PICKER_PROJECT_PICKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PROJECT_PICKER_TYPE_PROJECT_PICKER, DialogsProjectPickerProjectPicker))
#define DIALOGS_PROJECT_PICKER_PROJECT_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PROJECT_PICKER_TYPE_PROJECT_PICKER, DialogsProjectPickerProjectPickerClass))
#define DIALOGS_PROJECT_PICKER_IS_PROJECT_PICKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PROJECT_PICKER_TYPE_PROJECT_PICKER))
#define DIALOGS_PROJECT_PICKER_IS_PROJECT_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PROJECT_PICKER_TYPE_PROJECT_PICKER))
#define DIALOGS_PROJECT_PICKER_PROJECT_PICKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PROJECT_PICKER_TYPE_PROJECT_PICKER, DialogsProjectPickerProjectPickerClass))

typedef struct _DialogsProjectPickerProjectPicker DialogsProjectPickerProjectPicker;
typedef struct _DialogsProjectPickerProjectPickerClass DialogsProjectPickerProjectPickerClass;
typedef struct _DialogsProjectPickerProjectPickerPrivate DialogsProjectPickerProjectPickerPrivate;
enum  {
	DIALOGS_PROJECT_PICKER_PROJECT_PICKER_0_PROPERTY,
	DIALOGS_PROJECT_PICKER_PROJECT_PICKER_SOURCE_PROPERTY,
	DIALOGS_PROJECT_PICKER_PROJECT_PICKER_PROJECT_PROPERTY,
	DIALOGS_PROJECT_PICKER_PROJECT_PICKER_NUM_PROPERTIES
};
static GParamSpec* dialogs_project_picker_project_picker_properties[DIALOGS_PROJECT_PICKER_PROJECT_PICKER_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
enum  {
	DIALOGS_PROJECT_PICKER_PROJECT_PICKER_CHANGED_SIGNAL,
	DIALOGS_PROJECT_PICKER_PROJECT_PICKER_NUM_SIGNALS
};
static guint dialogs_project_picker_project_picker_signals[DIALOGS_PROJECT_PICKER_PROJECT_PICKER_NUM_SIGNALS] = {0};

struct _DialogsProjectPickerProjectPicker {
	AdwDialog parent_instance;
	DialogsProjectPickerProjectPickerPrivate * priv;
};

struct _DialogsProjectPickerProjectPickerClass {
	AdwDialogClass parent_class;
};

struct _DialogsProjectPickerProjectPickerPrivate {
	ObjectsSource* _source;
	WidgetsProjectPickerCore* project_picker_core;
};

static gint DialogsProjectPickerProjectPicker_private_offset;
static gpointer dialogs_project_picker_project_picker_parent_class = NULL;

VALA_EXTERN GType dialogs_project_picker_project_picker_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsProjectPickerProjectPicker, g_object_unref)
VALA_EXTERN DialogsProjectPickerProjectPicker* dialogs_project_picker_project_picker_new_for_source (ObjectsSource* source);
VALA_EXTERN DialogsProjectPickerProjectPicker* dialogs_project_picker_project_picker_construct_for_source (GType object_type,
                                                                                               ObjectsSource* source);
VALA_EXTERN DialogsProjectPickerProjectPicker* dialogs_project_picker_project_picker_new_for_projects (void);
VALA_EXTERN DialogsProjectPickerProjectPicker* dialogs_project_picker_project_picker_construct_for_projects (GType object_type);
VALA_EXTERN void dialogs_project_picker_project_picker_clean_up (DialogsProjectPickerProjectPicker* self);
VALA_EXTERN DialogsProjectPickerProjectPicker* dialogs_project_picker_project_picker_new (void);
VALA_EXTERN DialogsProjectPickerProjectPicker* dialogs_project_picker_project_picker_construct (GType object_type);
VALA_EXTERN ObjectsSource* dialogs_project_picker_project_picker_get_source (DialogsProjectPickerProjectPicker* self);
static void dialogs_project_picker_project_picker_set_source (DialogsProjectPickerProjectPicker* self,
                                                       ObjectsSource* value);
VALA_EXTERN void dialogs_project_picker_project_picker_set_project (DialogsProjectPickerProjectPicker* self,
                                                        ObjectsProject* value);
static void g_cclosure_user_marshal_VOID__STRING_STRING (GClosure * closure,
                                                  GValue * return_value,
                                                  guint n_param_values,
                                                  const GValue * param_values,
                                                  gpointer invocation_hint,
                                                  gpointer marshal_data);
static GObject * dialogs_project_picker_project_picker_constructor (GType type,
                                                             guint n_construct_properties,
                                                             GObjectConstructParam * construct_properties);
static void _dialogs_project_picker_project_picker___lambda56_ (DialogsProjectPickerProjectPicker* self,
                                                         ObjectsProject* project);
static void __dialogs_project_picker_project_picker___lambda56__widgets_project_picker_core_selected (WidgetsProjectPickerCore* _sender,
                                                                                               ObjectsProject* project,
                                                                                               gpointer self);
static void _dialogs_project_picker_project_picker___lambda57_ (DialogsProjectPickerProjectPicker* self);
static void __dialogs_project_picker_project_picker___lambda57__widgets_project_picker_core_close (WidgetsProjectPickerCore* _sender,
                                                                                            gpointer self);
static void _dialogs_project_picker_project_picker___lambda58_ (DialogsProjectPickerProjectPicker* self);
static void __dialogs_project_picker_project_picker___lambda58__adw_dialog_closed (AdwDialog* _sender,
                                                                            gpointer self);
static void dialogs_project_picker_project_picker_finalize (GObject * obj);
static GType dialogs_project_picker_project_picker_get_type_once (void);
static void _vala_dialogs_project_picker_project_picker_get_property (GObject * object,
                                                               guint property_id,
                                                               GValue * value,
                                                               GParamSpec * pspec);
static void _vala_dialogs_project_picker_project_picker_set_property (GObject * object,
                                                               guint property_id,
                                                               const GValue * value,
                                                               GParamSpec * pspec);

static inline gpointer
dialogs_project_picker_project_picker_get_instance_private (DialogsProjectPickerProjectPicker* self)
{
	return G_STRUCT_MEMBER_P (self, DialogsProjectPickerProjectPicker_private_offset);
}

DialogsProjectPickerProjectPicker*
dialogs_project_picker_project_picker_construct_for_source (GType object_type,
                                                            ObjectsSource* source)
{
	DialogsProjectPickerProjectPicker * self = NULL;
	g_return_val_if_fail (source != NULL, NULL);
	self = (DialogsProjectPickerProjectPicker*) g_object_new (object_type, "source", source, "title", _ ("Move"), "content-width", 400, "content-height", 550, NULL);
	return self;
}

DialogsProjectPickerProjectPicker*
dialogs_project_picker_project_picker_new_for_source (ObjectsSource* source)
{
	return dialogs_project_picker_project_picker_construct_for_source (DIALOGS_PROJECT_PICKER_TYPE_PROJECT_PICKER, source);
}

DialogsProjectPickerProjectPicker*
dialogs_project_picker_project_picker_construct_for_projects (GType object_type)
{
	DialogsProjectPickerProjectPicker * self = NULL;
	self = (DialogsProjectPickerProjectPicker*) g_object_new (object_type, "source", NULL, "title", _ ("Move"), "content-width", 400, "content-height", 550, NULL);
	return self;
}

DialogsProjectPickerProjectPicker*
dialogs_project_picker_project_picker_new_for_projects (void)
{
	return dialogs_project_picker_project_picker_construct_for_projects (DIALOGS_PROJECT_PICKER_TYPE_PROJECT_PICKER);
}

void
dialogs_project_picker_project_picker_clean_up (DialogsProjectPickerProjectPicker* self)
{
	WidgetsProjectPickerCore* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->project_picker_core;
	if (_tmp0_ != NULL) {
		WidgetsProjectPickerCore* _tmp1_;
		_tmp1_ = self->priv->project_picker_core;
		widgets_project_picker_core_clean_up (_tmp1_);
	}
}

DialogsProjectPickerProjectPicker*
dialogs_project_picker_project_picker_construct (GType object_type)
{
	DialogsProjectPickerProjectPicker * self = NULL;
	self = (DialogsProjectPickerProjectPicker*) g_object_new (object_type, NULL);
	return self;
}

DialogsProjectPickerProjectPicker*
dialogs_project_picker_project_picker_new (void)
{
	return dialogs_project_picker_project_picker_construct (DIALOGS_PROJECT_PICKER_TYPE_PROJECT_PICKER);
}

ObjectsSource*
dialogs_project_picker_project_picker_get_source (DialogsProjectPickerProjectPicker* self)
{
	ObjectsSource* result;
	ObjectsSource* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_source;
	result = _tmp0_;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
dialogs_project_picker_project_picker_set_source (DialogsProjectPickerProjectPicker* self,
                                                  ObjectsSource* value)
{
	ObjectsSource* old_value;
	g_return_if_fail (self != NULL);
	old_value = dialogs_project_picker_project_picker_get_source (self);
	if (old_value != value) {
		ObjectsSource* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_source);
		self->priv->_source = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, dialogs_project_picker_project_picker_properties[DIALOGS_PROJECT_PICKER_PROJECT_PICKER_SOURCE_PROPERTY]);
	}
}

void
dialogs_project_picker_project_picker_set_project (DialogsProjectPickerProjectPicker* self,
                                                   ObjectsProject* value)
{
	WidgetsProjectPickerCore* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->project_picker_core;
	widgets_project_picker_core_set_selected_project (_tmp0_, value);
	g_object_notify_by_pspec ((GObject *) self, dialogs_project_picker_project_picker_properties[DIALOGS_PROJECT_PICKER_PROJECT_PICKER_PROJECT_PROPERTY]);
}

static void
g_cclosure_user_marshal_VOID__STRING_STRING (GClosure * closure,
                                             GValue * return_value,
                                             guint n_param_values,
                                             const GValue * param_values,
                                             gpointer invocation_hint,
                                             gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__STRING_STRING) (gpointer data1, const char* arg_1, const char* arg_2, gpointer data2);
	register GMarshalFunc_VOID__STRING_STRING callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 3);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__STRING_STRING) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_string (param_values + 1), g_value_get_string (param_values + 2), data2);
}

static void
_dialogs_project_picker_project_picker___lambda56_ (DialogsProjectPickerProjectPicker* self,
                                                    ObjectsProject* project)
{
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	g_return_if_fail (project != NULL);
	_tmp0_ = objects_base_object_get_id ((ObjectsBaseObject*) project);
	_tmp1_ = _tmp0_;
	g_signal_emit (self, dialogs_project_picker_project_picker_signals[DIALOGS_PROJECT_PICKER_PROJECT_PICKER_CHANGED_SIGNAL], 0, "project", _tmp1_);
}

static void
__dialogs_project_picker_project_picker___lambda56__widgets_project_picker_core_selected (WidgetsProjectPickerCore* _sender,
                                                                                          ObjectsProject* project,
                                                                                          gpointer self)
{
	_dialogs_project_picker_project_picker___lambda56_ ((DialogsProjectPickerProjectPicker*) self, project);
}

static void
_dialogs_project_picker_project_picker___lambda57_ (DialogsProjectPickerProjectPicker* self)
{
	adw_dialog_close ((AdwDialog*) self);
}

static void
__dialogs_project_picker_project_picker___lambda57__widgets_project_picker_core_close (WidgetsProjectPickerCore* _sender,
                                                                                       gpointer self)
{
	_dialogs_project_picker_project_picker___lambda57_ ((DialogsProjectPickerProjectPicker*) self);
}

static void
_dialogs_project_picker_project_picker___lambda58_ (DialogsProjectPickerProjectPicker* self)
{
	ServicesEventBus* _tmp0_;
	ServicesEventBus* _tmp1_;
	dialogs_project_picker_project_picker_clean_up (self);
	_tmp0_ = services_event_bus_get_default ();
	_tmp1_ = _tmp0_;
	g_signal_emit_by_name (_tmp1_, "connect-all-accels");
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_project_picker_project_picker___lambda58__adw_dialog_closed (AdwDialog* _sender,
                                                                       gpointer self)
{
	_dialogs_project_picker_project_picker___lambda58_ ((DialogsProjectPickerProjectPicker*) self);
}

static GObject *
dialogs_project_picker_project_picker_constructor (GType type,
                                                   guint n_construct_properties,
                                                   GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	DialogsProjectPickerProjectPicker * self;
	ObjectsSource* _tmp0_;
	WidgetsProjectPickerCore* _tmp1_;
	AdwToolbarView* toolbar_view = NULL;
	WidgetsProjectPickerCore* _tmp2_;
	GtkWidget* _tmp3_;
	AdwToolbarView* _tmp4_ = NULL;
	AdwToolbarView* _tmp5_;
	AdwHeaderBar* _tmp6_;
	AdwHeaderBar* _tmp7_;
	AdwToolbarView* _tmp8_;
	ServicesEventBus* _tmp9_;
	ServicesEventBus* _tmp10_;
	WidgetsProjectPickerCore* _tmp11_;
	WidgetsProjectPickerCore* _tmp12_;
	parent_class = G_OBJECT_CLASS (dialogs_project_picker_project_picker_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DIALOGS_PROJECT_PICKER_TYPE_PROJECT_PICKER, DialogsProjectPickerProjectPicker);
	_tmp0_ = self->priv->_source;
	_tmp1_ = widgets_project_picker_core_new (_tmp0_);
	g_object_ref_sink (_tmp1_);
	_g_object_unref0 (self->priv->project_picker_core);
	self->priv->project_picker_core = _tmp1_;
	_tmp2_ = self->priv->project_picker_core;
	_tmp3_ = _g_object_ref0 ((GtkWidget*) _tmp2_);
	_tmp4_ = (AdwToolbarView*) adw_toolbar_view_new ();
	adw_toolbar_view_set_content (_tmp4_, _tmp3_);
	_g_object_unref0 (_tmp3_);
	g_object_ref_sink (_tmp4_);
	toolbar_view = _tmp4_;
	_tmp5_ = toolbar_view;
	_tmp6_ = (AdwHeaderBar*) adw_header_bar_new ();
	g_object_ref_sink (_tmp6_);
	_tmp7_ = _tmp6_;
	adw_toolbar_view_add_top_bar (_tmp5_, (GtkWidget*) _tmp7_);
	_g_object_unref0 (_tmp7_);
	_tmp8_ = toolbar_view;
	adw_dialog_set_child ((AdwDialog*) self, (GtkWidget*) _tmp8_);
	_tmp9_ = services_event_bus_get_default ();
	_tmp10_ = _tmp9_;
	g_signal_emit_by_name (_tmp10_, "disconnect-all-accels");
	_g_object_unref0 (_tmp10_);
	_tmp11_ = self->priv->project_picker_core;
	g_signal_connect_object (_tmp11_, "selected", (GCallback) __dialogs_project_picker_project_picker___lambda56__widgets_project_picker_core_selected, self, 0);
	_tmp12_ = self->priv->project_picker_core;
	g_signal_connect_object (_tmp12_, "close", (GCallback) __dialogs_project_picker_project_picker___lambda57__widgets_project_picker_core_close, self, 0);
	g_signal_connect_object ((AdwDialog*) self, "closed", (GCallback) __dialogs_project_picker_project_picker___lambda58__adw_dialog_closed, self, 0);
	_g_object_unref0 (toolbar_view);
	return obj;
}

static void
dialogs_project_picker_project_picker_class_init (DialogsProjectPickerProjectPickerClass * klass,
                                                  gpointer klass_data)
{
	dialogs_project_picker_project_picker_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &DialogsProjectPickerProjectPicker_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_dialogs_project_picker_project_picker_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_dialogs_project_picker_project_picker_set_property;
	G_OBJECT_CLASS (klass)->constructor = dialogs_project_picker_project_picker_constructor;
	G_OBJECT_CLASS (klass)->finalize = dialogs_project_picker_project_picker_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), DIALOGS_PROJECT_PICKER_PROJECT_PICKER_SOURCE_PROPERTY, dialogs_project_picker_project_picker_properties[DIALOGS_PROJECT_PICKER_PROJECT_PICKER_SOURCE_PROPERTY] = g_param_spec_object ("source", "source", "source", OBJECTS_TYPE_SOURCE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
	g_object_class_install_property (G_OBJECT_CLASS (klass), DIALOGS_PROJECT_PICKER_PROJECT_PICKER_PROJECT_PROPERTY, dialogs_project_picker_project_picker_properties[DIALOGS_PROJECT_PICKER_PROJECT_PICKER_PROJECT_PROPERTY] = g_param_spec_object ("project", "project", "project", OBJECTS_TYPE_PROJECT, G_PARAM_STATIC_STRINGS | G_PARAM_WRITABLE));
	dialogs_project_picker_project_picker_signals[DIALOGS_PROJECT_PICKER_PROJECT_PICKER_CHANGED_SIGNAL] = g_signal_new ("changed", DIALOGS_PROJECT_PICKER_TYPE_PROJECT_PICKER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_STRING, G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_STRING);
}

static void
dialogs_project_picker_project_picker_instance_init (DialogsProjectPickerProjectPicker * self,
                                                     gpointer klass)
{
	self->priv = dialogs_project_picker_project_picker_get_instance_private (self);
}

static void
dialogs_project_picker_project_picker_finalize (GObject * obj)
{
	DialogsProjectPickerProjectPicker * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DIALOGS_PROJECT_PICKER_TYPE_PROJECT_PICKER, DialogsProjectPickerProjectPicker);
	g_debug ("ProjectPicker.vala:54: Destroying Dialogs.ProjectPicker.ProjectPicker\n");
	_g_object_unref0 (self->priv->_source);
	_g_object_unref0 (self->priv->project_picker_core);
	G_OBJECT_CLASS (dialogs_project_picker_project_picker_parent_class)->finalize (obj);
}

static GType
dialogs_project_picker_project_picker_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (DialogsProjectPickerProjectPickerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dialogs_project_picker_project_picker_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DialogsProjectPickerProjectPicker), 0, (GInstanceInitFunc) dialogs_project_picker_project_picker_instance_init, NULL };
	GType dialogs_project_picker_project_picker_type_id;
	dialogs_project_picker_project_picker_type_id = g_type_register_static (adw_dialog_get_type (), "DialogsProjectPickerProjectPicker", &g_define_type_info, 0);
	DialogsProjectPickerProjectPicker_private_offset = g_type_add_instance_private (dialogs_project_picker_project_picker_type_id, sizeof (DialogsProjectPickerProjectPickerPrivate));
	return dialogs_project_picker_project_picker_type_id;
}

GType
dialogs_project_picker_project_picker_get_type (void)
{
	static volatile gsize dialogs_project_picker_project_picker_type_id__once = 0;
	if (g_once_init_enter (&dialogs_project_picker_project_picker_type_id__once)) {
		GType dialogs_project_picker_project_picker_type_id;
		dialogs_project_picker_project_picker_type_id = dialogs_project_picker_project_picker_get_type_once ();
		g_once_init_leave (&dialogs_project_picker_project_picker_type_id__once, dialogs_project_picker_project_picker_type_id);
	}
	return dialogs_project_picker_project_picker_type_id__once;
}

static void
_vala_dialogs_project_picker_project_picker_get_property (GObject * object,
                                                          guint property_id,
                                                          GValue * value,
                                                          GParamSpec * pspec)
{
	DialogsProjectPickerProjectPicker * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, DIALOGS_PROJECT_PICKER_TYPE_PROJECT_PICKER, DialogsProjectPickerProjectPicker);
	switch (property_id) {
		case DIALOGS_PROJECT_PICKER_PROJECT_PICKER_SOURCE_PROPERTY:
		g_value_set_object (value, dialogs_project_picker_project_picker_get_source (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_dialogs_project_picker_project_picker_set_property (GObject * object,
                                                          guint property_id,
                                                          const GValue * value,
                                                          GParamSpec * pspec)
{
	DialogsProjectPickerProjectPicker * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, DIALOGS_PROJECT_PICKER_TYPE_PROJECT_PICKER, DialogsProjectPickerProjectPicker);
	switch (property_id) {
		case DIALOGS_PROJECT_PICKER_PROJECT_PICKER_SOURCE_PROPERTY:
		dialogs_project_picker_project_picker_set_source (self, g_value_get_object (value));
		break;
		case DIALOGS_PROJECT_PICKER_PROJECT_PICKER_PROJECT_PROPERTY:
		dialogs_project_picker_project_picker_set_project (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

