/* TaskSetting.c generated by valac 0.56.19, the Vala compiler
 * generated from TaskSetting.vala, do not modify */

/*
 * Copyright © 2025 Alain M. (https://github.com/alainm23/planify)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * Authored by: Alain M. <alainmh23@gmail.com>
 */

#include <adwaita.h>
#include <glib-object.h>
#include <gee.h>
#include <glib.h>
#include <glib/gi18n-lib.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include "planify.h"
#include <gio/gio.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE (dialogs_preferences_pages_base_page_get_type ())
#define DIALOGS_PREFERENCES_PAGES_BASE_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, DialogsPreferencesPagesBasePage))
#define DIALOGS_PREFERENCES_PAGES_BASE_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, DialogsPreferencesPagesBasePageClass))
#define DIALOGS_PREFERENCES_PAGES_IS_BASE_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE))
#define DIALOGS_PREFERENCES_PAGES_IS_BASE_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE))
#define DIALOGS_PREFERENCES_PAGES_BASE_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, DialogsPreferencesPagesBasePageClass))

typedef struct _DialogsPreferencesPagesBasePage DialogsPreferencesPagesBasePage;
typedef struct _DialogsPreferencesPagesBasePageClass DialogsPreferencesPagesBasePageClass;
typedef struct _DialogsPreferencesPagesBasePagePrivate DialogsPreferencesPagesBasePagePrivate;

#define DIALOGS_PREFERENCES_PAGES_TYPE_TASK_SETTING (dialogs_preferences_pages_task_setting_get_type ())
#define DIALOGS_PREFERENCES_PAGES_TASK_SETTING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_TASK_SETTING, DialogsPreferencesPagesTaskSetting))
#define DIALOGS_PREFERENCES_PAGES_TASK_SETTING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_TASK_SETTING, DialogsPreferencesPagesTaskSettingClass))
#define DIALOGS_PREFERENCES_PAGES_IS_TASK_SETTING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_TASK_SETTING))
#define DIALOGS_PREFERENCES_PAGES_IS_TASK_SETTING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_TASK_SETTING))
#define DIALOGS_PREFERENCES_PAGES_TASK_SETTING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_TASK_SETTING, DialogsPreferencesPagesTaskSettingClass))

typedef struct _DialogsPreferencesPagesTaskSetting DialogsPreferencesPagesTaskSetting;
typedef struct _DialogsPreferencesPagesTaskSettingClass DialogsPreferencesPagesTaskSettingClass;
typedef struct _DialogsPreferencesPagesTaskSettingPrivate DialogsPreferencesPagesTaskSettingPrivate;
enum  {
	DIALOGS_PREFERENCES_PAGES_TASK_SETTING_0_PROPERTY,
	DIALOGS_PREFERENCES_PAGES_TASK_SETTING_NUM_PROPERTIES
};
static GParamSpec* dialogs_preferences_pages_task_setting_properties[DIALOGS_PREFERENCES_PAGES_TASK_SETTING_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define WIDGETS_TYPE_COMBO_WRAP_ROW (widgets_combo_wrap_row_get_type ())
#define WIDGETS_COMBO_WRAP_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_COMBO_WRAP_ROW, WidgetsComboWrapRow))
#define WIDGETS_COMBO_WRAP_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_COMBO_WRAP_ROW, WidgetsComboWrapRowClass))
#define WIDGETS_IS_COMBO_WRAP_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_COMBO_WRAP_ROW))
#define WIDGETS_IS_COMBO_WRAP_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_COMBO_WRAP_ROW))
#define WIDGETS_COMBO_WRAP_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_COMBO_WRAP_ROW, WidgetsComboWrapRowClass))

typedef struct _WidgetsComboWrapRow WidgetsComboWrapRow;
typedef struct _WidgetsComboWrapRowClass WidgetsComboWrapRowClass;
typedef struct _Block104Data Block104Data;
#define _g_free0(var) (var = (g_free (var), NULL))

struct _DialogsPreferencesPagesBasePage {
	AdwNavigationPage parent_instance;
	DialogsPreferencesPagesBasePagePrivate * priv;
	GeeHashMap* signal_map;
};

struct _DialogsPreferencesPagesBasePageClass {
	AdwNavigationPageClass parent_class;
	void (*clean_up) (DialogsPreferencesPagesBasePage* self);
};

struct _DialogsPreferencesPagesTaskSetting {
	DialogsPreferencesPagesBasePage parent_instance;
	DialogsPreferencesPagesTaskSettingPrivate * priv;
};

struct _DialogsPreferencesPagesTaskSettingClass {
	DialogsPreferencesPagesBasePageClass parent_class;
};

struct _Block104Data {
	int _ref_count_;
	DialogsPreferencesPagesTaskSetting* self;
	WidgetsComboWrapRow* complete_tasks_row;
	AdwComboRow* default_priority_row;
	GtkSwitch* underline_completed_switch;
	AdwComboRow* tasks_position_row;
	WidgetsComboWrapRow* reminders_comborow;
};

static gpointer dialogs_preferences_pages_task_setting_parent_class = NULL;

VALA_EXTERN GType dialogs_preferences_pages_base_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesBasePage, g_object_unref)
VALA_EXTERN GType dialogs_preferences_pages_task_setting_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesTaskSetting, g_object_unref)
VALA_EXTERN void dialogs_preferences_pages_base_page_clean_up (DialogsPreferencesPagesBasePage* self);
VALA_EXTERN DialogsPreferencesPagesTaskSetting* dialogs_preferences_pages_task_setting_new (AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN DialogsPreferencesPagesTaskSetting* dialogs_preferences_pages_task_setting_construct (GType object_type,
                                                                                      AdwPreferencesDialog* preferences_dialog);
static void dialogs_preferences_pages_task_setting_real_clean_up (DialogsPreferencesPagesBasePage* base);
static GObject * dialogs_preferences_pages_task_setting_constructor (GType type,
                                                              guint n_construct_properties,
                                                              GObjectConstructParam * construct_properties);
VALA_EXTERN GType widgets_combo_wrap_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsComboWrapRow, g_object_unref)
static Block104Data* block104_data_ref (Block104Data* _data104_);
static void block104_data_unref (void * _userdata_);
VALA_EXTERN WidgetsComboWrapRow* widgets_combo_wrap_row_new (void);
VALA_EXTERN WidgetsComboWrapRow* widgets_combo_wrap_row_construct (GType object_type);
VALA_EXTERN void widgets_combo_wrap_row_set_title (WidgetsComboWrapRow* self,
                                       const gchar* value);
VALA_EXTERN void widgets_combo_wrap_row_set_subtitle (WidgetsComboWrapRow* self,
                                          const gchar* value);
VALA_EXTERN void widgets_combo_wrap_row_set_model (WidgetsComboWrapRow* self,
                                       GtkStringList* value);
VALA_EXTERN void widgets_combo_wrap_row_set_selected (WidgetsComboWrapRow* self,
                                          gint value);
static void _dialogs_preferences_pages_task_setting___lambda414_ (Block104Data* _data104_);
VALA_EXTERN gint widgets_combo_wrap_row_get_selected (WidgetsComboWrapRow* self);
static void __dialogs_preferences_pages_task_setting___lambda414__g_object_notify (GObject* _sender,
                                                                            GParamSpec* pspec,
                                                                            gpointer self);
static void _dialogs_preferences_pages_task_setting___lambda415_ (Block104Data* _data104_);
static void __dialogs_preferences_pages_task_setting___lambda415__g_object_notify (GObject* _sender,
                                                                            GParamSpec* pspec,
                                                                            gpointer self);
static void _dialogs_preferences_pages_task_setting___lambda416_ (Block104Data* _data104_);
static void __dialogs_preferences_pages_task_setting___lambda416__g_object_notify (GObject* _sender,
                                                                            GParamSpec* pspec,
                                                                            gpointer self);
static void _dialogs_preferences_pages_task_setting___lambda417_ (Block104Data* _data104_);
static void __dialogs_preferences_pages_task_setting___lambda417__g_object_notify (GObject* _sender,
                                                                            GParamSpec* pspec,
                                                                            gpointer self);
static void _dialogs_preferences_pages_task_setting___lambda418_ (Block104Data* _data104_);
static void __dialogs_preferences_pages_task_setting___lambda418__g_object_notify (GObject* _sender,
                                                                            GParamSpec* pspec,
                                                                            gpointer self);
static void _dialogs_preferences_pages_task_setting___lambda419_ (DialogsPreferencesPagesTaskSetting* self);
static void __dialogs_preferences_pages_task_setting___lambda419__gtk_widget_destroy (GtkWidget* _sender,
                                                                               gpointer self);
static void dialogs_preferences_pages_task_setting_finalize (GObject * obj);
static GType dialogs_preferences_pages_task_setting_get_type_once (void);

DialogsPreferencesPagesTaskSetting*
dialogs_preferences_pages_task_setting_construct (GType object_type,
                                                  AdwPreferencesDialog* preferences_dialog)
{
	DialogsPreferencesPagesTaskSetting * self = NULL;
	g_return_val_if_fail (preferences_dialog != NULL, NULL);
	self = (DialogsPreferencesPagesTaskSetting*) g_object_new (object_type, "preferences-dialog", preferences_dialog, "title", _ ("Task Settings"), NULL);
	return self;
}

DialogsPreferencesPagesTaskSetting*
dialogs_preferences_pages_task_setting_new (AdwPreferencesDialog* preferences_dialog)
{
	return dialogs_preferences_pages_task_setting_construct (DIALOGS_PREFERENCES_PAGES_TYPE_TASK_SETTING, preferences_dialog);
}

static void
dialogs_preferences_pages_task_setting_real_clean_up (DialogsPreferencesPagesBasePage* base)
{
	DialogsPreferencesPagesTaskSetting * self;
	GeeHashMap* _tmp15_;
	self = (DialogsPreferencesPagesTaskSetting*) base;
	{
		GeeIterator* _entry_it = NULL;
		GeeHashMap* _tmp0_;
		GeeSet* _tmp1_;
		GeeSet* _tmp2_;
		GeeSet* _tmp3_;
		GeeIterator* _tmp4_;
		GeeIterator* _tmp5_;
		_tmp0_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
		_tmp1_ = gee_abstract_map_get_entries ((GeeAbstractMap*) _tmp0_);
		_tmp2_ = _tmp1_;
		_tmp3_ = _tmp2_;
		_tmp4_ = gee_iterable_iterator ((GeeIterable*) _tmp3_);
		_tmp5_ = _tmp4_;
		_g_object_unref0 (_tmp3_);
		_entry_it = _tmp5_;
		while (TRUE) {
			GeeIterator* _tmp6_;
			GeeMapEntry* entry = NULL;
			GeeIterator* _tmp7_;
			gpointer _tmp8_;
			GeeMapEntry* _tmp9_;
			gconstpointer _tmp10_;
			gconstpointer _tmp11_;
			GeeMapEntry* _tmp12_;
			gconstpointer _tmp13_;
			gconstpointer _tmp14_;
			_tmp6_ = _entry_it;
			if (!gee_iterator_next (_tmp6_)) {
				break;
			}
			_tmp7_ = _entry_it;
			_tmp8_ = gee_iterator_get (_tmp7_);
			entry = (GeeMapEntry*) _tmp8_;
			_tmp9_ = entry;
			_tmp10_ = gee_map_entry_get_value (_tmp9_);
			_tmp11_ = _tmp10_;
			_tmp12_ = entry;
			_tmp13_ = gee_map_entry_get_key (_tmp12_);
			_tmp14_ = _tmp13_;
			g_signal_handler_disconnect ((GObject*) _tmp11_, (gulong) ((guintptr) _tmp14_));
			_g_object_unref0 (entry);
		}
		_g_object_unref0 (_entry_it);
	}
	_tmp15_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	gee_abstract_map_clear ((GeeAbstractMap*) _tmp15_);
}

static Block104Data*
block104_data_ref (Block104Data* _data104_)
{
	g_atomic_int_inc (&_data104_->_ref_count_);
	return _data104_;
}

static void
block104_data_unref (void * _userdata_)
{
	Block104Data* _data104_;
	_data104_ = (Block104Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data104_->_ref_count_)) {
		DialogsPreferencesPagesTaskSetting* self;
		self = _data104_->self;
		_g_object_unref0 (_data104_->reminders_comborow);
		_g_object_unref0 (_data104_->tasks_position_row);
		_g_object_unref0 (_data104_->underline_completed_switch);
		_g_object_unref0 (_data104_->default_priority_row);
		_g_object_unref0 (_data104_->complete_tasks_row);
		_g_object_unref0 (self);
		g_slice_free (Block104Data, _data104_);
	}
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
_dialogs_preferences_pages_task_setting___lambda414_ (Block104Data* _data104_)
{
	DialogsPreferencesPagesTaskSetting* self;
	ServicesSettings* _tmp0_;
	ServicesSettings* _tmp1_;
	GSettings* _tmp2_;
	WidgetsComboWrapRow* _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
	self = _data104_->self;
	_tmp0_ = services_settings_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_->settings;
	_tmp3_ = _data104_->complete_tasks_row;
	_tmp4_ = widgets_combo_wrap_row_get_selected (_tmp3_);
	_tmp5_ = _tmp4_;
	g_settings_set_enum (_tmp2_, "complete-task", _tmp5_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_pages_task_setting___lambda414__g_object_notify (GObject* _sender,
                                                                       GParamSpec* pspec,
                                                                       gpointer self)
{
	_dialogs_preferences_pages_task_setting___lambda414_ (self);
}

static void
_dialogs_preferences_pages_task_setting___lambda415_ (Block104Data* _data104_)
{
	DialogsPreferencesPagesTaskSetting* self;
	ServicesSettings* _tmp0_;
	ServicesSettings* _tmp1_;
	GSettings* _tmp2_;
	AdwComboRow* _tmp3_;
	guint _tmp4_;
	guint _tmp5_;
	self = _data104_->self;
	_tmp0_ = services_settings_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_->settings;
	_tmp3_ = _data104_->default_priority_row;
	_tmp4_ = adw_combo_row_get_selected (_tmp3_);
	_tmp5_ = _tmp4_;
	g_settings_set_enum (_tmp2_, "default-priority", (gint) _tmp5_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_pages_task_setting___lambda415__g_object_notify (GObject* _sender,
                                                                       GParamSpec* pspec,
                                                                       gpointer self)
{
	_dialogs_preferences_pages_task_setting___lambda415_ (self);
}

static void
_dialogs_preferences_pages_task_setting___lambda416_ (Block104Data* _data104_)
{
	DialogsPreferencesPagesTaskSetting* self;
	ServicesSettings* _tmp0_;
	ServicesSettings* _tmp1_;
	GSettings* _tmp2_;
	AdwComboRow* _tmp3_;
	guint _tmp4_;
	guint _tmp5_;
	self = _data104_->self;
	_tmp0_ = services_settings_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_->settings;
	_tmp3_ = _data104_->tasks_position_row;
	_tmp4_ = adw_combo_row_get_selected (_tmp3_);
	_tmp5_ = _tmp4_;
	g_settings_set_enum (_tmp2_, "new-tasks-position", (gint) _tmp5_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_pages_task_setting___lambda416__g_object_notify (GObject* _sender,
                                                                       GParamSpec* pspec,
                                                                       gpointer self)
{
	_dialogs_preferences_pages_task_setting___lambda416_ (self);
}

static void
_dialogs_preferences_pages_task_setting___lambda417_ (Block104Data* _data104_)
{
	DialogsPreferencesPagesTaskSetting* self;
	ServicesSettings* _tmp0_;
	ServicesSettings* _tmp1_;
	GSettings* _tmp2_;
	GtkSwitch* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	self = _data104_->self;
	_tmp0_ = services_settings_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_->settings;
	_tmp3_ = _data104_->underline_completed_switch;
	_tmp4_ = gtk_switch_get_active (_tmp3_);
	_tmp5_ = _tmp4_;
	g_settings_set_boolean (_tmp2_, "underline-completed-tasks", _tmp5_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_pages_task_setting___lambda417__g_object_notify (GObject* _sender,
                                                                       GParamSpec* pspec,
                                                                       gpointer self)
{
	_dialogs_preferences_pages_task_setting___lambda417_ (self);
}

static void
_dialogs_preferences_pages_task_setting___lambda418_ (Block104Data* _data104_)
{
	DialogsPreferencesPagesTaskSetting* self;
	ServicesSettings* _tmp0_;
	ServicesSettings* _tmp1_;
	GSettings* _tmp2_;
	WidgetsComboWrapRow* _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
	self = _data104_->self;
	_tmp0_ = services_settings_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_->settings;
	_tmp3_ = _data104_->reminders_comborow;
	_tmp4_ = widgets_combo_wrap_row_get_selected (_tmp3_);
	_tmp5_ = _tmp4_;
	g_settings_set_enum (_tmp2_, "automatic-reminders", _tmp5_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_pages_task_setting___lambda418__g_object_notify (GObject* _sender,
                                                                       GParamSpec* pspec,
                                                                       gpointer self)
{
	_dialogs_preferences_pages_task_setting___lambda418_ (self);
}

static void
_dialogs_preferences_pages_task_setting___lambda419_ (DialogsPreferencesPagesTaskSetting* self)
{
	dialogs_preferences_pages_base_page_clean_up ((DialogsPreferencesPagesBasePage*) self);
}

static void
__dialogs_preferences_pages_task_setting___lambda419__gtk_widget_destroy (GtkWidget* _sender,
                                                                          gpointer self)
{
	_dialogs_preferences_pages_task_setting___lambda419_ ((DialogsPreferencesPagesTaskSetting*) self);
}

static GObject *
dialogs_preferences_pages_task_setting_constructor (GType type,
                                                    guint n_construct_properties,
                                                    GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	DialogsPreferencesPagesTaskSetting * self;
	Block104Data* _data104_;
	AdwPreferencesGroup* group = NULL;
	gchar* _tmp0_;
	AdwPreferencesGroup* _tmp1_ = NULL;
	GtkStringList* complete_tasks_model = NULL;
	GtkStringList* _tmp2_;
	GtkStringList* _tmp3_;
	GtkStringList* _tmp4_;
	WidgetsComboWrapRow* _tmp5_;
	WidgetsComboWrapRow* _tmp6_;
	WidgetsComboWrapRow* _tmp7_;
	WidgetsComboWrapRow* _tmp8_;
	GtkStringList* _tmp9_;
	WidgetsComboWrapRow* _tmp10_;
	ServicesSettings* _tmp11_;
	ServicesSettings* _tmp12_;
	GSettings* _tmp13_;
	AdwPreferencesGroup* _tmp14_;
	WidgetsComboWrapRow* _tmp15_;
	GtkStringList* default_priority_model = NULL;
	GtkStringList* _tmp16_;
	GtkStringList* _tmp17_;
	GtkStringList* _tmp18_;
	GtkStringList* _tmp19_;
	GtkStringList* _tmp20_;
	AdwComboRow* _tmp21_;
	AdwComboRow* _tmp22_;
	AdwComboRow* _tmp23_;
	GtkStringList* _tmp24_;
	AdwComboRow* _tmp25_;
	ServicesSettings* _tmp26_;
	ServicesSettings* _tmp27_;
	GSettings* _tmp28_;
	AdwPreferencesGroup* _tmp29_;
	AdwComboRow* _tmp30_;
	ServicesSettings* _tmp31_;
	ServicesSettings* _tmp32_;
	GSettings* _tmp33_;
	GtkSwitch* _tmp34_ = NULL;
	GtkSwitch* _tmp35_;
	AdwActionRow* underline_completed_row = NULL;
	AdwActionRow* _tmp36_;
	AdwActionRow* _tmp37_;
	AdwActionRow* _tmp38_;
	GtkSwitch* _tmp39_;
	AdwActionRow* _tmp40_;
	GtkSwitch* _tmp41_;
	AdwPreferencesGroup* _tmp42_;
	AdwActionRow* _tmp43_;
	GtkStringList* tasks_position_model = NULL;
	GtkStringList* _tmp44_;
	GtkStringList* _tmp45_;
	GtkStringList* _tmp46_;
	AdwComboRow* _tmp47_;
	AdwComboRow* _tmp48_;
	AdwComboRow* _tmp49_;
	GtkStringList* _tmp50_;
	AdwComboRow* _tmp51_;
	ServicesSettings* _tmp52_;
	ServicesSettings* _tmp53_;
	GSettings* _tmp54_;
	AdwPreferencesGroup* _tmp55_;
	AdwComboRow* _tmp56_;
	AdwSwitchRow* show_completed_subtasks = NULL;
	AdwSwitchRow* _tmp57_;
	AdwSwitchRow* _tmp58_;
	AdwSwitchRow* _tmp59_;
	ServicesSettings* _tmp60_;
	ServicesSettings* _tmp61_;
	GSettings* _tmp62_;
	AdwSwitchRow* _tmp63_;
	AdwPreferencesGroup* _tmp64_;
	AdwSwitchRow* _tmp65_;
	AdwSwitchRow* task_complete_tone = NULL;
	AdwSwitchRow* _tmp66_;
	AdwSwitchRow* _tmp67_;
	AdwSwitchRow* _tmp68_;
	ServicesSettings* _tmp69_;
	ServicesSettings* _tmp70_;
	GSettings* _tmp71_;
	AdwSwitchRow* _tmp72_;
	AdwPreferencesGroup* _tmp73_;
	AdwSwitchRow* _tmp74_;
	AdwSwitchRow* open_task_sidebar = NULL;
	AdwSwitchRow* _tmp75_;
	AdwSwitchRow* _tmp76_;
	AdwSwitchRow* _tmp77_;
	ServicesSettings* _tmp78_;
	ServicesSettings* _tmp79_;
	GSettings* _tmp80_;
	AdwSwitchRow* _tmp81_;
	AdwPreferencesGroup* _tmp82_;
	AdwSwitchRow* _tmp83_;
	AdwSwitchRow* attention_at_one = NULL;
	AdwSwitchRow* _tmp84_;
	AdwSwitchRow* _tmp85_;
	AdwSwitchRow* _tmp86_;
	ServicesSettings* _tmp87_;
	ServicesSettings* _tmp88_;
	GSettings* _tmp89_;
	AdwSwitchRow* _tmp90_;
	ServicesSettings* _tmp91_;
	ServicesSettings* _tmp92_;
	GSettings* _tmp93_;
	AdwSwitchRow* _tmp94_;
	AdwPreferencesGroup* _tmp95_;
	AdwSwitchRow* _tmp96_;
	AdwSwitchRow* markdown_item = NULL;
	AdwSwitchRow* _tmp97_;
	AdwSwitchRow* _tmp98_;
	AdwSwitchRow* _tmp99_;
	ServicesSettings* _tmp100_;
	ServicesSettings* _tmp101_;
	GSettings* _tmp102_;
	AdwSwitchRow* _tmp103_;
	AdwPreferencesGroup* _tmp104_;
	AdwSwitchRow* _tmp105_;
	AdwSwitchRow* always_show_sidebar_item = NULL;
	AdwSwitchRow* _tmp106_;
	AdwSwitchRow* _tmp107_;
	AdwSwitchRow* _tmp108_;
	ServicesSettings* _tmp109_;
	ServicesSettings* _tmp110_;
	GSettings* _tmp111_;
	AdwSwitchRow* _tmp112_;
	AdwPreferencesGroup* _tmp113_;
	AdwSwitchRow* _tmp114_;
	AdwSwitchRow* spell_checking_item = NULL;
	AdwSwitchRow* _tmp115_;
	AdwSwitchRow* _tmp116_;
	AdwSwitchRow* _tmp117_;
	ServicesSettings* _tmp118_;
	ServicesSettings* _tmp119_;
	GSettings* _tmp120_;
	AdwSwitchRow* _tmp121_;
	AdwPreferencesGroup* _tmp122_;
	AdwSwitchRow* _tmp123_;
	AdwPreferencesGroup* reminders_group = NULL;
	gchar* _tmp124_;
	AdwPreferencesGroup* _tmp125_ = NULL;
	AdwSwitchRow* automatic_reminders = NULL;
	AdwSwitchRow* _tmp126_;
	AdwSwitchRow* _tmp127_;
	ServicesSettings* _tmp128_;
	ServicesSettings* _tmp129_;
	GSettings* _tmp130_;
	AdwSwitchRow* _tmp131_;
	GtkStringList* reminders_model = NULL;
	GtkStringList* _tmp132_;
	GtkStringList* _tmp133_;
	GtkStringList* _tmp134_;
	GtkStringList* _tmp135_;
	GtkStringList* _tmp136_;
	GtkStringList* _tmp137_;
	GtkStringList* _tmp138_;
	GtkStringList* _tmp139_;
	WidgetsComboWrapRow* _tmp140_;
	WidgetsComboWrapRow* _tmp141_;
	WidgetsComboWrapRow* _tmp142_;
	WidgetsComboWrapRow* _tmp143_;
	GtkStringList* _tmp144_;
	WidgetsComboWrapRow* _tmp145_;
	ServicesSettings* _tmp146_;
	ServicesSettings* _tmp147_;
	GSettings* _tmp148_;
	ServicesSettings* _tmp149_;
	ServicesSettings* _tmp150_;
	GSettings* _tmp151_;
	WidgetsComboWrapRow* _tmp152_;
	AdwPreferencesGroup* _tmp153_;
	AdwSwitchRow* _tmp154_;
	AdwPreferencesGroup* _tmp155_;
	WidgetsComboWrapRow* _tmp156_;
	GtkBox* content_box = NULL;
	GtkBox* _tmp157_ = NULL;
	GtkBox* _tmp158_;
	AdwPreferencesGroup* _tmp159_;
	GtkBox* _tmp160_;
	AdwPreferencesGroup* _tmp161_;
	GtkScrolledWindow* scrolled_window = NULL;
	GtkBox* _tmp162_;
	GtkWidget* _tmp163_;
	GtkScrolledWindow* _tmp164_ = NULL;
	AdwToolbarView* toolbar_view = NULL;
	GtkScrolledWindow* _tmp165_;
	GtkWidget* _tmp166_;
	AdwToolbarView* _tmp167_ = NULL;
	AdwToolbarView* _tmp168_;
	AdwHeaderBar* _tmp169_;
	AdwHeaderBar* _tmp170_;
	AdwToolbarView* _tmp171_;
	GeeHashMap* _tmp172_;
	WidgetsComboWrapRow* _tmp173_;
	gulong _tmp174_;
	WidgetsComboWrapRow* _tmp175_;
	GeeHashMap* _tmp176_;
	AdwComboRow* _tmp177_;
	gulong _tmp178_;
	AdwComboRow* _tmp179_;
	GeeHashMap* _tmp180_;
	AdwComboRow* _tmp181_;
	gulong _tmp182_;
	AdwComboRow* _tmp183_;
	GeeHashMap* _tmp184_;
	GtkSwitch* _tmp185_;
	gulong _tmp186_;
	GtkSwitch* _tmp187_;
	GeeHashMap* _tmp188_;
	WidgetsComboWrapRow* _tmp189_;
	gulong _tmp190_;
	WidgetsComboWrapRow* _tmp191_;
	parent_class = G_OBJECT_CLASS (dialogs_preferences_pages_task_setting_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DIALOGS_PREFERENCES_PAGES_TYPE_TASK_SETTING, DialogsPreferencesPagesTaskSetting);
	_data104_ = g_slice_new0 (Block104Data);
	_data104_->_ref_count_ = 1;
	_data104_->self = g_object_ref (self);
	_tmp0_ = g_strdup (_ ("General"));
	_tmp1_ = (AdwPreferencesGroup*) adw_preferences_group_new ();
	adw_preferences_group_set_title (_tmp1_, _tmp0_);
	_g_free0 (_tmp0_);
	g_object_ref_sink (_tmp1_);
	group = _tmp1_;
	_tmp2_ = gtk_string_list_new (NULL);
	complete_tasks_model = _tmp2_;
	_tmp3_ = complete_tasks_model;
	gtk_string_list_append (_tmp3_, _ ("Complete Instantly"));
	_tmp4_ = complete_tasks_model;
	gtk_string_list_append (_tmp4_, _ ("Complete with Undo"));
	_tmp5_ = widgets_combo_wrap_row_new ();
	g_object_ref_sink (_tmp5_);
	_data104_->complete_tasks_row = _tmp5_;
	_tmp6_ = _data104_->complete_tasks_row;
	widgets_combo_wrap_row_set_title (_tmp6_, _ ("Task Completion"));
	_tmp7_ = _data104_->complete_tasks_row;
	widgets_combo_wrap_row_set_subtitle (_tmp7_, _ ("Choose how tasks behave when marked as complete"));
	_tmp8_ = _data104_->complete_tasks_row;
	_tmp9_ = complete_tasks_model;
	widgets_combo_wrap_row_set_model (_tmp8_, _tmp9_);
	_tmp10_ = _data104_->complete_tasks_row;
	_tmp11_ = services_settings_get_default ();
	_tmp12_ = _tmp11_;
	_tmp13_ = _tmp12_->settings;
	widgets_combo_wrap_row_set_selected (_tmp10_, g_settings_get_enum (_tmp13_, "complete-task"));
	_g_object_unref0 (_tmp12_);
	_tmp14_ = group;
	_tmp15_ = _data104_->complete_tasks_row;
	adw_preferences_group_add (_tmp14_, (GtkWidget*) _tmp15_);
	_tmp16_ = gtk_string_list_new (NULL);
	default_priority_model = _tmp16_;
	_tmp17_ = default_priority_model;
	gtk_string_list_append (_tmp17_, _ ("Priority 1"));
	_tmp18_ = default_priority_model;
	gtk_string_list_append (_tmp18_, _ ("Priority 2"));
	_tmp19_ = default_priority_model;
	gtk_string_list_append (_tmp19_, _ ("Priority 3"));
	_tmp20_ = default_priority_model;
	gtk_string_list_append (_tmp20_, _ ("None"));
	_tmp21_ = (AdwComboRow*) adw_combo_row_new ();
	g_object_ref_sink (_tmp21_);
	_data104_->default_priority_row = _tmp21_;
	_tmp22_ = _data104_->default_priority_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp22_, _ ("Default Priority"));
	_tmp23_ = _data104_->default_priority_row;
	_tmp24_ = default_priority_model;
	adw_combo_row_set_model (_tmp23_, (GListModel*) _tmp24_);
	_tmp25_ = _data104_->default_priority_row;
	_tmp26_ = services_settings_get_default ();
	_tmp27_ = _tmp26_;
	_tmp28_ = _tmp27_->settings;
	adw_combo_row_set_selected (_tmp25_, (guint) g_settings_get_enum (_tmp28_, "default-priority"));
	_g_object_unref0 (_tmp27_);
	_tmp29_ = group;
	_tmp30_ = _data104_->default_priority_row;
	adw_preferences_group_add (_tmp29_, (GtkWidget*) _tmp30_);
	_tmp31_ = services_settings_get_default ();
	_tmp32_ = _tmp31_;
	_tmp33_ = _tmp32_->settings;
	_tmp34_ = (GtkSwitch*) gtk_switch_new ();
	gtk_widget_set_valign ((GtkWidget*) _tmp34_, GTK_ALIGN_CENTER);
	gtk_switch_set_active (_tmp34_, g_settings_get_boolean (_tmp33_, "underline-completed-tasks"));
	g_object_ref_sink (_tmp34_);
	_tmp35_ = _tmp34_;
	_g_object_unref0 (_tmp32_);
	_data104_->underline_completed_switch = _tmp35_;
	_tmp36_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp36_);
	underline_completed_row = _tmp36_;
	_tmp37_ = underline_completed_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp37_, _ ("Cross Out Completed Tasks"));
	_tmp38_ = underline_completed_row;
	_tmp39_ = _data104_->underline_completed_switch;
	adw_action_row_set_activatable_widget (_tmp38_, (GtkWidget*) _tmp39_);
	_tmp40_ = underline_completed_row;
	_tmp41_ = _data104_->underline_completed_switch;
	adw_action_row_add_suffix (_tmp40_, (GtkWidget*) _tmp41_);
	_tmp42_ = group;
	_tmp43_ = underline_completed_row;
	adw_preferences_group_add (_tmp42_, (GtkWidget*) _tmp43_);
	_tmp44_ = gtk_string_list_new (NULL);
	tasks_position_model = _tmp44_;
	_tmp45_ = tasks_position_model;
	gtk_string_list_append (_tmp45_, _ ("Start"));
	_tmp46_ = tasks_position_model;
	gtk_string_list_append (_tmp46_, _ ("End"));
	_tmp47_ = (AdwComboRow*) adw_combo_row_new ();
	g_object_ref_sink (_tmp47_);
	_data104_->tasks_position_row = _tmp47_;
	_tmp48_ = _data104_->tasks_position_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp48_, _ ("New Task Position"));
	_tmp49_ = _data104_->tasks_position_row;
	_tmp50_ = tasks_position_model;
	adw_combo_row_set_model (_tmp49_, (GListModel*) _tmp50_);
	_tmp51_ = _data104_->tasks_position_row;
	_tmp52_ = services_settings_get_default ();
	_tmp53_ = _tmp52_;
	_tmp54_ = _tmp53_->settings;
	adw_combo_row_set_selected (_tmp51_, (guint) g_settings_get_enum (_tmp54_, "new-tasks-position"));
	_g_object_unref0 (_tmp53_);
	_tmp55_ = group;
	_tmp56_ = _data104_->tasks_position_row;
	adw_preferences_group_add (_tmp55_, (GtkWidget*) _tmp56_);
	_tmp57_ = (AdwSwitchRow*) adw_switch_row_new ();
	g_object_ref_sink (_tmp57_);
	show_completed_subtasks = _tmp57_;
	_tmp58_ = show_completed_subtasks;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp58_, _ ("Always Show Completed Sub-Tasks"));
	_tmp59_ = show_completed_subtasks;
	adw_action_row_set_subtitle ((AdwActionRow*) _tmp59_, _ ("Keep all completed subtasks visible without collapsing them"));
	_tmp60_ = services_settings_get_default ();
	_tmp61_ = _tmp60_;
	_tmp62_ = _tmp61_->settings;
	_tmp63_ = show_completed_subtasks;
	g_settings_bind (_tmp62_, "always-show-completed-subtasks", (GObject*) _tmp63_, "active", G_SETTINGS_BIND_DEFAULT);
	_g_object_unref0 (_tmp61_);
	_tmp64_ = group;
	_tmp65_ = show_completed_subtasks;
	adw_preferences_group_add (_tmp64_, (GtkWidget*) _tmp65_);
	_tmp66_ = (AdwSwitchRow*) adw_switch_row_new ();
	g_object_ref_sink (_tmp66_);
	task_complete_tone = _tmp66_;
	_tmp67_ = task_complete_tone;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp67_, _ ("Task Complete Tone"));
	_tmp68_ = task_complete_tone;
	adw_action_row_set_subtitle ((AdwActionRow*) _tmp68_, _ ("Play a sound when tasks are completed"));
	_tmp69_ = services_settings_get_default ();
	_tmp70_ = _tmp69_;
	_tmp71_ = _tmp70_->settings;
	_tmp72_ = task_complete_tone;
	g_settings_bind (_tmp71_, "task-complete-tone", (GObject*) _tmp72_, "active", G_SETTINGS_BIND_DEFAULT);
	_g_object_unref0 (_tmp70_);
	_tmp73_ = group;
	_tmp74_ = task_complete_tone;
	adw_preferences_group_add (_tmp73_, (GtkWidget*) _tmp74_);
	_tmp75_ = (AdwSwitchRow*) adw_switch_row_new ();
	g_object_ref_sink (_tmp75_);
	open_task_sidebar = _tmp75_;
	_tmp76_ = open_task_sidebar;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp76_, _ ("Open Tasks in Sidebar View"));
	_tmp77_ = open_task_sidebar;
	adw_action_row_set_subtitle ((AdwActionRow*) _tmp77_, _ ("Always display task details in the sidebar instead of expanding in lis" \
"t view."));
	_tmp78_ = services_settings_get_default ();
	_tmp79_ = _tmp78_;
	_tmp80_ = _tmp79_->settings;
	_tmp81_ = open_task_sidebar;
	g_settings_bind (_tmp80_, "open-task-sidebar", (GObject*) _tmp81_, "active", G_SETTINGS_BIND_DEFAULT);
	_g_object_unref0 (_tmp79_);
	_tmp82_ = group;
	_tmp83_ = open_task_sidebar;
	adw_preferences_group_add (_tmp82_, (GtkWidget*) _tmp83_);
	_tmp84_ = (AdwSwitchRow*) adw_switch_row_new ();
	g_object_ref_sink (_tmp84_);
	attention_at_one = _tmp84_;
	_tmp85_ = attention_at_one;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp85_, _ ("Single Task Focus Mode"));
	_tmp86_ = attention_at_one;
	adw_action_row_set_subtitle ((AdwActionRow*) _tmp86_, _ ("Allow only one task to be expanded at a time in list view"));
	_tmp87_ = services_settings_get_default ();
	_tmp88_ = _tmp87_;
	_tmp89_ = _tmp88_->settings;
	_tmp90_ = attention_at_one;
	g_settings_bind (_tmp89_, "attention-at-one", (GObject*) _tmp90_, "active", G_SETTINGS_BIND_DEFAULT);
	_g_object_unref0 (_tmp88_);
	_tmp91_ = services_settings_get_default ();
	_tmp92_ = _tmp91_;
	_tmp93_ = _tmp92_->settings;
	_tmp94_ = attention_at_one;
	g_settings_bind (_tmp93_, "open-task-sidebar", (GObject*) _tmp94_, "sensitive", G_SETTINGS_BIND_INVERT_BOOLEAN);
	_g_object_unref0 (_tmp92_);
	_tmp95_ = group;
	_tmp96_ = attention_at_one;
	adw_preferences_group_add (_tmp95_, (GtkWidget*) _tmp96_);
	_tmp97_ = (AdwSwitchRow*) adw_switch_row_new ();
	g_object_ref_sink (_tmp97_);
	markdown_item = _tmp97_;
	_tmp98_ = markdown_item;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp98_, _ ("Enable Markdown Formatting"));
	_tmp99_ = markdown_item;
	adw_action_row_set_subtitle ((AdwActionRow*) _tmp99_, _ ("Toggle Markdown support for tasks on or off"));
	_tmp100_ = services_settings_get_default ();
	_tmp101_ = _tmp100_;
	_tmp102_ = _tmp101_->settings;
	_tmp103_ = markdown_item;
	g_settings_bind (_tmp102_, "enable-markdown-formatting", (GObject*) _tmp103_, "active", G_SETTINGS_BIND_DEFAULT);
	_g_object_unref0 (_tmp101_);
	_tmp104_ = group;
	_tmp105_ = markdown_item;
	adw_preferences_group_add (_tmp104_, (GtkWidget*) _tmp105_);
	_tmp106_ = (AdwSwitchRow*) adw_switch_row_new ();
	g_object_ref_sink (_tmp106_);
	always_show_sidebar_item = _tmp106_;
	_tmp107_ = always_show_sidebar_item;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp107_, _ ("Always Show Details Sidebar"));
	_tmp108_ = always_show_sidebar_item;
	adw_action_row_set_subtitle ((AdwActionRow*) _tmp108_, _ ("Keep the details sidebar always visible for faster task navigation, wi" \
"thout repeatedly opening and closing it"));
	_tmp109_ = services_settings_get_default ();
	_tmp110_ = _tmp109_;
	_tmp111_ = _tmp110_->settings;
	_tmp112_ = always_show_sidebar_item;
	g_settings_bind (_tmp111_, "always-show-details-sidebar", (GObject*) _tmp112_, "active", G_SETTINGS_BIND_DEFAULT);
	_g_object_unref0 (_tmp110_);
	_tmp113_ = group;
	_tmp114_ = always_show_sidebar_item;
	adw_preferences_group_add (_tmp113_, (GtkWidget*) _tmp114_);
	_tmp115_ = (AdwSwitchRow*) adw_switch_row_new ();
	g_object_ref_sink (_tmp115_);
	spell_checking_item = _tmp115_;
	_tmp116_ = spell_checking_item;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp116_, _ ("Enable Spell Checking"));
	_tmp117_ = spell_checking_item;
	adw_action_row_set_subtitle ((AdwActionRow*) _tmp117_, _ ("Check spelling in task descriptions and notes"));
	_tmp118_ = services_settings_get_default ();
	_tmp119_ = _tmp118_;
	_tmp120_ = _tmp119_->settings;
	_tmp121_ = spell_checking_item;
	g_settings_bind (_tmp120_, "spell-checking-enabled", (GObject*) _tmp121_, "active", G_SETTINGS_BIND_DEFAULT);
	_g_object_unref0 (_tmp119_);
	_tmp122_ = group;
	_tmp123_ = spell_checking_item;
	adw_preferences_group_add (_tmp122_, (GtkWidget*) _tmp123_);
	_tmp124_ = g_strdup (_ ("Reminders"));
	_tmp125_ = (AdwPreferencesGroup*) adw_preferences_group_new ();
	adw_preferences_group_set_title (_tmp125_, _tmp124_);
	_g_free0 (_tmp124_);
	g_object_ref_sink (_tmp125_);
	reminders_group = _tmp125_;
	_tmp126_ = (AdwSwitchRow*) adw_switch_row_new ();
	g_object_ref_sink (_tmp126_);
	automatic_reminders = _tmp126_;
	_tmp127_ = automatic_reminders;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp127_, _ ("Enabled"));
	_tmp128_ = services_settings_get_default ();
	_tmp129_ = _tmp128_;
	_tmp130_ = _tmp129_->settings;
	_tmp131_ = automatic_reminders;
	g_settings_bind (_tmp130_, "automatic-reminders-enabled", (GObject*) _tmp131_, "active", G_SETTINGS_BIND_DEFAULT);
	_g_object_unref0 (_tmp129_);
	_tmp132_ = gtk_string_list_new (NULL);
	reminders_model = _tmp132_;
	_tmp133_ = reminders_model;
	gtk_string_list_append (_tmp133_, _ ("At due time"));
	_tmp134_ = reminders_model;
	gtk_string_list_append (_tmp134_, _ ("10 minutes before"));
	_tmp135_ = reminders_model;
	gtk_string_list_append (_tmp135_, _ ("30 minutes before"));
	_tmp136_ = reminders_model;
	gtk_string_list_append (_tmp136_, _ ("45 minutes before"));
	_tmp137_ = reminders_model;
	gtk_string_list_append (_tmp137_, _ ("1 hour before"));
	_tmp138_ = reminders_model;
	gtk_string_list_append (_tmp138_, _ ("2 hours before"));
	_tmp139_ = reminders_model;
	gtk_string_list_append (_tmp139_, _ ("3 hours before"));
	_tmp140_ = widgets_combo_wrap_row_new ();
	g_object_ref_sink (_tmp140_);
	_data104_->reminders_comborow = _tmp140_;
	_tmp141_ = _data104_->reminders_comborow;
	widgets_combo_wrap_row_set_title (_tmp141_, _ ("Automatic reminders"));
	_tmp142_ = _data104_->reminders_comborow;
	widgets_combo_wrap_row_set_subtitle (_tmp142_, _ ("When enabled, a reminder before the task’s due time will be added by d" \
"efault."));
	_tmp143_ = _data104_->reminders_comborow;
	_tmp144_ = reminders_model;
	widgets_combo_wrap_row_set_model (_tmp143_, _tmp144_);
	_tmp145_ = _data104_->reminders_comborow;
	_tmp146_ = services_settings_get_default ();
	_tmp147_ = _tmp146_;
	_tmp148_ = _tmp147_->settings;
	widgets_combo_wrap_row_set_selected (_tmp145_, g_settings_get_enum (_tmp148_, "automatic-reminders"));
	_g_object_unref0 (_tmp147_);
	_tmp149_ = services_settings_get_default ();
	_tmp150_ = _tmp149_;
	_tmp151_ = _tmp150_->settings;
	_tmp152_ = _data104_->reminders_comborow;
	g_settings_bind (_tmp151_, "automatic-reminders-enabled", (GObject*) _tmp152_, "sensitive", G_SETTINGS_BIND_DEFAULT);
	_g_object_unref0 (_tmp150_);
	_tmp153_ = reminders_group;
	_tmp154_ = automatic_reminders;
	adw_preferences_group_add (_tmp153_, (GtkWidget*) _tmp154_);
	_tmp155_ = reminders_group;
	_tmp156_ = _data104_->reminders_comborow;
	adw_preferences_group_add (_tmp155_, (GtkWidget*) _tmp156_);
	_tmp157_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp157_, 12);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp157_, 12);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp157_, 12);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp157_, 6);
	g_object_ref_sink (_tmp157_);
	content_box = _tmp157_;
	_tmp158_ = content_box;
	_tmp159_ = group;
	gtk_box_append (_tmp158_, (GtkWidget*) _tmp159_);
	_tmp160_ = content_box;
	_tmp161_ = reminders_group;
	gtk_box_append (_tmp160_, (GtkWidget*) _tmp161_);
	_tmp162_ = content_box;
	_tmp163_ = _g_object_ref0 ((GtkWidget*) _tmp162_);
	_tmp164_ = (GtkScrolledWindow*) gtk_scrolled_window_new ();
	g_object_set (_tmp164_, "hscrollbar-policy", GTK_POLICY_NEVER, NULL);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp164_, TRUE);
	gtk_widget_set_vexpand ((GtkWidget*) _tmp164_, TRUE);
	gtk_scrolled_window_set_child (_tmp164_, _tmp163_);
	_g_object_unref0 (_tmp163_);
	g_object_ref_sink (_tmp164_);
	scrolled_window = _tmp164_;
	_tmp165_ = scrolled_window;
	_tmp166_ = _g_object_ref0 ((GtkWidget*) _tmp165_);
	_tmp167_ = (AdwToolbarView*) adw_toolbar_view_new ();
	adw_toolbar_view_set_content (_tmp167_, _tmp166_);
	_g_object_unref0 (_tmp166_);
	g_object_ref_sink (_tmp167_);
	toolbar_view = _tmp167_;
	_tmp168_ = toolbar_view;
	_tmp169_ = (AdwHeaderBar*) adw_header_bar_new ();
	g_object_ref_sink (_tmp169_);
	_tmp170_ = _tmp169_;
	adw_toolbar_view_add_top_bar (_tmp168_, (GtkWidget*) _tmp170_);
	_g_object_unref0 (_tmp170_);
	_tmp171_ = toolbar_view;
	adw_navigation_page_set_child ((AdwNavigationPage*) self, (GtkWidget*) _tmp171_);
	_tmp172_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	_tmp173_ = _data104_->complete_tasks_row;
	_tmp174_ = g_signal_connect_data ((GObject*) _tmp173_, "notify::selected", (GCallback) __dialogs_preferences_pages_task_setting___lambda414__g_object_notify, block104_data_ref (_data104_), (GClosureNotify) block104_data_unref, 0);
	_tmp175_ = _data104_->complete_tasks_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp172_, (gpointer) ((guintptr) _tmp174_), (GObject*) _tmp175_);
	_tmp176_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	_tmp177_ = _data104_->default_priority_row;
	_tmp178_ = g_signal_connect_data ((GObject*) _tmp177_, "notify::selected", (GCallback) __dialogs_preferences_pages_task_setting___lambda415__g_object_notify, block104_data_ref (_data104_), (GClosureNotify) block104_data_unref, 0);
	_tmp179_ = _data104_->default_priority_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp176_, (gpointer) ((guintptr) _tmp178_), (GObject*) _tmp179_);
	_tmp180_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	_tmp181_ = _data104_->tasks_position_row;
	_tmp182_ = g_signal_connect_data ((GObject*) _tmp181_, "notify::selected", (GCallback) __dialogs_preferences_pages_task_setting___lambda416__g_object_notify, block104_data_ref (_data104_), (GClosureNotify) block104_data_unref, 0);
	_tmp183_ = _data104_->tasks_position_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp180_, (gpointer) ((guintptr) _tmp182_), (GObject*) _tmp183_);
	_tmp184_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	_tmp185_ = _data104_->underline_completed_switch;
	_tmp186_ = g_signal_connect_data ((GObject*) _tmp185_, "notify::active", (GCallback) __dialogs_preferences_pages_task_setting___lambda417__g_object_notify, block104_data_ref (_data104_), (GClosureNotify) block104_data_unref, 0);
	_tmp187_ = _data104_->underline_completed_switch;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp184_, (gpointer) ((guintptr) _tmp186_), (GObject*) _tmp187_);
	_tmp188_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	_tmp189_ = _data104_->reminders_comborow;
	_tmp190_ = g_signal_connect_data ((GObject*) _tmp189_, "notify::selected", (GCallback) __dialogs_preferences_pages_task_setting___lambda418__g_object_notify, block104_data_ref (_data104_), (GClosureNotify) block104_data_unref, 0);
	_tmp191_ = _data104_->reminders_comborow;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp188_, (gpointer) ((guintptr) _tmp190_), (GObject*) _tmp191_);
	g_signal_connect_object ((GtkWidget*) self, "destroy", (GCallback) __dialogs_preferences_pages_task_setting___lambda419__gtk_widget_destroy, self, 0);
	_g_object_unref0 (toolbar_view);
	_g_object_unref0 (scrolled_window);
	_g_object_unref0 (content_box);
	_g_object_unref0 (reminders_model);
	_g_object_unref0 (automatic_reminders);
	_g_object_unref0 (reminders_group);
	_g_object_unref0 (spell_checking_item);
	_g_object_unref0 (always_show_sidebar_item);
	_g_object_unref0 (markdown_item);
	_g_object_unref0 (attention_at_one);
	_g_object_unref0 (open_task_sidebar);
	_g_object_unref0 (task_complete_tone);
	_g_object_unref0 (show_completed_subtasks);
	_g_object_unref0 (tasks_position_model);
	_g_object_unref0 (underline_completed_row);
	_g_object_unref0 (default_priority_model);
	_g_object_unref0 (complete_tasks_model);
	_g_object_unref0 (group);
	block104_data_unref (_data104_);
	_data104_ = NULL;
	return obj;
}

static void
dialogs_preferences_pages_task_setting_class_init (DialogsPreferencesPagesTaskSettingClass * klass,
                                                   gpointer klass_data)
{
	dialogs_preferences_pages_task_setting_parent_class = g_type_class_peek_parent (klass);
	((DialogsPreferencesPagesBasePageClass *) klass)->clean_up = (void (*) (DialogsPreferencesPagesBasePage*)) dialogs_preferences_pages_task_setting_real_clean_up;
	G_OBJECT_CLASS (klass)->constructor = dialogs_preferences_pages_task_setting_constructor;
	G_OBJECT_CLASS (klass)->finalize = dialogs_preferences_pages_task_setting_finalize;
}

static void
dialogs_preferences_pages_task_setting_instance_init (DialogsPreferencesPagesTaskSetting * self,
                                                      gpointer klass)
{
}

static void
dialogs_preferences_pages_task_setting_finalize (GObject * obj)
{
	DialogsPreferencesPagesTaskSetting * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DIALOGS_PREFERENCES_PAGES_TYPE_TASK_SETTING, DialogsPreferencesPagesTaskSetting);
	g_debug ("TaskSetting.vala:31: Destroying - Dialogs.Preferences.Pages.TaskSettin" \
"g\n");
	G_OBJECT_CLASS (dialogs_preferences_pages_task_setting_parent_class)->finalize (obj);
}

static GType
dialogs_preferences_pages_task_setting_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (DialogsPreferencesPagesTaskSettingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dialogs_preferences_pages_task_setting_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DialogsPreferencesPagesTaskSetting), 0, (GInstanceInitFunc) dialogs_preferences_pages_task_setting_instance_init, NULL };
	GType dialogs_preferences_pages_task_setting_type_id;
	dialogs_preferences_pages_task_setting_type_id = g_type_register_static (DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, "DialogsPreferencesPagesTaskSetting", &g_define_type_info, 0);
	return dialogs_preferences_pages_task_setting_type_id;
}

GType
dialogs_preferences_pages_task_setting_get_type (void)
{
	static volatile gsize dialogs_preferences_pages_task_setting_type_id__once = 0;
	if (g_once_init_enter (&dialogs_preferences_pages_task_setting_type_id__once)) {
		GType dialogs_preferences_pages_task_setting_type_id;
		dialogs_preferences_pages_task_setting_type_id = dialogs_preferences_pages_task_setting_get_type_once ();
		g_once_init_leave (&dialogs_preferences_pages_task_setting_type_id__once, dialogs_preferences_pages_task_setting_type_id);
	}
	return dialogs_preferences_pages_task_setting_type_id__once;
}

