/* General.c generated by valac 0.56.19, the Vala compiler
 * generated from General.vala, do not modify */

/*
 * Copyright © 2025 Alain M. (https://github.com/alainm23/planify)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * Authored by: Alain M. <alainmh23@gmail.com>
 */

#include <adwaita.h>
#include <glib-object.h>
#include <gee.h>
#include <glib.h>
#include <glib/gi18n-lib.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include "planify.h"

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE (dialogs_preferences_pages_base_page_get_type ())
#define DIALOGS_PREFERENCES_PAGES_BASE_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, DialogsPreferencesPagesBasePage))
#define DIALOGS_PREFERENCES_PAGES_BASE_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, DialogsPreferencesPagesBasePageClass))
#define DIALOGS_PREFERENCES_PAGES_IS_BASE_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE))
#define DIALOGS_PREFERENCES_PAGES_IS_BASE_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE))
#define DIALOGS_PREFERENCES_PAGES_BASE_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, DialogsPreferencesPagesBasePageClass))

typedef struct _DialogsPreferencesPagesBasePage DialogsPreferencesPagesBasePage;
typedef struct _DialogsPreferencesPagesBasePageClass DialogsPreferencesPagesBasePageClass;
typedef struct _DialogsPreferencesPagesBasePagePrivate DialogsPreferencesPagesBasePagePrivate;

#define DIALOGS_PREFERENCES_PAGES_TYPE_GENERAL (dialogs_preferences_pages_general_get_type ())
#define DIALOGS_PREFERENCES_PAGES_GENERAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_GENERAL, DialogsPreferencesPagesGeneral))
#define DIALOGS_PREFERENCES_PAGES_GENERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_GENERAL, DialogsPreferencesPagesGeneralClass))
#define DIALOGS_PREFERENCES_PAGES_IS_GENERAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_GENERAL))
#define DIALOGS_PREFERENCES_PAGES_IS_GENERAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DIALOGS_PREFERENCES_PAGES_TYPE_GENERAL))
#define DIALOGS_PREFERENCES_PAGES_GENERAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DIALOGS_PREFERENCES_PAGES_TYPE_GENERAL, DialogsPreferencesPagesGeneralClass))

typedef struct _DialogsPreferencesPagesGeneral DialogsPreferencesPagesGeneral;
typedef struct _DialogsPreferencesPagesGeneralClass DialogsPreferencesPagesGeneralClass;
typedef struct _DialogsPreferencesPagesGeneralPrivate DialogsPreferencesPagesGeneralPrivate;
enum  {
	DIALOGS_PREFERENCES_PAGES_GENERAL_0_PROPERTY,
	DIALOGS_PREFERENCES_PAGES_GENERAL_NUM_PROPERTIES
};
static GParamSpec* dialogs_preferences_pages_general_properties[DIALOGS_PREFERENCES_PAGES_GENERAL_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block103Data Block103Data;

struct _DialogsPreferencesPagesBasePage {
	AdwNavigationPage parent_instance;
	DialogsPreferencesPagesBasePagePrivate * priv;
	GeeHashMap* signal_map;
};

struct _DialogsPreferencesPagesBasePageClass {
	AdwNavigationPageClass parent_class;
	void (*clean_up) (DialogsPreferencesPagesBasePage* self);
};

struct _DialogsPreferencesPagesGeneral {
	DialogsPreferencesPagesBasePage parent_instance;
	DialogsPreferencesPagesGeneralPrivate * priv;
};

struct _DialogsPreferencesPagesGeneralClass {
	DialogsPreferencesPagesBasePageClass parent_class;
};

struct _Block103Data {
	int _ref_count_;
	DialogsPreferencesPagesGeneral* self;
	AdwComboRow* sort_projects_row;
	AdwComboRow* sort_order_projects_row;
	GtkSwitch* run_on_startup_switch;
	GtkSwitch* run_background_switch;
	GtkSwitch* calendar_events_switch;
	AdwComboRow* clock_format_row;
	AdwComboRow* start_week_row;
	GtkSwitch* smart_date_recognition_switch;
};

static gpointer dialogs_preferences_pages_general_parent_class = NULL;

VALA_EXTERN GType dialogs_preferences_pages_base_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesBasePage, g_object_unref)
VALA_EXTERN GType dialogs_preferences_pages_general_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DialogsPreferencesPagesGeneral, g_object_unref)
VALA_EXTERN void dialogs_preferences_pages_base_page_clean_up (DialogsPreferencesPagesBasePage* self);
VALA_EXTERN DialogsPreferencesPagesGeneral* dialogs_preferences_pages_general_new (AdwPreferencesDialog* preferences_dialog);
VALA_EXTERN DialogsPreferencesPagesGeneral* dialogs_preferences_pages_general_construct (GType object_type,
                                                                             AdwPreferencesDialog* preferences_dialog);
static void dialogs_preferences_pages_general_real_clean_up (DialogsPreferencesPagesBasePage* base);
static GObject * dialogs_preferences_pages_general_constructor (GType type,
                                                         guint n_construct_properties,
                                                         GObjectConstructParam * construct_properties);
static Block103Data* block103_data_ref (Block103Data* _data103_);
static void block103_data_unref (void * _userdata_);
static void _dialogs_preferences_pages_general___lambda405_ (Block103Data* _data103_);
static void __dialogs_preferences_pages_general___lambda405__g_object_notify (GObject* _sender,
                                                                       GParamSpec* pspec,
                                                                       gpointer self);
static void _dialogs_preferences_pages_general___lambda406_ (Block103Data* _data103_);
static void __dialogs_preferences_pages_general___lambda406__g_object_notify (GObject* _sender,
                                                                       GParamSpec* pspec,
                                                                       gpointer self);
static void _dialogs_preferences_pages_general___lambda407_ (Block103Data* _data103_);
static void __dialogs_preferences_pages_general___lambda407__g_object_notify (GObject* _sender,
                                                                       GParamSpec* pspec,
                                                                       gpointer self);
static void _dialogs_preferences_pages_general___lambda408_ (Block103Data* _data103_);
static void __dialogs_preferences_pages_general___lambda408__g_object_notify (GObject* _sender,
                                                                       GParamSpec* pspec,
                                                                       gpointer self);
static void _dialogs_preferences_pages_general___lambda409_ (Block103Data* _data103_);
static void __dialogs_preferences_pages_general___lambda409__g_object_notify (GObject* _sender,
                                                                       GParamSpec* pspec,
                                                                       gpointer self);
static void _dialogs_preferences_pages_general___lambda410_ (Block103Data* _data103_);
static void __dialogs_preferences_pages_general___lambda410__g_object_notify (GObject* _sender,
                                                                       GParamSpec* pspec,
                                                                       gpointer self);
static void _dialogs_preferences_pages_general___lambda411_ (Block103Data* _data103_);
static void __dialogs_preferences_pages_general___lambda411__g_object_notify (GObject* _sender,
                                                                       GParamSpec* pspec,
                                                                       gpointer self);
static void _dialogs_preferences_pages_general___lambda412_ (Block103Data* _data103_);
static void __dialogs_preferences_pages_general___lambda412__g_object_notify (GObject* _sender,
                                                                       GParamSpec* pspec,
                                                                       gpointer self);
static void _dialogs_preferences_pages_general___lambda413_ (DialogsPreferencesPagesGeneral* self);
static void __dialogs_preferences_pages_general___lambda413__gtk_widget_destroy (GtkWidget* _sender,
                                                                          gpointer self);
static void dialogs_preferences_pages_general_finalize (GObject * obj);
static GType dialogs_preferences_pages_general_get_type_once (void);

DialogsPreferencesPagesGeneral*
dialogs_preferences_pages_general_construct (GType object_type,
                                             AdwPreferencesDialog* preferences_dialog)
{
	DialogsPreferencesPagesGeneral * self = NULL;
	g_return_val_if_fail (preferences_dialog != NULL, NULL);
	self = (DialogsPreferencesPagesGeneral*) g_object_new (object_type, "preferences-dialog", preferences_dialog, "title", _ ("General"), NULL);
	return self;
}

DialogsPreferencesPagesGeneral*
dialogs_preferences_pages_general_new (AdwPreferencesDialog* preferences_dialog)
{
	return dialogs_preferences_pages_general_construct (DIALOGS_PREFERENCES_PAGES_TYPE_GENERAL, preferences_dialog);
}

static void
dialogs_preferences_pages_general_real_clean_up (DialogsPreferencesPagesBasePage* base)
{
	DialogsPreferencesPagesGeneral * self;
	GeeHashMap* _tmp15_;
	self = (DialogsPreferencesPagesGeneral*) base;
	{
		GeeIterator* _entry_it = NULL;
		GeeHashMap* _tmp0_;
		GeeSet* _tmp1_;
		GeeSet* _tmp2_;
		GeeSet* _tmp3_;
		GeeIterator* _tmp4_;
		GeeIterator* _tmp5_;
		_tmp0_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
		_tmp1_ = gee_abstract_map_get_entries ((GeeAbstractMap*) _tmp0_);
		_tmp2_ = _tmp1_;
		_tmp3_ = _tmp2_;
		_tmp4_ = gee_iterable_iterator ((GeeIterable*) _tmp3_);
		_tmp5_ = _tmp4_;
		_g_object_unref0 (_tmp3_);
		_entry_it = _tmp5_;
		while (TRUE) {
			GeeIterator* _tmp6_;
			GeeMapEntry* entry = NULL;
			GeeIterator* _tmp7_;
			gpointer _tmp8_;
			GeeMapEntry* _tmp9_;
			gconstpointer _tmp10_;
			gconstpointer _tmp11_;
			GeeMapEntry* _tmp12_;
			gconstpointer _tmp13_;
			gconstpointer _tmp14_;
			_tmp6_ = _entry_it;
			if (!gee_iterator_next (_tmp6_)) {
				break;
			}
			_tmp7_ = _entry_it;
			_tmp8_ = gee_iterator_get (_tmp7_);
			entry = (GeeMapEntry*) _tmp8_;
			_tmp9_ = entry;
			_tmp10_ = gee_map_entry_get_value (_tmp9_);
			_tmp11_ = _tmp10_;
			_tmp12_ = entry;
			_tmp13_ = gee_map_entry_get_key (_tmp12_);
			_tmp14_ = _tmp13_;
			g_signal_handler_disconnect ((GObject*) _tmp11_, (gulong) ((guintptr) _tmp14_));
			_g_object_unref0 (entry);
		}
		_g_object_unref0 (_entry_it);
	}
	_tmp15_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	gee_abstract_map_clear ((GeeAbstractMap*) _tmp15_);
}

static Block103Data*
block103_data_ref (Block103Data* _data103_)
{
	g_atomic_int_inc (&_data103_->_ref_count_);
	return _data103_;
}

static void
block103_data_unref (void * _userdata_)
{
	Block103Data* _data103_;
	_data103_ = (Block103Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data103_->_ref_count_)) {
		DialogsPreferencesPagesGeneral* self;
		self = _data103_->self;
		_g_object_unref0 (_data103_->smart_date_recognition_switch);
		_g_object_unref0 (_data103_->start_week_row);
		_g_object_unref0 (_data103_->clock_format_row);
		_g_object_unref0 (_data103_->calendar_events_switch);
		_g_object_unref0 (_data103_->run_background_switch);
		_g_object_unref0 (_data103_->run_on_startup_switch);
		_g_object_unref0 (_data103_->sort_order_projects_row);
		_g_object_unref0 (_data103_->sort_projects_row);
		_g_object_unref0 (self);
		g_slice_free (Block103Data, _data103_);
	}
}

static void
_dialogs_preferences_pages_general___lambda405_ (Block103Data* _data103_)
{
	DialogsPreferencesPagesGeneral* self;
	ServicesSettings* _tmp0_;
	ServicesSettings* _tmp1_;
	GSettings* _tmp2_;
	AdwComboRow* _tmp3_;
	guint _tmp4_;
	guint _tmp5_;
	AdwComboRow* _tmp6_;
	ServicesSettings* _tmp7_;
	ServicesSettings* _tmp8_;
	GSettings* _tmp9_;
	self = _data103_->self;
	_tmp0_ = services_settings_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_->settings;
	_tmp3_ = _data103_->sort_projects_row;
	_tmp4_ = adw_combo_row_get_selected (_tmp3_);
	_tmp5_ = _tmp4_;
	g_settings_set_enum (_tmp2_, "projects-sort-by", (gint) _tmp5_);
	_g_object_unref0 (_tmp1_);
	_tmp6_ = _data103_->sort_order_projects_row;
	_tmp7_ = services_settings_get_default ();
	_tmp8_ = _tmp7_;
	_tmp9_ = _tmp8_->settings;
	gtk_widget_set_sensitive ((GtkWidget*) _tmp6_, g_settings_get_enum (_tmp9_, "projects-sort-by") == 1);
	_g_object_unref0 (_tmp8_);
}

static void
__dialogs_preferences_pages_general___lambda405__g_object_notify (GObject* _sender,
                                                                  GParamSpec* pspec,
                                                                  gpointer self)
{
	_dialogs_preferences_pages_general___lambda405_ (self);
}

static void
_dialogs_preferences_pages_general___lambda406_ (Block103Data* _data103_)
{
	DialogsPreferencesPagesGeneral* self;
	ServicesSettings* _tmp0_;
	ServicesSettings* _tmp1_;
	GSettings* _tmp2_;
	AdwComboRow* _tmp3_;
	guint _tmp4_;
	guint _tmp5_;
	self = _data103_->self;
	_tmp0_ = services_settings_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_->settings;
	_tmp3_ = _data103_->sort_order_projects_row;
	_tmp4_ = adw_combo_row_get_selected (_tmp3_);
	_tmp5_ = _tmp4_;
	g_settings_set_enum (_tmp2_, "projects-ordered", (gint) _tmp5_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_pages_general___lambda406__g_object_notify (GObject* _sender,
                                                                  GParamSpec* pspec,
                                                                  gpointer self)
{
	_dialogs_preferences_pages_general___lambda406_ (self);
}

static void
_dialogs_preferences_pages_general___lambda407_ (Block103Data* _data103_)
{
	DialogsPreferencesPagesGeneral* self;
	ServicesSettings* _tmp0_;
	ServicesSettings* _tmp1_;
	GSettings* _tmp2_;
	GtkSwitch* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	self = _data103_->self;
	_tmp0_ = services_settings_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_->settings;
	_tmp3_ = _data103_->run_background_switch;
	_tmp4_ = gtk_switch_get_active (_tmp3_);
	_tmp5_ = _tmp4_;
	g_settings_set_boolean (_tmp2_, "run-in-background", _tmp5_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_pages_general___lambda407__g_object_notify (GObject* _sender,
                                                                  GParamSpec* pspec,
                                                                  gpointer self)
{
	_dialogs_preferences_pages_general___lambda407_ (self);
}

static void
_dialogs_preferences_pages_general___lambda408_ (Block103Data* _data103_)
{
	DialogsPreferencesPagesGeneral* self;
	ServicesSettings* _tmp0_;
	ServicesSettings* _tmp1_;
	GSettings* _tmp2_;
	GtkSwitch* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	self = _data103_->self;
	_tmp0_ = services_settings_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_->settings;
	_tmp3_ = _data103_->run_on_startup_switch;
	_tmp4_ = gtk_switch_get_active (_tmp3_);
	_tmp5_ = _tmp4_;
	g_settings_set_boolean (_tmp2_, "run-on-startup", _tmp5_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_pages_general___lambda408__g_object_notify (GObject* _sender,
                                                                  GParamSpec* pspec,
                                                                  gpointer self)
{
	_dialogs_preferences_pages_general___lambda408_ (self);
}

static void
_dialogs_preferences_pages_general___lambda409_ (Block103Data* _data103_)
{
	DialogsPreferencesPagesGeneral* self;
	ServicesSettings* _tmp0_;
	ServicesSettings* _tmp1_;
	GSettings* _tmp2_;
	GtkSwitch* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	self = _data103_->self;
	_tmp0_ = services_settings_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_->settings;
	_tmp3_ = _data103_->calendar_events_switch;
	_tmp4_ = gtk_switch_get_active (_tmp3_);
	_tmp5_ = _tmp4_;
	g_settings_set_boolean (_tmp2_, "calendar-enabled", _tmp5_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_pages_general___lambda409__g_object_notify (GObject* _sender,
                                                                  GParamSpec* pspec,
                                                                  gpointer self)
{
	_dialogs_preferences_pages_general___lambda409_ (self);
}

static void
_dialogs_preferences_pages_general___lambda410_ (Block103Data* _data103_)
{
	DialogsPreferencesPagesGeneral* self;
	ServicesSettings* _tmp0_;
	ServicesSettings* _tmp1_;
	GSettings* _tmp2_;
	GtkSwitch* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	self = _data103_->self;
	_tmp0_ = services_settings_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_->settings;
	_tmp3_ = _data103_->smart_date_recognition_switch;
	_tmp4_ = gtk_switch_get_active (_tmp3_);
	_tmp5_ = _tmp4_;
	g_settings_set_boolean (_tmp2_, "smart-date-recognition", _tmp5_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_pages_general___lambda410__g_object_notify (GObject* _sender,
                                                                  GParamSpec* pspec,
                                                                  gpointer self)
{
	_dialogs_preferences_pages_general___lambda410_ (self);
}

static void
_dialogs_preferences_pages_general___lambda411_ (Block103Data* _data103_)
{
	DialogsPreferencesPagesGeneral* self;
	ServicesSettings* _tmp0_;
	ServicesSettings* _tmp1_;
	GSettings* _tmp2_;
	AdwComboRow* _tmp3_;
	guint _tmp4_;
	guint _tmp5_;
	self = _data103_->self;
	_tmp0_ = services_settings_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_->settings;
	_tmp3_ = _data103_->clock_format_row;
	_tmp4_ = adw_combo_row_get_selected (_tmp3_);
	_tmp5_ = _tmp4_;
	g_settings_set_enum (_tmp2_, "clock-format", (gint) _tmp5_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_pages_general___lambda411__g_object_notify (GObject* _sender,
                                                                  GParamSpec* pspec,
                                                                  gpointer self)
{
	_dialogs_preferences_pages_general___lambda411_ (self);
}

static void
_dialogs_preferences_pages_general___lambda412_ (Block103Data* _data103_)
{
	DialogsPreferencesPagesGeneral* self;
	ServicesSettings* _tmp0_;
	ServicesSettings* _tmp1_;
	GSettings* _tmp2_;
	AdwComboRow* _tmp3_;
	guint _tmp4_;
	guint _tmp5_;
	self = _data103_->self;
	_tmp0_ = services_settings_get_default ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_->settings;
	_tmp3_ = _data103_->start_week_row;
	_tmp4_ = adw_combo_row_get_selected (_tmp3_);
	_tmp5_ = _tmp4_;
	g_settings_set_enum (_tmp2_, "start-week", (gint) _tmp5_);
	_g_object_unref0 (_tmp1_);
}

static void
__dialogs_preferences_pages_general___lambda412__g_object_notify (GObject* _sender,
                                                                  GParamSpec* pspec,
                                                                  gpointer self)
{
	_dialogs_preferences_pages_general___lambda412_ (self);
}

static void
_dialogs_preferences_pages_general___lambda413_ (DialogsPreferencesPagesGeneral* self)
{
	dialogs_preferences_pages_base_page_clean_up ((DialogsPreferencesPagesBasePage*) self);
}

static void
__dialogs_preferences_pages_general___lambda413__gtk_widget_destroy (GtkWidget* _sender,
                                                                     gpointer self)
{
	_dialogs_preferences_pages_general___lambda413_ ((DialogsPreferencesPagesGeneral*) self);
}

static GObject *
dialogs_preferences_pages_general_constructor (GType type,
                                               guint n_construct_properties,
                                               GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	DialogsPreferencesPagesGeneral * self;
	Block103Data* _data103_;
	GtkStringList* sort_projects_model = NULL;
	GtkStringList* _tmp0_;
	GtkStringList* _tmp1_;
	GtkStringList* _tmp2_;
	AdwComboRow* _tmp3_;
	AdwComboRow* _tmp4_;
	AdwComboRow* _tmp5_;
	GtkStringList* _tmp6_;
	AdwComboRow* _tmp7_;
	ServicesSettings* _tmp8_;
	ServicesSettings* _tmp9_;
	GSettings* _tmp10_;
	GtkStringList* sort_order_projects_model = NULL;
	GtkStringList* _tmp11_;
	GtkStringList* _tmp12_;
	GtkStringList* _tmp13_;
	AdwComboRow* _tmp14_;
	AdwComboRow* _tmp15_;
	AdwComboRow* _tmp16_;
	GtkStringList* _tmp17_;
	AdwComboRow* _tmp18_;
	ServicesSettings* _tmp19_;
	ServicesSettings* _tmp20_;
	GSettings* _tmp21_;
	AdwComboRow* _tmp22_;
	ServicesSettings* _tmp23_;
	ServicesSettings* _tmp24_;
	GSettings* _tmp25_;
	AdwPreferencesGroup* sort_setting_group = NULL;
	AdwPreferencesGroup* _tmp26_;
	AdwPreferencesGroup* _tmp27_;
	AdwPreferencesGroup* _tmp28_;
	AdwComboRow* _tmp29_;
	AdwPreferencesGroup* _tmp30_;
	AdwComboRow* _tmp31_;
	AdwPreferencesGroup* de_group = NULL;
	AdwPreferencesGroup* _tmp32_;
	AdwPreferencesGroup* _tmp33_;
	ServicesSettings* _tmp34_;
	ServicesSettings* _tmp35_;
	GSettings* _tmp36_;
	GtkSwitch* _tmp37_ = NULL;
	GtkSwitch* _tmp38_;
	AdwActionRow* run_on_startup_row = NULL;
	AdwActionRow* _tmp39_;
	AdwActionRow* _tmp40_;
	AdwActionRow* _tmp41_;
	AdwActionRow* _tmp42_;
	GtkSwitch* _tmp43_;
	AdwActionRow* _tmp44_;
	GtkSwitch* _tmp45_;
	AdwPreferencesGroup* _tmp46_;
	AdwActionRow* _tmp47_;
	ServicesSettings* _tmp48_;
	ServicesSettings* _tmp49_;
	GSettings* _tmp50_;
	GtkSwitch* _tmp51_ = NULL;
	GtkSwitch* _tmp52_;
	AdwActionRow* run_background_row = NULL;
	AdwActionRow* _tmp53_;
	AdwActionRow* _tmp54_;
	AdwActionRow* _tmp55_;
	AdwActionRow* _tmp56_;
	GtkSwitch* _tmp57_;
	AdwActionRow* _tmp58_;
	GtkSwitch* _tmp59_;
	AdwPreferencesGroup* _tmp60_;
	AdwActionRow* _tmp61_;
	ServicesSettings* _tmp62_;
	ServicesSettings* _tmp63_;
	GSettings* _tmp64_;
	GtkSwitch* _tmp65_ = NULL;
	GtkSwitch* _tmp66_;
	AdwActionRow* calendar_events_row = NULL;
	AdwActionRow* _tmp67_;
	AdwActionRow* _tmp68_;
	AdwActionRow* _tmp69_;
	GtkSwitch* _tmp70_;
	AdwActionRow* _tmp71_;
	GtkSwitch* _tmp72_;
	AdwPreferencesGroup* _tmp73_;
	AdwActionRow* _tmp74_;
	AdwActionRow* search_provider_row = NULL;
	AdwActionRow* _tmp75_;
	AdwActionRow* _tmp76_;
	AdwActionRow* _tmp77_;
	AdwPreferencesGroup* _tmp78_;
	AdwActionRow* _tmp79_;
	AdwPreferencesGroup* datetime_group = NULL;
	AdwPreferencesGroup* _tmp80_;
	AdwPreferencesGroup* _tmp81_;
	GtkStringList* clock_format_model = NULL;
	GtkStringList* _tmp82_;
	GtkStringList* _tmp83_;
	GtkStringList* _tmp84_;
	AdwComboRow* _tmp85_;
	AdwComboRow* _tmp86_;
	AdwComboRow* _tmp87_;
	GtkStringList* _tmp88_;
	AdwComboRow* _tmp89_;
	ServicesSettings* _tmp90_;
	ServicesSettings* _tmp91_;
	GSettings* _tmp92_;
	AdwPreferencesGroup* _tmp93_;
	AdwComboRow* _tmp94_;
	GtkStringList* start_week_model = NULL;
	GtkStringList* _tmp95_;
	GtkStringList* _tmp96_;
	GtkStringList* _tmp97_;
	GtkStringList* _tmp98_;
	GtkStringList* _tmp99_;
	GtkStringList* _tmp100_;
	GtkStringList* _tmp101_;
	GtkStringList* _tmp102_;
	AdwComboRow* _tmp103_;
	AdwComboRow* _tmp104_;
	AdwComboRow* _tmp105_;
	GtkStringList* _tmp106_;
	AdwComboRow* _tmp107_;
	ServicesSettings* _tmp108_;
	ServicesSettings* _tmp109_;
	GSettings* _tmp110_;
	AdwPreferencesGroup* _tmp111_;
	AdwComboRow* _tmp112_;
	ServicesSettings* _tmp113_;
	ServicesSettings* _tmp114_;
	GSettings* _tmp115_;
	GtkSwitch* _tmp116_ = NULL;
	GtkSwitch* _tmp117_;
	AdwActionRow* smart_date_recognition_row = NULL;
	AdwActionRow* _tmp118_;
	AdwActionRow* _tmp119_;
	AdwActionRow* _tmp120_;
	AdwActionRow* _tmp121_;
	GtkSwitch* _tmp122_;
	AdwActionRow* _tmp123_;
	GtkSwitch* _tmp124_;
	AdwPreferencesGroup* _tmp125_;
	AdwActionRow* _tmp126_;
	GtkBox* content_box = NULL;
	GtkBox* _tmp127_ = NULL;
	GtkBox* _tmp128_;
	AdwPreferencesGroup* _tmp129_;
	GtkBox* _tmp130_;
	AdwPreferencesGroup* _tmp131_;
	GtkBox* _tmp132_;
	AdwPreferencesGroup* _tmp133_;
	GtkScrolledWindow* scrolled_window = NULL;
	GtkScrolledWindow* _tmp134_ = NULL;
	GtkScrolledWindow* _tmp135_;
	GtkBox* _tmp136_;
	AdwToolbarView* toolbar_view = NULL;
	AdwToolbarView* _tmp137_;
	AdwToolbarView* _tmp138_;
	AdwHeaderBar* _tmp139_;
	AdwHeaderBar* _tmp140_;
	AdwToolbarView* _tmp141_;
	GtkScrolledWindow* _tmp142_;
	AdwToolbarView* _tmp143_;
	GeeHashMap* _tmp144_;
	AdwComboRow* _tmp145_;
	gulong _tmp146_;
	AdwComboRow* _tmp147_;
	GeeHashMap* _tmp148_;
	AdwComboRow* _tmp149_;
	gulong _tmp150_;
	AdwComboRow* _tmp151_;
	gulong run_background_handler = 0UL;
	GtkSwitch* _tmp152_;
	gulong _tmp153_;
	GeeHashMap* _tmp154_;
	GtkSwitch* _tmp155_;
	gulong run_on_startup_handler = 0UL;
	GtkSwitch* _tmp156_;
	gulong _tmp157_;
	GeeHashMap* _tmp158_;
	GtkSwitch* _tmp159_;
	GeeHashMap* _tmp160_;
	GtkSwitch* _tmp161_;
	gulong _tmp162_;
	GtkSwitch* _tmp163_;
	GeeHashMap* _tmp164_;
	GtkSwitch* _tmp165_;
	gulong _tmp166_;
	GtkSwitch* _tmp167_;
	GeeHashMap* _tmp168_;
	AdwComboRow* _tmp169_;
	gulong _tmp170_;
	AdwComboRow* _tmp171_;
	GeeHashMap* _tmp172_;
	AdwComboRow* _tmp173_;
	gulong _tmp174_;
	AdwComboRow* _tmp175_;
	parent_class = G_OBJECT_CLASS (dialogs_preferences_pages_general_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DIALOGS_PREFERENCES_PAGES_TYPE_GENERAL, DialogsPreferencesPagesGeneral);
	_data103_ = g_slice_new0 (Block103Data);
	_data103_->_ref_count_ = 1;
	_data103_->self = g_object_ref (self);
	_tmp0_ = gtk_string_list_new (NULL);
	sort_projects_model = _tmp0_;
	_tmp1_ = sort_projects_model;
	gtk_string_list_append (_tmp1_, _ ("Custom Sort Order"));
	_tmp2_ = sort_projects_model;
	gtk_string_list_append (_tmp2_, _ ("Alphabetically"));
	_tmp3_ = (AdwComboRow*) adw_combo_row_new ();
	g_object_ref_sink (_tmp3_);
	_data103_->sort_projects_row = _tmp3_;
	_tmp4_ = _data103_->sort_projects_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp4_, _ ("Sort by"));
	_tmp5_ = _data103_->sort_projects_row;
	_tmp6_ = sort_projects_model;
	adw_combo_row_set_model (_tmp5_, (GListModel*) _tmp6_);
	_tmp7_ = _data103_->sort_projects_row;
	_tmp8_ = services_settings_get_default ();
	_tmp9_ = _tmp8_;
	_tmp10_ = _tmp9_->settings;
	adw_combo_row_set_selected (_tmp7_, (guint) g_settings_get_enum (_tmp10_, "projects-sort-by"));
	_g_object_unref0 (_tmp9_);
	_tmp11_ = gtk_string_list_new (NULL);
	sort_order_projects_model = _tmp11_;
	_tmp12_ = sort_order_projects_model;
	gtk_string_list_append (_tmp12_, _ ("Ascending"));
	_tmp13_ = sort_order_projects_model;
	gtk_string_list_append (_tmp13_, _ ("Descending"));
	_tmp14_ = (AdwComboRow*) adw_combo_row_new ();
	g_object_ref_sink (_tmp14_);
	_data103_->sort_order_projects_row = _tmp14_;
	_tmp15_ = _data103_->sort_order_projects_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp15_, _ ("Ordered"));
	_tmp16_ = _data103_->sort_order_projects_row;
	_tmp17_ = sort_order_projects_model;
	adw_combo_row_set_model (_tmp16_, (GListModel*) _tmp17_);
	_tmp18_ = _data103_->sort_order_projects_row;
	_tmp19_ = services_settings_get_default ();
	_tmp20_ = _tmp19_;
	_tmp21_ = _tmp20_->settings;
	adw_combo_row_set_selected (_tmp18_, (guint) g_settings_get_enum (_tmp21_, "projects-ordered"));
	_g_object_unref0 (_tmp20_);
	_tmp22_ = _data103_->sort_order_projects_row;
	_tmp23_ = services_settings_get_default ();
	_tmp24_ = _tmp23_;
	_tmp25_ = _tmp24_->settings;
	gtk_widget_set_sensitive ((GtkWidget*) _tmp22_, g_settings_get_enum (_tmp25_, "projects-sort-by") == 1);
	_g_object_unref0 (_tmp24_);
	_tmp26_ = (AdwPreferencesGroup*) adw_preferences_group_new ();
	g_object_ref_sink (_tmp26_);
	sort_setting_group = _tmp26_;
	_tmp27_ = sort_setting_group;
	adw_preferences_group_set_title (_tmp27_, _ ("Projects"));
	_tmp28_ = sort_setting_group;
	_tmp29_ = _data103_->sort_projects_row;
	adw_preferences_group_add (_tmp28_, (GtkWidget*) _tmp29_);
	_tmp30_ = sort_setting_group;
	_tmp31_ = _data103_->sort_order_projects_row;
	adw_preferences_group_add (_tmp30_, (GtkWidget*) _tmp31_);
	_tmp32_ = (AdwPreferencesGroup*) adw_preferences_group_new ();
	g_object_ref_sink (_tmp32_);
	de_group = _tmp32_;
	_tmp33_ = de_group;
	adw_preferences_group_set_title (_tmp33_, _ ("DE Integration"));
	_tmp34_ = services_settings_get_default ();
	_tmp35_ = _tmp34_;
	_tmp36_ = _tmp35_->settings;
	_tmp37_ = (GtkSwitch*) gtk_switch_new ();
	gtk_widget_set_valign ((GtkWidget*) _tmp37_, GTK_ALIGN_CENTER);
	gtk_switch_set_active (_tmp37_, g_settings_get_boolean (_tmp36_, "run-on-startup"));
	g_object_ref_sink (_tmp37_);
	_tmp38_ = _tmp37_;
	_g_object_unref0 (_tmp35_);
	_data103_->run_on_startup_switch = _tmp38_;
	_tmp39_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp39_);
	run_on_startup_row = _tmp39_;
	_tmp40_ = run_on_startup_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp40_, _ ("Run on Startup"));
	_tmp41_ = run_on_startup_row;
	adw_action_row_set_subtitle (_tmp41_, _ ("Launch Planify automatically when you start your computer"));
	_tmp42_ = run_on_startup_row;
	_tmp43_ = _data103_->run_on_startup_switch;
	adw_action_row_set_activatable_widget (_tmp42_, (GtkWidget*) _tmp43_);
	_tmp44_ = run_on_startup_row;
	_tmp45_ = _data103_->run_on_startup_switch;
	adw_action_row_add_suffix (_tmp44_, (GtkWidget*) _tmp45_);
	_tmp46_ = de_group;
	_tmp47_ = run_on_startup_row;
	adw_preferences_group_add (_tmp46_, (GtkWidget*) _tmp47_);
	_tmp48_ = services_settings_get_default ();
	_tmp49_ = _tmp48_;
	_tmp50_ = _tmp49_->settings;
	_tmp51_ = (GtkSwitch*) gtk_switch_new ();
	gtk_widget_set_valign ((GtkWidget*) _tmp51_, GTK_ALIGN_CENTER);
	gtk_switch_set_active (_tmp51_, g_settings_get_boolean (_tmp50_, "run-in-background"));
	g_object_ref_sink (_tmp51_);
	_tmp52_ = _tmp51_;
	_g_object_unref0 (_tmp49_);
	_data103_->run_background_switch = _tmp52_;
	_tmp53_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp53_);
	run_background_row = _tmp53_;
	_tmp54_ = run_background_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp54_, _ ("Run in Background"));
	_tmp55_ = run_background_row;
	adw_action_row_set_subtitle (_tmp55_, _ ("Keep Planify running in the system tray when closing the window"));
	_tmp56_ = run_background_row;
	_tmp57_ = _data103_->run_background_switch;
	adw_action_row_set_activatable_widget (_tmp56_, (GtkWidget*) _tmp57_);
	_tmp58_ = run_background_row;
	_tmp59_ = _data103_->run_background_switch;
	adw_action_row_add_suffix (_tmp58_, (GtkWidget*) _tmp59_);
	_tmp60_ = de_group;
	_tmp61_ = run_background_row;
	adw_preferences_group_add (_tmp60_, (GtkWidget*) _tmp61_);
	_tmp62_ = services_settings_get_default ();
	_tmp63_ = _tmp62_;
	_tmp64_ = _tmp63_->settings;
	_tmp65_ = (GtkSwitch*) gtk_switch_new ();
	gtk_widget_set_valign ((GtkWidget*) _tmp65_, GTK_ALIGN_CENTER);
	gtk_switch_set_active (_tmp65_, g_settings_get_boolean (_tmp64_, "calendar-enabled"));
	g_object_ref_sink (_tmp65_);
	_tmp66_ = _tmp65_;
	_g_object_unref0 (_tmp63_);
	_data103_->calendar_events_switch = _tmp66_;
	_tmp67_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp67_);
	calendar_events_row = _tmp67_;
	_tmp68_ = calendar_events_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp68_, _ ("Calendar Events"));
	_tmp69_ = calendar_events_row;
	_tmp70_ = _data103_->calendar_events_switch;
	adw_action_row_set_activatable_widget (_tmp69_, (GtkWidget*) _tmp70_);
	_tmp71_ = calendar_events_row;
	_tmp72_ = _data103_->calendar_events_switch;
	adw_action_row_add_suffix (_tmp71_, (GtkWidget*) _tmp72_);
	_tmp73_ = de_group;
	_tmp74_ = calendar_events_row;
	adw_preferences_group_add (_tmp73_, (GtkWidget*) _tmp74_);
	_tmp75_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp75_);
	search_provider_row = _tmp75_;
	_tmp76_ = search_provider_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp76_, _ ("GNOME Shell Search"));
	_tmp77_ = search_provider_row;
	adw_action_row_set_subtitle (_tmp77_, _ ("Search tasks and projects directly from GNOME Shell. Enable it in Sett" \
"ings → Search"));
	_tmp78_ = de_group;
	_tmp79_ = search_provider_row;
	adw_preferences_group_add (_tmp78_, (GtkWidget*) _tmp79_);
	_tmp80_ = (AdwPreferencesGroup*) adw_preferences_group_new ();
	g_object_ref_sink (_tmp80_);
	datetime_group = _tmp80_;
	_tmp81_ = datetime_group;
	adw_preferences_group_set_title (_tmp81_, _ ("Date and Time"));
	_tmp82_ = gtk_string_list_new (NULL);
	clock_format_model = _tmp82_;
	_tmp83_ = clock_format_model;
	gtk_string_list_append (_tmp83_, _ ("24h"));
	_tmp84_ = clock_format_model;
	gtk_string_list_append (_tmp84_, _ ("12h"));
	_tmp85_ = (AdwComboRow*) adw_combo_row_new ();
	g_object_ref_sink (_tmp85_);
	_data103_->clock_format_row = _tmp85_;
	_tmp86_ = _data103_->clock_format_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp86_, _ ("Clock Format"));
	_tmp87_ = _data103_->clock_format_row;
	_tmp88_ = clock_format_model;
	adw_combo_row_set_model (_tmp87_, (GListModel*) _tmp88_);
	_tmp89_ = _data103_->clock_format_row;
	_tmp90_ = services_settings_get_default ();
	_tmp91_ = _tmp90_;
	_tmp92_ = _tmp91_->settings;
	adw_combo_row_set_selected (_tmp89_, (guint) g_settings_get_enum (_tmp92_, "clock-format"));
	_g_object_unref0 (_tmp91_);
	_tmp93_ = datetime_group;
	_tmp94_ = _data103_->clock_format_row;
	adw_preferences_group_add (_tmp93_, (GtkWidget*) _tmp94_);
	_tmp95_ = gtk_string_list_new (NULL);
	start_week_model = _tmp95_;
	_tmp96_ = start_week_model;
	gtk_string_list_append (_tmp96_, _ ("Sunday"));
	_tmp97_ = start_week_model;
	gtk_string_list_append (_tmp97_, _ ("Monday"));
	_tmp98_ = start_week_model;
	gtk_string_list_append (_tmp98_, _ ("Tuesday"));
	_tmp99_ = start_week_model;
	gtk_string_list_append (_tmp99_, _ ("Wednesday"));
	_tmp100_ = start_week_model;
	gtk_string_list_append (_tmp100_, _ ("Thursday"));
	_tmp101_ = start_week_model;
	gtk_string_list_append (_tmp101_, _ ("Friday"));
	_tmp102_ = start_week_model;
	gtk_string_list_append (_tmp102_, _ ("Saturday"));
	_tmp103_ = (AdwComboRow*) adw_combo_row_new ();
	g_object_ref_sink (_tmp103_);
	_data103_->start_week_row = _tmp103_;
	_tmp104_ = _data103_->start_week_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp104_, _ ("Start of the Week"));
	_tmp105_ = _data103_->start_week_row;
	_tmp106_ = start_week_model;
	adw_combo_row_set_model (_tmp105_, (GListModel*) _tmp106_);
	_tmp107_ = _data103_->start_week_row;
	_tmp108_ = services_settings_get_default ();
	_tmp109_ = _tmp108_;
	_tmp110_ = _tmp109_->settings;
	adw_combo_row_set_selected (_tmp107_, (guint) g_settings_get_enum (_tmp110_, "start-week"));
	_g_object_unref0 (_tmp109_);
	_tmp111_ = datetime_group;
	_tmp112_ = _data103_->start_week_row;
	adw_preferences_group_add (_tmp111_, (GtkWidget*) _tmp112_);
	_tmp113_ = services_settings_get_default ();
	_tmp114_ = _tmp113_;
	_tmp115_ = _tmp114_->settings;
	_tmp116_ = (GtkSwitch*) gtk_switch_new ();
	gtk_widget_set_valign ((GtkWidget*) _tmp116_, GTK_ALIGN_CENTER);
	gtk_switch_set_active (_tmp116_, g_settings_get_boolean (_tmp115_, "smart-date-recognition"));
	g_object_ref_sink (_tmp116_);
	_tmp117_ = _tmp116_;
	_g_object_unref0 (_tmp114_);
	_data103_->smart_date_recognition_switch = _tmp117_;
	_tmp118_ = (AdwActionRow*) adw_action_row_new ();
	g_object_ref_sink (_tmp118_);
	smart_date_recognition_row = _tmp118_;
	_tmp119_ = smart_date_recognition_row;
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp119_, _ ("Smart Date Recognition"));
	_tmp120_ = smart_date_recognition_row;
	adw_action_row_set_subtitle (_tmp120_, _ ("Automatically detect dates like \"tomorrow\" or \"next week\""));
	_tmp121_ = smart_date_recognition_row;
	_tmp122_ = _data103_->smart_date_recognition_switch;
	adw_action_row_set_activatable_widget (_tmp121_, (GtkWidget*) _tmp122_);
	_tmp123_ = smart_date_recognition_row;
	_tmp124_ = _data103_->smart_date_recognition_switch;
	adw_action_row_add_suffix (_tmp123_, (GtkWidget*) _tmp124_);
	_tmp125_ = datetime_group;
	_tmp126_ = smart_date_recognition_row;
	adw_preferences_group_add (_tmp125_, (GtkWidget*) _tmp126_);
	_tmp127_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp127_, 12);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp127_, 12);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp127_, 12);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp127_, 6);
	g_object_ref_sink (_tmp127_);
	content_box = _tmp127_;
	_tmp128_ = content_box;
	_tmp129_ = sort_setting_group;
	gtk_box_append (_tmp128_, (GtkWidget*) _tmp129_);
	_tmp130_ = content_box;
	_tmp131_ = de_group;
	gtk_box_append (_tmp130_, (GtkWidget*) _tmp131_);
	_tmp132_ = content_box;
	_tmp133_ = datetime_group;
	gtk_box_append (_tmp132_, (GtkWidget*) _tmp133_);
	_tmp134_ = (GtkScrolledWindow*) gtk_scrolled_window_new ();
	g_object_set (_tmp134_, "hscrollbar-policy", GTK_POLICY_NEVER, NULL);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp134_, TRUE);
	gtk_widget_set_vexpand ((GtkWidget*) _tmp134_, TRUE);
	g_object_ref_sink (_tmp134_);
	scrolled_window = _tmp134_;
	_tmp135_ = scrolled_window;
	_tmp136_ = content_box;
	gtk_scrolled_window_set_child (_tmp135_, (GtkWidget*) _tmp136_);
	_tmp137_ = (AdwToolbarView*) adw_toolbar_view_new ();
	g_object_ref_sink (_tmp137_);
	toolbar_view = _tmp137_;
	_tmp138_ = toolbar_view;
	_tmp139_ = (AdwHeaderBar*) adw_header_bar_new ();
	g_object_ref_sink (_tmp139_);
	_tmp140_ = _tmp139_;
	adw_toolbar_view_add_top_bar (_tmp138_, (GtkWidget*) _tmp140_);
	_g_object_unref0 (_tmp140_);
	_tmp141_ = toolbar_view;
	_tmp142_ = scrolled_window;
	adw_toolbar_view_set_content (_tmp141_, (GtkWidget*) _tmp142_);
	_tmp143_ = toolbar_view;
	adw_navigation_page_set_child ((AdwNavigationPage*) self, (GtkWidget*) _tmp143_);
	_tmp144_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	_tmp145_ = _data103_->sort_projects_row;
	_tmp146_ = g_signal_connect_data ((GObject*) _tmp145_, "notify::selected", (GCallback) __dialogs_preferences_pages_general___lambda405__g_object_notify, block103_data_ref (_data103_), (GClosureNotify) block103_data_unref, 0);
	_tmp147_ = _data103_->sort_projects_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp144_, (gpointer) ((guintptr) _tmp146_), (GObject*) _tmp147_);
	_tmp148_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	_tmp149_ = _data103_->sort_order_projects_row;
	_tmp150_ = g_signal_connect_data ((GObject*) _tmp149_, "notify::selected", (GCallback) __dialogs_preferences_pages_general___lambda406__g_object_notify, block103_data_ref (_data103_), (GClosureNotify) block103_data_unref, 0);
	_tmp151_ = _data103_->sort_order_projects_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp148_, (gpointer) ((guintptr) _tmp150_), (GObject*) _tmp151_);
	_tmp152_ = _data103_->run_background_switch;
	_tmp153_ = g_signal_connect_data ((GObject*) _tmp152_, "notify::active", (GCallback) __dialogs_preferences_pages_general___lambda407__g_object_notify, block103_data_ref (_data103_), (GClosureNotify) block103_data_unref, 0);
	run_background_handler = _tmp153_;
	_tmp154_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	_tmp155_ = _data103_->run_background_switch;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp154_, (gpointer) ((guintptr) run_background_handler), (GObject*) _tmp155_);
	_tmp156_ = _data103_->run_on_startup_switch;
	_tmp157_ = g_signal_connect_data ((GObject*) _tmp156_, "notify::active", (GCallback) __dialogs_preferences_pages_general___lambda408__g_object_notify, block103_data_ref (_data103_), (GClosureNotify) block103_data_unref, 0);
	run_on_startup_handler = _tmp157_;
	_tmp158_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	_tmp159_ = _data103_->run_on_startup_switch;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp158_, (gpointer) ((guintptr) run_on_startup_handler), (GObject*) _tmp159_);
	_tmp160_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	_tmp161_ = _data103_->calendar_events_switch;
	_tmp162_ = g_signal_connect_data ((GObject*) _tmp161_, "notify::active", (GCallback) __dialogs_preferences_pages_general___lambda409__g_object_notify, block103_data_ref (_data103_), (GClosureNotify) block103_data_unref, 0);
	_tmp163_ = _data103_->calendar_events_switch;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp160_, (gpointer) ((guintptr) _tmp162_), (GObject*) _tmp163_);
	_tmp164_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	_tmp165_ = _data103_->smart_date_recognition_switch;
	_tmp166_ = g_signal_connect_data ((GObject*) _tmp165_, "notify::active", (GCallback) __dialogs_preferences_pages_general___lambda410__g_object_notify, block103_data_ref (_data103_), (GClosureNotify) block103_data_unref, 0);
	_tmp167_ = _data103_->smart_date_recognition_switch;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp164_, (gpointer) ((guintptr) _tmp166_), (GObject*) _tmp167_);
	_tmp168_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	_tmp169_ = _data103_->clock_format_row;
	_tmp170_ = g_signal_connect_data ((GObject*) _tmp169_, "notify::selected", (GCallback) __dialogs_preferences_pages_general___lambda411__g_object_notify, block103_data_ref (_data103_), (GClosureNotify) block103_data_unref, 0);
	_tmp171_ = _data103_->clock_format_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp168_, (gpointer) ((guintptr) _tmp170_), (GObject*) _tmp171_);
	_tmp172_ = ((DialogsPreferencesPagesBasePage*) self)->signal_map;
	_tmp173_ = _data103_->start_week_row;
	_tmp174_ = g_signal_connect_data ((GObject*) _tmp173_, "notify::selected", (GCallback) __dialogs_preferences_pages_general___lambda412__g_object_notify, block103_data_ref (_data103_), (GClosureNotify) block103_data_unref, 0);
	_tmp175_ = _data103_->start_week_row;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp172_, (gpointer) ((guintptr) _tmp174_), (GObject*) _tmp175_);
	g_signal_connect_object ((GtkWidget*) self, "destroy", (GCallback) __dialogs_preferences_pages_general___lambda413__gtk_widget_destroy, self, 0);
	_g_object_unref0 (toolbar_view);
	_g_object_unref0 (scrolled_window);
	_g_object_unref0 (content_box);
	_g_object_unref0 (smart_date_recognition_row);
	_g_object_unref0 (start_week_model);
	_g_object_unref0 (clock_format_model);
	_g_object_unref0 (datetime_group);
	_g_object_unref0 (search_provider_row);
	_g_object_unref0 (calendar_events_row);
	_g_object_unref0 (run_background_row);
	_g_object_unref0 (run_on_startup_row);
	_g_object_unref0 (de_group);
	_g_object_unref0 (sort_setting_group);
	_g_object_unref0 (sort_order_projects_model);
	_g_object_unref0 (sort_projects_model);
	block103_data_unref (_data103_);
	_data103_ = NULL;
	return obj;
}

static void
dialogs_preferences_pages_general_class_init (DialogsPreferencesPagesGeneralClass * klass,
                                              gpointer klass_data)
{
	dialogs_preferences_pages_general_parent_class = g_type_class_peek_parent (klass);
	((DialogsPreferencesPagesBasePageClass *) klass)->clean_up = (void (*) (DialogsPreferencesPagesBasePage*)) dialogs_preferences_pages_general_real_clean_up;
	G_OBJECT_CLASS (klass)->constructor = dialogs_preferences_pages_general_constructor;
	G_OBJECT_CLASS (klass)->finalize = dialogs_preferences_pages_general_finalize;
}

static void
dialogs_preferences_pages_general_instance_init (DialogsPreferencesPagesGeneral * self,
                                                 gpointer klass)
{
}

static void
dialogs_preferences_pages_general_finalize (GObject * obj)
{
	DialogsPreferencesPagesGeneral * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DIALOGS_PREFERENCES_PAGES_TYPE_GENERAL, DialogsPreferencesPagesGeneral);
	g_debug ("General.vala:31: Destroying - Dialogs.Preferences.Pages.General\n");
	G_OBJECT_CLASS (dialogs_preferences_pages_general_parent_class)->finalize (obj);
}

static GType
dialogs_preferences_pages_general_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (DialogsPreferencesPagesGeneralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dialogs_preferences_pages_general_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DialogsPreferencesPagesGeneral), 0, (GInstanceInitFunc) dialogs_preferences_pages_general_instance_init, NULL };
	GType dialogs_preferences_pages_general_type_id;
	dialogs_preferences_pages_general_type_id = g_type_register_static (DIALOGS_PREFERENCES_PAGES_TYPE_BASE_PAGE, "DialogsPreferencesPagesGeneral", &g_define_type_info, 0);
	return dialogs_preferences_pages_general_type_id;
}

GType
dialogs_preferences_pages_general_get_type (void)
{
	static volatile gsize dialogs_preferences_pages_general_type_id__once = 0;
	if (g_once_init_enter (&dialogs_preferences_pages_general_type_id__once)) {
		GType dialogs_preferences_pages_general_type_id;
		dialogs_preferences_pages_general_type_id = dialogs_preferences_pages_general_get_type_once ();
		g_once_init_leave (&dialogs_preferences_pages_general_type_id__once, dialogs_preferences_pages_general_type_id);
	}
	return dialogs_preferences_pages_general_type_id__once;
}

