/* MenuSwitch.c generated by valac 0.56.19, the Vala compiler
 * generated from MenuSwitch.vala, do not modify */

/*
 * Copyright © 2023 Alain M. (https://github.com/alainm23/planify)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * Authored by: Alain M. <alainmh23@gmail.com>
 */

#include "planify.h"
#include <gtk/gtk.h>
#include <gee.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <pango/pango.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	WIDGETS_CONTEXT_MENU_MENU_SWITCH_0_PROPERTY,
	WIDGETS_CONTEXT_MENU_MENU_SWITCH_TITLE_PROPERTY,
	WIDGETS_CONTEXT_MENU_MENU_SWITCH_ICON_PROPERTY,
	WIDGETS_CONTEXT_MENU_MENU_SWITCH_ACTIVE_PROPERTY,
	WIDGETS_CONTEXT_MENU_MENU_SWITCH_NUM_PROPERTIES
};
static GParamSpec* widgets_context_menu_menu_switch_properties[WIDGETS_CONTEXT_MENU_MENU_SWITCH_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
enum  {
	WIDGETS_CONTEXT_MENU_MENU_SWITCH_ACTIVATE_ITEM_SIGNAL,
	WIDGETS_CONTEXT_MENU_MENU_SWITCH_NUM_SIGNALS
};
static guint widgets_context_menu_menu_switch_signals[WIDGETS_CONTEXT_MENU_MENU_SWITCH_NUM_SIGNALS] = {0};

struct _WidgetsContextMenuMenuSwitchPrivate {
	GtkImage* menu_icon;
	GtkRevealer* menu_icon_revealer;
	GtkLabel* menu_title;
	GtkSwitch* switch_widget;
	GeeHashMap* signals_map;
};

static gint WidgetsContextMenuMenuSwitch_private_offset;
static gpointer widgets_context_menu_menu_switch_parent_class = NULL;

static GObject * widgets_context_menu_menu_switch_constructor (GType type,
                                                        guint n_construct_properties,
                                                        GObjectConstructParam * construct_properties);
static void _widgets_context_menu_menu_switch___lambda366_ (WidgetsContextMenuMenuSwitch* self);
static void __widgets_context_menu_menu_switch___lambda366__gtk_button_clicked (GtkButton* _sender,
                                                                         gpointer self);
static void _widgets_context_menu_menu_switch___lambda367_ (WidgetsContextMenuMenuSwitch* self);
static void __widgets_context_menu_menu_switch___lambda367__gtk_widget_destroy (GtkWidget* _sender,
                                                                         gpointer self);
static void widgets_context_menu_menu_switch_finalize (GObject * obj);
static GType widgets_context_menu_menu_switch_get_type_once (void);
static void _vala_widgets_context_menu_menu_switch_get_property (GObject * object,
                                                          guint property_id,
                                                          GValue * value,
                                                          GParamSpec * pspec);
static void _vala_widgets_context_menu_menu_switch_set_property (GObject * object,
                                                          guint property_id,
                                                          const GValue * value,
                                                          GParamSpec * pspec);
static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

static inline gpointer
widgets_context_menu_menu_switch_get_instance_private (WidgetsContextMenuMenuSwitch* self)
{
	return G_STRUCT_MEMBER_P (self, WidgetsContextMenuMenuSwitch_private_offset);
}

WidgetsContextMenuMenuSwitch*
widgets_context_menu_menu_switch_construct (GType object_type,
                                            const gchar* title,
                                            const gchar* icon)
{
	WidgetsContextMenuMenuSwitch * self = NULL;
	g_return_val_if_fail (title != NULL, NULL);
	self = (WidgetsContextMenuMenuSwitch*) g_object_new (object_type, "title", title, "icon", icon, "hexpand", TRUE, NULL);
	return self;
}

WidgetsContextMenuMenuSwitch*
widgets_context_menu_menu_switch_new (const gchar* title,
                                      const gchar* icon)
{
	return widgets_context_menu_menu_switch_construct (WIDGETS_CONTEXT_MENU_TYPE_MENU_SWITCH, title, icon);
}

void
widgets_context_menu_menu_switch_set_title (WidgetsContextMenuMenuSwitch* self,
                                            const gchar* value)
{
	GtkLabel* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->menu_title;
	gtk_label_set_label (_tmp0_, value);
	g_object_notify_by_pspec ((GObject *) self, widgets_context_menu_menu_switch_properties[WIDGETS_CONTEXT_MENU_MENU_SWITCH_TITLE_PROPERTY]);
}

void
widgets_context_menu_menu_switch_set_icon (WidgetsContextMenuMenuSwitch* self,
                                           const gchar* value)
{
	g_return_if_fail (self != NULL);
	if (value != NULL) {
		GtkRevealer* _tmp0_;
		GtkImage* _tmp1_;
		_tmp0_ = self->priv->menu_icon_revealer;
		gtk_revealer_set_reveal_child (_tmp0_, TRUE);
		_tmp1_ = self->priv->menu_icon;
		g_object_set (_tmp1_, "icon-name", value, NULL);
	} else {
		GtkRevealer* _tmp2_;
		_tmp2_ = self->priv->menu_icon_revealer;
		gtk_revealer_set_reveal_child (_tmp2_, FALSE);
	}
	g_object_notify_by_pspec ((GObject *) self, widgets_context_menu_menu_switch_properties[WIDGETS_CONTEXT_MENU_MENU_SWITCH_ICON_PROPERTY]);
}

gboolean
widgets_context_menu_menu_switch_get_active (WidgetsContextMenuMenuSwitch* self)
{
	gboolean result;
	GtkSwitch* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->switch_widget;
	_tmp1_ = gtk_switch_get_active (_tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

void
widgets_context_menu_menu_switch_set_active (WidgetsContextMenuMenuSwitch* self,
                                             gboolean value)
{
	GtkSwitch* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->switch_widget;
	gtk_switch_set_active (_tmp0_, value);
	g_object_notify_by_pspec ((GObject *) self, widgets_context_menu_menu_switch_properties[WIDGETS_CONTEXT_MENU_MENU_SWITCH_ACTIVE_PROPERTY]);
}

static void
_widgets_context_menu_menu_switch___lambda366_ (WidgetsContextMenuMenuSwitch* self)
{
	GtkSwitch* _tmp0_;
	GtkSwitch* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	_tmp0_ = self->priv->switch_widget;
	_tmp1_ = self->priv->switch_widget;
	_tmp2_ = gtk_switch_get_active (_tmp1_);
	_tmp3_ = _tmp2_;
	gtk_switch_set_active (_tmp0_, !_tmp3_);
	g_signal_emit (self, widgets_context_menu_menu_switch_signals[WIDGETS_CONTEXT_MENU_MENU_SWITCH_ACTIVATE_ITEM_SIGNAL], 0);
}

static void
__widgets_context_menu_menu_switch___lambda366__gtk_button_clicked (GtkButton* _sender,
                                                                    gpointer self)
{
	_widgets_context_menu_menu_switch___lambda366_ ((WidgetsContextMenuMenuSwitch*) self);
}

static void
_widgets_context_menu_menu_switch___lambda367_ (WidgetsContextMenuMenuSwitch* self)
{
	GeeHashMap* _tmp21_;
	{
		GeeIterator* _entry_it = NULL;
		GeeHashMap* _tmp0_;
		GeeSet* _tmp1_;
		GeeSet* _tmp2_;
		GeeSet* _tmp3_;
		GeeIterator* _tmp4_;
		GeeIterator* _tmp5_;
		_tmp0_ = self->priv->signals_map;
		_tmp1_ = gee_abstract_map_get_entries ((GeeAbstractMap*) _tmp0_);
		_tmp2_ = _tmp1_;
		_tmp3_ = _tmp2_;
		_tmp4_ = gee_iterable_iterator ((GeeIterable*) _tmp3_);
		_tmp5_ = _tmp4_;
		_g_object_unref0 (_tmp3_);
		_entry_it = _tmp5_;
		while (TRUE) {
			GeeIterator* _tmp6_;
			GeeMapEntry* entry = NULL;
			GeeIterator* _tmp7_;
			gpointer _tmp8_;
			GeeMapEntry* _tmp9_;
			gconstpointer _tmp10_;
			gconstpointer _tmp11_;
			GeeMapEntry* _tmp12_;
			gconstpointer _tmp13_;
			gconstpointer _tmp14_;
			_tmp6_ = _entry_it;
			if (!gee_iterator_next (_tmp6_)) {
				break;
			}
			_tmp7_ = _entry_it;
			_tmp8_ = gee_iterator_get (_tmp7_);
			entry = (GeeMapEntry*) _tmp8_;
			_tmp9_ = entry;
			_tmp10_ = gee_map_entry_get_value (_tmp9_);
			_tmp11_ = _tmp10_;
			_tmp12_ = entry;
			_tmp13_ = gee_map_entry_get_key (_tmp12_);
			_tmp14_ = _tmp13_;
			if (g_signal_handler_is_connected ((GObject*) _tmp11_, (gulong) ((guintptr) _tmp14_))) {
				GeeMapEntry* _tmp15_;
				gconstpointer _tmp16_;
				gconstpointer _tmp17_;
				GeeMapEntry* _tmp18_;
				gconstpointer _tmp19_;
				gconstpointer _tmp20_;
				_tmp15_ = entry;
				_tmp16_ = gee_map_entry_get_value (_tmp15_);
				_tmp17_ = _tmp16_;
				_tmp18_ = entry;
				_tmp19_ = gee_map_entry_get_key (_tmp18_);
				_tmp20_ = _tmp19_;
				g_signal_handler_disconnect ((GObject*) _tmp17_, (gulong) ((guintptr) _tmp20_));
			}
			_g_object_unref0 (entry);
		}
		_g_object_unref0 (_entry_it);
	}
	_tmp21_ = self->priv->signals_map;
	gee_abstract_map_clear ((GeeAbstractMap*) _tmp21_);
}

static void
__widgets_context_menu_menu_switch___lambda367__gtk_widget_destroy (GtkWidget* _sender,
                                                                    gpointer self)
{
	_widgets_context_menu_menu_switch___lambda367_ ((WidgetsContextMenuMenuSwitch*) self);
}

static GObject *
widgets_context_menu_menu_switch_constructor (GType type,
                                              guint n_construct_properties,
                                              GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	WidgetsContextMenuMenuSwitch * self;
	GtkImage* _tmp0_ = NULL;
	GtkRevealer* _tmp1_ = NULL;
	GtkRevealer* _tmp2_;
	GtkImage* _tmp3_;
	GtkLabel* _tmp4_ = NULL;
	GtkSwitch* _tmp5_ = NULL;
	GtkSwitch* _tmp6_;
	GtkBox* content_box = NULL;
	GtkBox* _tmp7_ = NULL;
	GtkBox* _tmp8_;
	GtkRevealer* _tmp9_;
	GtkBox* _tmp10_;
	GtkLabel* _tmp11_;
	GtkBox* _tmp12_;
	GtkSwitch* _tmp13_;
	GtkBox* _tmp14_;
	GeeHashMap* _tmp15_;
	gulong _tmp16_;
	parent_class = G_OBJECT_CLASS (widgets_context_menu_menu_switch_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, WIDGETS_CONTEXT_MENU_TYPE_MENU_SWITCH, WidgetsContextMenuMenuSwitch);
	gtk_widget_add_css_class ((GtkWidget*) self, "flat");
	gtk_widget_add_css_class ((GtkWidget*) self, "no-font-bold");
	_tmp0_ = (GtkImage*) gtk_image_new ();
	gtk_widget_set_valign ((GtkWidget*) _tmp0_, GTK_ALIGN_CENTER);
	g_object_ref_sink (_tmp0_);
	_g_object_unref0 (self->priv->menu_icon);
	self->priv->menu_icon = _tmp0_;
	_tmp1_ = (GtkRevealer*) gtk_revealer_new ();
	gtk_revealer_set_transition_type (_tmp1_, GTK_REVEALER_TRANSITION_TYPE_SLIDE_RIGHT);
	gtk_revealer_set_reveal_child (_tmp1_, TRUE);
	g_object_ref_sink (_tmp1_);
	_g_object_unref0 (self->priv->menu_icon_revealer);
	self->priv->menu_icon_revealer = _tmp1_;
	_tmp2_ = self->priv->menu_icon_revealer;
	_tmp3_ = self->priv->menu_icon;
	gtk_revealer_set_child (_tmp2_, (GtkWidget*) _tmp3_);
	_tmp4_ = (GtkLabel*) gtk_label_new (NULL);
	gtk_label_set_ellipsize (_tmp4_, PANGO_ELLIPSIZE_END);
	gtk_label_set_max_width_chars (_tmp4_, 16);
	gtk_label_set_use_markup (_tmp4_, TRUE);
	g_object_ref_sink (_tmp4_);
	_g_object_unref0 (self->priv->menu_title);
	self->priv->menu_title = _tmp4_;
	_tmp5_ = (GtkSwitch*) gtk_switch_new ();
	gtk_widget_set_valign ((GtkWidget*) _tmp5_, GTK_ALIGN_CENTER);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp5_, TRUE);
	gtk_widget_set_halign ((GtkWidget*) _tmp5_, GTK_ALIGN_END);
	g_object_ref_sink (_tmp5_);
	_g_object_unref0 (self->priv->switch_widget);
	self->priv->switch_widget = _tmp5_;
	_tmp6_ = self->priv->switch_widget;
	gtk_widget_add_css_class ((GtkWidget*) _tmp6_, "switch-min");
	_tmp7_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp7_, TRUE);
	g_object_ref_sink (_tmp7_);
	content_box = _tmp7_;
	_tmp8_ = content_box;
	_tmp9_ = self->priv->menu_icon_revealer;
	gtk_box_append (_tmp8_, (GtkWidget*) _tmp9_);
	_tmp10_ = content_box;
	_tmp11_ = self->priv->menu_title;
	gtk_box_append (_tmp10_, (GtkWidget*) _tmp11_);
	_tmp12_ = content_box;
	_tmp13_ = self->priv->switch_widget;
	gtk_box_append (_tmp12_, (GtkWidget*) _tmp13_);
	_tmp14_ = content_box;
	gtk_button_set_child ((GtkButton*) self, (GtkWidget*) _tmp14_);
	_tmp15_ = self->priv->signals_map;
	_tmp16_ = g_signal_connect_object ((GtkButton*) self, "clicked", (GCallback) __widgets_context_menu_menu_switch___lambda366__gtk_button_clicked, self, 0);
	gee_abstract_map_set ((GeeAbstractMap*) _tmp15_, (gpointer) ((guintptr) _tmp16_), (GObject*) self);
	g_signal_connect_object ((GtkWidget*) self, "destroy", (GCallback) __widgets_context_menu_menu_switch___lambda367__gtk_widget_destroy, self, 0);
	_g_object_unref0 (content_box);
	return obj;
}

static void
widgets_context_menu_menu_switch_class_init (WidgetsContextMenuMenuSwitchClass * klass,
                                             gpointer klass_data)
{
	widgets_context_menu_menu_switch_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &WidgetsContextMenuMenuSwitch_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_widgets_context_menu_menu_switch_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_widgets_context_menu_menu_switch_set_property;
	G_OBJECT_CLASS (klass)->constructor = widgets_context_menu_menu_switch_constructor;
	G_OBJECT_CLASS (klass)->finalize = widgets_context_menu_menu_switch_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), WIDGETS_CONTEXT_MENU_MENU_SWITCH_TITLE_PROPERTY, widgets_context_menu_menu_switch_properties[WIDGETS_CONTEXT_MENU_MENU_SWITCH_TITLE_PROPERTY] = g_param_spec_string ("title", "title", "title", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), WIDGETS_CONTEXT_MENU_MENU_SWITCH_ICON_PROPERTY, widgets_context_menu_menu_switch_properties[WIDGETS_CONTEXT_MENU_MENU_SWITCH_ICON_PROPERTY] = g_param_spec_string ("icon", "icon", "icon", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), WIDGETS_CONTEXT_MENU_MENU_SWITCH_ACTIVE_PROPERTY, widgets_context_menu_menu_switch_properties[WIDGETS_CONTEXT_MENU_MENU_SWITCH_ACTIVE_PROPERTY] = g_param_spec_boolean ("active", "active", "active", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	widgets_context_menu_menu_switch_signals[WIDGETS_CONTEXT_MENU_MENU_SWITCH_ACTIVATE_ITEM_SIGNAL] = g_signal_new ("activate-item", WIDGETS_CONTEXT_MENU_TYPE_MENU_SWITCH, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
}

static void
widgets_context_menu_menu_switch_instance_init (WidgetsContextMenuMenuSwitch * self,
                                                gpointer klass)
{
	GeeHashMap* _tmp0_;
	self->priv = widgets_context_menu_menu_switch_get_instance_private (self);
	_tmp0_ = gee_hash_map_new (G_TYPE_ULONG, NULL, NULL, G_TYPE_OBJECT, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
	self->priv->signals_map = _tmp0_;
}

static void
widgets_context_menu_menu_switch_finalize (GObject * obj)
{
	WidgetsContextMenuMenuSwitch * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, WIDGETS_CONTEXT_MENU_TYPE_MENU_SWITCH, WidgetsContextMenuMenuSwitch);
	_g_object_unref0 (self->priv->menu_icon);
	_g_object_unref0 (self->priv->menu_icon_revealer);
	_g_object_unref0 (self->priv->menu_title);
	_g_object_unref0 (self->priv->switch_widget);
	_g_object_unref0 (self->priv->signals_map);
	G_OBJECT_CLASS (widgets_context_menu_menu_switch_parent_class)->finalize (obj);
}

static GType
widgets_context_menu_menu_switch_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (WidgetsContextMenuMenuSwitchClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) widgets_context_menu_menu_switch_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (WidgetsContextMenuMenuSwitch), 0, (GInstanceInitFunc) widgets_context_menu_menu_switch_instance_init, NULL };
	GType widgets_context_menu_menu_switch_type_id;
	widgets_context_menu_menu_switch_type_id = g_type_register_static (gtk_button_get_type (), "WidgetsContextMenuMenuSwitch", &g_define_type_info, 0);
	WidgetsContextMenuMenuSwitch_private_offset = g_type_add_instance_private (widgets_context_menu_menu_switch_type_id, sizeof (WidgetsContextMenuMenuSwitchPrivate));
	return widgets_context_menu_menu_switch_type_id;
}

GType
widgets_context_menu_menu_switch_get_type (void)
{
	static volatile gsize widgets_context_menu_menu_switch_type_id__once = 0;
	if (g_once_init_enter (&widgets_context_menu_menu_switch_type_id__once)) {
		GType widgets_context_menu_menu_switch_type_id;
		widgets_context_menu_menu_switch_type_id = widgets_context_menu_menu_switch_get_type_once ();
		g_once_init_leave (&widgets_context_menu_menu_switch_type_id__once, widgets_context_menu_menu_switch_type_id);
	}
	return widgets_context_menu_menu_switch_type_id__once;
}

static void
_vala_widgets_context_menu_menu_switch_get_property (GObject * object,
                                                     guint property_id,
                                                     GValue * value,
                                                     GParamSpec * pspec)
{
	WidgetsContextMenuMenuSwitch * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, WIDGETS_CONTEXT_MENU_TYPE_MENU_SWITCH, WidgetsContextMenuMenuSwitch);
	switch (property_id) {
		case WIDGETS_CONTEXT_MENU_MENU_SWITCH_ACTIVE_PROPERTY:
		g_value_set_boolean (value, widgets_context_menu_menu_switch_get_active (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_widgets_context_menu_menu_switch_set_property (GObject * object,
                                                     guint property_id,
                                                     const GValue * value,
                                                     GParamSpec * pspec)
{
	WidgetsContextMenuMenuSwitch * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, WIDGETS_CONTEXT_MENU_TYPE_MENU_SWITCH, WidgetsContextMenuMenuSwitch);
	switch (property_id) {
		case WIDGETS_CONTEXT_MENU_MENU_SWITCH_TITLE_PROPERTY:
		widgets_context_menu_menu_switch_set_title (self, g_value_get_string (value));
		break;
		case WIDGETS_CONTEXT_MENU_MENU_SWITCH_ICON_PROPERTY:
		widgets_context_menu_menu_switch_set_icon (self, g_value_get_string (value));
		break;
		case WIDGETS_CONTEXT_MENU_MENU_SWITCH_ACTIVE_PROPERTY:
		widgets_context_menu_menu_switch_set_active (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

