/* planify.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __CORE_PLANIFY_H__
#define __CORE_PLANIFY_H__

#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <adwaita.h>
#include <gee.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <json-glib/json-glib.h>
#include <libical-glib/libical-glib.h>
#include <float.h>
#include <math.h>
#include <sqlite3.h>
#include <gxml/gxml.h>
#include <libsoup/soup.h>
#include <cairo-gobject.h>
#include <gtksourceview/gtksource.h>
#include <libedataserver/libedataserver.h>
#include <libecal/libecal.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif
#define CONSTANTS_SOUP_USER_AGENT "Planify"
#define CONSTANTS_IS_DEVELOPMENT FALSE
#define CONSTANTS_TODOIST_CLIENT_ID "b0dd7d3714314b1dbbdab9ee03b6b432"
#define CONSTANTS_TODOIST_CLIENT_SECRET "a86dfeb12139459da3e5e2a8c197c678"
#define CONSTANTS_TODOIST_SCOPE "data:read_write,data:delete,project:delete"
#define CONSTANTS_TODOIST_REDIRECT_URI "planify://auth"
#define CONSTANTS_BACKUP_VERSION "2.0"
#define CONSTANTS_UPDATE_TIMEOUT 1500
#define CONSTANTS_DESTROY_TIMEOUT 750
#define CONSTANTS_STARTUP_SYNC_TIMEOUT 2500
#define CONSTANTS_SHORT_NAME_SIZE 20
#define CONSTANTS_PRIORITY_1 4
#define CONSTANTS_PRIORITY_2 3
#define CONSTANTS_PRIORITY_3 2
#define CONSTANTS_PRIORITY_4 1
#define CONSTANTS_SCROLL_STEPS 6
#define CONSTANTS_TWITTER_URL "https://twitter.com/useplanify"
#define CONSTANTS_CONTACT_US "alainmh23@gmail.com"
#define CONSTANTS_PATREON_URL "https://www.patreon.com/join/alainm23"
#define CONSTANTS_PAYPAL_ME_URL "https://www.paypal.com/paypalme/alainm23"
#define CONSTANTS_LIBERAPAY_URL "https://liberapay.com/Alain/"
#define CONSTANTS_KOFI_URL "https://ko-fi.com/alainm23"
#define CONSTANTS_MASTODON_URL "https://mastodon.social/@planifyapp"
#define CONSTANTS_DISCORD_URL "https://discord.com/invite/dxxyumrTJW"
#define CONSTANTS_ISSUE_URL "https://github.com/alainm23/planify/issues"
#define CONSTANTS_NEW_ISSUE_URL "https://github.com/alainm23/planify/issues/new?assignees=&labels=Type:" \
"+Bug&template=bug_report.yml"
#define CONSTANTS_WEBLATE_URL "https://hosted.weblate.org/engage/planner/"
#define CONSTANTS_FLATHUB_URL "https://flathub.org/apps/io.github.alainm23.planify"
#define CONSTANTS_PRIVACY_POLICY_URL "https://useplanify.com/privacy-policy/"
#define CONSTANTS_BLOCK_PAST_DAYS TRUE
#define CONSTANTS_COMPLETED_PAGE_SIZE 30
#define CONSTANTS_HEADERBAR_TITLE_SCROLL_THRESHOLD 24
#define CONSTANTS_DEFAULT_ACCENT_COLOR "#3584e4"
#define LAYOUTS_QUICK_ADD_CORE_SHORTCUTS_KEY_PROJECTS "#"
#define LAYOUTS_QUICK_ADD_CORE_SHORTCUTS_KEY_REMINDERS "!"
#define SERVICES_SETTINGS_ID "io.github.alainm23.planify"
#define OBJECTS_FILTERS_PRIORITY_HIGH 4
#define OBJECTS_FILTERS_PRIORITY_MEDIUM 3
#define OBJECTS_FILTERS_PRIORITY_LOW 2
#define OBJECTS_FILTERS_PRIORITY_NONE 1

typedef enum  {
	COLOR_SCHEME_NO_PREFERENCE,
	COLOR_SCHEME_DARK,
	COLOR_SCHEME_LIGHT
} ColorScheme;

#define TYPE_COLOR_SCHEME (color_scheme_get_type ())
typedef enum  {
	NOTIFICATION_STYLE_NORMAL,
	NOTIFICATION_STYLE_ERROR
} NotificationStyle;

#define TYPE_NOTIFICATION_STYLE (notification_style_get_type ())
typedef enum  {
	PROJECT_VIEW_STYLE_LIST,
	PROJECT_VIEW_STYLE_BOARD
} ProjectViewStyle;

#define TYPE_PROJECT_VIEW_STYLE (project_view_style_get_type ())
typedef enum  {
	PROJECT_ICON_STYLE_PROGRESS,
	PROJECT_ICON_STYLE_EMOJI
} ProjectIconStyle;

#define TYPE_PROJECT_ICON_STYLE (project_icon_style_get_type ())
typedef enum  {
	SOURCE_TYPE_NONE,
	SOURCE_TYPE_LOCAL,
	SOURCE_TYPE_TODOIST,
	SOURCE_TYPE_GOOGLE_TASKS,
	SOURCE_TYPE_CALDAV
} SourceType;

#define TYPE_SOURCE_TYPE (source_type_get_type ())
typedef enum  {
	PANE_TYPE_FILTER,
	PANE_TYPE_FAVORITE,
	PANE_TYPE_PROJECT,
	PANE_TYPE_LABEL
} PaneType;

#define TYPE_PANE_TYPE (pane_type_get_type ())
typedef enum  {
	LOADING_BUTTON_TYPE_LABEL,
	LOADING_BUTTON_TYPE_ICON
} LoadingButtonType;

#define TYPE_LOADING_BUTTON_TYPE (loading_button_type_get_type ())
typedef enum  {
	OBJECT_TYPE_PROJECT,
	OBJECT_TYPE_SECTION,
	OBJECT_TYPE_ITEM,
	OBJECT_TYPE_LABEL,
	OBJECT_TYPE_TASK,
	OBJECT_TYPE_TASK_LIST,
	OBJECT_TYPE_FILTER
} ObjectType;

#define TYPE_OBJECT_TYPE (object_type_get_type ())
typedef enum  {
	RECURRENCY_END_TYPE_NEVER,
	RECURRENCY_END_TYPE_ON_DATE,
	RECURRENCY_END_TYPE_AFTER
} RecurrencyEndType;

#define TYPE_RECURRENCY_END_TYPE (recurrency_end_type_get_type ())
typedef enum  {
	RECURRENCY_TYPE_MINUTELY,
	RECURRENCY_TYPE_HOURLY,
	RECURRENCY_TYPE_EVERY_DAY,
	RECURRENCY_TYPE_EVERY_WEEK,
	RECURRENCY_TYPE_EVERY_MONTH,
	RECURRENCY_TYPE_EVERY_YEAR,
	RECURRENCY_TYPE_NONE
} RecurrencyType;

#define TYPE_RECURRENCY_TYPE (recurrency_type_get_type ())
typedef enum  {
	PICKER_TYPE_PROJECTS,
	PICKER_TYPE_SECTIONS
} PickerType;

#define TYPE_PICKER_TYPE (picker_type_get_type ())
typedef enum  {
	NEW_TASK_POSITION_START = 0,
	NEW_TASK_POSITION_END = 1
} NewTaskPosition;

#define TYPE_NEW_TASK_POSITION (new_task_position_get_type ())
typedef enum  {
	CAL_DAV_TYPE_NEXTCLOUD = 0,
	CAL_DAV_TYPE_GENERIC = 1
} CalDAVType;

#define TYPE_CAL_DAV_TYPE (cal_dav_type_get_type ())
typedef enum  {
	FILTER_ITEM_TYPE_PRIORITY = 0,
	FILTER_ITEM_TYPE_LABEL = 1,
	FILTER_ITEM_TYPE_DUE_DATE = 2,
	FILTER_ITEM_TYPE_SECTION = 3,
	FILTER_ITEM_TYPE_ASSIGNMENT = 4
} FilterItemType;

#define TYPE_FILTER_ITEM_TYPE (filter_item_type_get_type ())
typedef enum  {
	REMINDER_TYPE_ABSOLUTE,
	REMINDER_TYPE_RELATIVE
} ReminderType;

#define TYPE_REMINDER_TYPE (reminder_type_get_type ())
typedef enum  {
	ITEM_TYPE_TASK,
	ITEM_TYPE_NOTE
} ItemType;

#define TYPE_ITEM_TYPE (item_type_get_type ())
typedef enum  {
	OBJECT_EVENT_TYPE_INSERT,
	OBJECT_EVENT_TYPE_UPDATE
} ObjectEventType;

#define TYPE_OBJECT_EVENT_TYPE (object_event_type_get_type ())
typedef enum  {
	OBJECT_EVENT_KEY_TYPE_CONTENT,
	OBJECT_EVENT_KEY_TYPE_DESCRIPTION,
	OBJECT_EVENT_KEY_TYPE_DUE,
	OBJECT_EVENT_KEY_TYPE_PRIORITY,
	OBJECT_EVENT_KEY_TYPE_LABELS,
	OBJECT_EVENT_KEY_TYPE_PINNED,
	OBJECT_EVENT_KEY_TYPE_CHECKED,
	OBJECT_EVENT_KEY_TYPE_PROJECT,
	OBJECT_EVENT_KEY_TYPE_SECTION,
	OBJECT_EVENT_KEY_TYPE_DEADLINE,
	OBJECT_EVENT_KEY_TYPE_PARENT
} ObjectEventKeyType;

#define TYPE_OBJECT_EVENT_KEY_TYPE (object_event_key_type_get_type ())
typedef enum  {
	LABEL_PICKER_TYPE_FILTER_AND_CREATE,
	LABEL_PICKER_TYPE_FILTER_ONLY
} LabelPickerType;

#define TYPE_LABEL_PICKER_TYPE (label_picker_type_get_type ())
typedef enum  {
	ITEM_PRIORITY_HIGHT = 4,
	ITEM_PRIORITY_MEDIUM = 3,
	ITEM_PRIORITY_LOW = 2,
	ITEM_PRIORITY_NONE = 1
} ItemPriority;

#define TYPE_ITEM_PRIORITY (item_priority_get_type ())
typedef enum  {
	SORT_ORDER_TYPE_ASC,
	SORT_ORDER_TYPE_DESC
} SortOrderType;

#define TYPE_SORT_ORDER_TYPE (sort_order_type_get_type ())
typedef enum  {
	SORTED_BY_TYPE_MANUAL,
	SORTED_BY_TYPE_NAME,
	SORTED_BY_TYPE_DUE_DATE,
	SORTED_BY_TYPE_ADDED_DATE,
	SORTED_BY_TYPE_UPDATED_DATE,
	SORTED_BY_TYPE_PRIORITY
} SortedByType;

#define TYPE_SORTED_BY_TYPE (sorted_by_type_get_type ())
typedef enum  {
	APPEARANCE_LIGHT,
	APPEARANCE_DARK,
	APPEARANCE_DARK_BLUE
} Appearance;

#define TYPE_APPEARANCE (appearance_get_type ())
typedef enum  {
	SYNC_ERROR_TYPE_AUTH_EXPIRED,
	SYNC_ERROR_TYPE_SERVER_ERROR,
	SYNC_ERROR_TYPE_NETWORK_ERROR
} SyncErrorType;

#define TYPE_SYNC_ERROR_TYPE (sync_error_type_get_type ())

#define TYPE_SYNC_STATUS (sync_status_get_type ())
#define SYNC_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SYNC_STATUS, SyncStatus))
#define SYNC_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SYNC_STATUS, SyncStatusClass))
#define IS_SYNC_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SYNC_STATUS))
#define IS_SYNC_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SYNC_STATUS))
#define SYNC_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SYNC_STATUS, SyncStatusClass))

typedef struct _SyncStatus SyncStatus;
typedef struct _SyncStatusClass SyncStatusClass;
typedef struct _SyncStatusPrivate SyncStatusPrivate;
typedef enum  {
	MARKDOWN_SETTING_GLOBAL_DEFAULT,
	MARKDOWN_SETTING_ENABLED,
	MARKDOWN_SETTING_DISABLED
} MarkdownSetting;

#define TYPE_MARKDOWN_SETTING (markdown_setting_get_type ())

#define LAYOUTS_TYPE_QUICK_ADD_CORE (layouts_quick_add_core_get_type ())
#define LAYOUTS_QUICK_ADD_CORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LAYOUTS_TYPE_QUICK_ADD_CORE, LayoutsQuickAddCore))
#define LAYOUTS_QUICK_ADD_CORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LAYOUTS_TYPE_QUICK_ADD_CORE, LayoutsQuickAddCoreClass))
#define LAYOUTS_IS_QUICK_ADD_CORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LAYOUTS_TYPE_QUICK_ADD_CORE))
#define LAYOUTS_IS_QUICK_ADD_CORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LAYOUTS_TYPE_QUICK_ADD_CORE))
#define LAYOUTS_QUICK_ADD_CORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LAYOUTS_TYPE_QUICK_ADD_CORE, LayoutsQuickAddCoreClass))

typedef struct _LayoutsQuickAddCore LayoutsQuickAddCore;
typedef struct _LayoutsQuickAddCoreClass LayoutsQuickAddCoreClass;
typedef struct _LayoutsQuickAddCorePrivate LayoutsQuickAddCorePrivate;
typedef enum  {
	LAYOUTS_QUICK_ADD_CORE_FOCUSED_WIDGET_CONTENT_ENTRY,
	LAYOUTS_QUICK_ADD_CORE_FOCUSED_WIDGET_DESCRIPTION_TEXTVIEW
} LayoutsQuickAddCoreFocusedWidget;

#define LAYOUTS_QUICK_ADD_CORE_TYPE_FOCUSED_WIDGET (layouts_quick_add_core_focused_widget_get_type ())

#define OBJECTS_TYPE_DUE_DATE (objects_due_date_get_type ())
#define OBJECTS_DUE_DATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_TYPE_DUE_DATE, ObjectsDueDate))
#define OBJECTS_DUE_DATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_TYPE_DUE_DATE, ObjectsDueDateClass))
#define OBJECTS_IS_DUE_DATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_TYPE_DUE_DATE))
#define OBJECTS_IS_DUE_DATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_TYPE_DUE_DATE))
#define OBJECTS_DUE_DATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_TYPE_DUE_DATE, ObjectsDueDateClass))

typedef struct _ObjectsDueDate ObjectsDueDate;
typedef struct _ObjectsDueDateClass ObjectsDueDateClass;

#define OBJECTS_TYPE_BASE_OBJECT (objects_base_object_get_type ())
#define OBJECTS_BASE_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_TYPE_BASE_OBJECT, ObjectsBaseObject))
#define OBJECTS_BASE_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_TYPE_BASE_OBJECT, ObjectsBaseObjectClass))
#define OBJECTS_IS_BASE_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_TYPE_BASE_OBJECT))
#define OBJECTS_IS_BASE_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_TYPE_BASE_OBJECT))
#define OBJECTS_BASE_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_TYPE_BASE_OBJECT, ObjectsBaseObjectClass))

typedef struct _ObjectsBaseObject ObjectsBaseObject;
typedef struct _ObjectsBaseObjectClass ObjectsBaseObjectClass;

#define OBJECTS_TYPE_LABEL (objects_label_get_type ())
#define OBJECTS_LABEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_TYPE_LABEL, ObjectsLabel))
#define OBJECTS_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_TYPE_LABEL, ObjectsLabelClass))
#define OBJECTS_IS_LABEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_TYPE_LABEL))
#define OBJECTS_IS_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_TYPE_LABEL))
#define OBJECTS_LABEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_TYPE_LABEL, ObjectsLabelClass))

typedef struct _ObjectsLabel ObjectsLabel;
typedef struct _ObjectsLabelClass ObjectsLabelClass;

#define OBJECTS_TYPE_PROJECT (objects_project_get_type ())
#define OBJECTS_PROJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_TYPE_PROJECT, ObjectsProject))
#define OBJECTS_PROJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_TYPE_PROJECT, ObjectsProjectClass))
#define OBJECTS_IS_PROJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_TYPE_PROJECT))
#define OBJECTS_IS_PROJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_TYPE_PROJECT))
#define OBJECTS_PROJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_TYPE_PROJECT, ObjectsProjectClass))

typedef struct _ObjectsProject ObjectsProject;
typedef struct _ObjectsProjectClass ObjectsProjectClass;

#define OBJECTS_TYPE_SECTION (objects_section_get_type ())
#define OBJECTS_SECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_TYPE_SECTION, ObjectsSection))
#define OBJECTS_SECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_TYPE_SECTION, ObjectsSectionClass))
#define OBJECTS_IS_SECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_TYPE_SECTION))
#define OBJECTS_IS_SECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_TYPE_SECTION))
#define OBJECTS_SECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_TYPE_SECTION, ObjectsSectionClass))

typedef struct _ObjectsSection ObjectsSection;
typedef struct _ObjectsSectionClass ObjectsSectionClass;

#define OBJECTS_TYPE_ITEM (objects_item_get_type ())
#define OBJECTS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_TYPE_ITEM, ObjectsItem))
#define OBJECTS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_TYPE_ITEM, ObjectsItemClass))
#define OBJECTS_IS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_TYPE_ITEM))
#define OBJECTS_IS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_TYPE_ITEM))
#define OBJECTS_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_TYPE_ITEM, ObjectsItemClass))

typedef struct _ObjectsItem ObjectsItem;
typedef struct _ObjectsItemClass ObjectsItemClass;

#define TYPE_UTIL (util_get_type ())
#define UTIL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_UTIL, Util))
#define UTIL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_UTIL, UtilClass))
#define IS_UTIL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_UTIL))
#define IS_UTIL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_UTIL))
#define UTIL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_UTIL, UtilClass))

typedef struct _Util Util;
typedef struct _UtilClass UtilClass;
typedef struct _UtilPrivate UtilPrivate;

#define OBJECTS_TYPE_COLOR (objects_color_get_type ())
#define OBJECTS_COLOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_TYPE_COLOR, ObjectsColor))
#define OBJECTS_COLOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_TYPE_COLOR, ObjectsColorClass))
#define OBJECTS_IS_COLOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_TYPE_COLOR))
#define OBJECTS_IS_COLOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_TYPE_COLOR))
#define OBJECTS_COLOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_TYPE_COLOR, ObjectsColorClass))

typedef struct _ObjectsColor ObjectsColor;
typedef struct _ObjectsColorClass ObjectsColorClass;

#define OBJECTS_TYPE_SOURCE (objects_source_get_type ())
#define OBJECTS_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_TYPE_SOURCE, ObjectsSource))
#define OBJECTS_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_TYPE_SOURCE, ObjectsSourceClass))
#define OBJECTS_IS_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_TYPE_SOURCE))
#define OBJECTS_IS_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_TYPE_SOURCE))
#define OBJECTS_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_TYPE_SOURCE, ObjectsSourceClass))

typedef struct _ObjectsSource ObjectsSource;
typedef struct _ObjectsSourceClass ObjectsSourceClass;

#define UTILS_TYPE_DATETIME (utils_datetime_get_type ())
#define UTILS_DATETIME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), UTILS_TYPE_DATETIME, UtilsDatetime))
#define UTILS_DATETIME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), UTILS_TYPE_DATETIME, UtilsDatetimeClass))
#define UTILS_IS_DATETIME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), UTILS_TYPE_DATETIME))
#define UTILS_IS_DATETIME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), UTILS_TYPE_DATETIME))
#define UTILS_DATETIME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), UTILS_TYPE_DATETIME, UtilsDatetimeClass))

typedef struct _UtilsDatetime UtilsDatetime;
typedef struct _UtilsDatetimeClass UtilsDatetimeClass;
typedef struct _UtilsDatetimePrivate UtilsDatetimePrivate;

#define TYPE_MARKDOWN_PROCESSOR (markdown_processor_get_type ())
#define MARKDOWN_PROCESSOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MARKDOWN_PROCESSOR, MarkdownProcessor))
#define MARKDOWN_PROCESSOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MARKDOWN_PROCESSOR, MarkdownProcessorClass))
#define IS_MARKDOWN_PROCESSOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MARKDOWN_PROCESSOR))
#define IS_MARKDOWN_PROCESSOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MARKDOWN_PROCESSOR))
#define MARKDOWN_PROCESSOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MARKDOWN_PROCESSOR, MarkdownProcessorClass))

typedef struct _MarkdownProcessor MarkdownProcessor;
typedef struct _MarkdownProcessorClass MarkdownProcessorClass;
typedef struct _MarkdownProcessorPrivate MarkdownProcessorPrivate;

#define UTILS_TYPE_JSON_UTILS (utils_json_utils_get_type ())
#define UTILS_JSON_UTILS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), UTILS_TYPE_JSON_UTILS, UtilsJsonUtils))
#define UTILS_JSON_UTILS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), UTILS_TYPE_JSON_UTILS, UtilsJsonUtilsClass))
#define UTILS_IS_JSON_UTILS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), UTILS_TYPE_JSON_UTILS))
#define UTILS_IS_JSON_UTILS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), UTILS_TYPE_JSON_UTILS))
#define UTILS_JSON_UTILS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), UTILS_TYPE_JSON_UTILS, UtilsJsonUtilsClass))

typedef struct _UtilsJsonUtils UtilsJsonUtils;
typedef struct _UtilsJsonUtilsClass UtilsJsonUtilsClass;
typedef struct _UtilsJsonUtilsPrivate UtilsJsonUtilsPrivate;

#define SERVICES_TYPE_SETTINGS (services_settings_get_type ())
#define SERVICES_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_TYPE_SETTINGS, ServicesSettings))
#define SERVICES_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_TYPE_SETTINGS, ServicesSettingsClass))
#define SERVICES_IS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_TYPE_SETTINGS))
#define SERVICES_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_TYPE_SETTINGS))
#define SERVICES_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_TYPE_SETTINGS, ServicesSettingsClass))

typedef struct _ServicesSettings ServicesSettings;
typedef struct _ServicesSettingsClass ServicesSettingsClass;
typedef struct _ServicesSettingsPrivate ServicesSettingsPrivate;

#define SERVICES_TYPE_EVENT_BUS (services_event_bus_get_type ())
#define SERVICES_EVENT_BUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_TYPE_EVENT_BUS, ServicesEventBus))
#define SERVICES_EVENT_BUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_TYPE_EVENT_BUS, ServicesEventBusClass))
#define SERVICES_IS_EVENT_BUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_TYPE_EVENT_BUS))
#define SERVICES_IS_EVENT_BUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_TYPE_EVENT_BUS))
#define SERVICES_EVENT_BUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_TYPE_EVENT_BUS, ServicesEventBusClass))

typedef struct _ServicesEventBus ServicesEventBus;
typedef struct _ServicesEventBusClass ServicesEventBusClass;
typedef struct _ServicesEventBusPrivate ServicesEventBusPrivate;

#define SERVICES_TYPE_DATABASE (services_database_get_type ())
#define SERVICES_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_TYPE_DATABASE, ServicesDatabase))
#define SERVICES_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_TYPE_DATABASE, ServicesDatabaseClass))
#define SERVICES_IS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_TYPE_DATABASE))
#define SERVICES_IS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_TYPE_DATABASE))
#define SERVICES_DATABASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_TYPE_DATABASE, ServicesDatabaseClass))

typedef struct _ServicesDatabase ServicesDatabase;
typedef struct _ServicesDatabaseClass ServicesDatabaseClass;
typedef struct _ServicesDatabasePrivate ServicesDatabasePrivate;

#define OBJECTS_TYPE_REMINDER (objects_reminder_get_type ())
#define OBJECTS_REMINDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_TYPE_REMINDER, ObjectsReminder))
#define OBJECTS_REMINDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_TYPE_REMINDER, ObjectsReminderClass))
#define OBJECTS_IS_REMINDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_TYPE_REMINDER))
#define OBJECTS_IS_REMINDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_TYPE_REMINDER))
#define OBJECTS_REMINDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_TYPE_REMINDER, ObjectsReminderClass))

typedef struct _ObjectsReminder ObjectsReminder;
typedef struct _ObjectsReminderClass ObjectsReminderClass;

#define OBJECTS_TYPE_ATTACHMENT (objects_attachment_get_type ())
#define OBJECTS_ATTACHMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_TYPE_ATTACHMENT, ObjectsAttachment))
#define OBJECTS_ATTACHMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_TYPE_ATTACHMENT, ObjectsAttachmentClass))
#define OBJECTS_IS_ATTACHMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_TYPE_ATTACHMENT))
#define OBJECTS_IS_ATTACHMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_TYPE_ATTACHMENT))
#define OBJECTS_ATTACHMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_TYPE_ATTACHMENT, ObjectsAttachmentClass))

typedef struct _ObjectsAttachment ObjectsAttachment;
typedef struct _ObjectsAttachmentClass ObjectsAttachmentClass;

#define OBJECTS_TYPE_QUEUE (objects_queue_get_type ())
#define OBJECTS_QUEUE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_TYPE_QUEUE, ObjectsQueue))
#define OBJECTS_QUEUE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_TYPE_QUEUE, ObjectsQueueClass))
#define OBJECTS_IS_QUEUE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_TYPE_QUEUE))
#define OBJECTS_IS_QUEUE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_TYPE_QUEUE))
#define OBJECTS_QUEUE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_TYPE_QUEUE, ObjectsQueueClass))

typedef struct _ObjectsQueue ObjectsQueue;
typedef struct _ObjectsQueueClass ObjectsQueueClass;

#define OBJECTS_TYPE_OBJECT_EVENT (objects_object_event_get_type ())
#define OBJECTS_OBJECT_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_TYPE_OBJECT_EVENT, ObjectsObjectEvent))
#define OBJECTS_OBJECT_EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_TYPE_OBJECT_EVENT, ObjectsObjectEventClass))
#define OBJECTS_IS_OBJECT_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_TYPE_OBJECT_EVENT))
#define OBJECTS_IS_OBJECT_EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_TYPE_OBJECT_EVENT))
#define OBJECTS_OBJECT_EVENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_TYPE_OBJECT_EVENT, ObjectsObjectEventClass))

typedef struct _ObjectsObjectEvent ObjectsObjectEvent;
typedef struct _ObjectsObjectEventClass ObjectsObjectEventClass;

#define SERVICES_TYPE_LOG_SERVICE (services_log_service_get_type ())
#define SERVICES_LOG_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_TYPE_LOG_SERVICE, ServicesLogService))
#define SERVICES_LOG_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_TYPE_LOG_SERVICE, ServicesLogServiceClass))
#define SERVICES_IS_LOG_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_TYPE_LOG_SERVICE))
#define SERVICES_IS_LOG_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_TYPE_LOG_SERVICE))
#define SERVICES_LOG_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_TYPE_LOG_SERVICE, ServicesLogServiceClass))

typedef struct _ServicesLogService ServicesLogService;
typedef struct _ServicesLogServiceClass ServicesLogServiceClass;
typedef struct _ServicesLogServicePrivate ServicesLogServicePrivate;
typedef enum  {
	SERVICES_LOG_SERVICE_LEVEL_DEBUG,
	SERVICES_LOG_SERVICE_LEVEL_INFO,
	SERVICES_LOG_SERVICE_LEVEL_WARNING,
	SERVICES_LOG_SERVICE_LEVEL_ERROR
} ServicesLogServiceLevel;

#define SERVICES_LOG_SERVICE_TYPE_LEVEL (services_log_service_level_get_type ())

#define SERVICES_TYPE_STORE (services_store_get_type ())
#define SERVICES_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_TYPE_STORE, ServicesStore))
#define SERVICES_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_TYPE_STORE, ServicesStoreClass))
#define SERVICES_IS_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_TYPE_STORE))
#define SERVICES_IS_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_TYPE_STORE))
#define SERVICES_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_TYPE_STORE, ServicesStoreClass))

typedef struct _ServicesStore ServicesStore;
typedef struct _ServicesStoreClass ServicesStoreClass;
typedef struct _ServicesStorePrivate ServicesStorePrivate;

#define SERVICES_TYPE_TODOIST (services_todoist_get_type ())
#define SERVICES_TODOIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_TYPE_TODOIST, ServicesTodoist))
#define SERVICES_TODOIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_TYPE_TODOIST, ServicesTodoistClass))
#define SERVICES_IS_TODOIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_TYPE_TODOIST))
#define SERVICES_IS_TODOIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_TYPE_TODOIST))
#define SERVICES_TODOIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_TYPE_TODOIST, ServicesTodoistClass))

typedef struct _ServicesTodoist ServicesTodoist;
typedef struct _ServicesTodoistClass ServicesTodoistClass;
typedef struct _ServicesTodoistPrivate ServicesTodoistPrivate;

#define TYPE_HTTP_RESPONSE (http_response_get_type ())
#define HTTP_RESPONSE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_HTTP_RESPONSE, HttpResponse))
#define HTTP_RESPONSE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_HTTP_RESPONSE, HttpResponseClass))
#define IS_HTTP_RESPONSE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_HTTP_RESPONSE))
#define IS_HTTP_RESPONSE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_HTTP_RESPONSE))
#define HTTP_RESPONSE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_HTTP_RESPONSE, HttpResponseClass))

typedef struct _HttpResponse HttpResponse;
typedef struct _HttpResponseClass HttpResponseClass;
typedef struct _HttpResponsePrivate HttpResponsePrivate;

#define SERVICES_TYPE_TODOIST_AUTH (services_todoist_auth_get_type ())
#define SERVICES_TODOIST_AUTH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_TYPE_TODOIST_AUTH, ServicesTodoistAuth))
#define SERVICES_TODOIST_AUTH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_TYPE_TODOIST_AUTH, ServicesTodoistAuthClass))
#define SERVICES_IS_TODOIST_AUTH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_TYPE_TODOIST_AUTH))
#define SERVICES_IS_TODOIST_AUTH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_TYPE_TODOIST_AUTH))
#define SERVICES_TODOIST_AUTH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_TYPE_TODOIST_AUTH, ServicesTodoistAuthClass))

typedef struct _ServicesTodoistAuth ServicesTodoistAuth;
typedef struct _ServicesTodoistAuthClass ServicesTodoistAuthClass;
typedef struct _ServicesTodoistAuthPrivate ServicesTodoistAuthPrivate;

#define SERVICES_TYPE_TODOIST_ITEMS (services_todoist_items_get_type ())
#define SERVICES_TODOIST_ITEMS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_TYPE_TODOIST_ITEMS, ServicesTodoistItems))
#define SERVICES_TODOIST_ITEMS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_TYPE_TODOIST_ITEMS, ServicesTodoistItemsClass))
#define SERVICES_IS_TODOIST_ITEMS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_TYPE_TODOIST_ITEMS))
#define SERVICES_IS_TODOIST_ITEMS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_TYPE_TODOIST_ITEMS))
#define SERVICES_TODOIST_ITEMS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_TYPE_TODOIST_ITEMS, ServicesTodoistItemsClass))

typedef struct _ServicesTodoistItems ServicesTodoistItems;
typedef struct _ServicesTodoistItemsClass ServicesTodoistItemsClass;
typedef struct _ServicesTodoistItemsPrivate ServicesTodoistItemsPrivate;

#define SERVICES_TYPE_TODOIST_PROJECTS (services_todoist_projects_get_type ())
#define SERVICES_TODOIST_PROJECTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_TYPE_TODOIST_PROJECTS, ServicesTodoistProjects))
#define SERVICES_TODOIST_PROJECTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_TYPE_TODOIST_PROJECTS, ServicesTodoistProjectsClass))
#define SERVICES_IS_TODOIST_PROJECTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_TYPE_TODOIST_PROJECTS))
#define SERVICES_IS_TODOIST_PROJECTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_TYPE_TODOIST_PROJECTS))
#define SERVICES_TODOIST_PROJECTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_TYPE_TODOIST_PROJECTS, ServicesTodoistProjectsClass))

typedef struct _ServicesTodoistProjects ServicesTodoistProjects;
typedef struct _ServicesTodoistProjectsClass ServicesTodoistProjectsClass;
typedef struct _ServicesTodoistProjectsPrivate ServicesTodoistProjectsPrivate;

#define SERVICES_TYPE_BACKUP_EXPORTER (services_backup_exporter_get_type ())
#define SERVICES_BACKUP_EXPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_TYPE_BACKUP_EXPORTER, ServicesBackupExporter))
#define SERVICES_BACKUP_EXPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_TYPE_BACKUP_EXPORTER, ServicesBackupExporterClass))
#define SERVICES_IS_BACKUP_EXPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_TYPE_BACKUP_EXPORTER))
#define SERVICES_IS_BACKUP_EXPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_TYPE_BACKUP_EXPORTER))
#define SERVICES_BACKUP_EXPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_TYPE_BACKUP_EXPORTER, ServicesBackupExporterClass))

typedef struct _ServicesBackupExporter ServicesBackupExporter;
typedef struct _ServicesBackupExporterClass ServicesBackupExporterClass;
typedef struct _ServicesBackupExporterPrivate ServicesBackupExporterPrivate;

#define COLOR_SCHEME_SETTINGS_TYPE_SETTINGS (color_scheme_settings_settings_get_type ())
#define COLOR_SCHEME_SETTINGS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), COLOR_SCHEME_SETTINGS_TYPE_SETTINGS, ColorSchemeSettingsSettings))
#define COLOR_SCHEME_SETTINGS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), COLOR_SCHEME_SETTINGS_TYPE_SETTINGS, ColorSchemeSettingsSettingsClass))
#define COLOR_SCHEME_SETTINGS_IS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), COLOR_SCHEME_SETTINGS_TYPE_SETTINGS))
#define COLOR_SCHEME_SETTINGS_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), COLOR_SCHEME_SETTINGS_TYPE_SETTINGS))
#define COLOR_SCHEME_SETTINGS_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), COLOR_SCHEME_SETTINGS_TYPE_SETTINGS, ColorSchemeSettingsSettingsClass))

typedef struct _ColorSchemeSettingsSettings ColorSchemeSettingsSettings;
typedef struct _ColorSchemeSettingsSettingsClass ColorSchemeSettingsSettingsClass;
typedef struct _ColorSchemeSettingsSettingsPrivate ColorSchemeSettingsSettingsPrivate;
typedef enum  {
	COLOR_SCHEME_SETTINGS_SETTINGS_COLOR_SCHEME_NO_PREFERENCE,
	COLOR_SCHEME_SETTINGS_SETTINGS_COLOR_SCHEME_DARK,
	COLOR_SCHEME_SETTINGS_SETTINGS_COLOR_SCHEME_LIGHT
} ColorSchemeSettingsSettingsColorScheme;

#define COLOR_SCHEME_SETTINGS_SETTINGS_TYPE_COLOR_SCHEME (color_scheme_settings_settings_color_scheme_get_type ())

#define SERVICES_CAL_DAV_TYPE_CORE (services_cal_dav_core_get_type ())
#define SERVICES_CAL_DAV_CORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_CAL_DAV_TYPE_CORE, ServicesCalDAVCore))
#define SERVICES_CAL_DAV_CORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_CAL_DAV_TYPE_CORE, ServicesCalDAVCoreClass))
#define SERVICES_CAL_DAV_IS_CORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_CAL_DAV_TYPE_CORE))
#define SERVICES_CAL_DAV_IS_CORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_CAL_DAV_TYPE_CORE))
#define SERVICES_CAL_DAV_CORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_CAL_DAV_TYPE_CORE, ServicesCalDAVCoreClass))

typedef struct _ServicesCalDAVCore ServicesCalDAVCore;
typedef struct _ServicesCalDAVCoreClass ServicesCalDAVCoreClass;
typedef struct _ServicesCalDAVCorePrivate ServicesCalDAVCorePrivate;

#define SERVICES_CAL_DAV_TYPE_WEB_DAV_CLIENT (services_cal_dav_web_dav_client_get_type ())
#define SERVICES_CAL_DAV_WEB_DAV_CLIENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_CAL_DAV_TYPE_WEB_DAV_CLIENT, ServicesCalDAVWebDAVClient))
#define SERVICES_CAL_DAV_WEB_DAV_CLIENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_CAL_DAV_TYPE_WEB_DAV_CLIENT, ServicesCalDAVWebDAVClientClass))
#define SERVICES_CAL_DAV_IS_WEB_DAV_CLIENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_CAL_DAV_TYPE_WEB_DAV_CLIENT))
#define SERVICES_CAL_DAV_IS_WEB_DAV_CLIENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_CAL_DAV_TYPE_WEB_DAV_CLIENT))
#define SERVICES_CAL_DAV_WEB_DAV_CLIENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_CAL_DAV_TYPE_WEB_DAV_CLIENT, ServicesCalDAVWebDAVClientClass))

typedef struct _ServicesCalDAVWebDAVClient ServicesCalDAVWebDAVClient;
typedef struct _ServicesCalDAVWebDAVClientClass ServicesCalDAVWebDAVClientClass;

#define SERVICES_CAL_DAV_TYPE_CAL_DAV_CLIENT (services_cal_dav_cal_dav_client_get_type ())
#define SERVICES_CAL_DAV_CAL_DAV_CLIENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_CAL_DAV_TYPE_CAL_DAV_CLIENT, ServicesCalDAVCalDAVClient))
#define SERVICES_CAL_DAV_CAL_DAV_CLIENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_CAL_DAV_TYPE_CAL_DAV_CLIENT, ServicesCalDAVCalDAVClientClass))
#define SERVICES_CAL_DAV_IS_CAL_DAV_CLIENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_CAL_DAV_TYPE_CAL_DAV_CLIENT))
#define SERVICES_CAL_DAV_IS_CAL_DAV_CLIENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_CAL_DAV_TYPE_CAL_DAV_CLIENT))
#define SERVICES_CAL_DAV_CAL_DAV_CLIENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_CAL_DAV_TYPE_CAL_DAV_CLIENT, ServicesCalDAVCalDAVClientClass))

typedef struct _ServicesCalDAVCalDAVClient ServicesCalDAVCalDAVClient;
typedef struct _ServicesCalDAVCalDAVClientClass ServicesCalDAVCalDAVClientClass;
typedef struct _ServicesCalDAVWebDAVClientPrivate ServicesCalDAVWebDAVClientPrivate;
typedef struct _ServicesCalDAVCalDAVClientPrivate ServicesCalDAVCalDAVClientPrivate;
typedef void (*ServicesCalDAVCalDAVClientProgressCallback) (gint current, gint total, const gchar* message, gpointer user_data);

#define SERVICES_CAL_DAV_TYPE_WEB_DAV_MULTI_STATUS (services_cal_dav_web_dav_multi_status_get_type ())
#define SERVICES_CAL_DAV_WEB_DAV_MULTI_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_CAL_DAV_TYPE_WEB_DAV_MULTI_STATUS, ServicesCalDAVWebDAVMultiStatus))
#define SERVICES_CAL_DAV_WEB_DAV_MULTI_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_CAL_DAV_TYPE_WEB_DAV_MULTI_STATUS, ServicesCalDAVWebDAVMultiStatusClass))
#define SERVICES_CAL_DAV_IS_WEB_DAV_MULTI_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_CAL_DAV_TYPE_WEB_DAV_MULTI_STATUS))
#define SERVICES_CAL_DAV_IS_WEB_DAV_MULTI_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_CAL_DAV_TYPE_WEB_DAV_MULTI_STATUS))
#define SERVICES_CAL_DAV_WEB_DAV_MULTI_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_CAL_DAV_TYPE_WEB_DAV_MULTI_STATUS, ServicesCalDAVWebDAVMultiStatusClass))

typedef struct _ServicesCalDAVWebDAVMultiStatus ServicesCalDAVWebDAVMultiStatus;
typedef struct _ServicesCalDAVWebDAVMultiStatusClass ServicesCalDAVWebDAVMultiStatusClass;
typedef struct _ServicesCalDAVWebDAVMultiStatusPrivate ServicesCalDAVWebDAVMultiStatusPrivate;

#define SERVICES_CAL_DAV_TYPE_WEB_DAV_RESPONSE (services_cal_dav_web_dav_response_get_type ())
#define SERVICES_CAL_DAV_WEB_DAV_RESPONSE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_CAL_DAV_TYPE_WEB_DAV_RESPONSE, ServicesCalDAVWebDAVResponse))
#define SERVICES_CAL_DAV_WEB_DAV_RESPONSE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_CAL_DAV_TYPE_WEB_DAV_RESPONSE, ServicesCalDAVWebDAVResponseClass))
#define SERVICES_CAL_DAV_IS_WEB_DAV_RESPONSE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_CAL_DAV_TYPE_WEB_DAV_RESPONSE))
#define SERVICES_CAL_DAV_IS_WEB_DAV_RESPONSE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_CAL_DAV_TYPE_WEB_DAV_RESPONSE))
#define SERVICES_CAL_DAV_WEB_DAV_RESPONSE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_CAL_DAV_TYPE_WEB_DAV_RESPONSE, ServicesCalDAVWebDAVResponseClass))

typedef struct _ServicesCalDAVWebDAVResponse ServicesCalDAVWebDAVResponse;
typedef struct _ServicesCalDAVWebDAVResponseClass ServicesCalDAVWebDAVResponseClass;
typedef struct _ServicesCalDAVWebDAVResponsePrivate ServicesCalDAVWebDAVResponsePrivate;

#define SERVICES_CAL_DAV_TYPE_WEB_DAV_PROP_STAT (services_cal_dav_web_dav_prop_stat_get_type ())
#define SERVICES_CAL_DAV_WEB_DAV_PROP_STAT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_CAL_DAV_TYPE_WEB_DAV_PROP_STAT, ServicesCalDAVWebDAVPropStat))
#define SERVICES_CAL_DAV_WEB_DAV_PROP_STAT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_CAL_DAV_TYPE_WEB_DAV_PROP_STAT, ServicesCalDAVWebDAVPropStatClass))
#define SERVICES_CAL_DAV_IS_WEB_DAV_PROP_STAT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_CAL_DAV_TYPE_WEB_DAV_PROP_STAT))
#define SERVICES_CAL_DAV_IS_WEB_DAV_PROP_STAT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_CAL_DAV_TYPE_WEB_DAV_PROP_STAT))
#define SERVICES_CAL_DAV_WEB_DAV_PROP_STAT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_CAL_DAV_TYPE_WEB_DAV_PROP_STAT, ServicesCalDAVWebDAVPropStatClass))

typedef struct _ServicesCalDAVWebDAVPropStat ServicesCalDAVWebDAVPropStat;
typedef struct _ServicesCalDAVWebDAVPropStatClass ServicesCalDAVWebDAVPropStatClass;
typedef struct _ServicesCalDAVWebDAVPropStatPrivate ServicesCalDAVWebDAVPropStatPrivate;

#define SERVICES_CAL_DAV_PROVIDERS_TYPE_NEXTCLOUD (services_cal_dav_providers_nextcloud_get_type ())
#define SERVICES_CAL_DAV_PROVIDERS_NEXTCLOUD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_CAL_DAV_PROVIDERS_TYPE_NEXTCLOUD, ServicesCalDAVProvidersNextcloud))
#define SERVICES_CAL_DAV_PROVIDERS_NEXTCLOUD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_CAL_DAV_PROVIDERS_TYPE_NEXTCLOUD, ServicesCalDAVProvidersNextcloudClass))
#define SERVICES_CAL_DAV_PROVIDERS_IS_NEXTCLOUD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_CAL_DAV_PROVIDERS_TYPE_NEXTCLOUD))
#define SERVICES_CAL_DAV_PROVIDERS_IS_NEXTCLOUD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_CAL_DAV_PROVIDERS_TYPE_NEXTCLOUD))
#define SERVICES_CAL_DAV_PROVIDERS_NEXTCLOUD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_CAL_DAV_PROVIDERS_TYPE_NEXTCLOUD, ServicesCalDAVProvidersNextcloudClass))

typedef struct _ServicesCalDAVProvidersNextcloud ServicesCalDAVProvidersNextcloud;
typedef struct _ServicesCalDAVProvidersNextcloudClass ServicesCalDAVProvidersNextcloudClass;
typedef struct _ServicesCalDAVProvidersNextcloudPrivate ServicesCalDAVProvidersNextcloudPrivate;

#define LAYOUTS_TYPE_HEADER_ITEM (layouts_header_item_get_type ())
#define LAYOUTS_HEADER_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LAYOUTS_TYPE_HEADER_ITEM, LayoutsHeaderItem))
#define LAYOUTS_HEADER_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LAYOUTS_TYPE_HEADER_ITEM, LayoutsHeaderItemClass))
#define LAYOUTS_IS_HEADER_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LAYOUTS_TYPE_HEADER_ITEM))
#define LAYOUTS_IS_HEADER_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LAYOUTS_TYPE_HEADER_ITEM))
#define LAYOUTS_HEADER_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LAYOUTS_TYPE_HEADER_ITEM, LayoutsHeaderItemClass))

typedef struct _LayoutsHeaderItem LayoutsHeaderItem;
typedef struct _LayoutsHeaderItemClass LayoutsHeaderItemClass;
typedef struct _LayoutsHeaderItemPrivate LayoutsHeaderItemPrivate;

#define WIDGETS_TYPE_LOADING_BUTTON (widgets_loading_button_get_type ())
#define WIDGETS_LOADING_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_LOADING_BUTTON, WidgetsLoadingButton))
#define WIDGETS_LOADING_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_LOADING_BUTTON, WidgetsLoadingButtonClass))
#define WIDGETS_IS_LOADING_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_LOADING_BUTTON))
#define WIDGETS_IS_LOADING_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_LOADING_BUTTON))
#define WIDGETS_LOADING_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_LOADING_BUTTON, WidgetsLoadingButtonClass))

typedef struct _WidgetsLoadingButton WidgetsLoadingButton;
typedef struct _WidgetsLoadingButtonClass WidgetsLoadingButtonClass;
typedef struct _WidgetsLoadingButtonPrivate WidgetsLoadingButtonPrivate;

#define WIDGETS_TYPE_TEXT_VIEW (widgets_text_view_get_type ())
#define WIDGETS_TEXT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_TEXT_VIEW, WidgetsTextView))
#define WIDGETS_TEXT_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_TEXT_VIEW, WidgetsTextViewClass))
#define WIDGETS_IS_TEXT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_TEXT_VIEW))
#define WIDGETS_IS_TEXT_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_TEXT_VIEW))
#define WIDGETS_TEXT_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_TEXT_VIEW, WidgetsTextViewClass))

typedef struct _WidgetsTextView WidgetsTextView;
typedef struct _WidgetsTextViewClass WidgetsTextViewClass;
typedef struct _WidgetsTextViewPrivate WidgetsTextViewPrivate;

#define WIDGETS_TYPE_ICON_COLOR_PROJECT (widgets_icon_color_project_get_type ())
#define WIDGETS_ICON_COLOR_PROJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_ICON_COLOR_PROJECT, WidgetsIconColorProject))
#define WIDGETS_ICON_COLOR_PROJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_ICON_COLOR_PROJECT, WidgetsIconColorProjectClass))
#define WIDGETS_IS_ICON_COLOR_PROJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_ICON_COLOR_PROJECT))
#define WIDGETS_IS_ICON_COLOR_PROJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_ICON_COLOR_PROJECT))
#define WIDGETS_ICON_COLOR_PROJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_ICON_COLOR_PROJECT, WidgetsIconColorProjectClass))

typedef struct _WidgetsIconColorProject WidgetsIconColorProject;
typedef struct _WidgetsIconColorProjectClass WidgetsIconColorProjectClass;
typedef struct _WidgetsIconColorProjectPrivate WidgetsIconColorProjectPrivate;

#define WIDGETS_TYPE_PIN_BUTTON (widgets_pin_button_get_type ())
#define WIDGETS_PIN_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_PIN_BUTTON, WidgetsPinButton))
#define WIDGETS_PIN_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_PIN_BUTTON, WidgetsPinButtonClass))
#define WIDGETS_IS_PIN_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_PIN_BUTTON))
#define WIDGETS_IS_PIN_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_PIN_BUTTON))
#define WIDGETS_PIN_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_PIN_BUTTON, WidgetsPinButtonClass))

typedef struct _WidgetsPinButton WidgetsPinButton;
typedef struct _WidgetsPinButtonClass WidgetsPinButtonClass;
typedef struct _WidgetsPinButtonPrivate WidgetsPinButtonPrivate;

#define WIDGETS_TYPE_PRIORITY_BUTTON (widgets_priority_button_get_type ())
#define WIDGETS_PRIORITY_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_PRIORITY_BUTTON, WidgetsPriorityButton))
#define WIDGETS_PRIORITY_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_PRIORITY_BUTTON, WidgetsPriorityButtonClass))
#define WIDGETS_IS_PRIORITY_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_PRIORITY_BUTTON))
#define WIDGETS_IS_PRIORITY_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_PRIORITY_BUTTON))
#define WIDGETS_PRIORITY_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_PRIORITY_BUTTON, WidgetsPriorityButtonClass))

typedef struct _WidgetsPriorityButton WidgetsPriorityButton;
typedef struct _WidgetsPriorityButtonClass WidgetsPriorityButtonClass;
typedef struct _WidgetsPriorityButtonPrivate WidgetsPriorityButtonPrivate;

#define WIDGETS_TYPE_ITEM_LABELS (widgets_item_labels_get_type ())
#define WIDGETS_ITEM_LABELS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_ITEM_LABELS, WidgetsItemLabels))
#define WIDGETS_ITEM_LABELS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_ITEM_LABELS, WidgetsItemLabelsClass))
#define WIDGETS_IS_ITEM_LABELS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_ITEM_LABELS))
#define WIDGETS_IS_ITEM_LABELS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_ITEM_LABELS))
#define WIDGETS_ITEM_LABELS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_ITEM_LABELS, WidgetsItemLabelsClass))

typedef struct _WidgetsItemLabels WidgetsItemLabels;
typedef struct _WidgetsItemLabelsClass WidgetsItemLabelsClass;
typedef struct _WidgetsItemLabelsPrivate WidgetsItemLabelsPrivate;

#define WIDGETS_TYPE_ITEM_LABEL_CHILD (widgets_item_label_child_get_type ())
#define WIDGETS_ITEM_LABEL_CHILD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_ITEM_LABEL_CHILD, WidgetsItemLabelChild))
#define WIDGETS_ITEM_LABEL_CHILD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_ITEM_LABEL_CHILD, WidgetsItemLabelChildClass))
#define WIDGETS_IS_ITEM_LABEL_CHILD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_ITEM_LABEL_CHILD))
#define WIDGETS_IS_ITEM_LABEL_CHILD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_ITEM_LABEL_CHILD))
#define WIDGETS_ITEM_LABEL_CHILD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_ITEM_LABEL_CHILD, WidgetsItemLabelChildClass))

typedef struct _WidgetsItemLabelChild WidgetsItemLabelChild;
typedef struct _WidgetsItemLabelChildClass WidgetsItemLabelChildClass;
typedef struct _WidgetsItemLabelChildPrivate WidgetsItemLabelChildPrivate;

#define WIDGETS_TYPE_CIRCULAR_PROGRESS_BAR (widgets_circular_progress_bar_get_type ())
#define WIDGETS_CIRCULAR_PROGRESS_BAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_CIRCULAR_PROGRESS_BAR, WidgetsCircularProgressBar))
#define WIDGETS_CIRCULAR_PROGRESS_BAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_CIRCULAR_PROGRESS_BAR, WidgetsCircularProgressBarClass))
#define WIDGETS_IS_CIRCULAR_PROGRESS_BAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_CIRCULAR_PROGRESS_BAR))
#define WIDGETS_IS_CIRCULAR_PROGRESS_BAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_CIRCULAR_PROGRESS_BAR))
#define WIDGETS_CIRCULAR_PROGRESS_BAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_CIRCULAR_PROGRESS_BAR, WidgetsCircularProgressBarClass))

typedef struct _WidgetsCircularProgressBar WidgetsCircularProgressBar;
typedef struct _WidgetsCircularProgressBarClass WidgetsCircularProgressBarClass;
typedef struct _WidgetsCircularProgressBarPrivate WidgetsCircularProgressBarPrivate;

#define WIDGETS_TYPE_STATUS_BUTTON (widgets_status_button_get_type ())
#define WIDGETS_STATUS_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_STATUS_BUTTON, WidgetsStatusButton))
#define WIDGETS_STATUS_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_STATUS_BUTTON, WidgetsStatusButtonClass))
#define WIDGETS_IS_STATUS_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_STATUS_BUTTON))
#define WIDGETS_IS_STATUS_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_STATUS_BUTTON))
#define WIDGETS_STATUS_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_STATUS_BUTTON, WidgetsStatusButtonClass))

typedef struct _WidgetsStatusButton WidgetsStatusButton;
typedef struct _WidgetsStatusButtonClass WidgetsStatusButtonClass;
typedef struct _WidgetsStatusButtonPrivate WidgetsStatusButtonPrivate;

#define WIDGETS_TYPE_MARKDOWN_EDITOR (widgets_markdown_editor_get_type ())
#define WIDGETS_MARKDOWN_EDITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_MARKDOWN_EDITOR, WidgetsMarkdownEditor))
#define WIDGETS_MARKDOWN_EDITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_MARKDOWN_EDITOR, WidgetsMarkdownEditorClass))
#define WIDGETS_IS_MARKDOWN_EDITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_MARKDOWN_EDITOR))
#define WIDGETS_IS_MARKDOWN_EDITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_MARKDOWN_EDITOR))
#define WIDGETS_MARKDOWN_EDITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_MARKDOWN_EDITOR, WidgetsMarkdownEditorClass))

typedef struct _WidgetsMarkdownEditor WidgetsMarkdownEditor;
typedef struct _WidgetsMarkdownEditorClass WidgetsMarkdownEditorClass;
typedef struct _WidgetsMarkdownEditorPrivate WidgetsMarkdownEditorPrivate;
typedef enum  {
	DEADLINE_BUTTON_TYPE_BUTTON,
	DEADLINE_BUTTON_TYPE_BUTTON_DETAIL,
	DEADLINE_BUTTON_TYPE_CARD
} DeadlineButtonType;

#define TYPE_DEADLINE_BUTTON_TYPE (deadline_button_type_get_type ())

#define WIDGETS_TYPE_DEADLINE_BUTTON (widgets_deadline_button_get_type ())
#define WIDGETS_DEADLINE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_DEADLINE_BUTTON, WidgetsDeadlineButton))
#define WIDGETS_DEADLINE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_DEADLINE_BUTTON, WidgetsDeadlineButtonClass))
#define WIDGETS_IS_DEADLINE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_DEADLINE_BUTTON))
#define WIDGETS_IS_DEADLINE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_DEADLINE_BUTTON))
#define WIDGETS_DEADLINE_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_DEADLINE_BUTTON, WidgetsDeadlineButtonClass))

typedef struct _WidgetsDeadlineButton WidgetsDeadlineButton;
typedef struct _WidgetsDeadlineButtonClass WidgetsDeadlineButtonClass;
typedef struct _WidgetsDeadlineButtonPrivate WidgetsDeadlineButtonPrivate;

#define WIDGETS_CALENDAR_TYPE_CALENDAR (widgets_calendar_calendar_get_type ())
#define WIDGETS_CALENDAR_CALENDAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR, WidgetsCalendarCalendar))
#define WIDGETS_CALENDAR_CALENDAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_CALENDAR_TYPE_CALENDAR, WidgetsCalendarCalendarClass))
#define WIDGETS_CALENDAR_IS_CALENDAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR))
#define WIDGETS_CALENDAR_IS_CALENDAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_CALENDAR_TYPE_CALENDAR))
#define WIDGETS_CALENDAR_CALENDAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR, WidgetsCalendarCalendarClass))

typedef struct _WidgetsCalendarCalendar WidgetsCalendarCalendar;
typedef struct _WidgetsCalendarCalendarClass WidgetsCalendarCalendarClass;
typedef struct _WidgetsCalendarCalendarPrivate WidgetsCalendarCalendarPrivate;

#define WIDGETS_CALENDAR_TYPE_CALENDAR_DAY (widgets_calendar_calendar_day_get_type ())
#define WIDGETS_CALENDAR_CALENDAR_DAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_DAY, WidgetsCalendarCalendarDay))
#define WIDGETS_CALENDAR_CALENDAR_DAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_CALENDAR_TYPE_CALENDAR_DAY, WidgetsCalendarCalendarDayClass))
#define WIDGETS_CALENDAR_IS_CALENDAR_DAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_DAY))
#define WIDGETS_CALENDAR_IS_CALENDAR_DAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_CALENDAR_TYPE_CALENDAR_DAY))
#define WIDGETS_CALENDAR_CALENDAR_DAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_DAY, WidgetsCalendarCalendarDayClass))

typedef struct _WidgetsCalendarCalendarDay WidgetsCalendarCalendarDay;
typedef struct _WidgetsCalendarCalendarDayClass WidgetsCalendarCalendarDayClass;
typedef struct _WidgetsCalendarCalendarDayPrivate WidgetsCalendarCalendarDayPrivate;

#define WIDGETS_CALENDAR_TYPE_CALENDAR_HEADER (widgets_calendar_calendar_header_get_type ())
#define WIDGETS_CALENDAR_CALENDAR_HEADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_HEADER, WidgetsCalendarCalendarHeader))
#define WIDGETS_CALENDAR_CALENDAR_HEADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_CALENDAR_TYPE_CALENDAR_HEADER, WidgetsCalendarCalendarHeaderClass))
#define WIDGETS_CALENDAR_IS_CALENDAR_HEADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_HEADER))
#define WIDGETS_CALENDAR_IS_CALENDAR_HEADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_CALENDAR_TYPE_CALENDAR_HEADER))
#define WIDGETS_CALENDAR_CALENDAR_HEADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_HEADER, WidgetsCalendarCalendarHeaderClass))

typedef struct _WidgetsCalendarCalendarHeader WidgetsCalendarCalendarHeader;
typedef struct _WidgetsCalendarCalendarHeaderClass WidgetsCalendarCalendarHeaderClass;
typedef struct _WidgetsCalendarCalendarHeaderPrivate WidgetsCalendarCalendarHeaderPrivate;

#define WIDGETS_CALENDAR_TYPE_CALENDAR_VIEW (widgets_calendar_calendar_view_get_type ())
#define WIDGETS_CALENDAR_CALENDAR_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_VIEW, WidgetsCalendarCalendarView))
#define WIDGETS_CALENDAR_CALENDAR_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_CALENDAR_TYPE_CALENDAR_VIEW, WidgetsCalendarCalendarViewClass))
#define WIDGETS_CALENDAR_IS_CALENDAR_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_VIEW))
#define WIDGETS_CALENDAR_IS_CALENDAR_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_CALENDAR_TYPE_CALENDAR_VIEW))
#define WIDGETS_CALENDAR_CALENDAR_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_VIEW, WidgetsCalendarCalendarViewClass))

typedef struct _WidgetsCalendarCalendarView WidgetsCalendarCalendarView;
typedef struct _WidgetsCalendarCalendarViewClass WidgetsCalendarCalendarViewClass;
typedef struct _WidgetsCalendarCalendarViewPrivate WidgetsCalendarCalendarViewPrivate;

#define WIDGETS_CALENDAR_TYPE_CALENDAR_WEEK (widgets_calendar_calendar_week_get_type ())
#define WIDGETS_CALENDAR_CALENDAR_WEEK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_WEEK, WidgetsCalendarCalendarWeek))
#define WIDGETS_CALENDAR_CALENDAR_WEEK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_CALENDAR_TYPE_CALENDAR_WEEK, WidgetsCalendarCalendarWeekClass))
#define WIDGETS_CALENDAR_IS_CALENDAR_WEEK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_WEEK))
#define WIDGETS_CALENDAR_IS_CALENDAR_WEEK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_CALENDAR_TYPE_CALENDAR_WEEK))
#define WIDGETS_CALENDAR_CALENDAR_WEEK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_WEEK, WidgetsCalendarCalendarWeekClass))

typedef struct _WidgetsCalendarCalendarWeek WidgetsCalendarCalendarWeek;
typedef struct _WidgetsCalendarCalendarWeekClass WidgetsCalendarCalendarWeekClass;
typedef struct _WidgetsCalendarCalendarWeekPrivate WidgetsCalendarCalendarWeekPrivate;

#define WIDGETS_CALENDAR_TYPE_CALENDAR_MONTH (widgets_calendar_calendar_month_get_type ())
#define WIDGETS_CALENDAR_CALENDAR_MONTH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_MONTH, WidgetsCalendarCalendarMonth))
#define WIDGETS_CALENDAR_CALENDAR_MONTH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_CALENDAR_TYPE_CALENDAR_MONTH, WidgetsCalendarCalendarMonthClass))
#define WIDGETS_CALENDAR_IS_CALENDAR_MONTH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_MONTH))
#define WIDGETS_CALENDAR_IS_CALENDAR_MONTH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_CALENDAR_TYPE_CALENDAR_MONTH))
#define WIDGETS_CALENDAR_CALENDAR_MONTH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_MONTH, WidgetsCalendarCalendarMonthClass))

typedef struct _WidgetsCalendarCalendarMonth WidgetsCalendarCalendarMonth;
typedef struct _WidgetsCalendarCalendarMonthClass WidgetsCalendarCalendarMonthClass;
typedef struct _WidgetsCalendarCalendarMonthPrivate WidgetsCalendarCalendarMonthPrivate;

#define WIDGETS_CALENDAR_TYPE_CALENDAR_SCROLL (widgets_calendar_calendar_scroll_get_type ())
#define WIDGETS_CALENDAR_CALENDAR_SCROLL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_SCROLL, WidgetsCalendarCalendarScroll))
#define WIDGETS_CALENDAR_CALENDAR_SCROLL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_CALENDAR_TYPE_CALENDAR_SCROLL, WidgetsCalendarCalendarScrollClass))
#define WIDGETS_CALENDAR_IS_CALENDAR_SCROLL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_SCROLL))
#define WIDGETS_CALENDAR_IS_CALENDAR_SCROLL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_CALENDAR_TYPE_CALENDAR_SCROLL))
#define WIDGETS_CALENDAR_CALENDAR_SCROLL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_CALENDAR_TYPE_CALENDAR_SCROLL, WidgetsCalendarCalendarScrollClass))

typedef struct _WidgetsCalendarCalendarScroll WidgetsCalendarCalendarScroll;
typedef struct _WidgetsCalendarCalendarScrollClass WidgetsCalendarCalendarScrollClass;
typedef struct _WidgetsCalendarCalendarScrollPrivate WidgetsCalendarCalendarScrollPrivate;

#define WIDGETS_CONTEXT_MENU_TYPE_MENU_ITEM (widgets_context_menu_menu_item_get_type ())
#define WIDGETS_CONTEXT_MENU_MENU_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_ITEM, WidgetsContextMenuMenuItem))
#define WIDGETS_CONTEXT_MENU_MENU_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_CONTEXT_MENU_TYPE_MENU_ITEM, WidgetsContextMenuMenuItemClass))
#define WIDGETS_CONTEXT_MENU_IS_MENU_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_ITEM))
#define WIDGETS_CONTEXT_MENU_IS_MENU_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_CONTEXT_MENU_TYPE_MENU_ITEM))
#define WIDGETS_CONTEXT_MENU_MENU_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_ITEM, WidgetsContextMenuMenuItemClass))

typedef struct _WidgetsContextMenuMenuItem WidgetsContextMenuMenuItem;
typedef struct _WidgetsContextMenuMenuItemClass WidgetsContextMenuMenuItemClass;
typedef struct _WidgetsContextMenuMenuItemPrivate WidgetsContextMenuMenuItemPrivate;

#define WIDGETS_CONTEXT_MENU_TYPE_MENU_SEPARATOR (widgets_context_menu_menu_separator_get_type ())
#define WIDGETS_CONTEXT_MENU_MENU_SEPARATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_SEPARATOR, WidgetsContextMenuMenuSeparator))
#define WIDGETS_CONTEXT_MENU_MENU_SEPARATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_CONTEXT_MENU_TYPE_MENU_SEPARATOR, WidgetsContextMenuMenuSeparatorClass))
#define WIDGETS_CONTEXT_MENU_IS_MENU_SEPARATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_SEPARATOR))
#define WIDGETS_CONTEXT_MENU_IS_MENU_SEPARATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_CONTEXT_MENU_TYPE_MENU_SEPARATOR))
#define WIDGETS_CONTEXT_MENU_MENU_SEPARATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_SEPARATOR, WidgetsContextMenuMenuSeparatorClass))

typedef struct _WidgetsContextMenuMenuSeparator WidgetsContextMenuMenuSeparator;
typedef struct _WidgetsContextMenuMenuSeparatorClass WidgetsContextMenuMenuSeparatorClass;
typedef struct _WidgetsContextMenuMenuSeparatorPrivate WidgetsContextMenuMenuSeparatorPrivate;

#define WIDGETS_CONTEXT_MENU_TYPE_MENU_PICKER (widgets_context_menu_menu_picker_get_type ())
#define WIDGETS_CONTEXT_MENU_MENU_PICKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_PICKER, WidgetsContextMenuMenuPicker))
#define WIDGETS_CONTEXT_MENU_MENU_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_CONTEXT_MENU_TYPE_MENU_PICKER, WidgetsContextMenuMenuPickerClass))
#define WIDGETS_CONTEXT_MENU_IS_MENU_PICKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_PICKER))
#define WIDGETS_CONTEXT_MENU_IS_MENU_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_CONTEXT_MENU_TYPE_MENU_PICKER))
#define WIDGETS_CONTEXT_MENU_MENU_PICKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_PICKER, WidgetsContextMenuMenuPickerClass))

typedef struct _WidgetsContextMenuMenuPicker WidgetsContextMenuMenuPicker;
typedef struct _WidgetsContextMenuMenuPickerClass WidgetsContextMenuMenuPickerClass;
typedef struct _WidgetsContextMenuMenuPickerPrivate WidgetsContextMenuMenuPickerPrivate;

#define WIDGETS_CONTEXT_MENU_MENU_PICKER_TYPE_MENU_ITEM_PICKER (widgets_context_menu_menu_picker_menu_item_picker_get_type ())
#define WIDGETS_CONTEXT_MENU_MENU_PICKER_MENU_ITEM_PICKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_CONTEXT_MENU_MENU_PICKER_TYPE_MENU_ITEM_PICKER, WidgetsContextMenuMenuPickerMenuItemPicker))
#define WIDGETS_CONTEXT_MENU_MENU_PICKER_MENU_ITEM_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_CONTEXT_MENU_MENU_PICKER_TYPE_MENU_ITEM_PICKER, WidgetsContextMenuMenuPickerMenuItemPickerClass))
#define WIDGETS_CONTEXT_MENU_MENU_PICKER_IS_MENU_ITEM_PICKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_CONTEXT_MENU_MENU_PICKER_TYPE_MENU_ITEM_PICKER))
#define WIDGETS_CONTEXT_MENU_MENU_PICKER_IS_MENU_ITEM_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_CONTEXT_MENU_MENU_PICKER_TYPE_MENU_ITEM_PICKER))
#define WIDGETS_CONTEXT_MENU_MENU_PICKER_MENU_ITEM_PICKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_CONTEXT_MENU_MENU_PICKER_TYPE_MENU_ITEM_PICKER, WidgetsContextMenuMenuPickerMenuItemPickerClass))

typedef struct _WidgetsContextMenuMenuPickerMenuItemPicker WidgetsContextMenuMenuPickerMenuItemPicker;
typedef struct _WidgetsContextMenuMenuPickerMenuItemPickerClass WidgetsContextMenuMenuPickerMenuItemPickerClass;
typedef struct _WidgetsContextMenuMenuPickerMenuItemPickerPrivate WidgetsContextMenuMenuPickerMenuItemPickerPrivate;

#define WIDGETS_CONTEXT_MENU_TYPE_MENU_CHECK_PICKER (widgets_context_menu_menu_check_picker_get_type ())
#define WIDGETS_CONTEXT_MENU_MENU_CHECK_PICKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_CHECK_PICKER, WidgetsContextMenuMenuCheckPicker))
#define WIDGETS_CONTEXT_MENU_MENU_CHECK_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_CONTEXT_MENU_TYPE_MENU_CHECK_PICKER, WidgetsContextMenuMenuCheckPickerClass))
#define WIDGETS_CONTEXT_MENU_IS_MENU_CHECK_PICKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_CHECK_PICKER))
#define WIDGETS_CONTEXT_MENU_IS_MENU_CHECK_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_CONTEXT_MENU_TYPE_MENU_CHECK_PICKER))
#define WIDGETS_CONTEXT_MENU_MENU_CHECK_PICKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_CHECK_PICKER, WidgetsContextMenuMenuCheckPickerClass))

typedef struct _WidgetsContextMenuMenuCheckPicker WidgetsContextMenuMenuCheckPicker;
typedef struct _WidgetsContextMenuMenuCheckPickerClass WidgetsContextMenuMenuCheckPickerClass;
typedef struct _WidgetsContextMenuMenuCheckPickerPrivate WidgetsContextMenuMenuCheckPickerPrivate;

#define WIDGETS_CONTEXT_MENU_TYPE_MENU_ITEM_CHECK_PICKER (widgets_context_menu_menu_item_check_picker_get_type ())
#define WIDGETS_CONTEXT_MENU_MENU_ITEM_CHECK_PICKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_ITEM_CHECK_PICKER, WidgetsContextMenuMenuItemCheckPicker))
#define WIDGETS_CONTEXT_MENU_MENU_ITEM_CHECK_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_CONTEXT_MENU_TYPE_MENU_ITEM_CHECK_PICKER, WidgetsContextMenuMenuItemCheckPickerClass))
#define WIDGETS_CONTEXT_MENU_IS_MENU_ITEM_CHECK_PICKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_ITEM_CHECK_PICKER))
#define WIDGETS_CONTEXT_MENU_IS_MENU_ITEM_CHECK_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_CONTEXT_MENU_TYPE_MENU_ITEM_CHECK_PICKER))
#define WIDGETS_CONTEXT_MENU_MENU_ITEM_CHECK_PICKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_ITEM_CHECK_PICKER, WidgetsContextMenuMenuItemCheckPickerClass))

typedef struct _WidgetsContextMenuMenuItemCheckPicker WidgetsContextMenuMenuItemCheckPicker;
typedef struct _WidgetsContextMenuMenuItemCheckPickerClass WidgetsContextMenuMenuItemCheckPickerClass;

#define OBJECTS_FILTERS_TYPE_FILTER_ITEM (objects_filters_filter_item_get_type ())
#define OBJECTS_FILTERS_FILTER_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_FILTERS_TYPE_FILTER_ITEM, ObjectsFiltersFilterItem))
#define OBJECTS_FILTERS_FILTER_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_FILTERS_TYPE_FILTER_ITEM, ObjectsFiltersFilterItemClass))
#define OBJECTS_FILTERS_IS_FILTER_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_FILTERS_TYPE_FILTER_ITEM))
#define OBJECTS_FILTERS_IS_FILTER_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_FILTERS_TYPE_FILTER_ITEM))
#define OBJECTS_FILTERS_FILTER_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_FILTERS_TYPE_FILTER_ITEM, ObjectsFiltersFilterItemClass))

typedef struct _ObjectsFiltersFilterItem ObjectsFiltersFilterItem;
typedef struct _ObjectsFiltersFilterItemClass ObjectsFiltersFilterItemClass;
typedef struct _WidgetsContextMenuMenuItemCheckPickerPrivate WidgetsContextMenuMenuItemCheckPickerPrivate;

#define WIDGETS_CONTEXT_MENU_TYPE_MENU_SWITCH (widgets_context_menu_menu_switch_get_type ())
#define WIDGETS_CONTEXT_MENU_MENU_SWITCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_SWITCH, WidgetsContextMenuMenuSwitch))
#define WIDGETS_CONTEXT_MENU_MENU_SWITCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_CONTEXT_MENU_TYPE_MENU_SWITCH, WidgetsContextMenuMenuSwitchClass))
#define WIDGETS_CONTEXT_MENU_IS_MENU_SWITCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_SWITCH))
#define WIDGETS_CONTEXT_MENU_IS_MENU_SWITCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_CONTEXT_MENU_TYPE_MENU_SWITCH))
#define WIDGETS_CONTEXT_MENU_MENU_SWITCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_CONTEXT_MENU_TYPE_MENU_SWITCH, WidgetsContextMenuMenuSwitchClass))

typedef struct _WidgetsContextMenuMenuSwitch WidgetsContextMenuMenuSwitch;
typedef struct _WidgetsContextMenuMenuSwitchClass WidgetsContextMenuMenuSwitchClass;
typedef struct _WidgetsContextMenuMenuSwitchPrivate WidgetsContextMenuMenuSwitchPrivate;

#define WIDGETS_TYPE_SCHEDULE_BUTTON (widgets_schedule_button_get_type ())
#define WIDGETS_SCHEDULE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_SCHEDULE_BUTTON, WidgetsScheduleButton))
#define WIDGETS_SCHEDULE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_SCHEDULE_BUTTON, WidgetsScheduleButtonClass))
#define WIDGETS_IS_SCHEDULE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_SCHEDULE_BUTTON))
#define WIDGETS_IS_SCHEDULE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_SCHEDULE_BUTTON))
#define WIDGETS_SCHEDULE_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_SCHEDULE_BUTTON, WidgetsScheduleButtonClass))

typedef struct _WidgetsScheduleButton WidgetsScheduleButton;
typedef struct _WidgetsScheduleButtonClass WidgetsScheduleButtonClass;
typedef struct _WidgetsScheduleButtonPrivate WidgetsScheduleButtonPrivate;

#define WIDGETS_DATE_TIME_PICKER_TYPE_DATE_TIME_PICKER (widgets_date_time_picker_date_time_picker_get_type ())
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_DATE_TIME_PICKER_TYPE_DATE_TIME_PICKER, WidgetsDateTimePickerDateTimePicker))
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_DATE_TIME_PICKER_TYPE_DATE_TIME_PICKER, WidgetsDateTimePickerDateTimePickerClass))
#define WIDGETS_DATE_TIME_PICKER_IS_DATE_TIME_PICKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_DATE_TIME_PICKER_TYPE_DATE_TIME_PICKER))
#define WIDGETS_DATE_TIME_PICKER_IS_DATE_TIME_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_DATE_TIME_PICKER_TYPE_DATE_TIME_PICKER))
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_DATE_TIME_PICKER_TYPE_DATE_TIME_PICKER, WidgetsDateTimePickerDateTimePickerClass))

typedef struct _WidgetsDateTimePickerDateTimePicker WidgetsDateTimePickerDateTimePicker;
typedef struct _WidgetsDateTimePickerDateTimePickerClass WidgetsDateTimePickerDateTimePickerClass;
typedef struct _WidgetsDateTimePickerDateTimePickerPrivate WidgetsDateTimePickerDateTimePickerPrivate;

#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_SUGGESTED_DATE (widgets_date_time_picker_date_time_picker_suggested_date_get_type ())
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_SUGGESTED_DATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_SUGGESTED_DATE, WidgetsDateTimePickerDateTimePickerSuggestedDate))
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_SUGGESTED_DATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_SUGGESTED_DATE, WidgetsDateTimePickerDateTimePickerSuggestedDateClass))
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_IS_SUGGESTED_DATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_SUGGESTED_DATE))
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_IS_SUGGESTED_DATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_SUGGESTED_DATE))
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_SUGGESTED_DATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_SUGGESTED_DATE, WidgetsDateTimePickerDateTimePickerSuggestedDateClass))

typedef struct _WidgetsDateTimePickerDateTimePickerSuggestedDate WidgetsDateTimePickerDateTimePickerSuggestedDate;
typedef struct _WidgetsDateTimePickerDateTimePickerSuggestedDateClass WidgetsDateTimePickerDateTimePickerSuggestedDateClass;
typedef struct _WidgetsDateTimePickerDateTimePickerSuggestedDatePrivate WidgetsDateTimePickerDateTimePickerSuggestedDatePrivate;

#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_NO_DATE_BUTTON (widgets_date_time_picker_date_time_picker_no_date_button_get_type ())
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_NO_DATE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_NO_DATE_BUTTON, WidgetsDateTimePickerDateTimePickerNoDateButton))
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_NO_DATE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_NO_DATE_BUTTON, WidgetsDateTimePickerDateTimePickerNoDateButtonClass))
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_IS_NO_DATE_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_NO_DATE_BUTTON))
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_IS_NO_DATE_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_NO_DATE_BUTTON))
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_NO_DATE_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_NO_DATE_BUTTON, WidgetsDateTimePickerDateTimePickerNoDateButtonClass))

typedef struct _WidgetsDateTimePickerDateTimePickerNoDateButton WidgetsDateTimePickerDateTimePickerNoDateButton;
typedef struct _WidgetsDateTimePickerDateTimePickerNoDateButtonClass WidgetsDateTimePickerDateTimePickerNoDateButtonClass;
typedef struct _WidgetsDateTimePickerDateTimePickerNoDateButtonPrivate WidgetsDateTimePickerDateTimePickerNoDateButtonPrivate;

#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_OPTION_BUTTON (widgets_date_time_picker_date_time_picker_option_button_get_type ())
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_OPTION_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_OPTION_BUTTON, WidgetsDateTimePickerDateTimePickerOptionButton))
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_OPTION_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_OPTION_BUTTON, WidgetsDateTimePickerDateTimePickerOptionButtonClass))
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_IS_OPTION_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_OPTION_BUTTON))
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_IS_OPTION_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_OPTION_BUTTON))
#define WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_OPTION_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_DATE_TIME_PICKER_DATE_TIME_PICKER_TYPE_OPTION_BUTTON, WidgetsDateTimePickerDateTimePickerOptionButtonClass))

typedef struct _WidgetsDateTimePickerDateTimePickerOptionButton WidgetsDateTimePickerDateTimePickerOptionButton;
typedef struct _WidgetsDateTimePickerDateTimePickerOptionButtonClass WidgetsDateTimePickerDateTimePickerOptionButtonClass;
typedef struct _WidgetsDateTimePickerDateTimePickerOptionButtonPrivate WidgetsDateTimePickerDateTimePickerOptionButtonPrivate;

#define WIDGETS_DATE_TIME_PICKER_TYPE_TIME_PICKER (widgets_date_time_picker_time_picker_get_type ())
#define WIDGETS_DATE_TIME_PICKER_TIME_PICKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_DATE_TIME_PICKER_TYPE_TIME_PICKER, WidgetsDateTimePickerTimePicker))
#define WIDGETS_DATE_TIME_PICKER_TIME_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_DATE_TIME_PICKER_TYPE_TIME_PICKER, WidgetsDateTimePickerTimePickerClass))
#define WIDGETS_DATE_TIME_PICKER_IS_TIME_PICKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_DATE_TIME_PICKER_TYPE_TIME_PICKER))
#define WIDGETS_DATE_TIME_PICKER_IS_TIME_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_DATE_TIME_PICKER_TYPE_TIME_PICKER))
#define WIDGETS_DATE_TIME_PICKER_TIME_PICKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_DATE_TIME_PICKER_TYPE_TIME_PICKER, WidgetsDateTimePickerTimePickerClass))

typedef struct _WidgetsDateTimePickerTimePicker WidgetsDateTimePickerTimePicker;
typedef struct _WidgetsDateTimePickerTimePickerClass WidgetsDateTimePickerTimePickerClass;
typedef struct _WidgetsDateTimePickerTimePickerPrivate WidgetsDateTimePickerTimePickerPrivate;

#define WIDGETS_DATE_TIME_PICKER_TYPE_REPEAT_CONFIG (widgets_date_time_picker_repeat_config_get_type ())
#define WIDGETS_DATE_TIME_PICKER_REPEAT_CONFIG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_DATE_TIME_PICKER_TYPE_REPEAT_CONFIG, WidgetsDateTimePickerRepeatConfig))
#define WIDGETS_DATE_TIME_PICKER_REPEAT_CONFIG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_DATE_TIME_PICKER_TYPE_REPEAT_CONFIG, WidgetsDateTimePickerRepeatConfigClass))
#define WIDGETS_DATE_TIME_PICKER_IS_REPEAT_CONFIG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_DATE_TIME_PICKER_TYPE_REPEAT_CONFIG))
#define WIDGETS_DATE_TIME_PICKER_IS_REPEAT_CONFIG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_DATE_TIME_PICKER_TYPE_REPEAT_CONFIG))
#define WIDGETS_DATE_TIME_PICKER_REPEAT_CONFIG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_DATE_TIME_PICKER_TYPE_REPEAT_CONFIG, WidgetsDateTimePickerRepeatConfigClass))

typedef struct _WidgetsDateTimePickerRepeatConfig WidgetsDateTimePickerRepeatConfig;
typedef struct _WidgetsDateTimePickerRepeatConfigClass WidgetsDateTimePickerRepeatConfigClass;
typedef struct _WidgetsDateTimePickerRepeatConfigPrivate WidgetsDateTimePickerRepeatConfigPrivate;

#define WIDGETS_LABEL_PICKER_TYPE_LABEL_PICKER (widgets_label_picker_label_picker_get_type ())
#define WIDGETS_LABEL_PICKER_LABEL_PICKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_LABEL_PICKER_TYPE_LABEL_PICKER, WidgetsLabelPickerLabelPicker))
#define WIDGETS_LABEL_PICKER_LABEL_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_LABEL_PICKER_TYPE_LABEL_PICKER, WidgetsLabelPickerLabelPickerClass))
#define WIDGETS_LABEL_PICKER_IS_LABEL_PICKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_LABEL_PICKER_TYPE_LABEL_PICKER))
#define WIDGETS_LABEL_PICKER_IS_LABEL_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_LABEL_PICKER_TYPE_LABEL_PICKER))
#define WIDGETS_LABEL_PICKER_LABEL_PICKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_LABEL_PICKER_TYPE_LABEL_PICKER, WidgetsLabelPickerLabelPickerClass))

typedef struct _WidgetsLabelPickerLabelPicker WidgetsLabelPickerLabelPicker;
typedef struct _WidgetsLabelPickerLabelPickerClass WidgetsLabelPickerLabelPickerClass;
typedef struct _WidgetsLabelPickerLabelPickerPrivate WidgetsLabelPickerLabelPickerPrivate;

#define WIDGETS_LABEL_PICKER_TYPE_LABEL_ROW (widgets_label_picker_label_row_get_type ())
#define WIDGETS_LABEL_PICKER_LABEL_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_LABEL_PICKER_TYPE_LABEL_ROW, WidgetsLabelPickerLabelRow))
#define WIDGETS_LABEL_PICKER_LABEL_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_LABEL_PICKER_TYPE_LABEL_ROW, WidgetsLabelPickerLabelRowClass))
#define WIDGETS_LABEL_PICKER_IS_LABEL_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_LABEL_PICKER_TYPE_LABEL_ROW))
#define WIDGETS_LABEL_PICKER_IS_LABEL_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_LABEL_PICKER_TYPE_LABEL_ROW))
#define WIDGETS_LABEL_PICKER_LABEL_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_LABEL_PICKER_TYPE_LABEL_ROW, WidgetsLabelPickerLabelRowClass))

typedef struct _WidgetsLabelPickerLabelRow WidgetsLabelPickerLabelRow;
typedef struct _WidgetsLabelPickerLabelRowClass WidgetsLabelPickerLabelRowClass;
typedef struct _WidgetsLabelPickerLabelRowPrivate WidgetsLabelPickerLabelRowPrivate;

#define WIDGETS_LABEL_PICKER_TYPE_LABEL_BUTTON (widgets_label_picker_label_button_get_type ())
#define WIDGETS_LABEL_PICKER_LABEL_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_LABEL_PICKER_TYPE_LABEL_BUTTON, WidgetsLabelPickerLabelButton))
#define WIDGETS_LABEL_PICKER_LABEL_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_LABEL_PICKER_TYPE_LABEL_BUTTON, WidgetsLabelPickerLabelButtonClass))
#define WIDGETS_LABEL_PICKER_IS_LABEL_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_LABEL_PICKER_TYPE_LABEL_BUTTON))
#define WIDGETS_LABEL_PICKER_IS_LABEL_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_LABEL_PICKER_TYPE_LABEL_BUTTON))
#define WIDGETS_LABEL_PICKER_LABEL_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_LABEL_PICKER_TYPE_LABEL_BUTTON, WidgetsLabelPickerLabelButtonClass))

typedef struct _WidgetsLabelPickerLabelButton WidgetsLabelPickerLabelButton;
typedef struct _WidgetsLabelPickerLabelButtonClass WidgetsLabelPickerLabelButtonClass;
typedef struct _WidgetsLabelPickerLabelButtonPrivate WidgetsLabelPickerLabelButtonPrivate;

#define WIDGETS_TYPE_LABELS_PICKER_CORE (widgets_labels_picker_core_get_type ())
#define WIDGETS_LABELS_PICKER_CORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_LABELS_PICKER_CORE, WidgetsLabelsPickerCore))
#define WIDGETS_LABELS_PICKER_CORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_LABELS_PICKER_CORE, WidgetsLabelsPickerCoreClass))
#define WIDGETS_IS_LABELS_PICKER_CORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_LABELS_PICKER_CORE))
#define WIDGETS_IS_LABELS_PICKER_CORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_LABELS_PICKER_CORE))
#define WIDGETS_LABELS_PICKER_CORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_LABELS_PICKER_CORE, WidgetsLabelsPickerCoreClass))

typedef struct _WidgetsLabelsPickerCore WidgetsLabelsPickerCore;
typedef struct _WidgetsLabelsPickerCoreClass WidgetsLabelsPickerCoreClass;
typedef struct _WidgetsLabelsPickerCorePrivate WidgetsLabelsPickerCorePrivate;

#define WIDGETS_LABEL_PICKER_TYPE_LABEL_QUICK_PICKER (widgets_label_picker_label_quick_picker_get_type ())
#define WIDGETS_LABEL_PICKER_LABEL_QUICK_PICKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_LABEL_PICKER_TYPE_LABEL_QUICK_PICKER, WidgetsLabelPickerLabelQuickPicker))
#define WIDGETS_LABEL_PICKER_LABEL_QUICK_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_LABEL_PICKER_TYPE_LABEL_QUICK_PICKER, WidgetsLabelPickerLabelQuickPickerClass))
#define WIDGETS_LABEL_PICKER_IS_LABEL_QUICK_PICKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_LABEL_PICKER_TYPE_LABEL_QUICK_PICKER))
#define WIDGETS_LABEL_PICKER_IS_LABEL_QUICK_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_LABEL_PICKER_TYPE_LABEL_QUICK_PICKER))
#define WIDGETS_LABEL_PICKER_LABEL_QUICK_PICKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_LABEL_PICKER_TYPE_LABEL_QUICK_PICKER, WidgetsLabelPickerLabelQuickPickerClass))

typedef struct _WidgetsLabelPickerLabelQuickPicker WidgetsLabelPickerLabelQuickPicker;
typedef struct _WidgetsLabelPickerLabelQuickPickerClass WidgetsLabelPickerLabelQuickPickerClass;
typedef struct _WidgetsLabelPickerLabelQuickPickerPrivate WidgetsLabelPickerLabelQuickPickerPrivate;

#define WIDGETS_TYPE_PROJECT_PICKER_CORE (widgets_project_picker_core_get_type ())
#define WIDGETS_PROJECT_PICKER_CORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_TYPE_PROJECT_PICKER_CORE, WidgetsProjectPickerCore))
#define WIDGETS_PROJECT_PICKER_CORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_TYPE_PROJECT_PICKER_CORE, WidgetsProjectPickerCoreClass))
#define WIDGETS_IS_PROJECT_PICKER_CORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_TYPE_PROJECT_PICKER_CORE))
#define WIDGETS_IS_PROJECT_PICKER_CORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_TYPE_PROJECT_PICKER_CORE))
#define WIDGETS_PROJECT_PICKER_CORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_TYPE_PROJECT_PICKER_CORE, WidgetsProjectPickerCoreClass))

typedef struct _WidgetsProjectPickerCore WidgetsProjectPickerCore;
typedef struct _WidgetsProjectPickerCoreClass WidgetsProjectPickerCoreClass;
typedef struct _WidgetsProjectPickerCorePrivate WidgetsProjectPickerCorePrivate;

#define WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_POPOVER (widgets_project_picker_project_picker_popover_get_type ())
#define WIDGETS_PROJECT_PICKER_PROJECT_PICKER_POPOVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_POPOVER, WidgetsProjectPickerProjectPickerPopover))
#define WIDGETS_PROJECT_PICKER_PROJECT_PICKER_POPOVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_POPOVER, WidgetsProjectPickerProjectPickerPopoverClass))
#define WIDGETS_PROJECT_PICKER_IS_PROJECT_PICKER_POPOVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_POPOVER))
#define WIDGETS_PROJECT_PICKER_IS_PROJECT_PICKER_POPOVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_POPOVER))
#define WIDGETS_PROJECT_PICKER_PROJECT_PICKER_POPOVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_POPOVER, WidgetsProjectPickerProjectPickerPopoverClass))

typedef struct _WidgetsProjectPickerProjectPickerPopover WidgetsProjectPickerProjectPickerPopover;
typedef struct _WidgetsProjectPickerProjectPickerPopoverClass WidgetsProjectPickerProjectPickerPopoverClass;
typedef struct _WidgetsProjectPickerProjectPickerPopoverPrivate WidgetsProjectPickerProjectPickerPopoverPrivate;

#define WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_ROW (widgets_project_picker_project_picker_row_get_type ())
#define WIDGETS_PROJECT_PICKER_PROJECT_PICKER_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_ROW, WidgetsProjectPickerProjectPickerRow))
#define WIDGETS_PROJECT_PICKER_PROJECT_PICKER_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_ROW, WidgetsProjectPickerProjectPickerRowClass))
#define WIDGETS_PROJECT_PICKER_IS_PROJECT_PICKER_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_ROW))
#define WIDGETS_PROJECT_PICKER_IS_PROJECT_PICKER_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_ROW))
#define WIDGETS_PROJECT_PICKER_PROJECT_PICKER_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_ROW, WidgetsProjectPickerProjectPickerRowClass))

typedef struct _WidgetsProjectPickerProjectPickerRow WidgetsProjectPickerProjectPickerRow;
typedef struct _WidgetsProjectPickerProjectPickerRowClass WidgetsProjectPickerProjectPickerRowClass;
typedef struct _WidgetsProjectPickerProjectPickerRowPrivate WidgetsProjectPickerProjectPickerRowPrivate;

#define WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_BUTTON (widgets_project_picker_project_picker_button_get_type ())
#define WIDGETS_PROJECT_PICKER_PROJECT_PICKER_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_BUTTON, WidgetsProjectPickerProjectPickerButton))
#define WIDGETS_PROJECT_PICKER_PROJECT_PICKER_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_BUTTON, WidgetsProjectPickerProjectPickerButtonClass))
#define WIDGETS_PROJECT_PICKER_IS_PROJECT_PICKER_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_BUTTON))
#define WIDGETS_PROJECT_PICKER_IS_PROJECT_PICKER_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_BUTTON))
#define WIDGETS_PROJECT_PICKER_PROJECT_PICKER_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_PROJECT_PICKER_TYPE_PROJECT_PICKER_BUTTON, WidgetsProjectPickerProjectPickerButtonClass))

typedef struct _WidgetsProjectPickerProjectPickerButton WidgetsProjectPickerProjectPickerButton;
typedef struct _WidgetsProjectPickerProjectPickerButtonClass WidgetsProjectPickerProjectPickerButtonClass;
typedef struct _WidgetsProjectPickerProjectPickerButtonPrivate WidgetsProjectPickerProjectPickerButtonPrivate;

#define WIDGETS_SECTION_PICKER_TYPE_SECTION_PICKER_ROW (widgets_section_picker_section_picker_row_get_type ())
#define WIDGETS_SECTION_PICKER_SECTION_PICKER_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_SECTION_PICKER_TYPE_SECTION_PICKER_ROW, WidgetsSectionPickerSectionPickerRow))
#define WIDGETS_SECTION_PICKER_SECTION_PICKER_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_SECTION_PICKER_TYPE_SECTION_PICKER_ROW, WidgetsSectionPickerSectionPickerRowClass))
#define WIDGETS_SECTION_PICKER_IS_SECTION_PICKER_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_SECTION_PICKER_TYPE_SECTION_PICKER_ROW))
#define WIDGETS_SECTION_PICKER_IS_SECTION_PICKER_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_SECTION_PICKER_TYPE_SECTION_PICKER_ROW))
#define WIDGETS_SECTION_PICKER_SECTION_PICKER_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_SECTION_PICKER_TYPE_SECTION_PICKER_ROW, WidgetsSectionPickerSectionPickerRowClass))

typedef struct _WidgetsSectionPickerSectionPickerRow WidgetsSectionPickerSectionPickerRow;
typedef struct _WidgetsSectionPickerSectionPickerRowClass WidgetsSectionPickerSectionPickerRowClass;

#define WIDGETS_SECTION_PICKER_TYPE_SECTION_BUTTON (widgets_section_picker_section_button_get_type ())
#define WIDGETS_SECTION_PICKER_SECTION_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_SECTION_PICKER_TYPE_SECTION_BUTTON, WidgetsSectionPickerSectionButton))
#define WIDGETS_SECTION_PICKER_SECTION_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_SECTION_PICKER_TYPE_SECTION_BUTTON, WidgetsSectionPickerSectionButtonClass))
#define WIDGETS_SECTION_PICKER_IS_SECTION_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_SECTION_PICKER_TYPE_SECTION_BUTTON))
#define WIDGETS_SECTION_PICKER_IS_SECTION_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_SECTION_PICKER_TYPE_SECTION_BUTTON))
#define WIDGETS_SECTION_PICKER_SECTION_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_SECTION_PICKER_TYPE_SECTION_BUTTON, WidgetsSectionPickerSectionButtonClass))

typedef struct _WidgetsSectionPickerSectionButton WidgetsSectionPickerSectionButton;
typedef struct _WidgetsSectionPickerSectionButtonClass WidgetsSectionPickerSectionButtonClass;
typedef struct _WidgetsSectionPickerSectionButtonPrivate WidgetsSectionPickerSectionButtonPrivate;

#define WIDGETS_SECTION_PICKER_TYPE_SECTION_PICKER (widgets_section_picker_section_picker_get_type ())
#define WIDGETS_SECTION_PICKER_SECTION_PICKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_SECTION_PICKER_TYPE_SECTION_PICKER, WidgetsSectionPickerSectionPicker))
#define WIDGETS_SECTION_PICKER_SECTION_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_SECTION_PICKER_TYPE_SECTION_PICKER, WidgetsSectionPickerSectionPickerClass))
#define WIDGETS_SECTION_PICKER_IS_SECTION_PICKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_SECTION_PICKER_TYPE_SECTION_PICKER))
#define WIDGETS_SECTION_PICKER_IS_SECTION_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_SECTION_PICKER_TYPE_SECTION_PICKER))
#define WIDGETS_SECTION_PICKER_SECTION_PICKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_SECTION_PICKER_TYPE_SECTION_PICKER, WidgetsSectionPickerSectionPickerClass))

typedef struct _WidgetsSectionPickerSectionPicker WidgetsSectionPickerSectionPicker;
typedef struct _WidgetsSectionPickerSectionPickerClass WidgetsSectionPickerSectionPickerClass;
typedef struct _WidgetsSectionPickerSectionPickerPrivate WidgetsSectionPickerSectionPickerPrivate;
typedef struct _WidgetsSectionPickerSectionPickerRowPrivate WidgetsSectionPickerSectionPickerRowPrivate;

#define WIDGETS_REMINDER_PICKER_TYPE_REMINDER_BUTTON (widgets_reminder_picker_reminder_button_get_type ())
#define WIDGETS_REMINDER_PICKER_REMINDER_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_REMINDER_PICKER_TYPE_REMINDER_BUTTON, WidgetsReminderPickerReminderButton))
#define WIDGETS_REMINDER_PICKER_REMINDER_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_REMINDER_PICKER_TYPE_REMINDER_BUTTON, WidgetsReminderPickerReminderButtonClass))
#define WIDGETS_REMINDER_PICKER_IS_REMINDER_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_REMINDER_PICKER_TYPE_REMINDER_BUTTON))
#define WIDGETS_REMINDER_PICKER_IS_REMINDER_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_REMINDER_PICKER_TYPE_REMINDER_BUTTON))
#define WIDGETS_REMINDER_PICKER_REMINDER_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_REMINDER_PICKER_TYPE_REMINDER_BUTTON, WidgetsReminderPickerReminderButtonClass))

typedef struct _WidgetsReminderPickerReminderButton WidgetsReminderPickerReminderButton;
typedef struct _WidgetsReminderPickerReminderButtonClass WidgetsReminderPickerReminderButtonClass;
typedef struct _WidgetsReminderPickerReminderButtonPrivate WidgetsReminderPickerReminderButtonPrivate;

#define WIDGETS_REMINDER_PICKER_TYPE_REMINDER_PICKER (widgets_reminder_picker_reminder_picker_get_type ())
#define WIDGETS_REMINDER_PICKER_REMINDER_PICKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_REMINDER_PICKER_TYPE_REMINDER_PICKER, WidgetsReminderPickerReminderPicker))
#define WIDGETS_REMINDER_PICKER_REMINDER_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_REMINDER_PICKER_TYPE_REMINDER_PICKER, WidgetsReminderPickerReminderPickerClass))
#define WIDGETS_REMINDER_PICKER_IS_REMINDER_PICKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_REMINDER_PICKER_TYPE_REMINDER_PICKER))
#define WIDGETS_REMINDER_PICKER_IS_REMINDER_PICKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_REMINDER_PICKER_TYPE_REMINDER_PICKER))
#define WIDGETS_REMINDER_PICKER_REMINDER_PICKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_REMINDER_PICKER_TYPE_REMINDER_PICKER, WidgetsReminderPickerReminderPickerClass))

typedef struct _WidgetsReminderPickerReminderPicker WidgetsReminderPickerReminderPicker;
typedef struct _WidgetsReminderPickerReminderPickerClass WidgetsReminderPickerReminderPickerClass;
typedef struct _WidgetsReminderPickerReminderPickerPrivate WidgetsReminderPickerReminderPickerPrivate;

#define WIDGETS_REMINDER_PICKER_TYPE_REMINDER_ROW (widgets_reminder_picker_reminder_row_get_type ())
#define WIDGETS_REMINDER_PICKER_REMINDER_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), WIDGETS_REMINDER_PICKER_TYPE_REMINDER_ROW, WidgetsReminderPickerReminderRow))
#define WIDGETS_REMINDER_PICKER_REMINDER_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), WIDGETS_REMINDER_PICKER_TYPE_REMINDER_ROW, WidgetsReminderPickerReminderRowClass))
#define WIDGETS_REMINDER_PICKER_IS_REMINDER_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), WIDGETS_REMINDER_PICKER_TYPE_REMINDER_ROW))
#define WIDGETS_REMINDER_PICKER_IS_REMINDER_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), WIDGETS_REMINDER_PICKER_TYPE_REMINDER_ROW))
#define WIDGETS_REMINDER_PICKER_REMINDER_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), WIDGETS_REMINDER_PICKER_TYPE_REMINDER_ROW, WidgetsReminderPickerReminderRowClass))

typedef struct _WidgetsReminderPickerReminderRow WidgetsReminderPickerReminderRow;
typedef struct _WidgetsReminderPickerReminderRowClass WidgetsReminderPickerReminderRowClass;
typedef struct _WidgetsReminderPickerReminderRowPrivate WidgetsReminderPickerReminderRowPrivate;
typedef struct _ObjectsBaseObjectPrivate ObjectsBaseObjectPrivate;
typedef struct _ObjectsColorPrivate ObjectsColorPrivate;
typedef struct _ObjectsDueDatePrivate ObjectsDueDatePrivate;
typedef struct _ObjectsItemPrivate ObjectsItemPrivate;
typedef struct _ObjectsLabelPrivate ObjectsLabelPrivate;
typedef struct _ObjectsProjectPrivate ObjectsProjectPrivate;
typedef struct _ObjectsQueuePrivate ObjectsQueuePrivate;
typedef struct _ObjectsReminderPrivate ObjectsReminderPrivate;
typedef struct _ObjectsSectionPrivate ObjectsSectionPrivate;
typedef struct _ObjectsAttachmentPrivate ObjectsAttachmentPrivate;
typedef struct _ObjectsObjectEventPrivate ObjectsObjectEventPrivate;
typedef struct _ObjectsSourcePrivate ObjectsSourcePrivate;

#define OBJECTS_TYPE_SOURCE_DATA (objects_source_data_get_type ())
#define OBJECTS_SOURCE_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_TYPE_SOURCE_DATA, ObjectsSourceData))
#define OBJECTS_SOURCE_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_TYPE_SOURCE_DATA, ObjectsSourceDataClass))
#define OBJECTS_IS_SOURCE_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_TYPE_SOURCE_DATA))
#define OBJECTS_IS_SOURCE_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_TYPE_SOURCE_DATA))
#define OBJECTS_SOURCE_DATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_TYPE_SOURCE_DATA, ObjectsSourceDataClass))

typedef struct _ObjectsSourceData ObjectsSourceData;
typedef struct _ObjectsSourceDataClass ObjectsSourceDataClass;

#define OBJECTS_TYPE_SOURCE_TODOIST_DATA (objects_source_todoist_data_get_type ())
#define OBJECTS_SOURCE_TODOIST_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_TYPE_SOURCE_TODOIST_DATA, ObjectsSourceTodoistData))
#define OBJECTS_SOURCE_TODOIST_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_TYPE_SOURCE_TODOIST_DATA, ObjectsSourceTodoistDataClass))
#define OBJECTS_IS_SOURCE_TODOIST_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_TYPE_SOURCE_TODOIST_DATA))
#define OBJECTS_IS_SOURCE_TODOIST_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_TYPE_SOURCE_TODOIST_DATA))
#define OBJECTS_SOURCE_TODOIST_DATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_TYPE_SOURCE_TODOIST_DATA, ObjectsSourceTodoistDataClass))

typedef struct _ObjectsSourceTodoistData ObjectsSourceTodoistData;
typedef struct _ObjectsSourceTodoistDataClass ObjectsSourceTodoistDataClass;

#define OBJECTS_TYPE_SOURCE_CAL_DAV_DATA (objects_source_cal_dav_data_get_type ())
#define OBJECTS_SOURCE_CAL_DAV_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_TYPE_SOURCE_CAL_DAV_DATA, ObjectsSourceCalDAVData))
#define OBJECTS_SOURCE_CAL_DAV_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_TYPE_SOURCE_CAL_DAV_DATA, ObjectsSourceCalDAVDataClass))
#define OBJECTS_IS_SOURCE_CAL_DAV_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_TYPE_SOURCE_CAL_DAV_DATA))
#define OBJECTS_IS_SOURCE_CAL_DAV_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_TYPE_SOURCE_CAL_DAV_DATA))
#define OBJECTS_SOURCE_CAL_DAV_DATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_TYPE_SOURCE_CAL_DAV_DATA, ObjectsSourceCalDAVDataClass))

typedef struct _ObjectsSourceCalDAVData ObjectsSourceCalDAVData;
typedef struct _ObjectsSourceCalDAVDataClass ObjectsSourceCalDAVDataClass;
typedef struct _ObjectsSourceDataPrivate ObjectsSourceDataPrivate;
typedef struct _ObjectsSourceTodoistDataPrivate ObjectsSourceTodoistDataPrivate;
typedef struct _ObjectsSourceCalDAVDataPrivate ObjectsSourceCalDAVDataPrivate;

#define OBJECTS_TYPE_TRANSLATION_METRIC (objects_translation_metric_get_type ())
#define OBJECTS_TRANSLATION_METRIC(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_TYPE_TRANSLATION_METRIC, ObjectsTranslationMetric))
#define OBJECTS_TRANSLATION_METRIC_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_TYPE_TRANSLATION_METRIC, ObjectsTranslationMetricClass))
#define OBJECTS_IS_TRANSLATION_METRIC(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_TYPE_TRANSLATION_METRIC))
#define OBJECTS_IS_TRANSLATION_METRIC_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_TYPE_TRANSLATION_METRIC))
#define OBJECTS_TRANSLATION_METRIC_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_TYPE_TRANSLATION_METRIC, ObjectsTranslationMetricClass))

typedef struct _ObjectsTranslationMetric ObjectsTranslationMetric;
typedef struct _ObjectsTranslationMetricClass ObjectsTranslationMetricClass;
typedef struct _ObjectsTranslationMetricPrivate ObjectsTranslationMetricPrivate;

#define OBJECTS_TYPE_RELEASE (objects_release_get_type ())
#define OBJECTS_RELEASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_TYPE_RELEASE, ObjectsRelease))
#define OBJECTS_RELEASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_TYPE_RELEASE, ObjectsReleaseClass))
#define OBJECTS_IS_RELEASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_TYPE_RELEASE))
#define OBJECTS_IS_RELEASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_TYPE_RELEASE))
#define OBJECTS_RELEASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_TYPE_RELEASE, ObjectsReleaseClass))

typedef struct _ObjectsRelease ObjectsRelease;
typedef struct _ObjectsReleaseClass ObjectsReleaseClass;
typedef struct _ObjectsReleasePrivate ObjectsReleasePrivate;

#define OBJECTS_FILTERS_TYPE_INBOX (objects_filters_inbox_get_type ())
#define OBJECTS_FILTERS_INBOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_FILTERS_TYPE_INBOX, ObjectsFiltersInbox))
#define OBJECTS_FILTERS_INBOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_FILTERS_TYPE_INBOX, ObjectsFiltersInboxClass))
#define OBJECTS_FILTERS_IS_INBOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_FILTERS_TYPE_INBOX))
#define OBJECTS_FILTERS_IS_INBOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_FILTERS_TYPE_INBOX))
#define OBJECTS_FILTERS_INBOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_FILTERS_TYPE_INBOX, ObjectsFiltersInboxClass))

typedef struct _ObjectsFiltersInbox ObjectsFiltersInbox;
typedef struct _ObjectsFiltersInboxClass ObjectsFiltersInboxClass;
typedef struct _ObjectsFiltersInboxPrivate ObjectsFiltersInboxPrivate;

#define OBJECTS_FILTERS_TYPE_PINBOARD (objects_filters_pinboard_get_type ())
#define OBJECTS_FILTERS_PINBOARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_FILTERS_TYPE_PINBOARD, ObjectsFiltersPinboard))
#define OBJECTS_FILTERS_PINBOARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_FILTERS_TYPE_PINBOARD, ObjectsFiltersPinboardClass))
#define OBJECTS_FILTERS_IS_PINBOARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_FILTERS_TYPE_PINBOARD))
#define OBJECTS_FILTERS_IS_PINBOARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_FILTERS_TYPE_PINBOARD))
#define OBJECTS_FILTERS_PINBOARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_FILTERS_TYPE_PINBOARD, ObjectsFiltersPinboardClass))

typedef struct _ObjectsFiltersPinboard ObjectsFiltersPinboard;
typedef struct _ObjectsFiltersPinboardClass ObjectsFiltersPinboardClass;
typedef struct _ObjectsFiltersPinboardPrivate ObjectsFiltersPinboardPrivate;

#define OBJECTS_FILTERS_TYPE_SCHEDULED (objects_filters_scheduled_get_type ())
#define OBJECTS_FILTERS_SCHEDULED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_FILTERS_TYPE_SCHEDULED, ObjectsFiltersScheduled))
#define OBJECTS_FILTERS_SCHEDULED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_FILTERS_TYPE_SCHEDULED, ObjectsFiltersScheduledClass))
#define OBJECTS_FILTERS_IS_SCHEDULED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_FILTERS_TYPE_SCHEDULED))
#define OBJECTS_FILTERS_IS_SCHEDULED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_FILTERS_TYPE_SCHEDULED))
#define OBJECTS_FILTERS_SCHEDULED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_FILTERS_TYPE_SCHEDULED, ObjectsFiltersScheduledClass))

typedef struct _ObjectsFiltersScheduled ObjectsFiltersScheduled;
typedef struct _ObjectsFiltersScheduledClass ObjectsFiltersScheduledClass;
typedef struct _ObjectsFiltersScheduledPrivate ObjectsFiltersScheduledPrivate;

#define OBJECTS_FILTERS_TYPE_TODAY (objects_filters_today_get_type ())
#define OBJECTS_FILTERS_TODAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_FILTERS_TYPE_TODAY, ObjectsFiltersToday))
#define OBJECTS_FILTERS_TODAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_FILTERS_TYPE_TODAY, ObjectsFiltersTodayClass))
#define OBJECTS_FILTERS_IS_TODAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_FILTERS_TYPE_TODAY))
#define OBJECTS_FILTERS_IS_TODAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_FILTERS_TYPE_TODAY))
#define OBJECTS_FILTERS_TODAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_FILTERS_TYPE_TODAY, ObjectsFiltersTodayClass))

typedef struct _ObjectsFiltersToday ObjectsFiltersToday;
typedef struct _ObjectsFiltersTodayClass ObjectsFiltersTodayClass;
typedef struct _ObjectsFiltersTodayPrivate ObjectsFiltersTodayPrivate;

#define OBJECTS_FILTERS_TYPE_PRIORITY (objects_filters_priority_get_type ())
#define OBJECTS_FILTERS_PRIORITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_FILTERS_TYPE_PRIORITY, ObjectsFiltersPriority))
#define OBJECTS_FILTERS_PRIORITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_FILTERS_TYPE_PRIORITY, ObjectsFiltersPriorityClass))
#define OBJECTS_FILTERS_IS_PRIORITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_FILTERS_TYPE_PRIORITY))
#define OBJECTS_FILTERS_IS_PRIORITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_FILTERS_TYPE_PRIORITY))
#define OBJECTS_FILTERS_PRIORITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_FILTERS_TYPE_PRIORITY, ObjectsFiltersPriorityClass))

typedef struct _ObjectsFiltersPriority ObjectsFiltersPriority;
typedef struct _ObjectsFiltersPriorityClass ObjectsFiltersPriorityClass;
typedef struct _ObjectsFiltersPriorityPrivate ObjectsFiltersPriorityPrivate;

#define OBJECTS_FILTERS_TYPE_COMPLETED (objects_filters_completed_get_type ())
#define OBJECTS_FILTERS_COMPLETED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_FILTERS_TYPE_COMPLETED, ObjectsFiltersCompleted))
#define OBJECTS_FILTERS_COMPLETED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_FILTERS_TYPE_COMPLETED, ObjectsFiltersCompletedClass))
#define OBJECTS_FILTERS_IS_COMPLETED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_FILTERS_TYPE_COMPLETED))
#define OBJECTS_FILTERS_IS_COMPLETED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_FILTERS_TYPE_COMPLETED))
#define OBJECTS_FILTERS_COMPLETED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_FILTERS_TYPE_COMPLETED, ObjectsFiltersCompletedClass))

typedef struct _ObjectsFiltersCompleted ObjectsFiltersCompleted;
typedef struct _ObjectsFiltersCompletedClass ObjectsFiltersCompletedClass;
typedef struct _ObjectsFiltersCompletedPrivate ObjectsFiltersCompletedPrivate;

#define OBJECTS_FILTERS_TYPE_LABELS (objects_filters_labels_get_type ())
#define OBJECTS_FILTERS_LABELS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_FILTERS_TYPE_LABELS, ObjectsFiltersLabels))
#define OBJECTS_FILTERS_LABELS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_FILTERS_TYPE_LABELS, ObjectsFiltersLabelsClass))
#define OBJECTS_FILTERS_IS_LABELS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_FILTERS_TYPE_LABELS))
#define OBJECTS_FILTERS_IS_LABELS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_FILTERS_TYPE_LABELS))
#define OBJECTS_FILTERS_LABELS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_FILTERS_TYPE_LABELS, ObjectsFiltersLabelsClass))

typedef struct _ObjectsFiltersLabels ObjectsFiltersLabels;
typedef struct _ObjectsFiltersLabelsClass ObjectsFiltersLabelsClass;
typedef struct _ObjectsFiltersLabelsPrivate ObjectsFiltersLabelsPrivate;

#define OBJECTS_FILTERS_TYPE_TOMORROW (objects_filters_tomorrow_get_type ())
#define OBJECTS_FILTERS_TOMORROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_FILTERS_TYPE_TOMORROW, ObjectsFiltersTomorrow))
#define OBJECTS_FILTERS_TOMORROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_FILTERS_TYPE_TOMORROW, ObjectsFiltersTomorrowClass))
#define OBJECTS_FILTERS_IS_TOMORROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_FILTERS_TYPE_TOMORROW))
#define OBJECTS_FILTERS_IS_TOMORROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_FILTERS_TYPE_TOMORROW))
#define OBJECTS_FILTERS_TOMORROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_FILTERS_TYPE_TOMORROW, ObjectsFiltersTomorrowClass))

typedef struct _ObjectsFiltersTomorrow ObjectsFiltersTomorrow;
typedef struct _ObjectsFiltersTomorrowClass ObjectsFiltersTomorrowClass;
typedef struct _ObjectsFiltersTomorrowPrivate ObjectsFiltersTomorrowPrivate;

#define OBJECTS_FILTERS_TYPE_ANYTIME (objects_filters_anytime_get_type ())
#define OBJECTS_FILTERS_ANYTIME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_FILTERS_TYPE_ANYTIME, ObjectsFiltersAnytime))
#define OBJECTS_FILTERS_ANYTIME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_FILTERS_TYPE_ANYTIME, ObjectsFiltersAnytimeClass))
#define OBJECTS_FILTERS_IS_ANYTIME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_FILTERS_TYPE_ANYTIME))
#define OBJECTS_FILTERS_IS_ANYTIME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_FILTERS_TYPE_ANYTIME))
#define OBJECTS_FILTERS_ANYTIME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_FILTERS_TYPE_ANYTIME, ObjectsFiltersAnytimeClass))

typedef struct _ObjectsFiltersAnytime ObjectsFiltersAnytime;
typedef struct _ObjectsFiltersAnytimeClass ObjectsFiltersAnytimeClass;
typedef struct _ObjectsFiltersAnytimePrivate ObjectsFiltersAnytimePrivate;

#define OBJECTS_FILTERS_TYPE_REPEATING (objects_filters_repeating_get_type ())
#define OBJECTS_FILTERS_REPEATING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_FILTERS_TYPE_REPEATING, ObjectsFiltersRepeating))
#define OBJECTS_FILTERS_REPEATING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_FILTERS_TYPE_REPEATING, ObjectsFiltersRepeatingClass))
#define OBJECTS_FILTERS_IS_REPEATING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_FILTERS_TYPE_REPEATING))
#define OBJECTS_FILTERS_IS_REPEATING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_FILTERS_TYPE_REPEATING))
#define OBJECTS_FILTERS_REPEATING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_FILTERS_TYPE_REPEATING, ObjectsFiltersRepeatingClass))

typedef struct _ObjectsFiltersRepeating ObjectsFiltersRepeating;
typedef struct _ObjectsFiltersRepeatingClass ObjectsFiltersRepeatingClass;
typedef struct _ObjectsFiltersRepeatingPrivate ObjectsFiltersRepeatingPrivate;

#define OBJECTS_FILTERS_TYPE_UNLABELED (objects_filters_unlabeled_get_type ())
#define OBJECTS_FILTERS_UNLABELED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_FILTERS_TYPE_UNLABELED, ObjectsFiltersUnlabeled))
#define OBJECTS_FILTERS_UNLABELED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_FILTERS_TYPE_UNLABELED, ObjectsFiltersUnlabeledClass))
#define OBJECTS_FILTERS_IS_UNLABELED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_FILTERS_TYPE_UNLABELED))
#define OBJECTS_FILTERS_IS_UNLABELED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_FILTERS_TYPE_UNLABELED))
#define OBJECTS_FILTERS_UNLABELED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_FILTERS_TYPE_UNLABELED, ObjectsFiltersUnlabeledClass))

typedef struct _ObjectsFiltersUnlabeled ObjectsFiltersUnlabeled;
typedef struct _ObjectsFiltersUnlabeledClass ObjectsFiltersUnlabeledClass;
typedef struct _ObjectsFiltersUnlabeledPrivate ObjectsFiltersUnlabeledPrivate;
typedef struct _ObjectsFiltersFilterItemPrivate ObjectsFiltersFilterItemPrivate;

#define OBJECTS_FILTERS_TYPE_ALL_ITEMS (objects_filters_all_items_get_type ())
#define OBJECTS_FILTERS_ALL_ITEMS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OBJECTS_FILTERS_TYPE_ALL_ITEMS, ObjectsFiltersAllItems))
#define OBJECTS_FILTERS_ALL_ITEMS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OBJECTS_FILTERS_TYPE_ALL_ITEMS, ObjectsFiltersAllItemsClass))
#define OBJECTS_FILTERS_IS_ALL_ITEMS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OBJECTS_FILTERS_TYPE_ALL_ITEMS))
#define OBJECTS_FILTERS_IS_ALL_ITEMS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OBJECTS_FILTERS_TYPE_ALL_ITEMS))
#define OBJECTS_FILTERS_ALL_ITEMS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OBJECTS_FILTERS_TYPE_ALL_ITEMS, ObjectsFiltersAllItemsClass))

typedef struct _ObjectsFiltersAllItems ObjectsFiltersAllItems;
typedef struct _ObjectsFiltersAllItemsClass ObjectsFiltersAllItemsClass;
typedef struct _ObjectsFiltersAllItemsPrivate ObjectsFiltersAllItemsPrivate;

#define SERVICES_TYPE_CALENDAR_EVENTS (services_calendar_events_get_type ())
#define SERVICES_CALENDAR_EVENTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERVICES_TYPE_CALENDAR_EVENTS, ServicesCalendarEvents))
#define SERVICES_CALENDAR_EVENTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERVICES_TYPE_CALENDAR_EVENTS, ServicesCalendarEventsClass))
#define SERVICES_IS_CALENDAR_EVENTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERVICES_TYPE_CALENDAR_EVENTS))
#define SERVICES_IS_CALENDAR_EVENTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERVICES_TYPE_CALENDAR_EVENTS))
#define SERVICES_CALENDAR_EVENTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERVICES_TYPE_CALENDAR_EVENTS, ServicesCalendarEventsClass))

typedef struct _ServicesCalendarEvents ServicesCalendarEvents;
typedef struct _ServicesCalendarEventsClass ServicesCalendarEventsClass;
typedef struct _ServicesCalendarEventsPrivate ServicesCalendarEventsPrivate;

#define CALENDAR_EVENTS_UTIL_TYPE_DATE_RANGE (calendar_events_util_date_range_get_type ())
#define CALENDAR_EVENTS_UTIL_DATE_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CALENDAR_EVENTS_UTIL_TYPE_DATE_RANGE, CalendarEventsUtilDateRange))
#define CALENDAR_EVENTS_UTIL_DATE_RANGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CALENDAR_EVENTS_UTIL_TYPE_DATE_RANGE, CalendarEventsUtilDateRangeClass))
#define CALENDAR_EVENTS_UTIL_IS_DATE_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CALENDAR_EVENTS_UTIL_TYPE_DATE_RANGE))
#define CALENDAR_EVENTS_UTIL_IS_DATE_RANGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CALENDAR_EVENTS_UTIL_TYPE_DATE_RANGE))
#define CALENDAR_EVENTS_UTIL_DATE_RANGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CALENDAR_EVENTS_UTIL_TYPE_DATE_RANGE, CalendarEventsUtilDateRangeClass))

typedef struct _CalendarEventsUtilDateRange CalendarEventsUtilDateRange;
typedef struct _CalendarEventsUtilDateRangeClass CalendarEventsUtilDateRangeClass;

#define CALENDAR_EVENTS_UTIL_TYPE_DATE_ITERATOR (calendar_events_util_date_iterator_get_type ())
#define CALENDAR_EVENTS_UTIL_DATE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CALENDAR_EVENTS_UTIL_TYPE_DATE_ITERATOR, CalendarEventsUtilDateIterator))
#define CALENDAR_EVENTS_UTIL_DATE_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CALENDAR_EVENTS_UTIL_TYPE_DATE_ITERATOR, CalendarEventsUtilDateIteratorClass))
#define CALENDAR_EVENTS_UTIL_IS_DATE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CALENDAR_EVENTS_UTIL_TYPE_DATE_ITERATOR))
#define CALENDAR_EVENTS_UTIL_IS_DATE_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CALENDAR_EVENTS_UTIL_TYPE_DATE_ITERATOR))
#define CALENDAR_EVENTS_UTIL_DATE_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CALENDAR_EVENTS_UTIL_TYPE_DATE_ITERATOR, CalendarEventsUtilDateIteratorClass))

typedef struct _CalendarEventsUtilDateIterator CalendarEventsUtilDateIterator;
typedef struct _CalendarEventsUtilDateIteratorClass CalendarEventsUtilDateIteratorClass;
typedef struct _CalendarEventsUtilDateIteratorPrivate CalendarEventsUtilDateIteratorPrivate;
typedef struct _CalendarEventsUtilDateRangePrivate CalendarEventsUtilDateRangePrivate;

struct _SyncStatus {
	GObject parent_instance;
	SyncStatusPrivate * priv;
};

struct _SyncStatusClass {
	GObjectClass parent_class;
};

struct _LayoutsQuickAddCore {
	AdwBin parent_instance;
	LayoutsQuickAddCorePrivate * priv;
};

struct _LayoutsQuickAddCoreClass {
	AdwBinClass parent_class;
};

struct _Util {
	GObject parent_instance;
	UtilPrivate * priv;
};

struct _UtilClass {
	GObjectClass parent_class;
};

struct _UtilsDatetime {
	GTypeInstance parent_instance;
	volatile int ref_count;
	UtilsDatetimePrivate * priv;
};

struct _UtilsDatetimeClass {
	GTypeClass parent_class;
	void (*finalize) (UtilsDatetime *self);
};

struct _MarkdownProcessor {
	GObject parent_instance;
	MarkdownProcessorPrivate * priv;
};

struct _MarkdownProcessorClass {
	GObjectClass parent_class;
};

struct _UtilsJsonUtils {
	GTypeInstance parent_instance;
	volatile int ref_count;
	UtilsJsonUtilsPrivate * priv;
};

struct _UtilsJsonUtilsClass {
	GTypeClass parent_class;
	void (*finalize) (UtilsJsonUtils *self);
};

struct _ServicesSettings {
	GObject parent_instance;
	ServicesSettingsPrivate * priv;
	GSettings* settings;
	GSettingsSchema* settings_schema;
};

struct _ServicesSettingsClass {
	GObjectClass parent_class;
};

struct _ServicesEventBus {
	GObject parent_instance;
	ServicesEventBusPrivate * priv;
	gboolean _mobile_mode;
	gboolean multi_select_enabled;
	gboolean item_edit_active;
};

struct _ServicesEventBusClass {
	GObjectClass parent_class;
};

struct _ServicesDatabase {
	GObject parent_instance;
	ServicesDatabasePrivate * priv;
};

struct _ServicesDatabaseClass {
	GObjectClass parent_class;
};

struct _ServicesLogService {
	GObject parent_instance;
	ServicesLogServicePrivate * priv;
};

struct _ServicesLogServiceClass {
	GObjectClass parent_class;
};

struct _ServicesStore {
	GObject parent_instance;
	ServicesStorePrivate * priv;
};

struct _ServicesStoreClass {
	GObjectClass parent_class;
};

struct _ServicesTodoist {
	GObject parent_instance;
	ServicesTodoistPrivate * priv;
};

struct _ServicesTodoistClass {
	GObjectClass parent_class;
};

struct _HttpResponse {
	GTypeInstance parent_instance;
	volatile int ref_count;
	HttpResponsePrivate * priv;
};

struct _HttpResponseClass {
	GTypeClass parent_class;
	void (*finalize) (HttpResponse *self);
};

struct _ServicesTodoistAuth {
	GObject parent_instance;
	ServicesTodoistAuthPrivate * priv;
};

struct _ServicesTodoistAuthClass {
	GObjectClass parent_class;
};

struct _ServicesTodoistItems {
	GObject parent_instance;
	ServicesTodoistItemsPrivate * priv;
};

struct _ServicesTodoistItemsClass {
	GObjectClass parent_class;
};

struct _ServicesTodoistProjects {
	GObject parent_instance;
	ServicesTodoistProjectsPrivate * priv;
};

struct _ServicesTodoistProjectsClass {
	GObjectClass parent_class;
};

struct _ServicesBackupExporter {
	GObject parent_instance;
	ServicesBackupExporterPrivate * priv;
};

struct _ServicesBackupExporterClass {
	GObjectClass parent_class;
};

struct _ColorSchemeSettingsSettings {
	GObject parent_instance;
	ColorSchemeSettingsSettingsPrivate * priv;
};

struct _ColorSchemeSettingsSettingsClass {
	GObjectClass parent_class;
};

struct _ServicesCalDAVCore {
	GObject parent_instance;
	ServicesCalDAVCorePrivate * priv;
};

struct _ServicesCalDAVCoreClass {
	GObjectClass parent_class;
};

struct _ServicesCalDAVWebDAVClient {
	GObject parent_instance;
	ServicesCalDAVWebDAVClientPrivate * priv;
	SoupSession* session;
	gchar* username;
	gchar* password;
	gchar* base_url;
	gboolean ignore_ssl;
};

struct _ServicesCalDAVWebDAVClientClass {
	GObjectClass parent_class;
};

struct _ServicesCalDAVCalDAVClient {
	ServicesCalDAVWebDAVClient parent_instance;
	ServicesCalDAVCalDAVClientPrivate * priv;
};

struct _ServicesCalDAVCalDAVClientClass {
	ServicesCalDAVWebDAVClientClass parent_class;
};

struct _ServicesCalDAVWebDAVMultiStatus {
	GObject parent_instance;
	ServicesCalDAVWebDAVMultiStatusPrivate * priv;
};

struct _ServicesCalDAVWebDAVMultiStatusClass {
	GObjectClass parent_class;
};

struct _ServicesCalDAVWebDAVResponse {
	GObject parent_instance;
	ServicesCalDAVWebDAVResponsePrivate * priv;
};

struct _ServicesCalDAVWebDAVResponseClass {
	GObjectClass parent_class;
};

struct _ServicesCalDAVWebDAVPropStat {
	GObject parent_instance;
	ServicesCalDAVWebDAVPropStatPrivate * priv;
};

struct _ServicesCalDAVWebDAVPropStatClass {
	GObjectClass parent_class;
};

struct _ServicesCalDAVProvidersNextcloud {
	GObject parent_instance;
	ServicesCalDAVProvidersNextcloudPrivate * priv;
};

struct _ServicesCalDAVProvidersNextcloudClass {
	GObjectClass parent_class;
};

struct _LayoutsHeaderItem {
	AdwBin parent_instance;
	LayoutsHeaderItemPrivate * priv;
	gchar* _header_title;
	gchar* _subheader_title;
	gchar* _placeholder_message;
	GtkListBox* listbox;
	GtkGrid* drop_target_end;
	GtkRevealer* drop_target_end_revealer;
};

struct _LayoutsHeaderItemClass {
	AdwBinClass parent_class;
};

struct _WidgetsLoadingButton {
	GtkButton parent_instance;
	WidgetsLoadingButtonPrivate * priv;
};

struct _WidgetsLoadingButtonClass {
	GtkButtonClass parent_class;
};

struct _WidgetsTextView {
	GtkTextView parent_instance;
	WidgetsTextViewPrivate * priv;
};

struct _WidgetsTextViewClass {
	GtkTextViewClass parent_class;
};

struct _WidgetsIconColorProject {
	AdwBin parent_instance;
	WidgetsIconColorProjectPrivate * priv;
	GtkImage* inbox_icon;
};

struct _WidgetsIconColorProjectClass {
	AdwBinClass parent_class;
};

struct _WidgetsPinButton {
	GtkButton parent_instance;
	WidgetsPinButtonPrivate * priv;
};

struct _WidgetsPinButtonClass {
	GtkButtonClass parent_class;
};

struct _WidgetsPriorityButton {
	AdwBin parent_instance;
	WidgetsPriorityButtonPrivate * priv;
};

struct _WidgetsPriorityButtonClass {
	AdwBinClass parent_class;
};

struct _WidgetsItemLabels {
	AdwBin parent_instance;
	WidgetsItemLabelsPrivate * priv;
};

struct _WidgetsItemLabelsClass {
	AdwBinClass parent_class;
};

struct _WidgetsItemLabelChild {
	GtkButton parent_instance;
	WidgetsItemLabelChildPrivate * priv;
};

struct _WidgetsItemLabelChildClass {
	GtkButtonClass parent_class;
};

struct _WidgetsCircularProgressBar {
	GtkDrawingArea parent_instance;
	WidgetsCircularProgressBarPrivate * priv;
};

struct _WidgetsCircularProgressBarClass {
	GtkDrawingAreaClass parent_class;
};

struct _WidgetsStatusButton {
	AdwBin parent_instance;
	WidgetsStatusButtonPrivate * priv;
};

struct _WidgetsStatusButtonClass {
	AdwBinClass parent_class;
};

struct _WidgetsMarkdownEditor {
	AdwBin parent_instance;
	WidgetsMarkdownEditorPrivate * priv;
	GtkTextView* text_view;
	GtkSourceBuffer* buffer;
};

struct _WidgetsMarkdownEditorClass {
	AdwBinClass parent_class;
};

struct _WidgetsDeadlineButton {
	AdwBin parent_instance;
	WidgetsDeadlineButtonPrivate * priv;
};

struct _WidgetsDeadlineButtonClass {
	AdwBinClass parent_class;
};

struct _WidgetsCalendarCalendar {
	GtkBox parent_instance;
	WidgetsCalendarCalendarPrivate * priv;
};

struct _WidgetsCalendarCalendarClass {
	GtkBoxClass parent_class;
};

struct _WidgetsCalendarCalendarDay {
	AdwBin parent_instance;
	WidgetsCalendarCalendarDayPrivate * priv;
};

struct _WidgetsCalendarCalendarDayClass {
	AdwBinClass parent_class;
};

struct _WidgetsCalendarCalendarHeader {
	GtkBox parent_instance;
	WidgetsCalendarCalendarHeaderPrivate * priv;
};

struct _WidgetsCalendarCalendarHeaderClass {
	GtkBoxClass parent_class;
};

struct _WidgetsCalendarCalendarView {
	AdwBin parent_instance;
	WidgetsCalendarCalendarViewPrivate * priv;
};

struct _WidgetsCalendarCalendarViewClass {
	AdwBinClass parent_class;
};

struct _WidgetsCalendarCalendarWeek {
	GtkBox parent_instance;
	WidgetsCalendarCalendarWeekPrivate * priv;
};

struct _WidgetsCalendarCalendarWeekClass {
	GtkBoxClass parent_class;
};

struct _WidgetsCalendarCalendarMonth {
	GtkBox parent_instance;
	WidgetsCalendarCalendarMonthPrivate * priv;
};

struct _WidgetsCalendarCalendarMonthClass {
	GtkBoxClass parent_class;
};

struct _WidgetsCalendarCalendarScroll {
	AdwBin parent_instance;
	WidgetsCalendarCalendarScrollPrivate * priv;
};

struct _WidgetsCalendarCalendarScrollClass {
	AdwBinClass parent_class;
};

struct _WidgetsContextMenuMenuItem {
	GtkButton parent_instance;
	WidgetsContextMenuMenuItemPrivate * priv;
};

struct _WidgetsContextMenuMenuItemClass {
	GtkButtonClass parent_class;
};

struct _WidgetsContextMenuMenuSeparator {
	AdwBin parent_instance;
	WidgetsContextMenuMenuSeparatorPrivate * priv;
};

struct _WidgetsContextMenuMenuSeparatorClass {
	AdwBinClass parent_class;
};

struct _WidgetsContextMenuMenuPicker {
	AdwBin parent_instance;
	WidgetsContextMenuMenuPickerPrivate * priv;
	gchar* _selected;
};

struct _WidgetsContextMenuMenuPickerClass {
	AdwBinClass parent_class;
};

struct _WidgetsContextMenuMenuPickerMenuItemPicker {
	GtkListBoxRow parent_instance;
	WidgetsContextMenuMenuPickerMenuItemPickerPrivate * priv;
};

struct _WidgetsContextMenuMenuPickerMenuItemPickerClass {
	GtkListBoxRowClass parent_class;
};

struct _WidgetsContextMenuMenuCheckPicker {
	AdwBin parent_instance;
	WidgetsContextMenuMenuCheckPickerPrivate * priv;
	GeeHashMap* filters_map;
};

struct _WidgetsContextMenuMenuCheckPickerClass {
	AdwBinClass parent_class;
};

struct _WidgetsContextMenuMenuItemCheckPicker {
	GtkListBoxRow parent_instance;
	WidgetsContextMenuMenuItemCheckPickerPrivate * priv;
};

struct _WidgetsContextMenuMenuItemCheckPickerClass {
	GtkListBoxRowClass parent_class;
};

struct _WidgetsContextMenuMenuSwitch {
	GtkButton parent_instance;
	WidgetsContextMenuMenuSwitchPrivate * priv;
};

struct _WidgetsContextMenuMenuSwitchClass {
	GtkButtonClass parent_class;
};

struct _WidgetsScheduleButton {
	GtkGrid parent_instance;
	WidgetsScheduleButtonPrivate * priv;
};

struct _WidgetsScheduleButtonClass {
	GtkGridClass parent_class;
};

struct _WidgetsDateTimePickerDateTimePicker {
	GtkPopover parent_instance;
	WidgetsDateTimePickerDateTimePickerPrivate * priv;
};

struct _WidgetsDateTimePickerDateTimePickerClass {
	GtkPopoverClass parent_class;
};

struct _WidgetsDateTimePickerDateTimePickerSuggestedDate {
	AdwBin parent_instance;
	WidgetsDateTimePickerDateTimePickerSuggestedDatePrivate * priv;
};

struct _WidgetsDateTimePickerDateTimePickerSuggestedDateClass {
	AdwBinClass parent_class;
};

struct _WidgetsDateTimePickerDateTimePickerNoDateButton {
	AdwBin parent_instance;
	WidgetsDateTimePickerDateTimePickerNoDateButtonPrivate * priv;
};

struct _WidgetsDateTimePickerDateTimePickerNoDateButtonClass {
	AdwBinClass parent_class;
};

struct _WidgetsDateTimePickerDateTimePickerOptionButton {
	GtkBox parent_instance;
	WidgetsDateTimePickerDateTimePickerOptionButtonPrivate * priv;
};

struct _WidgetsDateTimePickerDateTimePickerOptionButtonClass {
	GtkBoxClass parent_class;
};

struct _WidgetsDateTimePickerTimePicker {
	AdwBin parent_instance;
	WidgetsDateTimePickerTimePickerPrivate * priv;
};

struct _WidgetsDateTimePickerTimePickerClass {
	AdwBinClass parent_class;
};

struct _WidgetsDateTimePickerRepeatConfig {
	AdwNavigationPage parent_instance;
	WidgetsDateTimePickerRepeatConfigPrivate * priv;
};

struct _WidgetsDateTimePickerRepeatConfigClass {
	AdwNavigationPageClass parent_class;
};

struct _WidgetsLabelPickerLabelPicker {
	GtkPopover parent_instance;
	WidgetsLabelPickerLabelPickerPrivate * priv;
};

struct _WidgetsLabelPickerLabelPickerClass {
	GtkPopoverClass parent_class;
};

struct _WidgetsLabelPickerLabelRow {
	GtkListBoxRow parent_instance;
	WidgetsLabelPickerLabelRowPrivate * priv;
};

struct _WidgetsLabelPickerLabelRowClass {
	GtkListBoxRowClass parent_class;
};

struct _WidgetsLabelPickerLabelButton {
	AdwBin parent_instance;
	WidgetsLabelPickerLabelButtonPrivate * priv;
};

struct _WidgetsLabelPickerLabelButtonClass {
	AdwBinClass parent_class;
};

struct _WidgetsLabelsPickerCore {
	AdwBin parent_instance;
	WidgetsLabelsPickerCorePrivate * priv;
	GeeHashMap* labels_widgets_map;
	GeeHashMap* picked;
};

struct _WidgetsLabelsPickerCoreClass {
	AdwBinClass parent_class;
};

struct _WidgetsLabelPickerLabelQuickPicker {
	GtkPopover parent_instance;
	WidgetsLabelPickerLabelQuickPickerPrivate * priv;
	GeeHashMap* labels_widgets_map;
};

struct _WidgetsLabelPickerLabelQuickPickerClass {
	GtkPopoverClass parent_class;
};

struct _WidgetsProjectPickerCore {
	AdwBin parent_instance;
	WidgetsProjectPickerCorePrivate * priv;
};

struct _WidgetsProjectPickerCoreClass {
	AdwBinClass parent_class;
};

struct _WidgetsProjectPickerProjectPickerPopover {
	GtkPopover parent_instance;
	WidgetsProjectPickerProjectPickerPopoverPrivate * priv;
};

struct _WidgetsProjectPickerProjectPickerPopoverClass {
	GtkPopoverClass parent_class;
};

struct _WidgetsProjectPickerProjectPickerRow {
	GtkListBoxRow parent_instance;
	WidgetsProjectPickerProjectPickerRowPrivate * priv;
};

struct _WidgetsProjectPickerProjectPickerRowClass {
	GtkListBoxRowClass parent_class;
};

struct _WidgetsProjectPickerProjectPickerButton {
	AdwBin parent_instance;
	WidgetsProjectPickerProjectPickerButtonPrivate * priv;
	GeeHashMap* sections_map;
};

struct _WidgetsProjectPickerProjectPickerButtonClass {
	AdwBinClass parent_class;
};

struct _WidgetsSectionPickerSectionButton {
	AdwBin parent_instance;
	WidgetsSectionPickerSectionButtonPrivate * priv;
};

struct _WidgetsSectionPickerSectionButtonClass {
	AdwBinClass parent_class;
};

struct _WidgetsSectionPickerSectionPicker {
	GtkPopover parent_instance;
	WidgetsSectionPickerSectionPickerPrivate * priv;
};

struct _WidgetsSectionPickerSectionPickerClass {
	GtkPopoverClass parent_class;
};

struct _WidgetsSectionPickerSectionPickerRow {
	GtkListBoxRow parent_instance;
	WidgetsSectionPickerSectionPickerRowPrivate * priv;
};

struct _WidgetsSectionPickerSectionPickerRowClass {
	GtkListBoxRowClass parent_class;
};

struct _WidgetsReminderPickerReminderButton {
	AdwBin parent_instance;
	WidgetsReminderPickerReminderButtonPrivate * priv;
};

struct _WidgetsReminderPickerReminderButtonClass {
	AdwBinClass parent_class;
};

struct _WidgetsReminderPickerReminderPicker {
	GtkPopover parent_instance;
	WidgetsReminderPickerReminderPickerPrivate * priv;
};

struct _WidgetsReminderPickerReminderPickerClass {
	GtkPopoverClass parent_class;
};

struct _WidgetsReminderPickerReminderRow {
	GtkListBoxRow parent_instance;
	WidgetsReminderPickerReminderRowPrivate * priv;
};

struct _WidgetsReminderPickerReminderRowClass {
	GtkListBoxRowClass parent_class;
};

struct _ObjectsBaseObject {
	GObject parent_instance;
	ObjectsBaseObjectPrivate * priv;
	GeeHashMap* filters;
	gint* _item_count;
	gdouble* _percentage;
};

struct _ObjectsBaseObjectClass {
	GObjectClass parent_class;
	gchar* (*get_update_json) (ObjectsBaseObject* self, const gchar* uuid, const gchar* temp_id);
	gchar* (*get_add_json) (ObjectsBaseObject* self, const gchar* temp_id, const gchar* uuid);
	gchar* (*get_move_json) (ObjectsBaseObject* self, const gchar* uuid, const gchar* new_project_id);
	gchar* (*to_json) (ObjectsBaseObject* self);
	gint (*update_count) (ObjectsBaseObject* self);
	gdouble (*update_percentage) (ObjectsBaseObject* self);
	void (*count_update) (ObjectsBaseObject* self);
	gchar* (*theme_color) (ObjectsBaseObject* self);
};

struct _ObjectsColor {
	GObject parent_instance;
	ObjectsColorPrivate * priv;
};

struct _ObjectsColorClass {
	GObjectClass parent_class;
};

struct _ObjectsDueDate {
	GObject parent_instance;
	ObjectsDueDatePrivate * priv;
};

struct _ObjectsDueDateClass {
	GObjectClass parent_class;
};

struct _ObjectsItem {
	ObjectsBaseObject parent_instance;
	ObjectsItemPrivate * priv;
};

struct _ObjectsItemClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ObjectsLabel {
	ObjectsBaseObject parent_instance;
	ObjectsLabelPrivate * priv;
};

struct _ObjectsLabelClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ObjectsProject {
	ObjectsBaseObject parent_instance;
	ObjectsProjectPrivate * priv;
};

struct _ObjectsProjectClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ObjectsQueue {
	GObject parent_instance;
	ObjectsQueuePrivate * priv;
};

struct _ObjectsQueueClass {
	GObjectClass parent_class;
};

struct _ObjectsReminder {
	ObjectsBaseObject parent_instance;
	ObjectsReminderPrivate * priv;
};

struct _ObjectsReminderClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ObjectsSection {
	ObjectsBaseObject parent_instance;
	ObjectsSectionPrivate * priv;
};

struct _ObjectsSectionClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ObjectsAttachment {
	GObject parent_instance;
	ObjectsAttachmentPrivate * priv;
};

struct _ObjectsAttachmentClass {
	GObjectClass parent_class;
};

struct _ObjectsObjectEvent {
	GObject parent_instance;
	ObjectsObjectEventPrivate * priv;
};

struct _ObjectsObjectEventClass {
	GObjectClass parent_class;
};

struct _ObjectsSource {
	ObjectsBaseObject parent_instance;
	ObjectsSourcePrivate * priv;
};

struct _ObjectsSourceClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ObjectsSourceData {
	GObject parent_instance;
	ObjectsSourceDataPrivate * priv;
};

struct _ObjectsSourceDataClass {
	GObjectClass parent_class;
	gchar* (*to_json) (ObjectsSourceData* self);
};

struct _ObjectsSourceTodoistData {
	ObjectsSourceData parent_instance;
	ObjectsSourceTodoistDataPrivate * priv;
};

struct _ObjectsSourceTodoistDataClass {
	ObjectsSourceDataClass parent_class;
};

struct _ObjectsSourceCalDAVData {
	ObjectsSourceData parent_instance;
	ObjectsSourceCalDAVDataPrivate * priv;
};

struct _ObjectsSourceCalDAVDataClass {
	ObjectsSourceDataClass parent_class;
};

struct _ObjectsTranslationMetric {
	GObject parent_instance;
	ObjectsTranslationMetricPrivate * priv;
};

struct _ObjectsTranslationMetricClass {
	GObjectClass parent_class;
};

struct _ObjectsRelease {
	GObject parent_instance;
	ObjectsReleasePrivate * priv;
};

struct _ObjectsReleaseClass {
	GObjectClass parent_class;
};

struct _ObjectsFiltersInbox {
	ObjectsBaseObject parent_instance;
	ObjectsFiltersInboxPrivate * priv;
};

struct _ObjectsFiltersInboxClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ObjectsFiltersPinboard {
	ObjectsBaseObject parent_instance;
	ObjectsFiltersPinboardPrivate * priv;
};

struct _ObjectsFiltersPinboardClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ObjectsFiltersScheduled {
	ObjectsBaseObject parent_instance;
	ObjectsFiltersScheduledPrivate * priv;
};

struct _ObjectsFiltersScheduledClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ObjectsFiltersToday {
	ObjectsBaseObject parent_instance;
	ObjectsFiltersTodayPrivate * priv;
};

struct _ObjectsFiltersTodayClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ObjectsFiltersPriority {
	ObjectsBaseObject parent_instance;
	ObjectsFiltersPriorityPrivate * priv;
};

struct _ObjectsFiltersPriorityClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ObjectsFiltersCompleted {
	ObjectsBaseObject parent_instance;
	ObjectsFiltersCompletedPrivate * priv;
};

struct _ObjectsFiltersCompletedClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ObjectsFiltersLabels {
	ObjectsBaseObject parent_instance;
	ObjectsFiltersLabelsPrivate * priv;
};

struct _ObjectsFiltersLabelsClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ObjectsFiltersTomorrow {
	ObjectsBaseObject parent_instance;
	ObjectsFiltersTomorrowPrivate * priv;
};

struct _ObjectsFiltersTomorrowClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ObjectsFiltersAnytime {
	ObjectsBaseObject parent_instance;
	ObjectsFiltersAnytimePrivate * priv;
};

struct _ObjectsFiltersAnytimeClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ObjectsFiltersRepeating {
	ObjectsBaseObject parent_instance;
	ObjectsFiltersRepeatingPrivate * priv;
};

struct _ObjectsFiltersRepeatingClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ObjectsFiltersUnlabeled {
	ObjectsBaseObject parent_instance;
	ObjectsFiltersUnlabeledPrivate * priv;
};

struct _ObjectsFiltersUnlabeledClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ObjectsFiltersFilterItem {
	GObject parent_instance;
	ObjectsFiltersFilterItemPrivate * priv;
};

struct _ObjectsFiltersFilterItemClass {
	GObjectClass parent_class;
};

struct _ObjectsFiltersAllItems {
	ObjectsBaseObject parent_instance;
	ObjectsFiltersAllItemsPrivate * priv;
};

struct _ObjectsFiltersAllItemsClass {
	ObjectsBaseObjectClass parent_class;
};

struct _ServicesCalendarEvents {
	GObject parent_instance;
	ServicesCalendarEventsPrivate * priv;
};

struct _ServicesCalendarEventsClass {
	GObjectClass parent_class;
};

struct _CalendarEventsUtilDateIterator {
	GObject parent_instance;
	CalendarEventsUtilDateIteratorPrivate * priv;
};

struct _CalendarEventsUtilDateIteratorClass {
	GObjectClass parent_class;
};

struct _CalendarEventsUtilDateRange {
	GObject parent_instance;
	CalendarEventsUtilDateRangePrivate * priv;
};

struct _CalendarEventsUtilDateRangeClass {
	GObjectClass parent_class;
};

VALA_EXTERN GType color_scheme_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType notification_style_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType project_view_style_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* project_view_style_to_string (ProjectViewStyle self);
VALA_EXTERN ProjectViewStyle project_view_style_parse (const gchar* value);
VALA_EXTERN GType project_icon_style_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* project_icon_style_to_string (ProjectIconStyle self);
VALA_EXTERN ProjectIconStyle project_icon_style_parse (const gchar* value);
VALA_EXTERN GType source_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* source_type_to_string (SourceType self);
VALA_EXTERN SourceType source_type_parse (const gchar* value);
VALA_EXTERN GType pane_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType loading_button_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType object_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* object_type_get_header (ObjectType self);
VALA_EXTERN GType recurrency_end_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType recurrency_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* recurrency_type_to_friendly_string (RecurrencyType self,
                                           gint* interval);
VALA_EXTERN GType picker_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* picker_type_to_string (PickerType self);
VALA_EXTERN GType new_task_position_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType cal_dav_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* cal_dav_type_to_string (CalDAVType self);
VALA_EXTERN gchar* cal_dav_type_title (CalDAVType self);
VALA_EXTERN CalDAVType cal_dav_type_parse_index (guint value);
VALA_EXTERN CalDAVType cal_dav_type_parse (const gchar* value);
VALA_EXTERN GType filter_item_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* filter_item_type_to_string (FilterItemType self);
VALA_EXTERN gchar* filter_item_type_get_title (FilterItemType self);
VALA_EXTERN gchar* filter_item_type_get_icon (FilterItemType self);
VALA_EXTERN GType reminder_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* reminder_type_to_string (ReminderType self);
VALA_EXTERN GType item_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* item_type_to_string (ItemType self);
VALA_EXTERN ItemType item_type_parse (const gchar* value);
VALA_EXTERN GType object_event_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN ObjectEventType object_event_type_parse (const gchar* value);
VALA_EXTERN gchar* object_event_type_to_string (ObjectEventType self);
VALA_EXTERN gchar* object_event_type_get_label (ObjectEventType self);
VALA_EXTERN GType object_event_key_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN ObjectEventKeyType object_event_key_type_parse (const gchar* value);
VALA_EXTERN gchar* object_event_key_type_get_label (ObjectEventKeyType self);
VALA_EXTERN GType label_picker_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType item_priority_get_type (void) G_GNUC_CONST ;
VALA_EXTERN ItemPriority item_priority_parse (const gchar* value);
VALA_EXTERN gchar* item_priority_get_color (ItemPriority self);
VALA_EXTERN GType sort_order_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* sort_order_type_to_string (SortOrderType self);
VALA_EXTERN SortOrderType sort_order_type_parse (const gchar* value);
VALA_EXTERN GType sorted_by_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* sorted_by_type_to_string (SortedByType self);
VALA_EXTERN SortedByType sorted_by_type_parse (const gchar* value);
VALA_EXTERN GType appearance_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* appearance_to_string (Appearance self);
VALA_EXTERN Appearance appearance_parse (gint value);
VALA_EXTERN Appearance appearance_get_default (void);
VALA_EXTERN GType sync_error_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType sync_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SyncStatus, g_object_unref)
VALA_EXTERN SyncStatus* sync_status_new (SyncErrorType error_type,
                             const gchar* title,
                             const gchar* description);
VALA_EXTERN SyncStatus* sync_status_construct (GType object_type,
                                   SyncErrorType error_type,
                                   const gchar* title,
                                   const gchar* description);
VALA_EXTERN SyncErrorType sync_status_get_error_type (SyncStatus* self);
VALA_EXTERN void sync_status_set_error_type (SyncStatus* self,
                                 SyncErrorType value);
VALA_EXTERN const gchar* sync_status_get_title (SyncStatus* self);
VALA_EXTERN void sync_status_set_title (SyncStatus* self,
                            const gchar* value);
VALA_EXTERN const gchar* sync_status_get_description (SyncStatus* self);
VALA_EXTERN void sync_status_set_description (SyncStatus* self,
                                  const gchar* value);
VALA_EXTERN gchar* sync_status_get_tooltip (SyncStatus* self);
VALA_EXTERN GType markdown_setting_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* markdown_setting_to_string (MarkdownSetting self);
VALA_EXTERN MarkdownSetting markdown_setting_parse (const gchar* value);
VALA_EXTERN GType layouts_quick_add_core_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LayoutsQuickAddCore, g_object_unref)
VALA_EXTERN GType layouts_quick_add_core_focused_widget_get_type (void) G_GNUC_CONST ;
VALA_EXTERN LayoutsQuickAddCore* layouts_quick_add_core_new (gboolean is_window_quick_add);
VALA_EXTERN LayoutsQuickAddCore* layouts_quick_add_core_construct (GType object_type,
                                                       gboolean is_window_quick_add);
VALA_EXTERN void layouts_quick_add_core_added_successfully (LayoutsQuickAddCore* self);
VALA_EXTERN void layouts_quick_add_core_update_content (LayoutsQuickAddCore* self,
                                            const gchar* content);
VALA_EXTERN void layouts_quick_add_core_set_due (LayoutsQuickAddCore* self,
                                     GDateTime* datetime);
VALA_EXTERN GType objects_due_date_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsDueDate, g_object_unref)
VALA_EXTERN void layouts_quick_add_core_set_duedate (LayoutsQuickAddCore* self,
                                         ObjectsDueDate* duedate);
VALA_EXTERN void layouts_quick_add_core_set_priority (LayoutsQuickAddCore* self,
                                          gint priority);
VALA_EXTERN void layouts_quick_add_core_set_pinned (LayoutsQuickAddCore* self,
                                        gboolean pinned);
VALA_EXTERN GType objects_base_object_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsBaseObject, g_object_unref)
VALA_EXTERN GType objects_label_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsLabel, g_object_unref)
VALA_EXTERN void layouts_quick_add_core_set_labels (LayoutsQuickAddCore* self,
                                        GeeHashMap* new_labels);
VALA_EXTERN GType objects_project_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsProject, g_object_unref)
VALA_EXTERN void layouts_quick_add_core_for_project (LayoutsQuickAddCore* self,
                                         ObjectsProject* project);
VALA_EXTERN GType objects_section_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsSection, g_object_unref)
VALA_EXTERN void layouts_quick_add_core_for_section (LayoutsQuickAddCore* self,
                                         ObjectsSection* section);
VALA_EXTERN GType objects_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsItem, g_object_unref)
VALA_EXTERN void layouts_quick_add_core_for_parent (LayoutsQuickAddCore* self,
                                        ObjectsItem* _item);
VALA_EXTERN void layouts_quick_add_core_clean_up (LayoutsQuickAddCore* self);
VALA_EXTERN gboolean layouts_quick_add_core_get_is_window_quick_add (LayoutsQuickAddCore* self);
VALA_EXTERN ObjectsItem* layouts_quick_add_core_get_item (LayoutsQuickAddCore* self);
VALA_EXTERN void layouts_quick_add_core_set_item (LayoutsQuickAddCore* self,
                                      ObjectsItem* value);
VALA_EXTERN gboolean layouts_quick_add_core_get_ctrl_pressed (LayoutsQuickAddCore* self);
VALA_EXTERN void layouts_quick_add_core_set_ctrl_pressed (LayoutsQuickAddCore* self,
                                              gboolean value);
VALA_EXTERN gboolean layouts_quick_add_core_get_shift_pressed (LayoutsQuickAddCore* self);
VALA_EXTERN void layouts_quick_add_core_set_shift_pressed (LayoutsQuickAddCore* self,
                                               gboolean value);
VALA_EXTERN gboolean layouts_quick_add_core_get_labels_picker_activate_shortcut (LayoutsQuickAddCore* self);
VALA_EXTERN void layouts_quick_add_core_set_labels_picker_activate_shortcut (LayoutsQuickAddCore* self,
                                                                 gboolean value);
VALA_EXTERN gboolean layouts_quick_add_core_get_project_picker_activate_shortcut (LayoutsQuickAddCore* self);
VALA_EXTERN void layouts_quick_add_core_set_project_picker_activate_shortcut (LayoutsQuickAddCore* self,
                                                                  gboolean value);
VALA_EXTERN gboolean layouts_quick_add_core_get_reminder_picker_activate_shortcut (LayoutsQuickAddCore* self);
VALA_EXTERN void layouts_quick_add_core_set_reminder_picker_activate_shortcut (LayoutsQuickAddCore* self,
                                                                   gboolean value);
VALA_EXTERN LayoutsQuickAddCoreFocusedWidget layouts_quick_add_core_get_current_focus (LayoutsQuickAddCore* self);
VALA_EXTERN gint layouts_quick_add_core_get_position (LayoutsQuickAddCore* self);
VALA_EXTERN void layouts_quick_add_core_set_position (LayoutsQuickAddCore* self,
                                          gint value);
VALA_EXTERN NewTaskPosition layouts_quick_add_core_get_new_task_position (LayoutsQuickAddCore* self);
VALA_EXTERN void layouts_quick_add_core_set_new_task_position (LayoutsQuickAddCore* self,
                                                   NewTaskPosition value);
VALA_EXTERN gboolean layouts_quick_add_core_get_is_loading (LayoutsQuickAddCore* self);
VALA_EXTERN void layouts_quick_add_core_set_is_loading (LayoutsQuickAddCore* self,
                                            gboolean value);
VALA_EXTERN GType util_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Util, g_object_unref)
VALA_EXTERN Util* util_get_default (void);
VALA_EXTERN GType objects_color_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsColor, g_object_unref)
VALA_EXTERN GeeHashMap* util_get_colors (Util* self);
VALA_EXTERN gchar* util_get_color_name (Util* self,
                            const gchar* key);
VALA_EXTERN gchar* util_get_color (Util* self,
                       const gchar* key);
VALA_EXTERN gchar* util_get_random_color (Util* self);
VALA_EXTERN void util_set_widget_color (Util* self,
                            const gchar* color,
                            GtkWidget* widget);
VALA_EXTERN void util_set_widget_priority (Util* self,
                               gint priority,
                               GtkWidget* widget);
VALA_EXTERN void util_download_profile_image (Util* self,
                                  const gchar* id,
                                  const gchar* avatar_url);
VALA_EXTERN gchar* util_get_avatar_path (Util* self,
                             const gchar* id);
VALA_EXTERN gchar* util_generate_id (Util* self,
                         ObjectsBaseObject* base_object);
VALA_EXTERN gchar* util_generate_string (Util* self);
VALA_EXTERN gchar* util_get_encode_text (Util* self,
                             const gchar* text);
VALA_EXTERN gchar* util_get_theme_name (Util* self);
VALA_EXTERN gchar* util_get_user_language (void);
VALA_EXTERN gchar* util_get_badge_name (Util* self);
VALA_EXTERN gchar* util_get_accent_color (Util* self);
VALA_EXTERN void util_update_theme (Util* self);
VALA_EXTERN void util_update_font_scale (Util* self);
VALA_EXTERN gchar* util_line_break_to_space (Util* self,
                                 const gchar* str);
VALA_EXTERN void util_play_audio (Util* self);
VALA_EXTERN gboolean util_is_input_valid (Util* self,
                              GtkEntry* entry);
VALA_EXTERN gboolean util_is_text_valid (Util* self,
                             const gchar* text);
VALA_EXTERN gchar* util_get_short_name (Util* self,
                            const gchar* name,
                            gint size);
VALA_EXTERN void util_clear_database (Util* self,
                          const gchar* title,
                          const gchar* message,
                          GtkWindow* window);
VALA_EXTERN void util_show_alert_destroy (Util* self,
                              GtkWindow* window);
VALA_EXTERN gint util_get_default_priority (Util* self);
VALA_EXTERN gint util_to_caldav_priority (Util* self,
                              gint priority);
VALA_EXTERN gboolean util_is_dark_theme (Util* self);
VALA_EXTERN gboolean util_is_flatpak (Util* self);
VALA_EXTERN GList* util_get_children (Util* self,
                          GtkListBox* list);
VALA_EXTERN GList* util_get_flowbox_children (Util* self,
                                  GtkFlowBox* list);
VALA_EXTERN AdwToast* util_create_toast (Util* self,
                             const gchar* title,
                             guint timeout,
                             AdwToastPriority priority);
VALA_EXTERN GType objects_source_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsSource, g_object_unref)
VALA_EXTERN ObjectsSource* util_create_local_source (Util* self);
VALA_EXTERN ObjectsProject* util_create_inbox_project (Util* self);
VALA_EXTERN void util_create_tutorial_project (Util* self);
VALA_EXTERN void util_create_default_labels (Util* self);
VALA_EXTERN gchar* util_markup_accel_tooltip (Util* self,
                                  const gchar* description,
                                  const gchar* accel);
VALA_EXTERN gchar* util_markup_accels_tooltip (Util* self,
                                   const gchar* description,
                                   gchar** accels,
                                   gint accels_length1);
VALA_EXTERN gchar* util_generate_extra_data (const gchar* ical_url,
                                 const gchar* etag,
                                 const gchar* data);
VALA_EXTERN void util_move_backend_type_item (Util* self,
                                  ObjectsItem* item,
                                  ObjectsProject* target_project,
                                  const gchar* parent_id,
                                  gboolean notify,
                                  GAsyncReadyCallback _callback_,
                                  gpointer _user_data_);
VALA_EXTERN void util_move_backend_type_item_finish (Util* self,
                                         GAsyncResult* _res_);
VALA_EXTERN void util_add_final_duplicate_item (Util* self,
                                    ObjectsItem* new_item,
                                    ObjectsItem* item,
                                    gboolean notify,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN void util_add_final_duplicate_item_finish (Util* self,
                                           GAsyncResult* _res_);
VALA_EXTERN void util_duplicate_item (Util* self,
                          ObjectsItem* item,
                          const gchar* project_id,
                          const gchar* section_id,
                          const gchar* parent_id,
                          gboolean notify,
                          GAsyncReadyCallback _callback_,
                          gpointer _user_data_);
VALA_EXTERN void util_duplicate_item_finish (Util* self,
                                 GAsyncResult* _res_);
VALA_EXTERN void util_duplicate_section (Util* self,
                             ObjectsSection* section,
                             const gchar* project_id,
                             gboolean notify,
                             GAsyncReadyCallback _callback_,
                             gpointer _user_data_);
VALA_EXTERN void util_duplicate_section_finish (Util* self,
                                    GAsyncResult* _res_);
VALA_EXTERN void util_duplicate_project (Util* self,
                             ObjectsProject* project,
                             const gchar* parent_id,
                             GAsyncReadyCallback _callback_,
                             gpointer _user_data_);
VALA_EXTERN void util_duplicate_project_finish (Util* self,
                                    GAsyncResult* _res_);
VALA_EXTERN gint util_get_reminders_mm_offset (void);
VALA_EXTERN gchar* util_get_reminders_mm_offset_text (gint value);
VALA_EXTERN void util_nap (guint interval,
               gint priority,
               GAsyncReadyCallback _callback_,
               gpointer _user_data_);
VALA_EXTERN void util_nap_finish (GAsyncResult* _res_);
VALA_EXTERN gint util_natural_compare (Util* self,
                           const gchar* a,
                           const gchar* b);
VALA_EXTERN gint util_set_item_sort_func (Util* self,
                              ObjectsItem* item1,
                              ObjectsItem* item2,
                              SortedByType sorted_by,
                              SortOrderType sort_order);
VALA_EXTERN Util* util_new (void);
VALA_EXTERN Util* util_construct (GType object_type);
VALA_EXTERN gpointer utils_datetime_ref (gpointer instance);
VALA_EXTERN void utils_datetime_unref (gpointer instance);
VALA_EXTERN GParamSpec* utils_param_spec_datetime (const gchar* name,
                                       const gchar* nick,
                                       const gchar* blurb,
                                       GType object_type,
                                       GParamFlags flags);
VALA_EXTERN void utils_value_set_datetime (GValue* value,
                               gpointer v_object);
VALA_EXTERN void utils_value_take_datetime (GValue* value,
                                gpointer v_object);
VALA_EXTERN gpointer utils_value_get_datetime (const GValue* value);
VALA_EXTERN GType utils_datetime_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (UtilsDatetime, utils_datetime_unref)
VALA_EXTERN GDateTime* utils_datetime_get_todoist_datetime (const gchar* date);
VALA_EXTERN gchar* utils_datetime_get_relative_date_from_date (GDateTime* datetime);
VALA_EXTERN gchar* utils_datetime_days_left (GDateTime* datetime,
                                 gboolean show_today);
VALA_EXTERN gchar* utils_datetime_get_default_time_format (gboolean is_12h,
                                               gboolean with_second);
VALA_EXTERN gboolean utils_datetime_is_clock_format_12h (void);
VALA_EXTERN gboolean utils_datetime_is_yesterday (GDateTime* date);
VALA_EXTERN gboolean utils_datetime_is_same_day (GDateTime* day1,
                                     GDateTime* day2);
VALA_EXTERN gboolean utils_datetime_is_overdue (GDateTime* date);
VALA_EXTERN gchar* utils_datetime_get_calendar_icon (GDateTime* date);
VALA_EXTERN void utils_datetime_parse_todoist_recurrency (ObjectsDueDate* duedate,
                                              JsonObject* object);
VALA_EXTERN gboolean utils_datetime_has_time (GDateTime* datetime);
VALA_EXTERN gboolean utils_datetime_is_today (GDateTime* date);
VALA_EXTERN gboolean utils_datetime_is_tomorrow (GDateTime* date);
VALA_EXTERN gboolean utils_datetime_is_next_week (GDateTime* date);
VALA_EXTERN GDateTime* utils_datetime_get_date_from_string (const gchar* date);
VALA_EXTERN void utils_datetime_recurrence_to_due (ICalRecurrence* recurrence,
                                       ObjectsDueDate* due);
VALA_EXTERN GDateTime* utils_datetime_format_date (GDateTime* date);
VALA_EXTERN gboolean utils_datetime_is_this_week (GDateTime* date);
VALA_EXTERN gboolean utils_datetime_is_next_x_week (GDateTime* date,
                                        gint days);
VALA_EXTERN gboolean utils_datetime_is_this_month (GDateTime* date);
VALA_EXTERN GDateTime* utils_datetime_next_recurrency (GDateTime* datetime,
                                           ObjectsDueDate* duedate);
VALA_EXTERN gint utils_datetime_get_next_day_of_week_from_recurrency_week (GDateTime* datetime,
                                                               ObjectsDueDate* duedate);
VALA_EXTERN GDateTime* utils_datetime_next_recurrency_week (GDateTime* datetime,
                                                ObjectsDueDate* duedate,
                                                gboolean user);
VALA_EXTERN gchar* utils_datetime_get_recurrency_weeks (RecurrencyType recurrency_type,
                                            gint recurrency_interval,
                                            const gchar* recurrency_weeks,
                                            const gchar* end,
                                            gboolean recurrency_last_day_of_month);
VALA_EXTERN GDateTime* utils_datetime_get_today_format_date (void);
VALA_EXTERN GDateTime* utils_datetime_get_date_only (GDateTime* date);
VALA_EXTERN gchar* utils_datetime_get_default_date_format_from_date (GDateTime* date);
VALA_EXTERN gchar* utils_datetime_get_todoist_datetime_format (GDateTime* date);
VALA_EXTERN gchar* utils_datetime_due_to_todoist_natural_language (ObjectsDueDate* due);
VALA_EXTERN gboolean utils_datetime_has_time_from_string (const gchar* date);
VALA_EXTERN gint utils_datetime_get_days_of_month (gint index,
                                       gint year_nav);
VALA_EXTERN GDateTime* utils_datetime_get_start_of_month (GDateTime* date);
VALA_EXTERN gboolean utils_datetime_is_current_month (GDateTime* date);
VALA_EXTERN GDateTime* utils_datetime_ical_to_date_time_local (ICalTime* date);
VALA_EXTERN ICalTime* utils_datetime_ical_convert_to_local (ICalTime* time);
VALA_EXTERN ICalTime* utils_datetime_datetimes_to_icaltime (GDateTime* date,
                                                GDateTime* time_local,
                                                ICalTimezone* timezone);
VALA_EXTERN ICalTimezone* utils_datetime_get_system_timezone (void);
VALA_EXTERN gchar* utils_datetime_get_markdown_format_date (ObjectsItem* item);
VALA_EXTERN GDateTime* utils_datetime_get_datetime_no_seconds (GDateTime* date,
                                                   GDateTime* time);
VALA_EXTERN gchar* utils_datetime_get_relative_time_from_date (GDateTime* date);
VALA_EXTERN gchar* utils_datetime_get_short_date_format_from_date (GDateTime* date);
VALA_EXTERN gchar* utils_datetime_get_default_date_format (gboolean with_weekday,
                                               gboolean with_day,
                                               gboolean with_year);
VALA_EXTERN UtilsDatetime* utils_datetime_new (void);
VALA_EXTERN UtilsDatetime* utils_datetime_construct (GType object_type);
VALA_EXTERN GType markdown_processor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MarkdownProcessor, g_object_unref)
VALA_EXTERN MarkdownProcessor* markdown_processor_get_default (void);
VALA_EXTERN MarkdownProcessor* markdown_processor_new (void);
VALA_EXTERN MarkdownProcessor* markdown_processor_construct (GType object_type);
VALA_EXTERN gchar* markdown_processor_markup_string (MarkdownProcessor* self,
                                         const gchar* text);
VALA_EXTERN gpointer utils_json_utils_ref (gpointer instance);
VALA_EXTERN void utils_json_utils_unref (gpointer instance);
VALA_EXTERN GParamSpec* utils_param_spec_json_utils (const gchar* name,
                                         const gchar* nick,
                                         const gchar* blurb,
                                         GType object_type,
                                         GParamFlags flags);
VALA_EXTERN void utils_value_set_json_utils (GValue* value,
                                 gpointer v_object);
VALA_EXTERN void utils_value_take_json_utils (GValue* value,
                                  gpointer v_object);
VALA_EXTERN gpointer utils_value_get_json_utils (const GValue* value);
VALA_EXTERN GType utils_json_utils_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (UtilsJsonUtils, utils_json_utils_unref)
VALA_EXTERN JsonObject* utils_json_utils_get_object (const gchar* data);
VALA_EXTERN JsonObject* utils_json_utils_get_object_member (const gchar* data,
                                                const gchar* member);
VALA_EXTERN gchar* utils_json_utils_get_string (const gchar* data,
                                    const gchar* member);
VALA_EXTERN gint64 utils_json_utils_get_int (const gchar* data,
                                 const gchar* member);
VALA_EXTERN gboolean utils_json_utils_get_bool (const gchar* data,
                                    const gchar* member);
VALA_EXTERN gboolean utils_json_utils_has_member (const gchar* data,
                                      const gchar* member);
VALA_EXTERN gboolean utils_json_utils_is_null_member (const gchar* data,
                                          const gchar* member);
VALA_EXTERN UtilsJsonUtils* utils_json_utils_new (void);
VALA_EXTERN UtilsJsonUtils* utils_json_utils_construct (GType object_type);
VALA_EXTERN GType services_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesSettings, g_object_unref)
VALA_EXTERN ServicesSettings* services_settings_get_default (void);
VALA_EXTERN ServicesSettings* services_settings_new (void);
VALA_EXTERN ServicesSettings* services_settings_construct (GType object_type);
VALA_EXTERN void services_settings_reset_settings (ServicesSettings* self);
VALA_EXTERN gboolean services_settings_has_key (ServicesSettings* self,
                                    const gchar* key);
VALA_EXTERN NewTaskPosition services_settings_get_new_task_position (ServicesSettings* self);
VALA_EXTERN gboolean services_settings_get_boolean (ServicesSettings* self,
                                        const gchar* key);
VALA_EXTERN gdouble services_settings_get_double (ServicesSettings* self,
                                      const gchar* key);
VALA_EXTERN gchar* services_settings_get_string (ServicesSettings* self,
                                     const gchar* key);
VALA_EXTERN GType services_event_bus_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesEventBus, g_object_unref)
VALA_EXTERN ServicesEventBus* services_event_bus_get_default (void);
VALA_EXTERN void services_event_bus_unfocus_item (ServicesEventBus* self);
VALA_EXTERN ServicesEventBus* services_event_bus_new (void);
VALA_EXTERN ServicesEventBus* services_event_bus_construct (GType object_type);
VALA_EXTERN gboolean services_event_bus_get_mobile_mode (ServicesEventBus* self);
VALA_EXTERN void services_event_bus_set_mobile_mode (ServicesEventBus* self,
                                         gboolean value);
VALA_EXTERN GType services_database_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesDatabase, g_object_unref)
VALA_EXTERN ServicesDatabase* services_database_get_default (void);
VALA_EXTERN void services_database_init_database (ServicesDatabase* self);
VALA_EXTERN void services_database_clear_database (ServicesDatabase* self);
VALA_EXTERN gboolean services_database_verify_integrity (ServicesDatabase* self);
VALA_EXTERN GeeArrayList* services_database_get_sources_collection (ServicesDatabase* self);
VALA_EXTERN gboolean services_database_insert_source (ServicesDatabase* self,
                                          ObjectsSource* source);
VALA_EXTERN gboolean services_database_delete_source (ServicesDatabase* self,
                                          ObjectsSource* source);
VALA_EXTERN gboolean services_database_update_source (ServicesDatabase* self,
                                          ObjectsSource* source);
VALA_EXTERN GeeArrayList* services_database_get_projects_collection (ServicesDatabase* self);
VALA_EXTERN ObjectsProject* _services_database_fill_project (ServicesDatabase* self,
                                                 sqlite3_stmt* stmt);
VALA_EXTERN gboolean services_database_insert_project (ServicesDatabase* self,
                                           ObjectsProject* project);
VALA_EXTERN gboolean services_database_delete_project (ServicesDatabase* self,
                                           ObjectsProject* project);
VALA_EXTERN void services_database_delete_project_db (ServicesDatabase* self,
                                          ObjectsProject* project);
VALA_EXTERN gboolean services_database_update_project (ServicesDatabase* self,
                                           ObjectsProject* project);
VALA_EXTERN gboolean services_database_archive_project (ServicesDatabase* self,
                                            ObjectsProject* project);
VALA_EXTERN GeeArrayList* services_database_get_labels_collection (ServicesDatabase* self);
VALA_EXTERN ObjectsLabel* _services_database_fill_label (ServicesDatabase* self,
                                             sqlite3_stmt* stmt);
VALA_EXTERN gboolean services_database_insert_label (ServicesDatabase* self,
                                         ObjectsLabel* label);
VALA_EXTERN gboolean services_database_delete_label (ServicesDatabase* self,
                                         ObjectsLabel* label);
VALA_EXTERN gboolean services_database_update_label (ServicesDatabase* self,
                                         ObjectsLabel* label);
VALA_EXTERN gboolean services_database_insert_section (ServicesDatabase* self,
                                           ObjectsSection* section);
VALA_EXTERN GeeArrayList* services_database_get_sections_collection (ServicesDatabase* self);
VALA_EXTERN ObjectsSection* _services_database_fill_section (ServicesDatabase* self,
                                                 sqlite3_stmt* stmt);
VALA_EXTERN gboolean services_database_delete_section (ServicesDatabase* self,
                                           ObjectsSection* section);
VALA_EXTERN gboolean services_database_update_section (ServicesDatabase* self,
                                           ObjectsSection* section);
VALA_EXTERN gboolean services_database_move_section (ServicesDatabase* self,
                                         ObjectsSection* section,
                                         const gchar* old_project_id);
VALA_EXTERN gboolean services_database_move_section_items (ServicesDatabase* self,
                                               ObjectsSection* section);
VALA_EXTERN gboolean services_database_archive_section (ServicesDatabase* self,
                                            ObjectsSection* section);
VALA_EXTERN gboolean services_database_insert_item (ServicesDatabase* self,
                                        ObjectsItem* item);
VALA_EXTERN gboolean services_database_insert_items_transaction (ServicesDatabase* self,
                                                     GeeArrayList* items);
VALA_EXTERN GeeArrayList* services_database_get_items_collection (ServicesDatabase* self);
VALA_EXTERN ObjectsItem* services_database_get_item_by_id (ServicesDatabase* self,
                                               const gchar* id);
VALA_EXTERN ObjectsItem* _services_database_fill_item (ServicesDatabase* self,
                                           sqlite3_stmt* stmt);
VALA_EXTERN gboolean services_database_delete_item (ServicesDatabase* self,
                                        ObjectsItem* item);
VALA_EXTERN gboolean services_database_delete_all_items_by_project (ServicesDatabase* self,
                                                        ObjectsProject* project);
VALA_EXTERN gboolean services_database_update_item (ServicesDatabase* self,
                                        ObjectsItem* item,
                                        const gchar* update_id);
VALA_EXTERN gboolean services_database_move_item (ServicesDatabase* self,
                                      ObjectsItem* item);
VALA_EXTERN gboolean services_database_complete_item (ServicesDatabase* self,
                                          ObjectsItem* item,
                                          gboolean old_checked);
VALA_EXTERN void services_database_update_child_order (ServicesDatabase* self,
                                           ObjectsBaseObject* base_object);
VALA_EXTERN GType objects_reminder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsReminder, g_object_unref)
VALA_EXTERN gboolean services_database_insert_reminder (ServicesDatabase* self,
                                            ObjectsReminder* reminder);
VALA_EXTERN GeeArrayList* services_database_get_reminders_collection (ServicesDatabase* self);
VALA_EXTERN ObjectsReminder* _services_database_fill_reminder (ServicesDatabase* self,
                                                   sqlite3_stmt* stmt);
VALA_EXTERN GeeArrayList* services_database_get_reminders_by_item_id (ServicesDatabase* self,
                                                          const gchar* id);
VALA_EXTERN gboolean services_database_delete_reminder (ServicesDatabase* self,
                                            ObjectsReminder* reminder);
VALA_EXTERN GType objects_attachment_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsAttachment, g_object_unref)
VALA_EXTERN gboolean services_database_insert_attachment (ServicesDatabase* self,
                                              ObjectsAttachment* attachment);
VALA_EXTERN GeeArrayList* services_database_get_attachments_collection (ServicesDatabase* self);
VALA_EXTERN ObjectsAttachment* _services_database_fill_attachment (ServicesDatabase* self,
                                                       sqlite3_stmt* stmt);
VALA_EXTERN gboolean services_database_delete_attachment (ServicesDatabase* self,
                                              ObjectsAttachment* attachment);
VALA_EXTERN GType objects_queue_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsQueue, g_object_unref)
VALA_EXTERN void services_database_insert_queue (ServicesDatabase* self,
                                     ObjectsQueue* queue);
VALA_EXTERN GeeArrayList* services_database_get_all_queue (ServicesDatabase* self,
                                               const gchar* source_id);
VALA_EXTERN ObjectsQueue* _services_database_fill_queue (ServicesDatabase* self,
                                             sqlite3_stmt* stmt);
VALA_EXTERN void services_database_insert_CurTempIds (ServicesDatabase* self,
                                          const gchar* id,
                                          const gchar* temp_id,
                                          const gchar* object);
VALA_EXTERN gboolean services_database_curTempIds_exists (ServicesDatabase* self,
                                              const gchar* id);
VALA_EXTERN gchar* services_database_get_temp_id (ServicesDatabase* self,
                                      const gchar* id);
VALA_EXTERN gboolean services_database_update_project_id (ServicesDatabase* self,
                                              const gchar* current_id,
                                              const gchar* new_id);
VALA_EXTERN gboolean services_database_update_project_section_id (ServicesDatabase* self,
                                                      const gchar* current_id,
                                                      const gchar* new_id);
VALA_EXTERN gboolean services_database_update_project_item_id (ServicesDatabase* self,
                                                   const gchar* current_id,
                                                   const gchar* new_id);
VALA_EXTERN gboolean services_database_update_section_id (ServicesDatabase* self,
                                              const gchar* current_id,
                                              const gchar* new_id);
VALA_EXTERN gboolean services_database_update_section_item_id (ServicesDatabase* self,
                                                   const gchar* current_id,
                                                   const gchar* new_id);
VALA_EXTERN gboolean services_database_update_item_id (ServicesDatabase* self,
                                           const gchar* current_id,
                                           const gchar* new_id);
VALA_EXTERN gboolean services_database_update_item_child_id (ServicesDatabase* self,
                                                 const gchar* current_id,
                                                 const gchar* new_id);
VALA_EXTERN void services_database_remove_CurTempIds (ServicesDatabase* self,
                                          const gchar* id);
VALA_EXTERN void services_database_remove_queue (ServicesDatabase* self,
                                     const gchar* uuid);
VALA_EXTERN void services_database_clear_queue (ServicesDatabase* self);
VALA_EXTERN void services_database_clear_cur_temp_ids (ServicesDatabase* self);
VALA_EXTERN GType objects_object_event_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsObjectEvent, g_object_unref)
VALA_EXTERN GeeArrayList* services_database_get_events_by_item (ServicesDatabase* self,
                                                    const gchar* id,
                                                    gint start_week,
                                                    gint end_week);
VALA_EXTERN ObjectsObjectEvent* _services_database_fill_object_event (ServicesDatabase* self,
                                                          sqlite3_stmt* stmt);
VALA_EXTERN JsonObject* services_database_get_due_parameter (ServicesDatabase* self,
                                                 const gchar* data);
VALA_EXTERN gchar* services_database_get_labels_ids (ServicesDatabase* self,
                                         GeeArrayList* labels);
VALA_EXTERN gboolean services_database_column_exists (ServicesDatabase* self,
                                          const gchar* table,
                                          const gchar* column);
VALA_EXTERN void services_database_add_text_column (ServicesDatabase* self,
                                        const gchar* table,
                                        const gchar* column,
                                        const gchar* default_value);
VALA_EXTERN void services_database_add_int_column (ServicesDatabase* self,
                                       const gchar* table,
                                       const gchar* column,
                                       gint default_value);
VALA_EXTERN void services_database_add_item_label_column (ServicesDatabase* self);
VALA_EXTERN void services_database_add_project_labels_source_id (ServicesDatabase* self);
VALA_EXTERN void services_database_add_calendar_url_to_project (ServicesDatabase* self);
VALA_EXTERN ServicesDatabase* services_database_new (void);
VALA_EXTERN ServicesDatabase* services_database_construct (GType object_type);
VALA_EXTERN gboolean services_database_get_is_opened (ServicesDatabase* self);
VALA_EXTERN void services_database_set_is_opened (ServicesDatabase* self,
                                      gboolean value);
VALA_EXTERN GType services_log_service_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesLogService, g_object_unref)
VALA_EXTERN GType services_log_service_level_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gchar* services_log_service_level_to_string (ServicesLogServiceLevel self);
VALA_EXTERN ServicesLogService* services_log_service_get_default (void);
VALA_EXTERN void services_log_service_log (ServicesLogService* self,
                               ServicesLogServiceLevel level,
                               const gchar* context,
                               const gchar* message);
VALA_EXTERN void services_log_service_debug (ServicesLogService* self,
                                 const gchar* context,
                                 const gchar* message);
VALA_EXTERN void services_log_service_info (ServicesLogService* self,
                                const gchar* context,
                                const gchar* message);
VALA_EXTERN void services_log_service_warn (ServicesLogService* self,
                                const gchar* context,
                                const gchar* message);
VALA_EXTERN void services_log_service_error (ServicesLogService* self,
                                 const gchar* context,
                                 const gchar* message);
VALA_EXTERN gchar* services_log_service_get_log_path (ServicesLogService* self);
VALA_EXTERN ServicesLogService* services_log_service_new (void);
VALA_EXTERN ServicesLogService* services_log_service_construct (GType object_type);
VALA_EXTERN GType services_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesStore, g_object_unref)
VALA_EXTERN ServicesStore* services_store_instance (void);
VALA_EXTERN void services_store_setup_calendar_events (ServicesStore* self);
VALA_EXTERN gboolean services_store_is_database_empty (ServicesStore* self);
VALA_EXTERN gboolean services_store_is_sources_empty (ServicesStore* self);
VALA_EXTERN GeeArrayList* services_store_get_collection_by_type (ServicesStore* self,
                                                     ObjectsBaseObject* base_object);
VALA_EXTERN void services_store_insert_source (ServicesStore* self,
                                   ObjectsSource* source);
VALA_EXTERN void services_store_delete_source (ServicesStore* self,
                                   ObjectsSource* source,
                                   GAsyncReadyCallback _callback_,
                                   gpointer _user_data_);
VALA_EXTERN void services_store_delete_source_finish (ServicesStore* self,
                                          GAsyncResult* _res_);
VALA_EXTERN void services_store_update_source (ServicesStore* self,
                                   ObjectsSource* source);
VALA_EXTERN ObjectsSource* services_store_get_source (ServicesStore* self,
                                          const gchar* id);
VALA_EXTERN ObjectsSource* services_store_get_default_source (ServicesStore* self);
VALA_EXTERN gboolean services_store_source_todoist_exists (ServicesStore* self,
                                               const gchar* email);
VALA_EXTERN gboolean services_store_source_caldav_exists (ServicesStore* self,
                                              const gchar* server_url,
                                              const gchar* username);
VALA_EXTERN void services_store_insert_project (ServicesStore* self,
                                    ObjectsProject* project);
VALA_EXTERN GeeArrayList* services_store_get_projects_by_source (ServicesStore* self,
                                                     const gchar* source_id);
VALA_EXTERN void services_store_delete_project (ServicesStore* self,
                                    ObjectsProject* project,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN void services_store_delete_project_finish (ServicesStore* self,
                                           GAsyncResult* _res_);
VALA_EXTERN void services_store_archive_project (ServicesStore* self,
                                     ObjectsProject* project);
VALA_EXTERN void services_store_update_project (ServicesStore* self,
                                    ObjectsProject* project);
VALA_EXTERN void services_store_update_project_id (ServicesStore* self,
                                       const gchar* current_id,
                                       const gchar* new_id);
VALA_EXTERN ObjectsProject* services_store_get_inbox_project (ServicesStore* self);
VALA_EXTERN ObjectsProject* services_store_get_project (ServicesStore* self,
                                            const gchar* id);
VALA_EXTERN ObjectsProject* services_store_get_project_via_url (ServicesStore* self,
                                                    const gchar* calendar_url);
VALA_EXTERN GeeArrayList* services_store_get_subprojects (ServicesStore* self,
                                              ObjectsProject* _project);
VALA_EXTERN gint services_store_next_project_child_order (ServicesStore* self,
                                              ObjectsSource* source);
VALA_EXTERN void services_store_insert_section (ServicesStore* self,
                                    ObjectsSection* section);
VALA_EXTERN void services_store_update_section (ServicesStore* self,
                                    ObjectsSection* section);
VALA_EXTERN void services_store_delete_section (ServicesStore* self,
                                    ObjectsSection* section);
VALA_EXTERN void services_store_move_section (ServicesStore* self,
                                  ObjectsSection* section,
                                  const gchar* old_project_id);
VALA_EXTERN void services_store_update_section_id (ServicesStore* self,
                                       const gchar* current_id,
                                       const gchar* new_id);
VALA_EXTERN void services_store_archive_section (ServicesStore* self,
                                     ObjectsSection* section);
VALA_EXTERN GeeArrayList* services_store_get_sections_by_project (ServicesStore* self,
                                                      ObjectsProject* project);
VALA_EXTERN GeeArrayList* services_store_get_sections_archived_by_project (ServicesStore* self,
                                                               ObjectsProject* project);
VALA_EXTERN ObjectsSection* services_store_get_section (ServicesStore* self,
                                            const gchar* id);
VALA_EXTERN void services_store_insert_item (ServicesStore* self,
                                 ObjectsItem* item,
                                 gboolean insert,
                                 gboolean persist);
VALA_EXTERN gboolean services_store_insert_items_transaction (ServicesStore* self,
                                                  GeeArrayList* items,
                                                  gboolean insert);
VALA_EXTERN void services_store_update_item (ServicesStore* self,
                                 ObjectsItem* item,
                                 const gchar* update_id);
VALA_EXTERN void services_store_update_item_pin (ServicesStore* self,
                                     ObjectsItem* item);
VALA_EXTERN void services_store_delete_item (ServicesStore* self,
                                 ObjectsItem* item);
VALA_EXTERN void services_store_move_item (ServicesStore* self,
                               ObjectsItem* item,
                               const gchar* old_project_id,
                               const gchar* old_section_id,
                               const gchar* old_parent_id);
VALA_EXTERN void services_store_complete_item (ServicesStore* self,
                                   ObjectsItem* item,
                                   gboolean old_checked,
                                   gboolean complete_subitems);
VALA_EXTERN void services_store_archive_item (ServicesStore* self,
                                  ObjectsItem* item,
                                  gboolean is_archived);
VALA_EXTERN void services_store_update_item_id (ServicesStore* self,
                                    const gchar* current_id,
                                    const gchar* new_id);
VALA_EXTERN gint services_store_next_item_child_order (ServicesStore* self,
                                           const gchar* project_id,
                                           const gchar* section_id);
VALA_EXTERN ObjectsItem* services_store_get_item (ServicesStore* self,
                                      const gchar* id);
VALA_EXTERN ObjectsItem* services_store_get_item_by_ical_url (ServicesStore* self,
                                                  const gchar* ical_url);
VALA_EXTERN GeeArrayList* services_store_get_items_by_baseobject (ServicesStore* self,
                                                      ObjectsBaseObject* object);
VALA_EXTERN GeeArrayList* services_store_get_items_checked (ServicesStore* self);
VALA_EXTERN GeeArrayList* services_store_get_items_checked_by_project (ServicesStore* self,
                                                           ObjectsProject* project);
VALA_EXTERN GeeArrayList* services_store_get_subitems (ServicesStore* self,
                                           ObjectsItem* i);
VALA_EXTERN GeeArrayList* services_store_get_subitems_uncomplete (ServicesStore* self,
                                                      ObjectsItem* i);
VALA_EXTERN GeeArrayList* services_store_get_items_by_project (ServicesStore* self,
                                                   ObjectsProject* project);
VALA_EXTERN GeeArrayList* services_store_get_items_by_project_pinned (ServicesStore* self,
                                                          ObjectsProject* project);
VALA_EXTERN GeeArrayList* services_store_get_items_by_date (ServicesStore* self,
                                                GDateTime* date,
                                                gboolean checked);
VALA_EXTERN GeeArrayList* services_store_get_items_no_date (ServicesStore* self,
                                                gboolean checked);
VALA_EXTERN GeeArrayList* services_store_get_items_repeating (ServicesStore* self,
                                                  gboolean checked);
VALA_EXTERN GeeArrayList* services_store_get_items_by_date_range (ServicesStore* self,
                                                      GDateTime* start_date,
                                                      GDateTime* end_date,
                                                      gboolean checked);
VALA_EXTERN GeeArrayList* services_store_get_items_by_month (ServicesStore* self,
                                                 GDateTime* date,
                                                 gboolean checked);
VALA_EXTERN GeeArrayList* services_store_get_items_pinned (ServicesStore* self,
                                               gboolean checked);
VALA_EXTERN GeeArrayList* services_store_get_items_by_priority (ServicesStore* self,
                                                    gint priority,
                                                    gboolean checked);
VALA_EXTERN GeeArrayList* services_store_get_items_completed (ServicesStore* self);
VALA_EXTERN GeeArrayList* services_store_get_items_by_label (ServicesStore* self,
                                                 ObjectsLabel* label,
                                                 gboolean checked);
VALA_EXTERN GeeArrayList* services_store_get_items_unlabeled (ServicesStore* self,
                                                  gboolean checked);
VALA_EXTERN GeeArrayList* services_store_get_items_by_scheduled (ServicesStore* self,
                                                     gboolean checked);
VALA_EXTERN GeeArrayList* services_store_get_items_no_parent (ServicesStore* self,
                                                  gboolean checked);
VALA_EXTERN gboolean services_store_valid_item_by_date (ServicesStore* self,
                                            ObjectsItem* item,
                                            GDateTime* date,
                                            gboolean checked);
VALA_EXTERN gboolean services_store_valid_item_by_date_range (ServicesStore* self,
                                                  ObjectsItem* item,
                                                  GDateTime* start_date,
                                                  GDateTime* end_date,
                                                  gboolean checked);
VALA_EXTERN gboolean services_store_valid_item_by_month (ServicesStore* self,
                                             ObjectsItem* item,
                                             GDateTime* date,
                                             gboolean checked);
VALA_EXTERN GeeArrayList* services_store_get_items_by_overdue_view (ServicesStore* self,
                                                        gboolean checked);
VALA_EXTERN gboolean services_store_valid_item_by_overdue (ServicesStore* self,
                                               ObjectsItem* item,
                                               GDateTime* date,
                                               gboolean checked);
VALA_EXTERN void services_store_insert_label (ServicesStore* self,
                                  ObjectsLabel* label);
VALA_EXTERN void services_store_delete_label (ServicesStore* self,
                                  ObjectsLabel* label);
VALA_EXTERN void services_store_update_label (ServicesStore* self,
                                  ObjectsLabel* label);
VALA_EXTERN GeeArrayList* services_store_get_labels_by_item_labels (ServicesStore* self,
                                                        const gchar* labels);
VALA_EXTERN GeeArrayList* services_store_get_items_has_labels (ServicesStore* self);
VALA_EXTERN gboolean services_store_label_exists (ServicesStore* self,
                                      const gchar* id);
VALA_EXTERN ObjectsLabel* services_store_get_label (ServicesStore* self,
                                        const gchar* id);
VALA_EXTERN ObjectsLabel* services_store_get_label_by_name (ServicesStore* self,
                                                const gchar* name,
                                                gboolean lowercase,
                                                const gchar* source_id);
VALA_EXTERN GeeArrayList* services_store_get_labels_by_source (ServicesStore* self,
                                                   const gchar* source_id);
VALA_EXTERN GeeArrayList* services_store_get_all_labels_by_search (ServicesStore* self,
                                                       const gchar* search_text);
VALA_EXTERN GeeArrayList* services_store_get_all_projects_by_search (ServicesStore* self,
                                                         const gchar* search_text);
VALA_EXTERN GeeArrayList* services_store_get_all_sections_by_search (ServicesStore* self,
                                                         const gchar* search_text);
VALA_EXTERN GeeArrayList* services_store_get_all_projects_archived (ServicesStore* self);
VALA_EXTERN GeeArrayList* services_store_get_all_items_by_search (ServicesStore* self,
                                                      const gchar* search_text);
VALA_EXTERN void services_store_insert_reminder (ServicesStore* self,
                                     ObjectsReminder* reminder);
VALA_EXTERN void services_store_delete_reminder (ServicesStore* self,
                                     ObjectsReminder* reminder);
VALA_EXTERN GeeArrayList* services_store_get_reminders_by_item (ServicesStore* self,
                                                    ObjectsItem* item);
VALA_EXTERN ObjectsReminder* services_store_get_reminder (ServicesStore* self,
                                              const gchar* id);
VALA_EXTERN void services_store_insert_attachment (ServicesStore* self,
                                       ObjectsAttachment* attachment);
VALA_EXTERN void services_store_delete_attachment (ServicesStore* self,
                                       ObjectsAttachment* attachment);
VALA_EXTERN GeeArrayList* services_store_get_attachments_by_item (ServicesStore* self,
                                                      ObjectsItem* item);
VALA_EXTERN GeeArrayList* services_store_get_used_calendar_sources (ServicesStore* self);
VALA_EXTERN void services_store_clear_project_cache (ServicesStore* self,
                                         const gchar* project_id);
VALA_EXTERN ServicesStore* services_store_new (void);
VALA_EXTERN ServicesStore* services_store_construct (GType object_type);
VALA_EXTERN GeeArrayList* services_store_get_sources (ServicesStore* self);
VALA_EXTERN GeeArrayList* services_store_get_projects (ServicesStore* self);
VALA_EXTERN GeeArrayList* services_store_get_sections (ServicesStore* self);
VALA_EXTERN GeeArrayList* services_store_get_items (ServicesStore* self);
VALA_EXTERN GeeArrayList* services_store_get_labels (ServicesStore* self);
VALA_EXTERN GeeArrayList* services_store_get_reminders (ServicesStore* self);
VALA_EXTERN GeeArrayList* services_store_get_attachments (ServicesStore* self);
VALA_EXTERN GType services_todoist_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesTodoist, g_object_unref)
VALA_EXTERN ServicesTodoist* services_todoist_get_default (void);
VALA_EXTERN ServicesTodoist* services_todoist_new (void);
VALA_EXTERN ServicesTodoist* services_todoist_construct (GType object_type);
VALA_EXTERN void services_todoist_login (ServicesTodoist* self,
                             const gchar* _url,
                             ObjectsSource* migrate_source,
                             GAsyncReadyCallback _callback_,
                             gpointer _user_data_);
VALA_EXTERN gpointer http_response_ref (gpointer instance);
VALA_EXTERN void http_response_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_http_response (const gchar* name,
                                      const gchar* nick,
                                      const gchar* blurb,
                                      GType object_type,
                                      GParamFlags flags);
VALA_EXTERN void value_set_http_response (GValue* value,
                              gpointer v_object);
VALA_EXTERN void value_take_http_response (GValue* value,
                               gpointer v_object);
VALA_EXTERN gpointer value_get_http_response (const GValue* value);
VALA_EXTERN GType http_response_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (HttpResponse, http_response_unref)
VALA_EXTERN HttpResponse* services_todoist_login_finish (ServicesTodoist* self,
                                             GAsyncResult* _res_);
VALA_EXTERN void services_todoist_login_token (ServicesTodoist* self,
                                   const gchar* token,
                                   ObjectsSource* migrate_source,
                                   GAsyncReadyCallback _callback_,
                                   gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_login_token_finish (ServicesTodoist* self,
                                                   GAsyncResult* _res_);
VALA_EXTERN void services_todoist_add_todoist_account (ServicesTodoist* self,
                                           const gchar* token,
                                           HttpResponse* response,
                                           ObjectsSource* migrate_source,
                                           GAsyncReadyCallback _callback_,
                                           gpointer _user_data_);
VALA_EXTERN void services_todoist_add_todoist_account_finish (ServicesTodoist* self,
                                                  GAsyncResult* _res_);
VALA_EXTERN void services_todoist_sync (ServicesTodoist* self,
                            ObjectsSource* source,
                            GAsyncReadyCallback _callback_,
                            gpointer _user_data_);
VALA_EXTERN void services_todoist_sync_finish (ServicesTodoist* self,
                                   GAsyncResult* _res_);
VALA_EXTERN void services_todoist_queue (ServicesTodoist* self,
                             ObjectsSource* source,
                             GAsyncReadyCallback _callback_,
                             gpointer _user_data_);
VALA_EXTERN void services_todoist_queue_finish (ServicesTodoist* self,
                                    GAsyncResult* _res_);
VALA_EXTERN gchar* services_todoist_get_queue_json (ServicesTodoist* self,
                                        GeeArrayList* queue,
                                        const gchar* sync_token);
VALA_EXTERN gchar* services_todoist_get_delete_json (ServicesTodoist* self,
                                         const gchar* id,
                                         const gchar* type,
                                         const gchar* uuid);
VALA_EXTERN void services_todoist_add (ServicesTodoist* self,
                           ObjectsBaseObject* object,
                           GAsyncReadyCallback _callback_,
                           gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_add_finish (ServicesTodoist* self,
                                           GAsyncResult* _res_);
VALA_EXTERN void services_todoist_update (ServicesTodoist* self,
                              ObjectsBaseObject* object,
                              GAsyncReadyCallback _callback_,
                              gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_update_finish (ServicesTodoist* self,
                                              GAsyncResult* _res_);
VALA_EXTERN void services_todoist_delete (ServicesTodoist* self,
                              ObjectsBaseObject* object,
                              GAsyncReadyCallback _callback_,
                              gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_delete_finish (ServicesTodoist* self,
                                              GAsyncResult* _res_);
VALA_EXTERN void services_todoist_complete_item (ServicesTodoist* self,
                                     ObjectsItem* item,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_complete_item_finish (ServicesTodoist* self,
                                                     GAsyncResult* _res_);
VALA_EXTERN void services_todoist_close_item (ServicesTodoist* self,
                                  ObjectsItem* item,
                                  GAsyncReadyCallback _callback_,
                                  gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_close_item_finish (ServicesTodoist* self,
                                                  GAsyncResult* _res_);
VALA_EXTERN void services_todoist_move_item (ServicesTodoist* self,
                                 ObjectsItem* item,
                                 const gchar* type,
                                 const gchar* id,
                                 GAsyncReadyCallback _callback_,
                                 gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_move_item_finish (ServicesTodoist* self,
                                                 GAsyncResult* _res_);
VALA_EXTERN void services_todoist_update_items (ServicesTodoist* self,
                                    GeeArrayList* objects,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN void services_todoist_update_items_finish (ServicesTodoist* self,
                                           GAsyncResult* _res_);
VALA_EXTERN void services_todoist_move_project_section (ServicesTodoist* self,
                                            ObjectsBaseObject* base_object,
                                            const gchar* project_id,
                                            GAsyncReadyCallback _callback_,
                                            gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_move_project_section_finish (ServicesTodoist* self,
                                                            GAsyncResult* _res_);
VALA_EXTERN void services_todoist_duplicate_project (ServicesTodoist* self,
                                         ObjectsProject* project,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_duplicate_project_finish (ServicesTodoist* self,
                                                         GAsyncResult* _res_);
VALA_EXTERN void services_todoist_add_item_if_not_exists (ServicesTodoist* self,
                                              JsonNode* node);
VALA_EXTERN void services_todoist_add_section_if_not_exists (ServicesTodoist* self,
                                                 JsonNode* node);
VALA_EXTERN gboolean services_todoist_is_todoist_error (ServicesTodoist* self,
                                            guint status_code);
VALA_EXTERN gchar* services_todoist_get_todoist_error (ServicesTodoist* self,
                                           guint code);
VALA_EXTERN void http_response_from_error_json (HttpResponse* self,
                                    JsonNode* node);
VALA_EXTERN void http_response_from_error_xml (HttpResponse* self,
                                   GXmlDomDocument* doc,
                                   gint error_code);
VALA_EXTERN HttpResponse* http_response_new (void);
VALA_EXTERN HttpResponse* http_response_construct (GType object_type);
VALA_EXTERN gboolean http_response_get_status (HttpResponse* self);
VALA_EXTERN void http_response_set_status (HttpResponse* self,
                               gboolean value);
VALA_EXTERN const gchar* http_response_get_error (HttpResponse* self);
VALA_EXTERN void http_response_set_error (HttpResponse* self,
                              const gchar* value);
VALA_EXTERN gint http_response_get_error_code (HttpResponse* self);
VALA_EXTERN void http_response_set_error_code (HttpResponse* self,
                                   gint value);
VALA_EXTERN gint http_response_get_http_code (HttpResponse* self);
VALA_EXTERN void http_response_set_http_code (HttpResponse* self,
                                  gint value);
VALA_EXTERN const gchar* http_response_get_data (HttpResponse* self);
VALA_EXTERN void http_response_set_data (HttpResponse* self,
                             const gchar* value);
VALA_EXTERN void http_response_get_data_object (HttpResponse* self,
                                    GValue * result);
VALA_EXTERN void http_response_set_data_object (HttpResponse* self,
                                    GValue * value);
VALA_EXTERN GType services_todoist_auth_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesTodoistAuth, g_object_unref)
VALA_EXTERN ServicesTodoistAuth* services_todoist_auth_new (SoupSession* session);
VALA_EXTERN ServicesTodoistAuth* services_todoist_auth_construct (GType object_type,
                                                      SoupSession* session);
VALA_EXTERN void services_todoist_auth_login (ServicesTodoistAuth* self,
                                  const gchar* _url,
                                  ObjectsSource* migrate_source,
                                  GAsyncReadyCallback _callback_,
                                  gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_auth_login_finish (ServicesTodoistAuth* self,
                                                  GAsyncResult* _res_);
VALA_EXTERN void services_todoist_auth_login_token (ServicesTodoistAuth* self,
                                        const gchar* token,
                                        ObjectsSource* migrate_source,
                                        GAsyncReadyCallback _callback_,
                                        gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_auth_login_token_finish (ServicesTodoistAuth* self,
                                                        GAsyncResult* _res_);
VALA_EXTERN void services_todoist_auth_add_todoist_account (ServicesTodoistAuth* self,
                                                const gchar* token,
                                                HttpResponse* response,
                                                ObjectsSource* migrate_source,
                                                GAsyncReadyCallback _callback_,
                                                gpointer _user_data_);
VALA_EXTERN void services_todoist_auth_add_todoist_account_finish (ServicesTodoistAuth* self,
                                                       GAsyncResult* _res_);
VALA_EXTERN GType services_todoist_items_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesTodoistItems, g_object_unref)
VALA_EXTERN ServicesTodoistItems* services_todoist_items_new (SoupSession* session);
VALA_EXTERN ServicesTodoistItems* services_todoist_items_construct (GType object_type,
                                                        SoupSession* session);
VALA_EXTERN void services_todoist_items_add (ServicesTodoistItems* self,
                                 ObjectsBaseObject* object,
                                 GAsyncReadyCallback _callback_,
                                 gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_items_add_finish (ServicesTodoistItems* self,
                                                 GAsyncResult* _res_);
VALA_EXTERN void services_todoist_items_update (ServicesTodoistItems* self,
                                    ObjectsBaseObject* object,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_items_update_finish (ServicesTodoistItems* self,
                                                    GAsyncResult* _res_);
VALA_EXTERN void services_todoist_items_delete (ServicesTodoistItems* self,
                                    ObjectsBaseObject* object,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_items_delete_finish (ServicesTodoistItems* self,
                                                    GAsyncResult* _res_);
VALA_EXTERN void services_todoist_items_close_item (ServicesTodoistItems* self,
                                        ObjectsItem* item,
                                        GAsyncReadyCallback _callback_,
                                        gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_items_close_item_finish (ServicesTodoistItems* self,
                                                        GAsyncResult* _res_);
VALA_EXTERN void services_todoist_items_complete_item (ServicesTodoistItems* self,
                                           ObjectsItem* item,
                                           GAsyncReadyCallback _callback_,
                                           gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_items_complete_item_finish (ServicesTodoistItems* self,
                                                           GAsyncResult* _res_);
VALA_EXTERN void services_todoist_items_move_item (ServicesTodoistItems* self,
                                       ObjectsItem* item,
                                       const gchar* type,
                                       const gchar* id,
                                       GAsyncReadyCallback _callback_,
                                       gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_items_move_item_finish (ServicesTodoistItems* self,
                                                       GAsyncResult* _res_);
VALA_EXTERN void services_todoist_items_update_items (ServicesTodoistItems* self,
                                          GeeArrayList* objects,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_);
VALA_EXTERN void services_todoist_items_update_items_finish (ServicesTodoistItems* self,
                                                 GAsyncResult* _res_);
VALA_EXTERN gchar* services_todoist_items_get_update_items_json (ServicesTodoistItems* self,
                                                     GeeArrayList* objects);
VALA_EXTERN GType services_todoist_projects_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesTodoistProjects, g_object_unref)
VALA_EXTERN ServicesTodoistProjects* services_todoist_projects_new (SoupSession* session);
VALA_EXTERN ServicesTodoistProjects* services_todoist_projects_construct (GType object_type,
                                                              SoupSession* session);
VALA_EXTERN void services_todoist_projects_move_project_section (ServicesTodoistProjects* self,
                                                     ObjectsBaseObject* base_object,
                                                     const gchar* project_id,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_projects_move_project_section_finish (ServicesTodoistProjects* self,
                                                                     GAsyncResult* _res_);
VALA_EXTERN void services_todoist_projects_duplicate_project (ServicesTodoistProjects* self,
                                                  ObjectsProject* project,
                                                  GAsyncReadyCallback _callback_,
                                                  gpointer _user_data_);
VALA_EXTERN HttpResponse* services_todoist_projects_duplicate_project_finish (ServicesTodoistProjects* self,
                                                                  GAsyncResult* _res_);
VALA_EXTERN GType services_backup_exporter_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesBackupExporter, g_object_unref)
VALA_EXTERN ServicesBackupExporter* services_backup_exporter_get_default (void);
VALA_EXTERN gchar* services_backup_exporter_export_to_json (ServicesBackupExporter* self);
VALA_EXTERN ServicesBackupExporter* services_backup_exporter_new (void);
VALA_EXTERN ServicesBackupExporter* services_backup_exporter_construct (GType object_type);
VALA_EXTERN GType color_scheme_settings_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ColorSchemeSettingsSettings, g_object_unref)
VALA_EXTERN GType color_scheme_settings_settings_color_scheme_get_type (void) G_GNUC_CONST ;
VALA_EXTERN ColorSchemeSettingsSettings* color_scheme_settings_settings_get_default (void);
VALA_EXTERN ColorSchemeSettingsSettingsColorScheme color_scheme_settings_settings_get_prefers_color_scheme (ColorSchemeSettingsSettings* self);
VALA_EXTERN GType services_cal_dav_core_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesCalDAVCore, g_object_unref)
VALA_EXTERN ServicesCalDAVCore* services_cal_dav_core_get_default (void);
VALA_EXTERN ServicesCalDAVCore* services_cal_dav_core_new (void);
VALA_EXTERN ServicesCalDAVCore* services_cal_dav_core_construct (GType object_type);
VALA_EXTERN GType services_cal_dav_web_dav_client_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesCalDAVWebDAVClient, g_object_unref)
VALA_EXTERN GType services_cal_dav_cal_dav_client_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesCalDAVCalDAVClient, g_object_unref)
VALA_EXTERN ServicesCalDAVCalDAVClient* services_cal_dav_core_get_client (ServicesCalDAVCore* self,
                                                              ObjectsSource* source);
VALA_EXTERN ServicesCalDAVCalDAVClient* services_cal_dav_core_get_client_by_id (ServicesCalDAVCore* self,
                                                                    const gchar* source_id);
VALA_EXTERN void services_cal_dav_core_remove_client (ServicesCalDAVCore* self,
                                          const gchar* source_id);
VALA_EXTERN void services_cal_dav_core_clear (ServicesCalDAVCore* self);
VALA_EXTERN void services_cal_dav_core_resolve_well_known_caldav (ServicesCalDAVCore* self,
                                                      SoupSession* session,
                                                      const gchar* base_url,
                                                      gboolean ignore_ssl,
                                                      GAsyncReadyCallback _callback_,
                                                      gpointer _user_data_);
VALA_EXTERN gchar* services_cal_dav_core_resolve_well_known_caldav_finish (ServicesCalDAVCore* self,
                                                               GAsyncResult* _res_,
                                                               GError** error);
VALA_EXTERN void services_cal_dav_core_resolve_calendar_home (ServicesCalDAVCore* self,
                                                  CalDAVType caldav_type,
                                                  const gchar* dav_url,
                                                  const gchar* username,
                                                  const gchar* password,
                                                  GCancellable* cancellable,
                                                  gboolean ignore_ssl,
                                                  GAsyncReadyCallback _callback_,
                                                  gpointer _user_data_);
VALA_EXTERN gchar* services_cal_dav_core_resolve_calendar_home_finish (ServicesCalDAVCore* self,
                                                           GAsyncResult* _res_,
                                                           GError** error);
VALA_EXTERN void services_cal_dav_core_login (ServicesCalDAVCore* self,
                                  CalDAVType caldav_type,
                                  const gchar* dav_url,
                                  const gchar* username,
                                  const gchar* password,
                                  const gchar* calendar_home,
                                  GCancellable* cancellable,
                                  gboolean ignore_ssl,
                                  GAsyncReadyCallback _callback_,
                                  gpointer _user_data_);
VALA_EXTERN HttpResponse* services_cal_dav_core_login_finish (ServicesCalDAVCore* self,
                                                  GAsyncResult* _res_);
VALA_EXTERN void services_cal_dav_core_add_caldav_account (ServicesCalDAVCore* self,
                                               ObjectsSource* source,
                                               GCancellable* cancellable,
                                               GAsyncReadyCallback _callback_,
                                               gpointer _user_data_);
VALA_EXTERN HttpResponse* services_cal_dav_core_add_caldav_account_finish (ServicesCalDAVCore* self,
                                                               GAsyncResult* _res_);
VALA_EXTERN void services_cal_dav_core_sync (ServicesCalDAVCore* self,
                                 ObjectsSource* source,
                                 GAsyncReadyCallback _callback_,
                                 gpointer _user_data_);
VALA_EXTERN void services_cal_dav_core_sync_finish (ServicesCalDAVCore* self,
                                        GAsyncResult* _res_);
VALA_EXTERN ServicesCalDAVCalDAVClient* services_cal_dav_cal_dav_client_new (SoupSession* session,
                                                                 const gchar* base_url,
                                                                 const gchar* username,
                                                                 const gchar* password,
                                                                 gboolean ignore_ssl);
VALA_EXTERN ServicesCalDAVCalDAVClient* services_cal_dav_cal_dav_client_construct (GType object_type,
                                                                       SoupSession* session,
                                                                       const gchar* base_url,
                                                                       const gchar* username,
                                                                       const gchar* password,
                                                                       gboolean ignore_ssl);
VALA_EXTERN void services_cal_dav_cal_dav_client_get_principal_url (ServicesCalDAVCalDAVClient* self,
                                                        GCancellable* cancellable,
                                                        GAsyncReadyCallback _callback_,
                                                        gpointer _user_data_);
VALA_EXTERN gchar* services_cal_dav_cal_dav_client_get_principal_url_finish (ServicesCalDAVCalDAVClient* self,
                                                                 GAsyncResult* _res_,
                                                                 GError** error);
VALA_EXTERN void services_cal_dav_cal_dav_client_get_calendar_home (ServicesCalDAVCalDAVClient* self,
                                                        const gchar* principal_url,
                                                        GCancellable* cancellable,
                                                        GAsyncReadyCallback _callback_,
                                                        gpointer _user_data_);
VALA_EXTERN gchar* services_cal_dav_cal_dav_client_get_calendar_home_finish (ServicesCalDAVCalDAVClient* self,
                                                                 GAsyncResult* _res_,
                                                                 GError** error);
VALA_EXTERN void services_cal_dav_cal_dav_client_update_userdata (ServicesCalDAVCalDAVClient* self,
                                                      const gchar* principal_url,
                                                      ObjectsSource* source,
                                                      GCancellable* cancellable,
                                                      GAsyncReadyCallback _callback_,
                                                      gpointer _user_data_);
VALA_EXTERN void services_cal_dav_cal_dav_client_update_userdata_finish (ServicesCalDAVCalDAVClient* self,
                                                             GAsyncResult* _res_,
                                                             GError** error);
VALA_EXTERN void services_cal_dav_cal_dav_client_fetch_project_list (ServicesCalDAVCalDAVClient* self,
                                                         ObjectsSource* source,
                                                         GCancellable* cancellable,
                                                         GAsyncReadyCallback _callback_,
                                                         gpointer _user_data_);
VALA_EXTERN GeeArrayList* services_cal_dav_cal_dav_client_fetch_project_list_finish (ServicesCalDAVCalDAVClient* self,
                                                                         GAsyncResult* _res_,
                                                                         GError** error);
VALA_EXTERN void services_cal_dav_cal_dav_client_sync (ServicesCalDAVCalDAVClient* self,
                                           ObjectsSource* source,
                                           GCancellable* cancellable,
                                           GAsyncReadyCallback _callback_,
                                           gpointer _user_data_);
VALA_EXTERN void services_cal_dav_cal_dav_client_sync_finish (ServicesCalDAVCalDAVClient* self,
                                                  GAsyncResult* _res_,
                                                  GError** error);
VALA_EXTERN void services_cal_dav_cal_dav_client_fetch_project_details (ServicesCalDAVCalDAVClient* self,
                                                            ObjectsProject* project,
                                                            GCancellable* cancellable,
                                                            GAsyncReadyCallback _callback_,
                                                            gpointer _user_data_);
VALA_EXTERN void services_cal_dav_cal_dav_client_fetch_project_details_finish (ServicesCalDAVCalDAVClient* self,
                                                                   GAsyncResult* _res_,
                                                                   GError** error);
VALA_EXTERN void services_cal_dav_cal_dav_client_fetch_items_for_project (ServicesCalDAVCalDAVClient* self,
                                                              ObjectsProject* project,
                                                              GCancellable* cancellable,
                                                              ServicesCalDAVCalDAVClientProgressCallback progress_callback,
                                                              gpointer progress_callback_target,
                                                              GDestroyNotify progress_callback_target_destroy_notify,
                                                              GAsyncReadyCallback _callback_,
                                                              gpointer _user_data_);
VALA_EXTERN void services_cal_dav_cal_dav_client_fetch_items_for_project_finish (ServicesCalDAVCalDAVClient* self,
                                                                     GAsyncResult* _res_,
                                                                     GError** error);
VALA_EXTERN void services_cal_dav_cal_dav_client_sync_tasklist (ServicesCalDAVCalDAVClient* self,
                                                    ObjectsProject* project,
                                                    GCancellable* cancellable,
                                                    GAsyncReadyCallback _callback_,
                                                    gpointer _user_data_);
VALA_EXTERN void services_cal_dav_cal_dav_client_sync_tasklist_finish (ServicesCalDAVCalDAVClient* self,
                                                           GAsyncResult* _res_,
                                                           GError** error);
VALA_EXTERN void services_cal_dav_cal_dav_client_update_sync_token (ServicesCalDAVCalDAVClient* self,
                                                        ObjectsProject* project,
                                                        GCancellable* cancellable,
                                                        GAsyncReadyCallback _callback_,
                                                        gpointer _user_data_);
VALA_EXTERN void services_cal_dav_cal_dav_client_update_sync_token_finish (ServicesCalDAVCalDAVClient* self,
                                                               GAsyncResult* _res_,
                                                               GError** error);
VALA_EXTERN void services_cal_dav_cal_dav_client_create_project (ServicesCalDAVCalDAVClient* self,
                                                     ObjectsProject* project,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN HttpResponse* services_cal_dav_cal_dav_client_create_project_finish (ServicesCalDAVCalDAVClient* self,
                                                                     GAsyncResult* _res_);
VALA_EXTERN void services_cal_dav_cal_dav_client_update_project (ServicesCalDAVCalDAVClient* self,
                                                     ObjectsProject* project,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN HttpResponse* services_cal_dav_cal_dav_client_update_project_finish (ServicesCalDAVCalDAVClient* self,
                                                                     GAsyncResult* _res_);
VALA_EXTERN void services_cal_dav_cal_dav_client_delete_project (ServicesCalDAVCalDAVClient* self,
                                                     ObjectsProject* project,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN HttpResponse* services_cal_dav_cal_dav_client_delete_project_finish (ServicesCalDAVCalDAVClient* self,
                                                                     GAsyncResult* _res_);
VALA_EXTERN void services_cal_dav_cal_dav_client_add_item (ServicesCalDAVCalDAVClient* self,
                                               ObjectsItem* item,
                                               gboolean update,
                                               GAsyncReadyCallback _callback_,
                                               gpointer _user_data_);
VALA_EXTERN HttpResponse* services_cal_dav_cal_dav_client_add_item_finish (ServicesCalDAVCalDAVClient* self,
                                                               GAsyncResult* _res_);
VALA_EXTERN void services_cal_dav_cal_dav_client_complete_item (ServicesCalDAVCalDAVClient* self,
                                                    ObjectsItem* item,
                                                    GAsyncReadyCallback _callback_,
                                                    gpointer _user_data_);
VALA_EXTERN HttpResponse* services_cal_dav_cal_dav_client_complete_item_finish (ServicesCalDAVCalDAVClient* self,
                                                                    GAsyncResult* _res_);
VALA_EXTERN void services_cal_dav_cal_dav_client_move_item (ServicesCalDAVCalDAVClient* self,
                                                ObjectsItem* item,
                                                ObjectsProject* destination_project,
                                                GAsyncReadyCallback _callback_,
                                                gpointer _user_data_);
VALA_EXTERN HttpResponse* services_cal_dav_cal_dav_client_move_item_finish (ServicesCalDAVCalDAVClient* self,
                                                                GAsyncResult* _res_);
VALA_EXTERN void services_cal_dav_cal_dav_client_delete_item (ServicesCalDAVCalDAVClient* self,
                                                  ObjectsItem* item,
                                                  GAsyncReadyCallback _callback_,
                                                  gpointer _user_data_);
VALA_EXTERN HttpResponse* services_cal_dav_cal_dav_client_delete_item_finish (ServicesCalDAVCalDAVClient* self,
                                                                  GAsyncResult* _res_);
VALA_EXTERN void services_cal_dav_cal_dav_client_add_section (ServicesCalDAVCalDAVClient* self,
                                                  ObjectsSection* section,
                                                  gboolean update,
                                                  GAsyncReadyCallback _callback_,
                                                  gpointer _user_data_);
VALA_EXTERN HttpResponse* services_cal_dav_cal_dav_client_add_section_finish (ServicesCalDAVCalDAVClient* self,
                                                                  GAsyncResult* _res_);
VALA_EXTERN void services_cal_dav_cal_dav_client_delete_section (ServicesCalDAVCalDAVClient* self,
                                                     ObjectsSection* section,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN HttpResponse* services_cal_dav_cal_dav_client_delete_section_finish (ServicesCalDAVCalDAVClient* self,
                                                                     GAsyncResult* _res_);
VALA_EXTERN gboolean services_cal_dav_cal_dav_client_is_deleted_calendar (ServicesCalDAVCalDAVClient* self,
                                                              GXmlDomElement* resourcetype);
VALA_EXTERN ServicesCalDAVWebDAVClient* services_cal_dav_web_dav_client_new (SoupSession* session,
                                                                 const gchar* base_url,
                                                                 const gchar* username,
                                                                 const gchar* password,
                                                                 gboolean ignore_ssl);
VALA_EXTERN ServicesCalDAVWebDAVClient* services_cal_dav_web_dav_client_construct (GType object_type,
                                                                       SoupSession* session,
                                                                       const gchar* base_url,
                                                                       const gchar* username,
                                                                       const gchar* password,
                                                                       gboolean ignore_ssl);
VALA_EXTERN void services_cal_dav_web_dav_client_cleanup (ServicesCalDAVWebDAVClient* self);
VALA_EXTERN gchar* services_cal_dav_web_dav_client_get_absolute_url (ServicesCalDAVWebDAVClient* self,
                                                         const gchar* href);
VALA_EXTERN void services_cal_dav_web_dav_client_propfind (ServicesCalDAVWebDAVClient* self,
                                               const gchar* url,
                                               const gchar* xml,
                                               const gchar* depth,
                                               GCancellable* cancellable,
                                               GAsyncReadyCallback _callback_,
                                               gpointer _user_data_);
VALA_EXTERN GType services_cal_dav_web_dav_multi_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesCalDAVWebDAVMultiStatus, g_object_unref)
VALA_EXTERN ServicesCalDAVWebDAVMultiStatus* services_cal_dav_web_dav_client_propfind_finish (ServicesCalDAVWebDAVClient* self,
                                                                                  GAsyncResult* _res_,
                                                                                  GError** error);
VALA_EXTERN void services_cal_dav_web_dav_client_report (ServicesCalDAVWebDAVClient* self,
                                             const gchar* url,
                                             const gchar* xml,
                                             const gchar* depth,
                                             GCancellable* cancellable,
                                             GAsyncReadyCallback _callback_,
                                             gpointer _user_data_);
VALA_EXTERN ServicesCalDAVWebDAVMultiStatus* services_cal_dav_web_dav_client_report_finish (ServicesCalDAVWebDAVClient* self,
                                                                                GAsyncResult* _res_,
                                                                                GError** error);
VALA_EXTERN void services_cal_dav_web_dav_client_send_request (ServicesCalDAVWebDAVClient* self,
                                                   const gchar* method,
                                                   const gchar* url,
                                                   const gchar* content_type,
                                                   const gchar* body,
                                                   const gchar* depth,
                                                   GCancellable* cancellable,
                                                   SoupStatus* expected_statuses,
                                                   gint expected_statuses_length1,
                                                   GHashTable* extra_headers,
                                                   GAsyncReadyCallback _callback_,
                                                   gpointer _user_data_);
VALA_EXTERN gchar* services_cal_dav_web_dav_client_send_request_finish (ServicesCalDAVWebDAVClient* self,
                                                            GAsyncResult* _res_,
                                                            GError** error);
VALA_EXTERN const gchar* services_cal_dav_web_dav_client_get_last_response_etag (ServicesCalDAVWebDAVClient* self);
VALA_EXTERN ServicesCalDAVWebDAVMultiStatus* services_cal_dav_web_dav_multi_status_new_from_string (const gchar* xml,
                                                                                        GError** error);
VALA_EXTERN ServicesCalDAVWebDAVMultiStatus* services_cal_dav_web_dav_multi_status_construct_from_string (GType object_type,
                                                                                              const gchar* xml,
                                                                                              GError** error);
VALA_EXTERN void services_cal_dav_web_dav_multi_status_debug_print (ServicesCalDAVWebDAVMultiStatus* self);
VALA_EXTERN GType services_cal_dav_web_dav_response_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesCalDAVWebDAVResponse, g_object_unref)
VALA_EXTERN GeeArrayList* services_cal_dav_web_dav_multi_status_responses (ServicesCalDAVWebDAVMultiStatus* self);
VALA_EXTERN gchar* services_cal_dav_web_dav_multi_status_get_first_text_content_by_tag_name (ServicesCalDAVWebDAVMultiStatus* self,
                                                                                 const gchar* tag_name);
VALA_EXTERN ServicesCalDAVWebDAVMultiStatus* services_cal_dav_web_dav_multi_status_new (void);
VALA_EXTERN ServicesCalDAVWebDAVMultiStatus* services_cal_dav_web_dav_multi_status_construct (GType object_type);
VALA_EXTERN ServicesCalDAVWebDAVResponse* services_cal_dav_web_dav_response_new (GXmlDomElement* element);
VALA_EXTERN ServicesCalDAVWebDAVResponse* services_cal_dav_web_dav_response_construct (GType object_type,
                                                                           GXmlDomElement* element);
VALA_EXTERN GType services_cal_dav_web_dav_prop_stat_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesCalDAVWebDAVPropStat, g_object_unref)
VALA_EXTERN GeeArrayList* services_cal_dav_web_dav_response_propstats (ServicesCalDAVWebDAVResponse* self);
VALA_EXTERN const gchar* services_cal_dav_web_dav_response_get_href (ServicesCalDAVWebDAVResponse* self);
VALA_EXTERN SoupStatus services_cal_dav_web_dav_response_get_status (ServicesCalDAVWebDAVResponse* self);
VALA_EXTERN ServicesCalDAVWebDAVPropStat* services_cal_dav_web_dav_prop_stat_new (GXmlDomElement* element);
VALA_EXTERN ServicesCalDAVWebDAVPropStat* services_cal_dav_web_dav_prop_stat_construct (GType object_type,
                                                                            GXmlDomElement* element);
VALA_EXTERN GXmlDomElement* services_cal_dav_web_dav_prop_stat_get_first_prop_with_tagname (ServicesCalDAVWebDAVPropStat* self,
                                                                                const gchar* tagname);
VALA_EXTERN SoupStatus services_cal_dav_web_dav_prop_stat_get_status (ServicesCalDAVWebDAVPropStat* self);
VALA_EXTERN GXmlDomElement* services_cal_dav_web_dav_prop_stat_get_prop (ServicesCalDAVWebDAVPropStat* self);
VALA_EXTERN GType services_cal_dav_providers_nextcloud_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesCalDAVProvidersNextcloud, g_object_unref)
VALA_EXTERN ServicesCalDAVProvidersNextcloud* services_cal_dav_providers_nextcloud_new (void);
VALA_EXTERN ServicesCalDAVProvidersNextcloud* services_cal_dav_providers_nextcloud_construct (GType object_type);
VALA_EXTERN void services_cal_dav_providers_nextcloud_start_login_flow (ServicesCalDAVProvidersNextcloud* self,
                                                            const gchar* server_url,
                                                            GCancellable* cancellable,
                                                            gboolean ignore_ssl,
                                                            GAsyncReadyCallback _callback_,
                                                            gpointer _user_data_);
VALA_EXTERN HttpResponse* services_cal_dav_providers_nextcloud_start_login_flow_finish (ServicesCalDAVProvidersNextcloud* self,
                                                                            GAsyncResult* _res_);
VALA_EXTERN GType layouts_header_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LayoutsHeaderItem, g_object_unref)
VALA_EXTERN LayoutsHeaderItem* layouts_header_item_new (const gchar* header_title);
VALA_EXTERN LayoutsHeaderItem* layouts_header_item_construct (GType object_type,
                                                  const gchar* header_title);
VALA_EXTERN void layouts_header_item_add_child (LayoutsHeaderItem* self,
                                    GtkWidget* widget);
VALA_EXTERN void layouts_header_item_insert_child (LayoutsHeaderItem* self,
                                       GtkWidget* widget,
                                       gint position);
VALA_EXTERN void layouts_header_item_clear (LayoutsHeaderItem* self);
VALA_EXTERN GList* layouts_header_item_get_children (LayoutsHeaderItem* self);
VALA_EXTERN void layouts_header_item_add_widget_end (LayoutsHeaderItem* self,
                                         GtkWidget* widget);
VALA_EXTERN void layouts_header_item_remove_child (LayoutsHeaderItem* self,
                                       GtkWidget* widget);
VALA_EXTERN void layouts_header_item_check_visibility (LayoutsHeaderItem* self,
                                           gint size);
VALA_EXTERN void layouts_header_item_set_sort_func (LayoutsHeaderItem* self,
                                        GtkListBoxSortFunc sort_func,
                                        gpointer sort_func_target,
                                        GDestroyNotify sort_func_target_destroy_notify);
VALA_EXTERN void layouts_header_item_set_filter_func (LayoutsHeaderItem* self,
                                          GtkListBoxFilterFunc filter_func,
                                          gpointer filter_func_target,
                                          GDestroyNotify filter_func_target_destroy_notify);
VALA_EXTERN void layouts_header_item_invalidate_filter (LayoutsHeaderItem* self);
VALA_EXTERN void layouts_header_item_clean_up (LayoutsHeaderItem* self);
VALA_EXTERN const gchar* layouts_header_item_get_header_title (LayoutsHeaderItem* self);
VALA_EXTERN void layouts_header_item_set_header_title (LayoutsHeaderItem* self,
                                           const gchar* value);
VALA_EXTERN const gchar* layouts_header_item_get_subheader_title (LayoutsHeaderItem* self);
VALA_EXTERN void layouts_header_item_set_subheader_title (LayoutsHeaderItem* self,
                                              const gchar* value);
VALA_EXTERN const gchar* layouts_header_item_get_placeholder_message (LayoutsHeaderItem* self);
VALA_EXTERN void layouts_header_item_set_placeholder_message (LayoutsHeaderItem* self,
                                                  const gchar* value);
VALA_EXTERN gboolean layouts_header_item_get_reveal (LayoutsHeaderItem* self);
VALA_EXTERN void layouts_header_item_set_reveal (LayoutsHeaderItem* self,
                                     gboolean value);
VALA_EXTERN GtkListBox* layouts_header_item_get_items (LayoutsHeaderItem* self);
VALA_EXTERN void layouts_header_item_set_show_separator (LayoutsHeaderItem* self,
                                             gboolean value);
VALA_EXTERN void layouts_header_item_set_reveal_child (LayoutsHeaderItem* self,
                                           gboolean value);
VALA_EXTERN void layouts_header_item_set_separator_space (LayoutsHeaderItem* self,
                                              gboolean value);
VALA_EXTERN void layouts_header_item_set_separator_lines (LayoutsHeaderItem* self,
                                              gboolean value);
VALA_EXTERN void layouts_header_item_set_listbox_no_margin (LayoutsHeaderItem* self,
                                                gboolean value);
VALA_EXTERN void layouts_header_item_set_card (LayoutsHeaderItem* self,
                                   gboolean value);
VALA_EXTERN void layouts_header_item_set_listbox_margin_top (LayoutsHeaderItem* self,
                                                 gint value);
VALA_EXTERN GType widgets_loading_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsLoadingButton, g_object_unref)
VALA_EXTERN WidgetsLoadingButton* widgets_loading_button_new (LoadingButtonType loading_type,
                                                  const gchar* text_icon);
VALA_EXTERN WidgetsLoadingButton* widgets_loading_button_construct (GType object_type,
                                                        LoadingButtonType loading_type,
                                                        const gchar* text_icon);
VALA_EXTERN WidgetsLoadingButton* widgets_loading_button_new_with_label (const gchar* label);
VALA_EXTERN WidgetsLoadingButton* widgets_loading_button_construct_with_label (GType object_type,
                                                                   const gchar* label);
VALA_EXTERN WidgetsLoadingButton* widgets_loading_button_new_with_icon (const gchar* icon_name,
                                                            gint icon_size);
VALA_EXTERN WidgetsLoadingButton* widgets_loading_button_construct_with_icon (GType object_type,
                                                                  const gchar* icon_name,
                                                                  gint icon_size);
VALA_EXTERN void widgets_loading_button_update_icon (WidgetsLoadingButton* self,
                                         const gchar* icon_name);
VALA_EXTERN const gchar* widgets_loading_button_get_text_icon (WidgetsLoadingButton* self);
VALA_EXTERN LoadingButtonType widgets_loading_button_get_loading_type (WidgetsLoadingButton* self);
VALA_EXTERN gint widgets_loading_button_get_icon_size (WidgetsLoadingButton* self);
VALA_EXTERN gboolean widgets_loading_button_get_is_loading (WidgetsLoadingButton* self);
VALA_EXTERN void widgets_loading_button_set_is_loading (WidgetsLoadingButton* self,
                                            gboolean value);
VALA_EXTERN GType widgets_text_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsTextView, g_object_unref)
VALA_EXTERN void widgets_text_view_update_on_leave (WidgetsTextView* self);
VALA_EXTERN gchar* widgets_text_view_get_text (WidgetsTextView* self);
VALA_EXTERN void widgets_text_view_set_text (WidgetsTextView* self,
                                 const gchar* text);
VALA_EXTERN WidgetsTextView* widgets_text_view_new (void);
VALA_EXTERN WidgetsTextView* widgets_text_view_construct (GType object_type);
VALA_EXTERN const gchar* widgets_text_view_get_placeholder_text (WidgetsTextView* self);
VALA_EXTERN void widgets_text_view_set_placeholder_text (WidgetsTextView* self,
                                             const gchar* value);
VALA_EXTERN gboolean widgets_text_view_get_event_focus (WidgetsTextView* self);
VALA_EXTERN void widgets_text_view_set_event_focus (WidgetsTextView* self,
                                        gboolean value);
VALA_EXTERN GType widgets_icon_color_project_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsIconColorProject, g_object_unref)
VALA_EXTERN WidgetsIconColorProject* widgets_icon_color_project_new (gint pixel_size);
VALA_EXTERN WidgetsIconColorProject* widgets_icon_color_project_construct (GType object_type,
                                                               gint pixel_size);
VALA_EXTERN void widgets_icon_color_project_update_request (WidgetsIconColorProject* self);
VALA_EXTERN void widgets_icon_color_project_clean_up (WidgetsIconColorProject* self);
VALA_EXTERN ObjectsProject* widgets_icon_color_project_get_project (WidgetsIconColorProject* self);
VALA_EXTERN void widgets_icon_color_project_set_project (WidgetsIconColorProject* self,
                                             ObjectsProject* value);
VALA_EXTERN gint widgets_icon_color_project_get_pixel_size (WidgetsIconColorProject* self);
VALA_EXTERN GType widgets_pin_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsPinButton, g_object_unref)
VALA_EXTERN WidgetsPinButton* widgets_pin_button_new (void);
VALA_EXTERN WidgetsPinButton* widgets_pin_button_construct (GType object_type);
VALA_EXTERN void widgets_pin_button_update_from_item (WidgetsPinButton* self,
                                          ObjectsItem* item);
VALA_EXTERN void widgets_pin_button_update_request (WidgetsPinButton* self,
                                        gboolean pinned);
VALA_EXTERN void widgets_pin_button_reset (WidgetsPinButton* self);
VALA_EXTERN void widgets_pin_button_set_no_padding (WidgetsPinButton* self,
                                        gboolean value);
VALA_EXTERN GType widgets_priority_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsPriorityButton, g_object_unref)
VALA_EXTERN WidgetsPriorityButton* widgets_priority_button_new (void);
VALA_EXTERN WidgetsPriorityButton* widgets_priority_button_construct (GType object_type);
VALA_EXTERN WidgetsPriorityButton* widgets_priority_button_new_for_board (void);
VALA_EXTERN WidgetsPriorityButton* widgets_priority_button_construct_for_board (GType object_type);
VALA_EXTERN GtkPopover* widgets_priority_button_build_popover (WidgetsPriorityButton* self);
VALA_EXTERN void widgets_priority_button_update_from_item (WidgetsPriorityButton* self,
                                               ObjectsItem* item);
VALA_EXTERN void widgets_priority_button_set_priority (WidgetsPriorityButton* self,
                                           gint priority);
VALA_EXTERN void widgets_priority_button_reset (WidgetsPriorityButton* self);
VALA_EXTERN void widgets_priority_button_animation (WidgetsPriorityButton* self);
VALA_EXTERN void widgets_priority_button_clean_up (WidgetsPriorityButton* self);
VALA_EXTERN gboolean widgets_priority_button_get_is_board (WidgetsPriorityButton* self);
VALA_EXTERN GType widgets_item_labels_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsItemLabels, g_object_unref)
VALA_EXTERN void widgets_item_labels_add_labels (WidgetsItemLabels* self);
VALA_EXTERN void widgets_item_labels_add_item_label (WidgetsItemLabels* self,
                                         ObjectsLabel* label);
VALA_EXTERN void widgets_item_labels_remove_item_label (WidgetsItemLabels* self,
                                            ObjectsLabel* label);
VALA_EXTERN void widgets_item_labels_update_labels (WidgetsItemLabels* self);
VALA_EXTERN void widgets_item_labels_reset (WidgetsItemLabels* self);
VALA_EXTERN void widgets_item_labels_clean_up (WidgetsItemLabels* self);
VALA_EXTERN WidgetsItemLabels* widgets_item_labels_new (void);
VALA_EXTERN WidgetsItemLabels* widgets_item_labels_construct (GType object_type);
VALA_EXTERN ObjectsItem* widgets_item_labels_get_item (WidgetsItemLabels* self);
VALA_EXTERN void widgets_item_labels_set_item (WidgetsItemLabels* self,
                                   ObjectsItem* value);
VALA_EXTERN void widgets_item_labels_set_top_margin (WidgetsItemLabels* self,
                                         gint value);
VALA_EXTERN GType widgets_item_label_child_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsItemLabelChild, g_object_unref)
VALA_EXTERN WidgetsItemLabelChild* widgets_item_label_child_new (ObjectsLabel* label);
VALA_EXTERN WidgetsItemLabelChild* widgets_item_label_child_construct (GType object_type,
                                                           ObjectsLabel* label);
VALA_EXTERN void widgets_item_label_child_update_request (WidgetsItemLabelChild* self);
VALA_EXTERN void widgets_item_label_child_hide_destroy (WidgetsItemLabelChild* self);
VALA_EXTERN void widgets_item_label_child_clean_up (WidgetsItemLabelChild* self);
VALA_EXTERN ObjectsLabel* widgets_item_label_child_get_label (WidgetsItemLabelChild* self);
VALA_EXTERN gboolean widgets_item_label_child_get_clickable (WidgetsItemLabelChild* self);
VALA_EXTERN void widgets_item_label_child_set_clickable (WidgetsItemLabelChild* self,
                                             gboolean value);
VALA_EXTERN GType widgets_circular_progress_bar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsCircularProgressBar, g_object_unref)
VALA_EXTERN WidgetsCircularProgressBar* widgets_circular_progress_bar_new (gint size);
VALA_EXTERN WidgetsCircularProgressBar* widgets_circular_progress_bar_construct (GType object_type,
                                                                     gint size);
VALA_EXTERN void widgets_circular_progress_bar_draw (WidgetsCircularProgressBar* self,
                                         GtkDrawingArea* da,
                                         cairo_t* cr,
                                         gint width,
                                         gint height);
VALA_EXTERN gint widgets_circular_progress_bar_get_size (WidgetsCircularProgressBar* self);
VALA_EXTERN gboolean widgets_circular_progress_bar_get_center_filled (WidgetsCircularProgressBar* self);
VALA_EXTERN void widgets_circular_progress_bar_set_center_filled (WidgetsCircularProgressBar* self,
                                                      gboolean value);
VALA_EXTERN gboolean widgets_circular_progress_bar_get_radius_filled (WidgetsCircularProgressBar* self);
VALA_EXTERN void widgets_circular_progress_bar_set_radius_filled (WidgetsCircularProgressBar* self,
                                                      gboolean value);
VALA_EXTERN gboolean widgets_circular_progress_bar_get_thick_style (WidgetsCircularProgressBar* self);
VALA_EXTERN void widgets_circular_progress_bar_set_thick_style (WidgetsCircularProgressBar* self,
                                                    gboolean value);
VALA_EXTERN cairo_line_cap_t widgets_circular_progress_bar_get_line_cap (WidgetsCircularProgressBar* self);
VALA_EXTERN void widgets_circular_progress_bar_set_line_cap (WidgetsCircularProgressBar* self,
                                                 cairo_line_cap_t value);
VALA_EXTERN const gchar* widgets_circular_progress_bar_get_center_fill_color (WidgetsCircularProgressBar* self);
VALA_EXTERN void widgets_circular_progress_bar_set_center_fill_color (WidgetsCircularProgressBar* self,
                                                          const gchar* value);
VALA_EXTERN const gchar* widgets_circular_progress_bar_get_radius_fill_color (WidgetsCircularProgressBar* self);
VALA_EXTERN void widgets_circular_progress_bar_set_radius_fill_color (WidgetsCircularProgressBar* self,
                                                          const gchar* value);
VALA_EXTERN const gchar* widgets_circular_progress_bar_get_progress_fill_color (WidgetsCircularProgressBar* self);
VALA_EXTERN void widgets_circular_progress_bar_set_progress_fill_color (WidgetsCircularProgressBar* self,
                                                            const gchar* value);
VALA_EXTERN gint widgets_circular_progress_bar_get_line_width (WidgetsCircularProgressBar* self);
VALA_EXTERN void widgets_circular_progress_bar_set_line_width (WidgetsCircularProgressBar* self,
                                                   gint value);
VALA_EXTERN gint widgets_circular_progress_bar_get_gap (WidgetsCircularProgressBar* self);
VALA_EXTERN void widgets_circular_progress_bar_set_gap (WidgetsCircularProgressBar* self,
                                            gint value);
VALA_EXTERN gint widgets_circular_progress_bar_get_border_width (WidgetsCircularProgressBar* self);
VALA_EXTERN void widgets_circular_progress_bar_set_border_width (WidgetsCircularProgressBar* self,
                                                     gint value);
VALA_EXTERN gdouble widgets_circular_progress_bar_get_percentage (WidgetsCircularProgressBar* self);
VALA_EXTERN void widgets_circular_progress_bar_set_percentage (WidgetsCircularProgressBar* self,
                                                   gdouble value);
VALA_EXTERN void widgets_circular_progress_bar_set_color (WidgetsCircularProgressBar* self,
                                              const gchar* value);
VALA_EXTERN GType widgets_status_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsStatusButton, g_object_unref)
VALA_EXTERN WidgetsStatusButton* widgets_status_button_new (void);
VALA_EXTERN WidgetsStatusButton* widgets_status_button_construct (GType object_type);
VALA_EXTERN GtkPopover* widgets_status_button_build_popover (WidgetsStatusButton* self);
VALA_EXTERN void widgets_status_button_update_from_item (WidgetsStatusButton* self,
                                             ObjectsItem* item);
VALA_EXTERN void widgets_status_button_set_status (WidgetsStatusButton* self,
                                       gboolean active);
VALA_EXTERN gboolean widgets_status_button_get_is_board (WidgetsStatusButton* self);
VALA_EXTERN GType widgets_markdown_editor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsMarkdownEditor, g_object_unref)
VALA_EXTERN void widgets_markdown_editor_toggle_bold_format (WidgetsMarkdownEditor* self);
VALA_EXTERN void widgets_markdown_editor_toggle_italic_format (WidgetsMarkdownEditor* self);
VALA_EXTERN void widgets_markdown_editor_toggle_strikethrough_format (WidgetsMarkdownEditor* self);
VALA_EXTERN void widgets_markdown_editor_apply_h1_format (WidgetsMarkdownEditor* self);
VALA_EXTERN void widgets_markdown_editor_apply_h2_format (WidgetsMarkdownEditor* self);
VALA_EXTERN void widgets_markdown_editor_toggle_code_format (WidgetsMarkdownEditor* self);
VALA_EXTERN void widgets_markdown_editor_apply_unordered_list_format (WidgetsMarkdownEditor* self);
VALA_EXTERN void widgets_markdown_editor_apply_ordered_list_format (WidgetsMarkdownEditor* self);
VALA_EXTERN void widgets_markdown_editor_set_text (WidgetsMarkdownEditor* self,
                                       const gchar* text);
VALA_EXTERN gchar* widgets_markdown_editor_get_text (WidgetsMarkdownEditor* self);
VALA_EXTERN gchar* widgets_markdown_editor_get_plain_text (WidgetsMarkdownEditor* self);
VALA_EXTERN void widgets_markdown_editor_clear (WidgetsMarkdownEditor* self);
VALA_EXTERN void widgets_markdown_editor_focus (WidgetsMarkdownEditor* self);
VALA_EXTERN void widgets_markdown_editor_cleanup (WidgetsMarkdownEditor* self);
VALA_EXTERN void widgets_markdown_editor_view_focus (WidgetsMarkdownEditor* self);
VALA_EXTERN WidgetsMarkdownEditor* widgets_markdown_editor_new (void);
VALA_EXTERN WidgetsMarkdownEditor* widgets_markdown_editor_construct (GType object_type);
VALA_EXTERN const gchar* widgets_markdown_editor_get_placeholder_text (WidgetsMarkdownEditor* self);
VALA_EXTERN void widgets_markdown_editor_set_placeholder_text (WidgetsMarkdownEditor* self,
                                                   const gchar* value);
VALA_EXTERN ObjectsProject* widgets_markdown_editor_get_project (WidgetsMarkdownEditor* self);
VALA_EXTERN void widgets_markdown_editor_set_project (WidgetsMarkdownEditor* self,
                                          ObjectsProject* value);
VALA_EXTERN gboolean widgets_markdown_editor_get_text_mode (WidgetsMarkdownEditor* self);
VALA_EXTERN gboolean widgets_markdown_editor_get_is_editable (WidgetsMarkdownEditor* self);
VALA_EXTERN void widgets_markdown_editor_set_is_editable (WidgetsMarkdownEditor* self,
                                              gboolean value);
VALA_EXTERN GType deadline_button_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType widgets_deadline_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsDeadlineButton, g_object_unref)
VALA_EXTERN WidgetsDeadlineButton* widgets_deadline_button_new (void);
VALA_EXTERN WidgetsDeadlineButton* widgets_deadline_button_construct (GType object_type);
VALA_EXTERN WidgetsDeadlineButton* widgets_deadline_button_new_with_detail (void);
VALA_EXTERN WidgetsDeadlineButton* widgets_deadline_button_construct_with_detail (GType object_type);
VALA_EXTERN WidgetsDeadlineButton* widgets_deadline_button_new_card (void);
VALA_EXTERN WidgetsDeadlineButton* widgets_deadline_button_construct_card (GType object_type);
VALA_EXTERN GtkPopover* widgets_deadline_button_build_popover (WidgetsDeadlineButton* self);
VALA_EXTERN void widgets_deadline_button_remove_error_style (WidgetsDeadlineButton* self);
VALA_EXTERN DeadlineButtonType widgets_deadline_button_get_button_type (WidgetsDeadlineButton* self);
VALA_EXTERN void widgets_deadline_button_set_datetime (WidgetsDeadlineButton* self,
                                           GDateTime* value);
VALA_EXTERN void widgets_deadline_button_set_reveal_content (WidgetsDeadlineButton* self,
                                                 gboolean value);
VALA_EXTERN GType widgets_calendar_calendar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsCalendarCalendar, g_object_unref)
VALA_EXTERN WidgetsCalendarCalendar* widgets_calendar_calendar_new (gboolean block_past_days);
VALA_EXTERN WidgetsCalendarCalendar* widgets_calendar_calendar_construct (GType object_type,
                                                              gboolean block_past_days);
VALA_EXTERN void widgets_calendar_calendar_next_month (WidgetsCalendarCalendar* self);
VALA_EXTERN void widgets_calendar_calendar_previous_month (WidgetsCalendarCalendar* self);
VALA_EXTERN void widgets_calendar_calendar_reset (WidgetsCalendarCalendar* self);
VALA_EXTERN void widgets_calendar_calendar_clean_up (WidgetsCalendarCalendar* self);
VALA_EXTERN gboolean widgets_calendar_calendar_get_block_past_days (WidgetsCalendarCalendar* self);
VALA_EXTERN GDateTime* widgets_calendar_calendar_get_current_date (WidgetsCalendarCalendar* self);
VALA_EXTERN GDateTime* widgets_calendar_calendar_get_date (WidgetsCalendarCalendar* self);
VALA_EXTERN void widgets_calendar_calendar_set_date (WidgetsCalendarCalendar* self,
                                         GDateTime* value);
VALA_EXTERN GType widgets_calendar_calendar_day_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsCalendarCalendarDay, g_object_unref)
VALA_EXTERN WidgetsCalendarCalendarDay* widgets_calendar_calendar_day_new (void);
VALA_EXTERN WidgetsCalendarCalendarDay* widgets_calendar_calendar_day_construct (GType object_type);
VALA_EXTERN void widgets_calendar_calendar_day_add_day_css_class (WidgetsCalendarCalendarDay* self,
                                                      const gchar* css_class);
VALA_EXTERN void widgets_calendar_calendar_day_clean_up (WidgetsCalendarCalendarDay* self);
VALA_EXTERN gint widgets_calendar_calendar_day_get_day (WidgetsCalendarCalendarDay* self);
VALA_EXTERN void widgets_calendar_calendar_day_set_day (WidgetsCalendarCalendarDay* self,
                                            gint value);
VALA_EXTERN GDateTime* widgets_calendar_calendar_day_get_date (WidgetsCalendarCalendarDay* self);
VALA_EXTERN void widgets_calendar_calendar_day_set_date (WidgetsCalendarCalendarDay* self,
                                             GDateTime* value);
VALA_EXTERN void widgets_calendar_calendar_day_set_show_month (WidgetsCalendarCalendarDay* self,
                                                   gboolean value);
VALA_EXTERN GType widgets_calendar_calendar_header_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsCalendarCalendarHeader, g_object_unref)
VALA_EXTERN WidgetsCalendarCalendarHeader* widgets_calendar_calendar_header_new (void);
VALA_EXTERN WidgetsCalendarCalendarHeader* widgets_calendar_calendar_header_construct (GType object_type);
VALA_EXTERN void widgets_calendar_calendar_header_set_date (WidgetsCalendarCalendarHeader* self,
                                                GDateTime* value);
VALA_EXTERN GType widgets_calendar_calendar_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsCalendarCalendarView, g_object_unref)
VALA_EXTERN WidgetsCalendarCalendarView* widgets_calendar_calendar_view_new (void);
VALA_EXTERN WidgetsCalendarCalendarView* widgets_calendar_calendar_view_construct (GType object_type);
VALA_EXTERN void widgets_calendar_calendar_view_fill_grid_days (WidgetsCalendarCalendarView* self,
                                                    gint start_day,
                                                    gint max_day,
                                                    GDateTime* day,
                                                    gboolean show_day,
                                                    gboolean block_past_days);
VALA_EXTERN void widgets_calendar_calendar_view_clear_style (WidgetsCalendarCalendarView* self);
VALA_EXTERN void widgets_calendar_calendar_view_clean_up (WidgetsCalendarCalendarView* self);
VALA_EXTERN GDateTime* widgets_calendar_calendar_view_get_current_date (WidgetsCalendarCalendarView* self);
VALA_EXTERN GType widgets_calendar_calendar_week_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsCalendarCalendarWeek, g_object_unref)
VALA_EXTERN void widgets_calendar_calendar_week_update (WidgetsCalendarCalendarWeek* self);
VALA_EXTERN WidgetsCalendarCalendarWeek* widgets_calendar_calendar_week_new (void);
VALA_EXTERN WidgetsCalendarCalendarWeek* widgets_calendar_calendar_week_construct (GType object_type);
VALA_EXTERN void widgets_calendar_calendar_week_set_margin_horizontal (WidgetsCalendarCalendarWeek* self,
                                                           gint value);
VALA_EXTERN GType widgets_calendar_calendar_month_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsCalendarCalendarMonth, g_object_unref)
VALA_EXTERN WidgetsCalendarCalendarMonth* widgets_calendar_calendar_month_new (void);
VALA_EXTERN WidgetsCalendarCalendarMonth* widgets_calendar_calendar_month_construct (GType object_type);
VALA_EXTERN void widgets_calendar_calendar_month_reset (WidgetsCalendarCalendarMonth* self);
VALA_EXTERN void widgets_calendar_calendar_month_clean_up (WidgetsCalendarCalendarMonth* self);
VALA_EXTERN GDateTime* widgets_calendar_calendar_month_get_current_date (WidgetsCalendarCalendarMonth* self);
VALA_EXTERN GDateTime* widgets_calendar_calendar_month_get_date (WidgetsCalendarCalendarMonth* self);
VALA_EXTERN void widgets_calendar_calendar_month_set_date (WidgetsCalendarCalendarMonth* self,
                                               GDateTime* value);
VALA_EXTERN GType widgets_calendar_calendar_scroll_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsCalendarCalendarScroll, g_object_unref)
VALA_EXTERN void widgets_calendar_calendar_scroll_reset (WidgetsCalendarCalendarScroll* self);
VALA_EXTERN void widgets_calendar_calendar_scroll_scroll_to_selected_date (WidgetsCalendarCalendarScroll* self);
VALA_EXTERN WidgetsCalendarCalendarScroll* widgets_calendar_calendar_scroll_new (void);
VALA_EXTERN WidgetsCalendarCalendarScroll* widgets_calendar_calendar_scroll_construct (GType object_type);
VALA_EXTERN GDateTime* widgets_calendar_calendar_scroll_get_date (WidgetsCalendarCalendarScroll* self);
VALA_EXTERN void widgets_calendar_calendar_scroll_set_date (WidgetsCalendarCalendarScroll* self,
                                                GDateTime* value);
VALA_EXTERN GType widgets_context_menu_menu_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsContextMenuMenuItem, g_object_unref)
VALA_EXTERN WidgetsContextMenuMenuItem* widgets_context_menu_menu_item_new (const gchar* title,
                                                                const gchar* icon);
VALA_EXTERN WidgetsContextMenuMenuItem* widgets_context_menu_menu_item_construct (GType object_type,
                                                                      const gchar* title,
                                                                      const gchar* icon);
VALA_EXTERN void widgets_context_menu_menu_item_set_title (WidgetsContextMenuMenuItem* self,
                                               const gchar* value);
VALA_EXTERN gboolean widgets_context_menu_menu_item_get_autohide_popover (WidgetsContextMenuMenuItem* self);
VALA_EXTERN void widgets_context_menu_menu_item_set_autohide_popover (WidgetsContextMenuMenuItem* self,
                                                          gboolean value);
VALA_EXTERN const gchar* widgets_context_menu_menu_item_get_icon (WidgetsContextMenuMenuItem* self);
VALA_EXTERN void widgets_context_menu_menu_item_set_icon (WidgetsContextMenuMenuItem* self,
                                              const gchar* value);
VALA_EXTERN void widgets_context_menu_menu_item_set_secondary_text (WidgetsContextMenuMenuItem* self,
                                                        const gchar* value);
VALA_EXTERN void widgets_context_menu_menu_item_set_subtitle (WidgetsContextMenuMenuItem* self,
                                                  const gchar* value);
VALA_EXTERN void widgets_context_menu_menu_item_set_badge (WidgetsContextMenuMenuItem* self,
                                               const gchar* value);
VALA_EXTERN gboolean widgets_context_menu_menu_item_get_is_loading (WidgetsContextMenuMenuItem* self);
VALA_EXTERN void widgets_context_menu_menu_item_set_is_loading (WidgetsContextMenuMenuItem* self,
                                                    gboolean value);
VALA_EXTERN gboolean widgets_context_menu_menu_item_get_selected (WidgetsContextMenuMenuItem* self);
VALA_EXTERN void widgets_context_menu_menu_item_set_selected (WidgetsContextMenuMenuItem* self,
                                                  gboolean value);
VALA_EXTERN gboolean widgets_context_menu_menu_item_get_arrow (WidgetsContextMenuMenuItem* self);
VALA_EXTERN void widgets_context_menu_menu_item_set_arrow (WidgetsContextMenuMenuItem* self,
                                               gboolean value);
VALA_EXTERN void widgets_context_menu_menu_item_set_max_width_chars (WidgetsContextMenuMenuItem* self,
                                                         gint value);
VALA_EXTERN GType widgets_context_menu_menu_separator_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsContextMenuMenuSeparator, g_object_unref)
VALA_EXTERN WidgetsContextMenuMenuSeparator* widgets_context_menu_menu_separator_new (void);
VALA_EXTERN WidgetsContextMenuMenuSeparator* widgets_context_menu_menu_separator_construct (GType object_type);
VALA_EXTERN GType widgets_context_menu_menu_picker_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsContextMenuMenuPicker, g_object_unref)
VALA_EXTERN WidgetsContextMenuMenuPicker* widgets_context_menu_menu_picker_new (const gchar* title,
                                                                    const gchar* icon);
VALA_EXTERN WidgetsContextMenuMenuPicker* widgets_context_menu_menu_picker_construct (GType object_type,
                                                                          const gchar* title,
                                                                          const gchar* icon);
VALA_EXTERN void widgets_context_menu_menu_picker_update_selected (WidgetsContextMenuMenuPicker* self,
                                                       const gchar* value);
VALA_EXTERN void widgets_context_menu_menu_picker_add_item (WidgetsContextMenuMenuPicker* self,
                                                const gchar* title,
                                                const gchar* value);
VALA_EXTERN const gchar* widgets_context_menu_menu_picker_get_title (WidgetsContextMenuMenuPicker* self);
VALA_EXTERN const gchar* widgets_context_menu_menu_picker_get_icon (WidgetsContextMenuMenuPicker* self);
VALA_EXTERN const gchar* widgets_context_menu_menu_picker_get_selected (WidgetsContextMenuMenuPicker* self);
VALA_EXTERN void widgets_context_menu_menu_picker_set_selected (WidgetsContextMenuMenuPicker* self,
                                                    const gchar* value);
VALA_EXTERN GType widgets_context_menu_menu_picker_menu_item_picker_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsContextMenuMenuPickerMenuItemPicker, g_object_unref)
VALA_EXTERN WidgetsContextMenuMenuPickerMenuItemPicker* widgets_context_menu_menu_picker_menu_item_picker_new (const gchar* title,
                                                                                                   const gchar* value);
VALA_EXTERN WidgetsContextMenuMenuPickerMenuItemPicker* widgets_context_menu_menu_picker_menu_item_picker_construct (GType object_type,
                                                                                                         const gchar* title,
                                                                                                         const gchar* value);
VALA_EXTERN const gchar* widgets_context_menu_menu_picker_menu_item_picker_get_title (WidgetsContextMenuMenuPickerMenuItemPicker* self);
VALA_EXTERN const gchar* widgets_context_menu_menu_picker_menu_item_picker_get_value (WidgetsContextMenuMenuPickerMenuItemPicker* self);
VALA_EXTERN gboolean widgets_context_menu_menu_picker_menu_item_picker_get_active (WidgetsContextMenuMenuPickerMenuItemPicker* self);
VALA_EXTERN void widgets_context_menu_menu_picker_menu_item_picker_set_active (WidgetsContextMenuMenuPickerMenuItemPicker* self,
                                                                   gboolean value);
VALA_EXTERN void widgets_context_menu_menu_picker_menu_item_picker_set_group (WidgetsContextMenuMenuPickerMenuItemPicker* self,
                                                                  GtkCheckButton* value);
VALA_EXTERN GType widgets_context_menu_menu_check_picker_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsContextMenuMenuCheckPicker, g_object_unref)
VALA_EXTERN GType widgets_context_menu_menu_item_check_picker_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsContextMenuMenuItemCheckPicker, g_object_unref)
VALA_EXTERN WidgetsContextMenuMenuCheckPicker* widgets_context_menu_menu_check_picker_new (const gchar* title,
                                                                               const gchar* icon);
VALA_EXTERN WidgetsContextMenuMenuCheckPicker* widgets_context_menu_menu_check_picker_construct (GType object_type,
                                                                                     const gchar* title,
                                                                                     const gchar* icon);
VALA_EXTERN GType objects_filters_filter_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsFiltersFilterItem, g_object_unref)
VALA_EXTERN void widgets_context_menu_menu_check_picker_set_items (WidgetsContextMenuMenuCheckPicker* self,
                                                       GeeArrayList* filters);
VALA_EXTERN void widgets_context_menu_menu_check_picker_unchecked (WidgetsContextMenuMenuCheckPicker* self,
                                                       ObjectsFiltersFilterItem* filter);
VALA_EXTERN const gchar* widgets_context_menu_menu_check_picker_get_title (WidgetsContextMenuMenuCheckPicker* self);
VALA_EXTERN const gchar* widgets_context_menu_menu_check_picker_get_icon (WidgetsContextMenuMenuCheckPicker* self);
VALA_EXTERN WidgetsContextMenuMenuItemCheckPicker* widgets_context_menu_menu_item_check_picker_new (ObjectsFiltersFilterItem* filter);
VALA_EXTERN WidgetsContextMenuMenuItemCheckPicker* widgets_context_menu_menu_item_check_picker_construct (GType object_type,
                                                                                              ObjectsFiltersFilterItem* filter);
VALA_EXTERN ObjectsFiltersFilterItem* widgets_context_menu_menu_item_check_picker_get_filter (WidgetsContextMenuMenuItemCheckPicker* self);
VALA_EXTERN gboolean widgets_context_menu_menu_item_check_picker_get_active (WidgetsContextMenuMenuItemCheckPicker* self);
VALA_EXTERN void widgets_context_menu_menu_item_check_picker_set_active (WidgetsContextMenuMenuItemCheckPicker* self,
                                                             gboolean value);
VALA_EXTERN GType widgets_context_menu_menu_switch_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsContextMenuMenuSwitch, g_object_unref)
VALA_EXTERN WidgetsContextMenuMenuSwitch* widgets_context_menu_menu_switch_new (const gchar* title,
                                                                    const gchar* icon);
VALA_EXTERN WidgetsContextMenuMenuSwitch* widgets_context_menu_menu_switch_construct (GType object_type,
                                                                          const gchar* title,
                                                                          const gchar* icon);
VALA_EXTERN void widgets_context_menu_menu_switch_set_title (WidgetsContextMenuMenuSwitch* self,
                                                 const gchar* value);
VALA_EXTERN void widgets_context_menu_menu_switch_set_icon (WidgetsContextMenuMenuSwitch* self,
                                                const gchar* value);
VALA_EXTERN gboolean widgets_context_menu_menu_switch_get_active (WidgetsContextMenuMenuSwitch* self);
VALA_EXTERN void widgets_context_menu_menu_switch_set_active (WidgetsContextMenuMenuSwitch* self,
                                                  gboolean value);
VALA_EXTERN GType widgets_schedule_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsScheduleButton, g_object_unref)
VALA_EXTERN WidgetsScheduleButton* widgets_schedule_button_new (const gchar* label);
VALA_EXTERN WidgetsScheduleButton* widgets_schedule_button_construct (GType object_type,
                                                          const gchar* label);
VALA_EXTERN WidgetsScheduleButton* widgets_schedule_button_new_for_board (const gchar* label);
VALA_EXTERN WidgetsScheduleButton* widgets_schedule_button_construct_for_board (GType object_type,
                                                                    const gchar* label);
VALA_EXTERN void widgets_schedule_button_update_from_item (WidgetsScheduleButton* self,
                                               ObjectsItem* item);
VALA_EXTERN void widgets_schedule_button_reset (WidgetsScheduleButton* self);
VALA_EXTERN void widgets_schedule_button_clean_up (WidgetsScheduleButton* self);
VALA_EXTERN void widgets_schedule_button_open_picker (WidgetsScheduleButton* self);
VALA_EXTERN gboolean widgets_schedule_button_get_is_board (WidgetsScheduleButton* self);
VALA_EXTERN const gchar* widgets_schedule_button_get_label (WidgetsScheduleButton* self);
VALA_EXTERN ObjectsDueDate* widgets_schedule_button_get_duedate (WidgetsScheduleButton* self);
VALA_EXTERN void widgets_schedule_button_set_duedate (WidgetsScheduleButton* self,
                                          ObjectsDueDate* value);
VALA_EXTERN void widgets_schedule_button_set_visible_no_date (WidgetsScheduleButton* self,
                                                  gboolean value);
VALA_EXTERN void widgets_schedule_button_set_visible_clear_button (WidgetsScheduleButton* self,
                                                       gboolean value);
VALA_EXTERN GType widgets_date_time_picker_date_time_picker_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsDateTimePickerDateTimePicker, g_object_unref)
VALA_EXTERN WidgetsDateTimePickerDateTimePicker* widgets_date_time_picker_date_time_picker_new (void);
VALA_EXTERN WidgetsDateTimePickerDateTimePicker* widgets_date_time_picker_date_time_picker_construct (GType object_type);
VALA_EXTERN void widgets_date_time_picker_date_time_picker_set_recurrency (WidgetsDateTimePickerDateTimePicker* self,
                                                               ObjectsDueDate* value);
VALA_EXTERN void widgets_date_time_picker_date_time_picker_reset (WidgetsDateTimePickerDateTimePicker* self);
VALA_EXTERN void widgets_date_time_picker_date_time_picker_clean_up (WidgetsDateTimePickerDateTimePicker* self);
VALA_EXTERN gboolean widgets_date_time_picker_date_time_picker_get_has_time (WidgetsDateTimePickerDateTimePicker* self);
VALA_EXTERN void widgets_date_time_picker_date_time_picker_set_has_time (WidgetsDateTimePickerDateTimePicker* self,
                                                             gboolean value);
VALA_EXTERN gboolean widgets_date_time_picker_date_time_picker_get_has_recurrency (WidgetsDateTimePickerDateTimePicker* self);
VALA_EXTERN void widgets_date_time_picker_date_time_picker_set_has_recurrency (WidgetsDateTimePickerDateTimePicker* self,
                                                                   gboolean value);
VALA_EXTERN ObjectsDueDate* widgets_date_time_picker_date_time_picker_get_duedate (WidgetsDateTimePickerDateTimePicker* self);
VALA_EXTERN void widgets_date_time_picker_date_time_picker_set_duedate (WidgetsDateTimePickerDateTimePicker* self,
                                                            ObjectsDueDate* value);
VALA_EXTERN void widgets_date_time_picker_date_time_picker_set_visible_no_date (WidgetsDateTimePickerDateTimePicker* self,
                                                                    gboolean value);
VALA_EXTERN GType widgets_date_time_picker_date_time_picker_suggested_date_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsDateTimePickerDateTimePickerSuggestedDate, g_object_unref)
VALA_EXTERN WidgetsDateTimePickerDateTimePickerSuggestedDate* widgets_date_time_picker_date_time_picker_suggested_date_new (ObjectsDueDate* due_date);
VALA_EXTERN WidgetsDateTimePickerDateTimePickerSuggestedDate* widgets_date_time_picker_date_time_picker_suggested_date_construct (GType object_type,
                                                                                                                      ObjectsDueDate* due_date);
VALA_EXTERN ObjectsDueDate* widgets_date_time_picker_date_time_picker_suggested_date_get_due_date (WidgetsDateTimePickerDateTimePickerSuggestedDate* self);
VALA_EXTERN void widgets_date_time_picker_date_time_picker_suggested_date_set_title (WidgetsDateTimePickerDateTimePickerSuggestedDate* self,
                                                                         const gchar* value);
VALA_EXTERN GType widgets_date_time_picker_date_time_picker_no_date_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsDateTimePickerDateTimePickerNoDateButton, g_object_unref)
VALA_EXTERN WidgetsDateTimePickerDateTimePickerNoDateButton* widgets_date_time_picker_date_time_picker_no_date_button_new (void);
VALA_EXTERN WidgetsDateTimePickerDateTimePickerNoDateButton* widgets_date_time_picker_date_time_picker_no_date_button_construct (GType object_type);
VALA_EXTERN GType widgets_date_time_picker_date_time_picker_option_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsDateTimePickerDateTimePickerOptionButton, g_object_unref)
VALA_EXTERN WidgetsDateTimePickerDateTimePickerOptionButton* widgets_date_time_picker_date_time_picker_option_button_new (const gchar* icon_name,
                                                                                                              const gchar* text);
VALA_EXTERN WidgetsDateTimePickerDateTimePickerOptionButton* widgets_date_time_picker_date_time_picker_option_button_construct (GType object_type,
                                                                                                                    const gchar* icon_name,
                                                                                                                    const gchar* text);
VALA_EXTERN GtkButton* widgets_date_time_picker_date_time_picker_option_button_get_main_button (WidgetsDateTimePickerDateTimePickerOptionButton* self);
VALA_EXTERN GtkRevealer* widgets_date_time_picker_date_time_picker_option_button_get_clear_revealer (WidgetsDateTimePickerDateTimePickerOptionButton* self);
VALA_EXTERN const gchar* widgets_date_time_picker_date_time_picker_option_button_get_icon_name (WidgetsDateTimePickerDateTimePickerOptionButton* self);
VALA_EXTERN const gchar* widgets_date_time_picker_date_time_picker_option_button_get_text (WidgetsDateTimePickerDateTimePickerOptionButton* self);
VALA_EXTERN gboolean widgets_date_time_picker_date_time_picker_option_button_get_has_value (WidgetsDateTimePickerDateTimePickerOptionButton* self);
VALA_EXTERN void widgets_date_time_picker_date_time_picker_option_button_set_has_value (WidgetsDateTimePickerDateTimePickerOptionButton* self,
                                                                            gboolean value);
VALA_EXTERN const gchar* widgets_date_time_picker_date_time_picker_option_button_get_label_text (WidgetsDateTimePickerDateTimePickerOptionButton* self);
VALA_EXTERN void widgets_date_time_picker_date_time_picker_option_button_set_label_text (WidgetsDateTimePickerDateTimePickerOptionButton* self,
                                                                             const gchar* value);
VALA_EXTERN GType widgets_date_time_picker_time_picker_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsDateTimePickerTimePicker, g_object_unref)
VALA_EXTERN void widgets_date_time_picker_time_picker_reset (WidgetsDateTimePickerTimePicker* self);
VALA_EXTERN void widgets_date_time_picker_time_picker_clean_up (WidgetsDateTimePickerTimePicker* self);
VALA_EXTERN void widgets_date_time_picker_time_picker_grab_entry_focus (WidgetsDateTimePickerTimePicker* self);
VALA_EXTERN WidgetsDateTimePickerTimePicker* widgets_date_time_picker_time_picker_new (void);
VALA_EXTERN WidgetsDateTimePickerTimePicker* widgets_date_time_picker_time_picker_construct (GType object_type);
VALA_EXTERN const gchar* widgets_date_time_picker_time_picker_get_format_12 (WidgetsDateTimePickerTimePicker* self);
VALA_EXTERN const gchar* widgets_date_time_picker_time_picker_get_format_24 (WidgetsDateTimePickerTimePicker* self);
VALA_EXTERN GDateTime* widgets_date_time_picker_time_picker_get_time (WidgetsDateTimePickerTimePicker* self);
VALA_EXTERN void widgets_date_time_picker_time_picker_set_time (WidgetsDateTimePickerTimePicker* self,
                                                    GDateTime* value);
VALA_EXTERN GType widgets_date_time_picker_repeat_config_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsDateTimePickerRepeatConfig, g_object_unref)
VALA_EXTERN WidgetsDateTimePickerRepeatConfig* widgets_date_time_picker_repeat_config_new (void);
VALA_EXTERN WidgetsDateTimePickerRepeatConfig* widgets_date_time_picker_repeat_config_construct (GType object_type);
VALA_EXTERN void widgets_date_time_picker_repeat_config_clean_up (WidgetsDateTimePickerRepeatConfig* self);
VALA_EXTERN void widgets_date_time_picker_repeat_config_set_duedate (WidgetsDateTimePickerRepeatConfig* self,
                                                         ObjectsDueDate* value);
VALA_EXTERN GType widgets_label_picker_label_picker_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsLabelPickerLabelPicker, g_object_unref)
VALA_EXTERN WidgetsLabelPickerLabelPicker* widgets_label_picker_label_picker_new (void);
VALA_EXTERN WidgetsLabelPickerLabelPicker* widgets_label_picker_label_picker_construct (GType object_type);
VALA_EXTERN void widgets_label_picker_label_picker_reset (WidgetsLabelPickerLabelPicker* self);
VALA_EXTERN void widgets_label_picker_label_picker_clean_up (WidgetsLabelPickerLabelPicker* self);
VALA_EXTERN void widgets_label_picker_label_picker_set_labels (WidgetsLabelPickerLabelPicker* self,
                                                   GeeArrayList* value);
VALA_EXTERN void widgets_label_picker_label_picker_set_source (WidgetsLabelPickerLabelPicker* self,
                                                   ObjectsSource* value);
VALA_EXTERN GeeHashMap* widgets_label_picker_label_picker_get_picked (WidgetsLabelPickerLabelPicker* self);
VALA_EXTERN GType widgets_label_picker_label_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsLabelPickerLabelRow, g_object_unref)
VALA_EXTERN WidgetsLabelPickerLabelRow* widgets_label_picker_label_row_new (ObjectsLabel* label);
VALA_EXTERN WidgetsLabelPickerLabelRow* widgets_label_picker_label_row_construct (GType object_type,
                                                                      ObjectsLabel* label);
VALA_EXTERN void widgets_label_picker_label_row_update_checked_toggled (WidgetsLabelPickerLabelRow* self);
VALA_EXTERN void widgets_label_picker_label_row_show_loading (WidgetsLabelPickerLabelRow* self,
                                                  gboolean show);
VALA_EXTERN void widgets_label_picker_label_row_clean_up (WidgetsLabelPickerLabelRow* self);
VALA_EXTERN ObjectsLabel* widgets_label_picker_label_row_get_label (WidgetsLabelPickerLabelRow* self);
VALA_EXTERN gboolean widgets_label_picker_label_row_get_hide_check_button (WidgetsLabelPickerLabelRow* self);
VALA_EXTERN void widgets_label_picker_label_row_set_hide_check_button (WidgetsLabelPickerLabelRow* self,
                                                           gboolean value);
VALA_EXTERN void widgets_label_picker_label_row_set_active (WidgetsLabelPickerLabelRow* self,
                                                gboolean value);
VALA_EXTERN void widgets_label_picker_label_row_set_margin (WidgetsLabelPickerLabelRow* self,
                                                gint value);
VALA_EXTERN GType widgets_label_picker_label_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsLabelPickerLabelButton, g_object_unref)
VALA_EXTERN WidgetsLabelPickerLabelButton* widgets_label_picker_label_button_new (void);
VALA_EXTERN WidgetsLabelPickerLabelButton* widgets_label_picker_label_button_construct (GType object_type);
VALA_EXTERN WidgetsLabelPickerLabelButton* widgets_label_picker_label_button_new_for_board (void);
VALA_EXTERN WidgetsLabelPickerLabelButton* widgets_label_picker_label_button_construct_for_board (GType object_type);
VALA_EXTERN void widgets_label_picker_label_button_reset (WidgetsLabelPickerLabelButton* self);
VALA_EXTERN void widgets_label_picker_label_button_update_tooltip_from_item (WidgetsLabelPickerLabelButton* self,
                                                                 ObjectsItem* item);
VALA_EXTERN void widgets_label_picker_label_button_open_picker (WidgetsLabelPickerLabelButton* self);
VALA_EXTERN void widgets_label_picker_label_button_clean_up (WidgetsLabelPickerLabelButton* self);
VALA_EXTERN gboolean widgets_label_picker_label_button_get_is_board (WidgetsLabelPickerLabelButton* self);
VALA_EXTERN void widgets_label_picker_label_button_set_labels (WidgetsLabelPickerLabelButton* self,
                                                   GeeArrayList* value);
VALA_EXTERN ObjectsSource* widgets_label_picker_label_button_get_source (WidgetsLabelPickerLabelButton* self);
VALA_EXTERN void widgets_label_picker_label_button_set_source (WidgetsLabelPickerLabelButton* self,
                                                   ObjectsSource* value);
VALA_EXTERN GType widgets_labels_picker_core_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsLabelsPickerCore, g_object_unref)
VALA_EXTERN WidgetsLabelsPickerCore* widgets_labels_picker_core_new (LabelPickerType picker_type);
VALA_EXTERN WidgetsLabelsPickerCore* widgets_labels_picker_core_construct (GType object_type,
                                                               LabelPickerType picker_type);
VALA_EXTERN void widgets_labels_picker_core_reset (WidgetsLabelsPickerCore* self);
VALA_EXTERN void widgets_labels_picker_core_add_labels_list (WidgetsLabelsPickerCore* self,
                                                 GeeArrayList* labels_list);
VALA_EXTERN void widgets_labels_picker_core_clean_up (WidgetsLabelsPickerCore* self);
VALA_EXTERN LabelPickerType widgets_labels_picker_core_get_picker_type (WidgetsLabelsPickerCore* self);
VALA_EXTERN void widgets_labels_picker_core_set_labels (WidgetsLabelsPickerCore* self,
                                            GeeArrayList* value);
VALA_EXTERN ObjectsSource* widgets_labels_picker_core_get_source (WidgetsLabelsPickerCore* self);
VALA_EXTERN void widgets_labels_picker_core_set_source (WidgetsLabelsPickerCore* self,
                                            ObjectsSource* value);
VALA_EXTERN void widgets_labels_picker_core_set_is_loading (WidgetsLabelsPickerCore* self,
                                                gboolean value);
VALA_EXTERN GType widgets_label_picker_label_quick_picker_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsLabelPickerLabelQuickPicker, g_object_unref)
VALA_EXTERN WidgetsLabelPickerLabelQuickPicker* widgets_label_picker_label_quick_picker_new (void);
VALA_EXTERN WidgetsLabelPickerLabelQuickPicker* widgets_label_picker_label_quick_picker_construct (GType object_type);
VALA_EXTERN void widgets_label_picker_label_quick_picker_navigate_listbox (WidgetsLabelPickerLabelQuickPicker* self,
                                                               gboolean down);
VALA_EXTERN void widgets_label_picker_label_quick_picker_activate_selected (WidgetsLabelPickerLabelQuickPicker* self);
VALA_EXTERN void widgets_label_picker_label_quick_picker_select_first_item (WidgetsLabelPickerLabelQuickPicker* self);
VALA_EXTERN void widgets_label_picker_label_quick_picker_reset_filter (WidgetsLabelPickerLabelQuickPicker* self);
VALA_EXTERN ObjectsSource* widgets_label_picker_label_quick_picker_get_source (WidgetsLabelPickerLabelQuickPicker* self);
VALA_EXTERN void widgets_label_picker_label_quick_picker_set_source (WidgetsLabelPickerLabelQuickPicker* self,
                                                         ObjectsSource* value);
VALA_EXTERN const gchar* widgets_label_picker_label_quick_picker_get_filter_text (WidgetsLabelPickerLabelQuickPicker* self);
VALA_EXTERN void widgets_label_picker_label_quick_picker_set_filter_text (WidgetsLabelPickerLabelQuickPicker* self,
                                                              const gchar* value);
VALA_EXTERN GType widgets_project_picker_core_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsProjectPickerCore, g_object_unref)
VALA_EXTERN WidgetsProjectPickerCore* widgets_project_picker_core_new (ObjectsSource* source);
VALA_EXTERN WidgetsProjectPickerCore* widgets_project_picker_core_construct (GType object_type,
                                                                 ObjectsSource* source);
VALA_EXTERN void widgets_project_picker_core_set_selected_project (WidgetsProjectPickerCore* self,
                                                       ObjectsProject* project);
VALA_EXTERN void widgets_project_picker_core_clean_up (WidgetsProjectPickerCore* self);
VALA_EXTERN ObjectsSource* widgets_project_picker_core_get_source (WidgetsProjectPickerCore* self);
VALA_EXTERN GType widgets_project_picker_project_picker_popover_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsProjectPickerProjectPickerPopover, g_object_unref)
VALA_EXTERN WidgetsProjectPickerProjectPickerPopover* widgets_project_picker_project_picker_popover_new (void);
VALA_EXTERN WidgetsProjectPickerProjectPickerPopover* widgets_project_picker_project_picker_popover_construct (GType object_type);
VALA_EXTERN void widgets_project_picker_project_picker_popover_set_selected_project (WidgetsProjectPickerProjectPickerPopover* self,
                                                                         ObjectsProject* project);
VALA_EXTERN void widgets_project_picker_project_picker_popover_clean_up (WidgetsProjectPickerProjectPickerPopover* self);
VALA_EXTERN GType widgets_project_picker_project_picker_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsProjectPickerProjectPickerRow, g_object_unref)
VALA_EXTERN WidgetsProjectPickerProjectPickerRow* widgets_project_picker_project_picker_row_new (ObjectsProject* project);
VALA_EXTERN WidgetsProjectPickerProjectPickerRow* widgets_project_picker_project_picker_row_construct (GType object_type,
                                                                                           ObjectsProject* project);
VALA_EXTERN void widgets_project_picker_project_picker_row_update_request (WidgetsProjectPickerProjectPickerRow* self);
VALA_EXTERN void widgets_project_picker_project_picker_row_clean_up (WidgetsProjectPickerProjectPickerRow* self);
VALA_EXTERN ObjectsProject* widgets_project_picker_project_picker_row_get_project (WidgetsProjectPickerProjectPickerRow* self);
VALA_EXTERN gboolean widgets_project_picker_project_picker_row_get_is_selected (WidgetsProjectPickerProjectPickerRow* self);
VALA_EXTERN void widgets_project_picker_project_picker_row_set_is_selected (WidgetsProjectPickerProjectPickerRow* self,
                                                                gboolean value);
VALA_EXTERN GType widgets_project_picker_project_picker_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsProjectPickerProjectPickerButton, g_object_unref)
VALA_EXTERN GType widgets_section_picker_section_picker_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsSectionPickerSectionPickerRow, g_object_unref)
VALA_EXTERN void widgets_project_picker_project_picker_button_update_project_request (WidgetsProjectPickerProjectPickerButton* self);
VALA_EXTERN void widgets_project_picker_project_picker_button_open_picker (WidgetsProjectPickerProjectPickerButton* self);
VALA_EXTERN void widgets_project_picker_project_picker_button_clean_up (WidgetsProjectPickerProjectPickerButton* self);
VALA_EXTERN WidgetsProjectPickerProjectPickerButton* widgets_project_picker_project_picker_button_new (void);
VALA_EXTERN WidgetsProjectPickerProjectPickerButton* widgets_project_picker_project_picker_button_construct (GType object_type);
VALA_EXTERN ObjectsProject* widgets_project_picker_project_picker_button_get_project (WidgetsProjectPickerProjectPickerButton* self);
VALA_EXTERN void widgets_project_picker_project_picker_button_set_project (WidgetsProjectPickerProjectPickerButton* self,
                                                               ObjectsProject* value);
VALA_EXTERN void widgets_project_picker_project_picker_button_set_section (WidgetsProjectPickerProjectPickerButton* self,
                                                               ObjectsSection* value);
VALA_EXTERN GType widgets_section_picker_section_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsSectionPickerSectionButton, g_object_unref)
VALA_EXTERN WidgetsSectionPickerSectionButton* widgets_section_picker_section_button_new (void);
VALA_EXTERN WidgetsSectionPickerSectionButton* widgets_section_picker_section_button_construct (GType object_type);
VALA_EXTERN void widgets_section_picker_section_button_set_sections (WidgetsSectionPickerSectionButton* self,
                                                         GeeArrayList* sections);
VALA_EXTERN void widgets_section_picker_section_button_update_from_item (WidgetsSectionPickerSectionButton* self,
                                                             ObjectsItem* item);
VALA_EXTERN GType widgets_section_picker_section_picker_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsSectionPickerSectionPicker, g_object_unref)
VALA_EXTERN WidgetsSectionPickerSectionPicker* widgets_section_picker_section_picker_new (void);
VALA_EXTERN WidgetsSectionPickerSectionPicker* widgets_section_picker_section_picker_construct (GType object_type);
VALA_EXTERN void widgets_section_picker_section_picker_set_sections (WidgetsSectionPickerSectionPicker* self,
                                                         GeeArrayList* sections);
VALA_EXTERN void widgets_section_picker_section_picker_set_section (WidgetsSectionPickerSectionPicker* self,
                                                        const gchar* section_id);
VALA_EXTERN WidgetsSectionPickerSectionPickerRow* widgets_section_picker_section_picker_row_new (ObjectsSection* section);
VALA_EXTERN WidgetsSectionPickerSectionPickerRow* widgets_section_picker_section_picker_row_construct (GType object_type,
                                                                                           ObjectsSection* section);
VALA_EXTERN WidgetsSectionPickerSectionPickerRow* widgets_section_picker_section_picker_row_new_for_no_section (void);
VALA_EXTERN WidgetsSectionPickerSectionPickerRow* widgets_section_picker_section_picker_row_construct_for_no_section (GType object_type);
VALA_EXTERN ObjectsSection* widgets_section_picker_section_picker_row_get_section (WidgetsSectionPickerSectionPickerRow* self);
VALA_EXTERN GType widgets_reminder_picker_reminder_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsReminderPickerReminderButton, g_object_unref)
VALA_EXTERN WidgetsReminderPickerReminderButton* widgets_reminder_picker_reminder_button_new (gboolean is_creating);
VALA_EXTERN WidgetsReminderPickerReminderButton* widgets_reminder_picker_reminder_button_construct (GType object_type,
                                                                                        gboolean is_creating);
VALA_EXTERN WidgetsReminderPickerReminderButton* widgets_reminder_picker_reminder_button_new_for_board (void);
VALA_EXTERN WidgetsReminderPickerReminderButton* widgets_reminder_picker_reminder_button_construct_for_board (GType object_type);
VALA_EXTERN void widgets_reminder_picker_reminder_button_set_reminders (WidgetsReminderPickerReminderButton* self,
                                                            GeeArrayList* reminders);
VALA_EXTERN void widgets_reminder_picker_reminder_button_add_reminder (WidgetsReminderPickerReminderButton* self,
                                                           ObjectsReminder* reminder,
                                                           GeeArrayList* reminders);
VALA_EXTERN void widgets_reminder_picker_reminder_button_delete_reminder (WidgetsReminderPickerReminderButton* self,
                                                              ObjectsReminder* reminder,
                                                              GeeArrayList* reminders);
VALA_EXTERN GeeArrayList* widgets_reminder_picker_reminder_button_reminders (WidgetsReminderPickerReminderButton* self);
VALA_EXTERN void widgets_reminder_picker_reminder_button_open_picker (WidgetsReminderPickerReminderButton* self,
                                                          gboolean suggestions_view);
VALA_EXTERN void widgets_reminder_picker_reminder_button_clean_up (WidgetsReminderPickerReminderButton* self);
VALA_EXTERN gboolean widgets_reminder_picker_reminder_button_get_is_board (WidgetsReminderPickerReminderButton* self);
VALA_EXTERN gboolean widgets_reminder_picker_reminder_button_get_is_creating (WidgetsReminderPickerReminderButton* self);
VALA_EXTERN GType widgets_reminder_picker_reminder_picker_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsReminderPickerReminderPicker, g_object_unref)
VALA_EXTERN WidgetsReminderPickerReminderPicker* widgets_reminder_picker_reminder_picker_new (gboolean is_creating);
VALA_EXTERN WidgetsReminderPickerReminderPicker* widgets_reminder_picker_reminder_picker_construct (GType object_type,
                                                                                        gboolean is_creating);
VALA_EXTERN void widgets_reminder_picker_reminder_picker_set_reminders (WidgetsReminderPickerReminderPicker* self,
                                                            GeeArrayList* reminders);
VALA_EXTERN void widgets_reminder_picker_reminder_picker_clear (WidgetsReminderPickerReminderPicker* self);
VALA_EXTERN void widgets_reminder_picker_reminder_picker_add_reminder (WidgetsReminderPickerReminderPicker* self,
                                                           ObjectsReminder* reminder);
VALA_EXTERN void widgets_reminder_picker_reminder_picker_delete_reminder (WidgetsReminderPickerReminderPicker* self,
                                                              ObjectsReminder* reminder);
VALA_EXTERN GeeArrayList* widgets_reminder_picker_reminder_picker_reminders (WidgetsReminderPickerReminderPicker* self);
VALA_EXTERN void widgets_reminder_picker_reminder_picker_clean_up (WidgetsReminderPickerReminderPicker* self);
VALA_EXTERN gboolean widgets_reminder_picker_reminder_picker_get_is_creating (WidgetsReminderPickerReminderPicker* self);
VALA_EXTERN void widgets_reminder_picker_reminder_picker_set_suggestions_view (WidgetsReminderPickerReminderPicker* self,
                                                                   gboolean value);
VALA_EXTERN gboolean widgets_reminder_picker_reminder_picker_get_has_reminders (WidgetsReminderPickerReminderPicker* self);
VALA_EXTERN GType widgets_reminder_picker_reminder_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (WidgetsReminderPickerReminderRow, g_object_unref)
VALA_EXTERN WidgetsReminderPickerReminderRow* widgets_reminder_picker_reminder_row_new (ObjectsReminder* reminder);
VALA_EXTERN WidgetsReminderPickerReminderRow* widgets_reminder_picker_reminder_row_construct (GType object_type,
                                                                                  ObjectsReminder* reminder);
VALA_EXTERN WidgetsReminderPickerReminderRow* widgets_reminder_picker_reminder_row_new_new (void);
VALA_EXTERN WidgetsReminderPickerReminderRow* widgets_reminder_picker_reminder_row_construct_new (GType object_type);
VALA_EXTERN void widgets_reminder_picker_reminder_row_hide_destroy (WidgetsReminderPickerReminderRow* self);
VALA_EXTERN void widgets_reminder_picker_reminder_row_clean_up (WidgetsReminderPickerReminderRow* self);
VALA_EXTERN ObjectsReminder* widgets_reminder_picker_reminder_row_get_reminder (WidgetsReminderPickerReminderRow* self);
VALA_EXTERN gchar* objects_base_object_get_update_json (ObjectsBaseObject* self,
                                            const gchar* uuid,
                                            const gchar* temp_id);
VALA_EXTERN gchar* objects_base_object_get_add_json (ObjectsBaseObject* self,
                                         const gchar* temp_id,
                                         const gchar* uuid);
VALA_EXTERN gchar* objects_base_object_get_move_json (ObjectsBaseObject* self,
                                          const gchar* uuid,
                                          const gchar* new_project_id);
VALA_EXTERN gchar* objects_base_object_to_json (ObjectsBaseObject* self);
VALA_EXTERN void objects_base_object_add_filter (ObjectsBaseObject* self,
                                     ObjectsFiltersFilterItem* filter);
VALA_EXTERN void objects_base_object_remove_filter (ObjectsBaseObject* self,
                                        ObjectsFiltersFilterItem* filter);
VALA_EXTERN void objects_base_object_update_filter (ObjectsBaseObject* self,
                                        ObjectsFiltersFilterItem* filter);
VALA_EXTERN ObjectsFiltersFilterItem* objects_base_object_get_filter (ObjectsBaseObject* self,
                                                          const gchar* id);
VALA_EXTERN gint objects_base_object_update_count (ObjectsBaseObject* self);
VALA_EXTERN gdouble objects_base_object_update_percentage (ObjectsBaseObject* self);
VALA_EXTERN void objects_base_object_count_update (ObjectsBaseObject* self);
VALA_EXTERN gchar* objects_base_object_theme_color (ObjectsBaseObject* self);
VALA_EXTERN ObjectsBaseObject* objects_base_object_new (void);
VALA_EXTERN ObjectsBaseObject* objects_base_object_construct (GType object_type);
VALA_EXTERN const gchar* objects_base_object_get_id (ObjectsBaseObject* self);
VALA_EXTERN void objects_base_object_set_id (ObjectsBaseObject* self,
                                 const gchar* value);
VALA_EXTERN const gchar* objects_base_object_get_name (ObjectsBaseObject* self);
VALA_EXTERN void objects_base_object_set_name (ObjectsBaseObject* self,
                                   const gchar* value);
VALA_EXTERN const gchar* objects_base_object_get_keywords (ObjectsBaseObject* self);
VALA_EXTERN void objects_base_object_set_keywords (ObjectsBaseObject* self,
                                       const gchar* value);
VALA_EXTERN const gchar* objects_base_object_get_icon_name (ObjectsBaseObject* self);
VALA_EXTERN void objects_base_object_set_icon_name (ObjectsBaseObject* self,
                                        const gchar* value);
VALA_EXTERN const gchar* objects_base_object_get_color (ObjectsBaseObject* self);
VALA_EXTERN void objects_base_object_set_color (ObjectsBaseObject* self,
                                    const gchar* value);
VALA_EXTERN guint objects_base_object_get_update_timeout_id (ObjectsBaseObject* self);
VALA_EXTERN void objects_base_object_set_update_timeout_id (ObjectsBaseObject* self,
                                                guint value);
VALA_EXTERN const gchar* objects_base_object_get_id_string (ObjectsBaseObject* self);
VALA_EXTERN gboolean objects_base_object_get_loading (ObjectsBaseObject* self);
VALA_EXTERN void objects_base_object_set_loading (ObjectsBaseObject* self,
                                      gboolean value);
VALA_EXTERN gboolean objects_base_object_get_sensitive (ObjectsBaseObject* self);
VALA_EXTERN void objects_base_object_set_sensitive (ObjectsBaseObject* self,
                                        gboolean value);
VALA_EXTERN const gchar* objects_base_object_get_view_id (ObjectsBaseObject* self);
VALA_EXTERN void objects_base_object_set_view_id (ObjectsBaseObject* self,
                                      const gchar* value);
VALA_EXTERN const gchar* objects_base_object_get_type_delete (ObjectsBaseObject* self);
VALA_EXTERN const gchar* objects_base_object_get_type_add (ObjectsBaseObject* self);
VALA_EXTERN const gchar* objects_base_object_get_type_update (ObjectsBaseObject* self);
VALA_EXTERN ObjectType objects_base_object_get_object_type (ObjectsBaseObject* self);
VALA_EXTERN const gchar* objects_base_object_get_object_type_string (ObjectsBaseObject* self);
VALA_EXTERN const gchar* objects_base_object_get_table_name (ObjectsBaseObject* self);
VALA_EXTERN const gchar* objects_base_object_get_column_order_name (ObjectsBaseObject* self);
VALA_EXTERN ObjectsSource* objects_base_object_get_source (ObjectsBaseObject* self);
VALA_EXTERN gint objects_base_object_get_item_count (ObjectsBaseObject* self);
VALA_EXTERN void objects_base_object_set_item_count (ObjectsBaseObject* self,
                                         gint value);
VALA_EXTERN gdouble objects_base_object_get_percentage (ObjectsBaseObject* self);
VALA_EXTERN ObjectsColor* objects_color_new (gint id,
                                 const gchar* name,
                                 const gchar* name_code,
                                 const gchar* hexadecimal);
VALA_EXTERN ObjectsColor* objects_color_construct (GType object_type,
                                       gint id,
                                       const gchar* name,
                                       const gchar* name_code,
                                       const gchar* hexadecimal);
VALA_EXTERN gint objects_color_get_id (ObjectsColor* self);
VALA_EXTERN const gchar* objects_color_get_name (ObjectsColor* self);
VALA_EXTERN const gchar* objects_color_get_name_code (ObjectsColor* self);
VALA_EXTERN const gchar* objects_color_get_hexadecimal (ObjectsColor* self);
VALA_EXTERN ObjectsDueDate* objects_due_date_new_from_json (JsonObject* object);
VALA_EXTERN ObjectsDueDate* objects_due_date_construct_from_json (GType object_type,
                                                      JsonObject* object);
VALA_EXTERN void objects_due_date_update_from_todoist_json (ObjectsDueDate* self,
                                                JsonObject* object);
VALA_EXTERN void objects_due_date_update_from_json (ObjectsDueDate* self,
                                        JsonObject* object);
VALA_EXTERN void objects_due_date_reset (ObjectsDueDate* self);
VALA_EXTERN gchar* objects_due_date_to_string (ObjectsDueDate* self);
VALA_EXTERN gboolean objects_due_date_is_recurrency_equal (ObjectsDueDate* self,
                                               ObjectsDueDate* duedate);
VALA_EXTERN gchar* objects_due_date_to_friendly_string (ObjectsDueDate* self);
VALA_EXTERN ObjectsDueDate* objects_due_date_duplicate (ObjectsDueDate* self);
VALA_EXTERN ObjectsDueDate* objects_due_date_new (void);
VALA_EXTERN ObjectsDueDate* objects_due_date_construct (GType object_type);
VALA_EXTERN const gchar* objects_due_date_get_date (ObjectsDueDate* self);
VALA_EXTERN void objects_due_date_set_date (ObjectsDueDate* self,
                                const gchar* value);
VALA_EXTERN const gchar* objects_due_date_get_recurrence_string (ObjectsDueDate* self);
VALA_EXTERN void objects_due_date_set_recurrence_string (ObjectsDueDate* self,
                                             const gchar* value);
VALA_EXTERN const gchar* objects_due_date_get_time_zone (ObjectsDueDate* self);
VALA_EXTERN void objects_due_date_set_time_zone (ObjectsDueDate* self,
                                     const gchar* value);
VALA_EXTERN const gchar* objects_due_date_get_recurrency_weeks (ObjectsDueDate* self);
VALA_EXTERN void objects_due_date_set_recurrency_weeks (ObjectsDueDate* self,
                                            const gchar* value);
VALA_EXTERN gboolean objects_due_date_get_is_recurring (ObjectsDueDate* self);
VALA_EXTERN void objects_due_date_set_is_recurring (ObjectsDueDate* self,
                                        gboolean value);
VALA_EXTERN RecurrencyType objects_due_date_get_recurrency_type (ObjectsDueDate* self);
VALA_EXTERN void objects_due_date_set_recurrency_type (ObjectsDueDate* self,
                                           RecurrencyType value);
VALA_EXTERN gint objects_due_date_get_recurrency_interval (ObjectsDueDate* self);
VALA_EXTERN void objects_due_date_set_recurrency_interval (ObjectsDueDate* self,
                                               gint value);
VALA_EXTERN gint objects_due_date_get_recurrency_count (ObjectsDueDate* self);
VALA_EXTERN void objects_due_date_set_recurrency_count (ObjectsDueDate* self,
                                            gint value);
VALA_EXTERN const gchar* objects_due_date_get_recurrency_end (ObjectsDueDate* self);
VALA_EXTERN void objects_due_date_set_recurrency_end (ObjectsDueDate* self,
                                          const gchar* value);
VALA_EXTERN gboolean objects_due_date_get_recurrency_last_day_of_month (ObjectsDueDate* self);
VALA_EXTERN void objects_due_date_set_recurrency_last_day_of_month (ObjectsDueDate* self,
                                                        gboolean value);
VALA_EXTERN gboolean objects_due_date_get_recurrence_supported (ObjectsDueDate* self);
VALA_EXTERN void objects_due_date_set_recurrence_supported (ObjectsDueDate* self,
                                                gboolean value);
VALA_EXTERN GDateTime* objects_due_date_get_datetime (ObjectsDueDate* self);
VALA_EXTERN void objects_due_date_set_datetime (ObjectsDueDate* self,
                                    GDateTime* value);
VALA_EXTERN GDateTime* objects_due_date_get_end_datetime (ObjectsDueDate* self);
VALA_EXTERN gboolean objects_due_date_get_has_weeks (ObjectsDueDate* self);
VALA_EXTERN RecurrencyEndType objects_due_date_get_end_type (ObjectsDueDate* self);
VALA_EXTERN gboolean objects_due_date_get_is_recurrency_end (ObjectsDueDate* self);
VALA_EXTERN GeeArrayList* objects_item_get_labels_list (ObjectsItem* self);
VALA_EXTERN ObjectsItem* objects_item_new_from_json (JsonNode* node);
VALA_EXTERN ObjectsItem* objects_item_construct_from_json (GType object_type,
                                               JsonNode* node);
VALA_EXTERN void objects_item_update_from_json (ObjectsItem* self,
                                    JsonNode* node);
VALA_EXTERN ObjectsItem* objects_item_new_from_import_json (JsonNode* node,
                                                GeeArrayList* _labels);
VALA_EXTERN ObjectsItem* objects_item_construct_from_import_json (GType object_type,
                                                      JsonNode* node,
                                                      GeeArrayList* _labels);
VALA_EXTERN ObjectsItem* objects_item_new_from_vtodo (const gchar* data,
                                          const gchar* _ical_url,
                                          const gchar* _project_id);
VALA_EXTERN ObjectsItem* objects_item_construct_from_vtodo (GType object_type,
                                                const gchar* data,
                                                const gchar* _ical_url,
                                                const gchar* _project_id);
VALA_EXTERN void objects_item_update_from_vtodo (ObjectsItem* self,
                                     const gchar* data,
                                     const gchar* _ical_url);
VALA_EXTERN void objects_item_check_labels (ObjectsItem* self,
                                GeeHashMap* new_labels);
VALA_EXTERN GeeArrayList* objects_item_get_labels_from_json (ObjectsItem* self,
                                                 JsonNode* node);
VALA_EXTERN GeeArrayList* objects_item_get_labels_from_labels_json (ObjectsItem* self,
                                                        JsonNode* node,
                                                        GeeArrayList* labels_list);
VALA_EXTERN GeeHashMap* objects_item_get_labels_maps_from_json (ObjectsItem* self,
                                                    JsonNode* node);
VALA_EXTERN GeeHashMap* objects_item_get_labels_maps_from_caldav (ObjectsItem* self,
                                                      GSList* categories_list);
VALA_EXTERN void objects_item_set_section (ObjectsItem* self,
                               ObjectsSection* section);
VALA_EXTERN void objects_item_set_parent (ObjectsItem* self,
                              ObjectsItem* item);
VALA_EXTERN void objects_item_set_project (ObjectsItem* self,
                               ObjectsProject* project);
VALA_EXTERN gchar* objects_item_get_check_json (ObjectsItem* self,
                                    const gchar* uuid,
                                    const gchar* type,
                                    const gchar* sync_token);
VALA_EXTERN void objects_item_update_local (ObjectsItem* self);
VALA_EXTERN void objects_item_update (ObjectsItem* self,
                          const gchar* update_id);
VALA_EXTERN void objects_item_update_async_timeout (ObjectsItem* self,
                                        const gchar* update_id);
VALA_EXTERN void objects_item_update_async (ObjectsItem* self,
                                const gchar* update_id);
VALA_EXTERN void objects_item_update_pin (ObjectsItem* self,
                              gboolean _pinned);
VALA_EXTERN ObjectsReminder* objects_item_add_reminder_if_not_exists (ObjectsItem* self,
                                                          ObjectsReminder* reminder,
                                                          gboolean insert_db);
VALA_EXTERN ObjectsAttachment* objects_item_add_attachment_if_not_exists (ObjectsItem* self,
                                                              ObjectsAttachment* attachment);
VALA_EXTERN ObjectsLabel* objects_item_add_label_if_not_exists (ObjectsItem* self,
                                                    ObjectsLabel* label);
VALA_EXTERN ObjectsLabel* objects_item_get_label (ObjectsItem* self,
                                      const gchar* id);
VALA_EXTERN gboolean objects_item_has_label (ObjectsItem* self,
                                 const gchar* id);
VALA_EXTERN gboolean objects_item_has_labels (ObjectsItem* self);
VALA_EXTERN void objects_item_add_item_label (ObjectsItem* self,
                                  ObjectsLabel* label);
VALA_EXTERN void objects_item_clean_labels (ObjectsItem* self);
VALA_EXTERN ObjectsLabel* objects_item_delete_item_label (ObjectsItem* self,
                                              const gchar* id);
VALA_EXTERN gchar* objects_item_to_move_json (ObjectsItem* self,
                                  const gchar* type,
                                  const gchar* move_id);
VALA_EXTERN gchar* objects_item_get_move_item (ObjectsItem* self,
                                   const gchar* uuid,
                                   const gchar* type,
                                   const gchar* move_id);
VALA_EXTERN gchar* objects_item_to_vtodo (ObjectsItem* self);
VALA_EXTERN ObjectsItem* objects_item_add_item_if_not_exists (ObjectsItem* self,
                                                  ObjectsItem* new_item,
                                                  gboolean insert);
VALA_EXTERN ObjectsItem* objects_item_get_item (ObjectsItem* self,
                                    const gchar* id);
VALA_EXTERN void objects_item_add_item (ObjectsItem* self,
                            ObjectsItem* item);
VALA_EXTERN gchar* objects_item_to_clipboard_text (ObjectsItem* self);
VALA_EXTERN void objects_item_copy_clipboard (ObjectsItem* self);
VALA_EXTERN gchar* objects_item_get_ics_content (ObjectsItem* self);
VALA_EXTERN void objects_item_export_ics (ObjectsItem* self,
                              GtkWindow* window);
VALA_EXTERN ObjectsItem* objects_item_generate_copy (ObjectsItem* self);
VALA_EXTERN ObjectsItem* objects_item_duplicate (ObjectsItem* self);
VALA_EXTERN void objects_item_delete_item (ObjectsItem* self);
VALA_EXTERN gchar* objects_item_get_labels_names (ObjectsItem* self,
                                      GeeArrayList* labels);
VALA_EXTERN void objects_item_set_recurrency (ObjectsItem* self,
                                  ObjectsDueDate* duedate);
VALA_EXTERN void objects_item_update_next_recurrency (ObjectsItem* self,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_);
VALA_EXTERN GDateTime* objects_item_update_next_recurrency_finish (ObjectsItem* self,
                                                       GAsyncResult* _res_);
VALA_EXTERN void objects_item_move (ObjectsItem* self,
                        ObjectsProject* project,
                        const gchar* _section_id,
                        gboolean notify);
VALA_EXTERN gboolean objects_item_was_archived (ObjectsItem* self);
VALA_EXTERN gboolean objects_item_exists_project (ObjectsItem* self,
                                      ObjectsProject* project);
VALA_EXTERN gchar* objects_item_to_markdown (ObjectsItem* self,
                                 gint level);
VALA_EXTERN void objects_item_update_date (ObjectsItem* self,
                               GDateTime* datetime);
VALA_EXTERN void objects_item_update_due (ObjectsItem* self,
                              ObjectsDueDate* duedate);
VALA_EXTERN void objects_item_add_reminder (ObjectsItem* self,
                                ObjectsReminder* reminder);
VALA_EXTERN void objects_item_add_reminder_events (ObjectsItem* self,
                                       ObjectsReminder* reminder);
VALA_EXTERN void objects_item_complete_item (ObjectsItem* self,
                                 gboolean old_checked,
                                 GAsyncReadyCallback _callback_,
                                 gpointer _user_data_);
VALA_EXTERN HttpResponse* objects_item_complete_item_finish (ObjectsItem* self,
                                                 GAsyncResult* _res_);
VALA_EXTERN void objects_item_update_labels (ObjectsItem* self,
                                 GeeHashMap* new_labels);
VALA_EXTERN void objects_item_to_string (ObjectsItem* self);
VALA_EXTERN ObjectsItem* objects_item_new (void);
VALA_EXTERN ObjectsItem* objects_item_construct (GType object_type);
VALA_EXTERN const gchar* objects_item_get_content (ObjectsItem* self);
VALA_EXTERN void objects_item_set_content (ObjectsItem* self,
                               const gchar* value);
VALA_EXTERN const gchar* objects_item_get_description (ObjectsItem* self);
VALA_EXTERN void objects_item_set_description (ObjectsItem* self,
                                   const gchar* value);
VALA_EXTERN const gchar* objects_item_get_added_at (ObjectsItem* self);
VALA_EXTERN void objects_item_set_added_at (ObjectsItem* self,
                                const gchar* value);
VALA_EXTERN const gchar* objects_item_get_completed_at (ObjectsItem* self);
VALA_EXTERN void objects_item_set_completed_at (ObjectsItem* self,
                                    const gchar* value);
VALA_EXTERN const gchar* objects_item_get_updated_at (ObjectsItem* self);
VALA_EXTERN void objects_item_set_updated_at (ObjectsItem* self,
                                  const gchar* value);
VALA_EXTERN const gchar* objects_item_get_calendar_event_uid (ObjectsItem* self);
VALA_EXTERN void objects_item_set_calendar_event_uid (ObjectsItem* self,
                                          const gchar* value);
VALA_EXTERN const gchar* objects_item_get_deadline_date (ObjectsItem* self);
VALA_EXTERN void objects_item_set_deadline_date (ObjectsItem* self,
                                     const gchar* value);
VALA_EXTERN const gchar* objects_item_get_section_id (ObjectsItem* self);
VALA_EXTERN void objects_item_set_section_id (ObjectsItem* self,
                                  const gchar* value);
VALA_EXTERN const gchar* objects_item_get_project_id (ObjectsItem* self);
VALA_EXTERN void objects_item_set_project_id (ObjectsItem* self,
                                  const gchar* value);
VALA_EXTERN const gchar* objects_item_get_parent_id (ObjectsItem* self);
VALA_EXTERN void objects_item_set_parent_id (ObjectsItem* self,
                                 const gchar* value);
VALA_EXTERN const gchar* objects_item_get_extra_data (ObjectsItem* self);
VALA_EXTERN void objects_item_set_extra_data (ObjectsItem* self,
                                  const gchar* value);
VALA_EXTERN ItemType objects_item_get_item_type (ObjectsItem* self);
VALA_EXTERN void objects_item_set_item_type (ObjectsItem* self,
                                 ItemType value);
VALA_EXTERN const gchar* objects_item_get_responsible_uid (ObjectsItem* self);
VALA_EXTERN void objects_item_set_responsible_uid (ObjectsItem* self,
                                       const gchar* value);
VALA_EXTERN ObjectsDueDate* objects_item_get_due (ObjectsItem* self);
VALA_EXTERN void objects_item_set_due (ObjectsItem* self,
                           ObjectsDueDate* value);
VALA_EXTERN GeeArrayList* objects_item_get_labels (ObjectsItem* self);
VALA_EXTERN void objects_item_set_labels (ObjectsItem* self,
                              GeeArrayList* value);
VALA_EXTERN gint objects_item_get_priority (ObjectsItem* self);
VALA_EXTERN void objects_item_set_priority (ObjectsItem* self,
                                gint value);
VALA_EXTERN gboolean objects_item_get_activate_name_editable (ObjectsItem* self);
VALA_EXTERN void objects_item_set_activate_name_editable (ObjectsItem* self,
                                              gboolean value);
VALA_EXTERN const gchar* objects_item_get_short_content (ObjectsItem* self);
VALA_EXTERN const gchar* objects_item_get_priority_icon (ObjectsItem* self);
VALA_EXTERN const gchar* objects_item_get_priority_color (ObjectsItem* self);
VALA_EXTERN const gchar* objects_item_get_priority_text (ObjectsItem* self);
VALA_EXTERN gint objects_item_get_child_order (ObjectsItem* self);
VALA_EXTERN void objects_item_set_child_order (ObjectsItem* self,
                                   gint value);
VALA_EXTERN gint objects_item_get_day_order (ObjectsItem* self);
VALA_EXTERN void objects_item_set_day_order (ObjectsItem* self,
                                 gint value);
VALA_EXTERN gboolean objects_item_get_checked (ObjectsItem* self);
VALA_EXTERN void objects_item_set_checked (ObjectsItem* self,
                               gboolean value);
VALA_EXTERN gboolean objects_item_get_is_deleted (ObjectsItem* self);
VALA_EXTERN void objects_item_set_is_deleted (ObjectsItem* self,
                                  gboolean value);
VALA_EXTERN gboolean objects_item_get_collapsed (ObjectsItem* self);
VALA_EXTERN void objects_item_set_collapsed (ObjectsItem* self,
                                 gboolean value);
VALA_EXTERN gboolean objects_item_get_pinned (ObjectsItem* self);
VALA_EXTERN void objects_item_set_pinned (ObjectsItem* self,
                              gboolean value);
VALA_EXTERN const gchar* objects_item_get_pinned_icon (ObjectsItem* self);
VALA_EXTERN gboolean objects_item_get_completed (ObjectsItem* self);
VALA_EXTERN gboolean objects_item_get_has_due (ObjectsItem* self);
VALA_EXTERN gboolean objects_item_get_has_time (ObjectsItem* self);
VALA_EXTERN GDateTime* objects_item_get_completed_date (ObjectsItem* self);
VALA_EXTERN gboolean objects_item_get_has_parent (ObjectsItem* self);
VALA_EXTERN gboolean objects_item_get_has_section (ObjectsItem* self);
VALA_EXTERN gboolean objects_item_get_show_item (ObjectsItem* self);
VALA_EXTERN void objects_item_set_show_item (ObjectsItem* self,
                                 gboolean value);
VALA_EXTERN const gchar* objects_item_get_ical_url (ObjectsItem* self);
VALA_EXTERN const gchar* objects_item_get_calendar_data (ObjectsItem* self);
VALA_EXTERN const gchar* objects_item_get_etag (ObjectsItem* self);
VALA_EXTERN GDateTime* objects_item_get_added_datetime (ObjectsItem* self);
VALA_EXTERN GDateTime* objects_item_get_updated_datetime (ObjectsItem* self);
VALA_EXTERN GDateTime* objects_item_get_deadline_datetime (ObjectsItem* self);
VALA_EXTERN gboolean objects_item_get_has_deadline (ObjectsItem* self);
VALA_EXTERN JsonBuilder* objects_item_get_builder (ObjectsItem* self);
VALA_EXTERN ObjectsItem* objects_item_get_parent (ObjectsItem* self);
VALA_EXTERN ObjectsProject* objects_item_get_project (ObjectsItem* self);
VALA_EXTERN ObjectsSection* objects_item_get_section (ObjectsItem* self);
VALA_EXTERN GeeArrayList* objects_item_get_items (ObjectsItem* self);
VALA_EXTERN GeeArrayList* objects_item_get_items_uncomplete (ObjectsItem* self);
VALA_EXTERN GeeArrayList* objects_item_get_reminders (ObjectsItem* self);
VALA_EXTERN GeeArrayList* objects_item_get_attachments (ObjectsItem* self);
VALA_EXTERN ObjectsLabel* objects_label_new_from_json (JsonNode* node);
VALA_EXTERN ObjectsLabel* objects_label_construct_from_json (GType object_type,
                                                 JsonNode* node);
VALA_EXTERN ObjectsLabel* objects_label_new_from_import_json (JsonNode* node);
VALA_EXTERN ObjectsLabel* objects_label_construct_from_import_json (GType object_type,
                                                        JsonNode* node);
VALA_EXTERN void objects_label_update_from_json (ObjectsLabel* self,
                                     JsonNode* node);
VALA_EXTERN void objects_label_delete_label (ObjectsLabel* self,
                                 GtkWindow* window,
                                 GAsyncReadyCallback _callback_,
                                 gpointer _user_data_);
VALA_EXTERN void objects_label_delete_label_finish (ObjectsLabel* self,
                                        GAsyncResult* _res_);
VALA_EXTERN ObjectsLabel* objects_label_new (void);
VALA_EXTERN ObjectsLabel* objects_label_construct (GType object_type);
VALA_EXTERN gint objects_label_get_item_order (ObjectsLabel* self);
VALA_EXTERN void objects_label_set_item_order (ObjectsLabel* self,
                                   gint value);
VALA_EXTERN gboolean objects_label_get_is_deleted (ObjectsLabel* self);
VALA_EXTERN void objects_label_set_is_deleted (ObjectsLabel* self,
                                   gboolean value);
VALA_EXTERN gboolean objects_label_get_is_favorite (ObjectsLabel* self);
VALA_EXTERN void objects_label_set_is_favorite (ObjectsLabel* self,
                                    gboolean value);
VALA_EXTERN SourceType objects_label_get_backend_type (ObjectsLabel* self);
VALA_EXTERN void objects_label_set_backend_type (ObjectsLabel* self,
                                     SourceType value);
VALA_EXTERN const gchar* objects_label_get_source_id (ObjectsLabel* self);
VALA_EXTERN void objects_label_set_source_id (ObjectsLabel* self,
                                  const gchar* value);
VALA_EXTERN ObjectsSource* objects_label_get_source (ObjectsLabel* self);
VALA_EXTERN SourceType objects_label_get_source_type (ObjectsLabel* self);
VALA_EXTERN gint objects_label_get_label_count (ObjectsLabel* self);
VALA_EXTERN void objects_label_set_label_count (ObjectsLabel* self,
                                    gint value);
VALA_EXTERN const gchar* objects_label_get_short_name (ObjectsLabel* self);
VALA_EXTERN ObjectsProject* objects_project_new_from_json (JsonNode* node);
VALA_EXTERN ObjectsProject* objects_project_construct_from_json (GType object_type,
                                                     JsonNode* node);
VALA_EXTERN ObjectsProject* objects_project_new_from_google_tasklist_json (JsonNode* node);
VALA_EXTERN ObjectsProject* objects_project_construct_from_google_tasklist_json (GType object_type,
                                                                     JsonNode* node);
VALA_EXTERN ObjectsProject* objects_project_new_from_propstat (ServicesCalDAVWebDAVPropStat* propstat,
                                                   const gchar* url);
VALA_EXTERN ObjectsProject* objects_project_construct_from_propstat (GType object_type,
                                                         ServicesCalDAVWebDAVPropStat* propstat,
                                                         const gchar* url);
VALA_EXTERN void objects_project_update_from_propstat (ObjectsProject* self,
                                           ServicesCalDAVWebDAVPropStat* propstat,
                                           gboolean update_sync_token);
VALA_EXTERN gchar* objects_project_get_id_from_url (ObjectsProject* self,
                                        GXmlDomElement* element);
VALA_EXTERN gchar* objects_project_get_content (ObjectsProject* self,
                                    GXmlDomElement* element);
VALA_EXTERN ObjectsProject* objects_project_new_from_import_json (JsonNode* node);
VALA_EXTERN ObjectsProject* objects_project_construct_from_import_json (GType object_type,
                                                            JsonNode* node);
VALA_EXTERN void objects_project_update_from_json (ObjectsProject* self,
                                       JsonNode* node);
VALA_EXTERN void objects_project_update_from_google_tasklist_json (ObjectsProject* self,
                                                       JsonNode* node);
VALA_EXTERN void objects_project_update_local (ObjectsProject* self);
VALA_EXTERN void objects_project_update (ObjectsProject* self,
                             gboolean use_timeout,
                             gboolean show_loading);
VALA_EXTERN ObjectsProject* objects_project_add_subproject_if_not_exists (ObjectsProject* self,
                                                              ObjectsProject* new_project);
VALA_EXTERN ObjectsProject* objects_project_get_subproject (ObjectsProject* self,
                                                const gchar* id);
VALA_EXTERN void objects_project_set_parent (ObjectsProject* self,
                                 ObjectsProject* project);
VALA_EXTERN ObjectsSection* objects_project_add_section_if_not_exists (ObjectsProject* self,
                                                           ObjectsSection* new_section);
VALA_EXTERN ObjectsSection* objects_project_get_section (ObjectsProject* self,
                                             const gchar* id);
VALA_EXTERN void objects_project_add_section (ObjectsProject* self,
                                  ObjectsSection* section);
VALA_EXTERN void objects_project_remove_section (ObjectsProject* self,
                                     ObjectsSection* section);
VALA_EXTERN void objects_project_add_items_batched (ObjectsProject* self,
                                        GeeArrayList* items);
VALA_EXTERN ObjectsItem* objects_project_add_item_if_not_exists (ObjectsProject* self,
                                                     ObjectsItem* new_item,
                                                     gboolean insert);
VALA_EXTERN void objects_project_add_item (ObjectsProject* self,
                               ObjectsItem* item);
VALA_EXTERN ObjectsItem* objects_project_get_item (ObjectsProject* self,
                                       const gchar* id);
VALA_EXTERN gchar* objects_project_to_string (ObjectsProject* self);
VALA_EXTERN void objects_project_share_markdown (ObjectsProject* self);
VALA_EXTERN void objects_project_share_mail (ObjectsProject* self);
VALA_EXTERN void objects_project_delete_project (ObjectsProject* self,
                                     GtkWindow* window);
VALA_EXTERN void objects_project_archive_project (ObjectsProject* self,
                                      GtkWindow* window);
VALA_EXTERN void objects_project_unarchive_project (ObjectsProject* self);
VALA_EXTERN ObjectsProject* objects_project_duplicate (ObjectsProject* self);
VALA_EXTERN ObjectsProject* objects_project_new (void);
VALA_EXTERN ObjectsProject* objects_project_construct (GType object_type);
VALA_EXTERN gboolean objects_project_get_freeze_update (ObjectsProject* self);
VALA_EXTERN void objects_project_set_freeze_update (ObjectsProject* self,
                                        gboolean value);
VALA_EXTERN const gchar* objects_project_get_parent_id (ObjectsProject* self);
VALA_EXTERN void objects_project_set_parent_id (ObjectsProject* self,
                                    const gchar* value);
VALA_EXTERN const gchar* objects_project_get_due_date (ObjectsProject* self);
VALA_EXTERN void objects_project_set_due_date (ObjectsProject* self,
                                   const gchar* value);
VALA_EXTERN const gchar* objects_project_get_emoji (ObjectsProject* self);
VALA_EXTERN void objects_project_set_emoji (ObjectsProject* self,
                                const gchar* value);
VALA_EXTERN const gchar* objects_project_get_description (ObjectsProject* self);
VALA_EXTERN void objects_project_set_description (ObjectsProject* self,
                                      const gchar* value);
VALA_EXTERN ProjectIconStyle objects_project_get_icon_style (ObjectsProject* self);
VALA_EXTERN void objects_project_set_icon_style (ObjectsProject* self,
                                     ProjectIconStyle value);
VALA_EXTERN SourceType objects_project_get_backend_type (ObjectsProject* self);
VALA_EXTERN void objects_project_set_backend_type (ObjectsProject* self,
                                       SourceType value);
VALA_EXTERN gboolean objects_project_get_inbox_project (ObjectsProject* self);
VALA_EXTERN void objects_project_set_inbox_project (ObjectsProject* self,
                                        gboolean value);
VALA_EXTERN gboolean objects_project_get_team_inbox (ObjectsProject* self);
VALA_EXTERN void objects_project_set_team_inbox (ObjectsProject* self,
                                     gboolean value);
VALA_EXTERN gboolean objects_project_get_is_deleted (ObjectsProject* self);
VALA_EXTERN void objects_project_set_is_deleted (ObjectsProject* self,
                                     gboolean value);
VALA_EXTERN gboolean objects_project_get_is_archived (ObjectsProject* self);
VALA_EXTERN void objects_project_set_is_archived (ObjectsProject* self,
                                      gboolean value);
VALA_EXTERN gboolean objects_project_get_is_favorite (ObjectsProject* self);
VALA_EXTERN void objects_project_set_is_favorite (ObjectsProject* self,
                                      gboolean value);
VALA_EXTERN gboolean objects_project_get_shared (ObjectsProject* self);
VALA_EXTERN void objects_project_set_shared (ObjectsProject* self,
                                 gboolean value);
VALA_EXTERN gboolean objects_project_get_collapsed (ObjectsProject* self);
VALA_EXTERN void objects_project_set_collapsed (ObjectsProject* self,
                                    gboolean value);
VALA_EXTERN gboolean objects_project_get_inbox_section_hidded (ObjectsProject* self);
VALA_EXTERN void objects_project_set_inbox_section_hidded (ObjectsProject* self,
                                               gboolean value);
VALA_EXTERN const gchar* objects_project_get_sync_id (ObjectsProject* self);
VALA_EXTERN void objects_project_set_sync_id (ObjectsProject* self,
                                  const gchar* value);
VALA_EXTERN const gchar* objects_project_get_source_id (ObjectsProject* self);
VALA_EXTERN void objects_project_set_source_id (ObjectsProject* self,
                                    const gchar* value);
VALA_EXTERN const gchar* objects_project_get_calendar_url (ObjectsProject* self);
VALA_EXTERN void objects_project_set_calendar_url (ObjectsProject* self,
                                       const gchar* value);
VALA_EXTERN const gchar* objects_project_get_calendar_source_uid (ObjectsProject* self);
VALA_EXTERN void objects_project_set_calendar_source_uid (ObjectsProject* self,
                                              const gchar* value);
VALA_EXTERN MarkdownSetting objects_project_get_markdown_setting (ObjectsProject* self);
VALA_EXTERN void objects_project_set_markdown_setting (ObjectsProject* self,
                                           MarkdownSetting value);
VALA_EXTERN gboolean objects_project_get_is_markdown_enabled (ObjectsProject* self);
VALA_EXTERN gboolean objects_project_get_show_completed (ObjectsProject* self);
VALA_EXTERN void objects_project_set_show_completed (ObjectsProject* self,
                                         gboolean value);
VALA_EXTERN ProjectViewStyle objects_project_get_view_style (ObjectsProject* self);
VALA_EXTERN void objects_project_set_view_style (ObjectsProject* self,
                                     ProjectViewStyle value);
VALA_EXTERN SortedByType objects_project_get_sorted_by (ObjectsProject* self);
VALA_EXTERN void objects_project_set_sorted_by (ObjectsProject* self,
                                    SortedByType value);
VALA_EXTERN SortOrderType objects_project_get_sort_order (ObjectsProject* self);
VALA_EXTERN void objects_project_set_sort_order (ObjectsProject* self,
                                     SortOrderType value);
VALA_EXTERN SourceType objects_project_get_source_type (ObjectsProject* self);
VALA_EXTERN ObjectsSource* objects_project_get_source (ObjectsProject* self);
VALA_EXTERN const gchar* objects_project_get_color_hex (ObjectsProject* self);
VALA_EXTERN gint objects_project_get_child_order (ObjectsProject* self);
VALA_EXTERN void objects_project_set_child_order (ObjectsProject* self,
                                      gint value);
VALA_EXTERN const gchar* objects_project_get_view_id (ObjectsProject* self);
VALA_EXTERN const gchar* objects_project_get_parent_id_string (ObjectsProject* self);
VALA_EXTERN const gchar* objects_project_get_short_name (ObjectsProject* self);
VALA_EXTERN gboolean objects_project_get_is_inbox_project (ObjectsProject* self);
VALA_EXTERN GeeArrayList* objects_project_get_sections (ObjectsProject* self);
VALA_EXTERN GeeArrayList* objects_project_get_sections_archived (ObjectsProject* self);
VALA_EXTERN GeeArrayList* objects_project_get_items (ObjectsProject* self);
VALA_EXTERN GeeArrayList* objects_project_get_items_checked (ObjectsProject* self);
VALA_EXTERN GeeArrayList* objects_project_get_all_items (ObjectsProject* self);
VALA_EXTERN GeeArrayList* objects_project_get_items_pinned (ObjectsProject* self);
VALA_EXTERN GeeArrayList* objects_project_get_subprojects (ObjectsProject* self);
VALA_EXTERN ObjectsProject* objects_project_get_parent (ObjectsProject* self);
VALA_EXTERN gboolean objects_project_get_show_multi_select (ObjectsProject* self);
VALA_EXTERN void objects_project_set_show_multi_select (ObjectsProject* self,
                                            gboolean value);
VALA_EXTERN gboolean objects_project_get_is_deck (ObjectsProject* self);
VALA_EXTERN ObjectsQueue* objects_queue_new (void);
VALA_EXTERN ObjectsQueue* objects_queue_construct (GType object_type);
VALA_EXTERN const gchar* objects_queue_get_uuid (ObjectsQueue* self);
VALA_EXTERN void objects_queue_set_uuid (ObjectsQueue* self,
                             const gchar* value);
VALA_EXTERN const gchar* objects_queue_get_object_id (ObjectsQueue* self);
VALA_EXTERN void objects_queue_set_object_id (ObjectsQueue* self,
                                  const gchar* value);
VALA_EXTERN const gchar* objects_queue_get_temp_id (ObjectsQueue* self);
VALA_EXTERN void objects_queue_set_temp_id (ObjectsQueue* self,
                                const gchar* value);
VALA_EXTERN const gchar* objects_queue_get_query (ObjectsQueue* self);
VALA_EXTERN void objects_queue_set_query (ObjectsQueue* self,
                              const gchar* value);
VALA_EXTERN const gchar* objects_queue_get_args (ObjectsQueue* self);
VALA_EXTERN void objects_queue_set_args (ObjectsQueue* self,
                             const gchar* value);
VALA_EXTERN const gchar* objects_queue_get_source_id (ObjectsQueue* self);
VALA_EXTERN void objects_queue_set_source_id (ObjectsQueue* self,
                                  const gchar* value);
VALA_EXTERN const gchar* objects_queue_get_date_added (ObjectsQueue* self);
VALA_EXTERN void objects_queue_set_date_added (ObjectsQueue* self,
                                   const gchar* value);
VALA_EXTERN ObjectsReminder* objects_reminder_new_from_json (JsonNode* node);
VALA_EXTERN ObjectsReminder* objects_reminder_construct_from_json (GType object_type,
                                                       JsonNode* node);
VALA_EXTERN void objects_reminder_delete (ObjectsReminder* self);
VALA_EXTERN ObjectsReminder* objects_reminder_duplicate (ObjectsReminder* self);
VALA_EXTERN ObjectsReminder* objects_reminder_new (void);
VALA_EXTERN ObjectsReminder* objects_reminder_construct (GType object_type);
VALA_EXTERN gint64 objects_reminder_get_notify_uid (ObjectsReminder* self);
VALA_EXTERN void objects_reminder_set_notify_uid (ObjectsReminder* self,
                                      gint64 value);
VALA_EXTERN const gchar* objects_reminder_get_item_id (ObjectsReminder* self);
VALA_EXTERN void objects_reminder_set_item_id (ObjectsReminder* self,
                                   const gchar* value);
VALA_EXTERN const gchar* objects_reminder_get_service (ObjectsReminder* self);
VALA_EXTERN void objects_reminder_set_service (ObjectsReminder* self,
                                   const gchar* value);
VALA_EXTERN ObjectsDueDate* objects_reminder_get_due (ObjectsReminder* self);
VALA_EXTERN void objects_reminder_set_due (ObjectsReminder* self,
                               ObjectsDueDate* value);
VALA_EXTERN gint objects_reminder_get_mm_offset (ObjectsReminder* self);
VALA_EXTERN void objects_reminder_set_mm_offset (ObjectsReminder* self,
                                     gint value);
VALA_EXTERN gint objects_reminder_get_is_deleted (ObjectsReminder* self);
VALA_EXTERN void objects_reminder_set_is_deleted (ObjectsReminder* self,
                                      gint value);
VALA_EXTERN ReminderType objects_reminder_get_reminder_type (ObjectsReminder* self);
VALA_EXTERN void objects_reminder_set_reminder_type (ObjectsReminder* self,
                                         ReminderType value);
VALA_EXTERN ObjectsItem* objects_reminder_get_item (ObjectsReminder* self);
VALA_EXTERN void objects_reminder_set_item (ObjectsReminder* self,
                                ObjectsItem* value);
VALA_EXTERN GDateTime* objects_reminder_get_datetime (ObjectsReminder* self);
VALA_EXTERN const gchar* objects_reminder_get_relative_text (ObjectsReminder* self);
VALA_EXTERN gchar* objects_section_CALDAV_PREFIX;
VALA_EXTERN void objects_section_update_count (ObjectsSection* self);
VALA_EXTERN ObjectsSection* objects_section_new_from_json (JsonNode* node);
VALA_EXTERN ObjectsSection* objects_section_construct_from_json (GType object_type,
                                                     JsonNode* node);
VALA_EXTERN ObjectsSection* objects_section_new_from_import_json (JsonNode* node);
VALA_EXTERN ObjectsSection* objects_section_construct_from_import_json (GType object_type,
                                                            JsonNode* node);
VALA_EXTERN void objects_section_update_from_json (ObjectsSection* self,
                                       JsonNode* node);
VALA_EXTERN void objects_section_set_project (ObjectsSection* self,
                                  ObjectsProject* project);
VALA_EXTERN ObjectsItem* objects_section_add_item_if_not_exists (ObjectsSection* self,
                                                     ObjectsItem* new_item,
                                                     gboolean insert);
VALA_EXTERN ObjectsItem* objects_section_get_item (ObjectsSection* self,
                                       const gchar* id);
VALA_EXTERN void objects_section_add_item (ObjectsSection* self,
                               ObjectsItem* item);
VALA_EXTERN void objects_section_update (ObjectsSection* self,
                             gboolean cloud);
VALA_EXTERN void objects_section_update_local (ObjectsSection* self);
VALA_EXTERN ObjectsSection* objects_section_duplicate (ObjectsSection* self);
VALA_EXTERN void objects_section_delete_section (ObjectsSection* self,
                                     GtkWindow* window);
VALA_EXTERN void objects_section_archive_section (ObjectsSection* self,
                                      GtkWindow* window);
VALA_EXTERN void objects_section_unarchive_section (ObjectsSection* self);
VALA_EXTERN gboolean objects_section_was_archived (ObjectsSection* self);
VALA_EXTERN gchar* objects_section_to_vtodo (ObjectsSection* self);
VALA_EXTERN void objects_section_patch_from_vtodo (ObjectsSection* self,
                                       const gchar* data,
                                       const gchar* _ical_url);
VALA_EXTERN gboolean objects_section_is_vtodo_section (const gchar* summary);
VALA_EXTERN ObjectsSection* objects_section_new (void);
VALA_EXTERN ObjectsSection* objects_section_construct (GType object_type);
VALA_EXTERN const gchar* objects_section_get_project_id (ObjectsSection* self);
VALA_EXTERN void objects_section_set_project_id (ObjectsSection* self,
                                     const gchar* value);
VALA_EXTERN const gchar* objects_section_get_archived_at (ObjectsSection* self);
VALA_EXTERN void objects_section_set_archived_at (ObjectsSection* self,
                                      const gchar* value);
VALA_EXTERN const gchar* objects_section_get_added_at (ObjectsSection* self);
VALA_EXTERN void objects_section_set_added_at (ObjectsSection* self,
                                   const gchar* value);
VALA_EXTERN gint objects_section_get_section_order (ObjectsSection* self);
VALA_EXTERN void objects_section_set_section_order (ObjectsSection* self,
                                        gint value);
VALA_EXTERN gboolean objects_section_get_collapsed (ObjectsSection* self);
VALA_EXTERN void objects_section_set_collapsed (ObjectsSection* self,
                                    gboolean value);
VALA_EXTERN gboolean objects_section_get_is_deleted (ObjectsSection* self);
VALA_EXTERN void objects_section_set_is_deleted (ObjectsSection* self,
                                     gboolean value);
VALA_EXTERN gboolean objects_section_get_is_archived (ObjectsSection* self);
VALA_EXTERN void objects_section_set_is_archived (ObjectsSection* self,
                                      gboolean value);
VALA_EXTERN const gchar* objects_section_get_description (ObjectsSection* self);
VALA_EXTERN void objects_section_set_description (ObjectsSection* self,
                                      const gchar* value);
VALA_EXTERN gboolean objects_section_get_hidded (ObjectsSection* self);
VALA_EXTERN void objects_section_set_hidded (ObjectsSection* self,
                                 gboolean value);
VALA_EXTERN const gchar* objects_section_get_extra_data (ObjectsSection* self);
VALA_EXTERN void objects_section_set_extra_data (ObjectsSection* self,
                                     const gchar* value);
VALA_EXTERN const gchar* objects_section_get_ical_url (ObjectsSection* self);
VALA_EXTERN const gchar* objects_section_get_etag (ObjectsSection* self);
VALA_EXTERN gboolean objects_section_get_is_caldav_section (ObjectsSection* self);
VALA_EXTERN gboolean objects_section_get_activate_name_editable (ObjectsSection* self);
VALA_EXTERN void objects_section_set_activate_name_editable (ObjectsSection* self,
                                                 gboolean value);
VALA_EXTERN const gchar* objects_section_get_short_name (ObjectsSection* self);
VALA_EXTERN ObjectsProject* objects_section_get_project (ObjectsSection* self);
VALA_EXTERN GeeArrayList* objects_section_get_items (ObjectsSection* self);
VALA_EXTERN gint objects_section_get_section_count (ObjectsSection* self);
VALA_EXTERN void objects_section_set_section_count (ObjectsSection* self,
                                        gint value);
VALA_EXTERN gchar* objects_attachment_to_string (ObjectsAttachment* self);
VALA_EXTERN void objects_attachment_delete (ObjectsAttachment* self);
VALA_EXTERN ObjectsAttachment* objects_attachment_duplicate (ObjectsAttachment* self);
VALA_EXTERN ObjectsAttachment* objects_attachment_new (void);
VALA_EXTERN ObjectsAttachment* objects_attachment_construct (GType object_type);
VALA_EXTERN const gchar* objects_attachment_get_id (ObjectsAttachment* self);
VALA_EXTERN void objects_attachment_set_id (ObjectsAttachment* self,
                                const gchar* value);
VALA_EXTERN const gchar* objects_attachment_get_item_id (ObjectsAttachment* self);
VALA_EXTERN void objects_attachment_set_item_id (ObjectsAttachment* self,
                                     const gchar* value);
VALA_EXTERN const gchar* objects_attachment_get_file_type (ObjectsAttachment* self);
VALA_EXTERN void objects_attachment_set_file_type (ObjectsAttachment* self,
                                       const gchar* value);
VALA_EXTERN const gchar* objects_attachment_get_file_name (ObjectsAttachment* self);
VALA_EXTERN void objects_attachment_set_file_name (ObjectsAttachment* self,
                                       const gchar* value);
VALA_EXTERN const gchar* objects_attachment_get_file_size (ObjectsAttachment* self);
VALA_EXTERN void objects_attachment_set_file_size (ObjectsAttachment* self,
                                       const gchar* value);
VALA_EXTERN const gchar* objects_attachment_get_file_path (ObjectsAttachment* self);
VALA_EXTERN void objects_attachment_set_file_path (ObjectsAttachment* self,
                                       const gchar* value);
VALA_EXTERN ObjectsItem* objects_attachment_get_item (ObjectsAttachment* self);
VALA_EXTERN void objects_attachment_set_item (ObjectsAttachment* self,
                                  ObjectsItem* value);
VALA_EXTERN ObjectsDueDate* objects_object_event_get_due_value (ObjectsObjectEvent* self,
                                                    const gchar* value);
VALA_EXTERN gchar* objects_object_event_get_labels_value (ObjectsObjectEvent* self,
                                              const gchar* value);
VALA_EXTERN ObjectsObjectEvent* objects_object_event_new (void);
VALA_EXTERN ObjectsObjectEvent* objects_object_event_construct (GType object_type);
VALA_EXTERN gint64 objects_object_event_get_id (ObjectsObjectEvent* self);
VALA_EXTERN void objects_object_event_set_id (ObjectsObjectEvent* self,
                                  gint64 value);
VALA_EXTERN ObjectEventType objects_object_event_get_event_type (ObjectsObjectEvent* self);
VALA_EXTERN void objects_object_event_set_event_type (ObjectsObjectEvent* self,
                                          ObjectEventType value);
VALA_EXTERN const gchar* objects_object_event_get_event_date (ObjectsObjectEvent* self);
VALA_EXTERN void objects_object_event_set_event_date (ObjectsObjectEvent* self,
                                          const gchar* value);
VALA_EXTERN const gchar* objects_object_event_get_object_id (ObjectsObjectEvent* self);
VALA_EXTERN void objects_object_event_set_object_id (ObjectsObjectEvent* self,
                                         const gchar* value);
VALA_EXTERN const gchar* objects_object_event_get_object_type (ObjectsObjectEvent* self);
VALA_EXTERN void objects_object_event_set_object_type (ObjectsObjectEvent* self,
                                           const gchar* value);
VALA_EXTERN ObjectEventKeyType objects_object_event_get_object_key (ObjectsObjectEvent* self);
VALA_EXTERN void objects_object_event_set_object_key (ObjectsObjectEvent* self,
                                          ObjectEventKeyType value);
VALA_EXTERN const gchar* objects_object_event_get_object_old_value (ObjectsObjectEvent* self);
VALA_EXTERN void objects_object_event_set_object_old_value (ObjectsObjectEvent* self,
                                                const gchar* value);
VALA_EXTERN const gchar* objects_object_event_get_object_new_value (ObjectsObjectEvent* self);
VALA_EXTERN void objects_object_event_set_object_new_value (ObjectsObjectEvent* self,
                                                const gchar* value);
VALA_EXTERN const gchar* objects_object_event_get_parent_item_id (ObjectsObjectEvent* self);
VALA_EXTERN void objects_object_event_set_parent_item_id (ObjectsObjectEvent* self,
                                              const gchar* value);
VALA_EXTERN const gchar* objects_object_event_get_parent_project_id (ObjectsObjectEvent* self);
VALA_EXTERN void objects_object_event_set_parent_project_id (ObjectsObjectEvent* self,
                                                 const gchar* value);
VALA_EXTERN const gchar* objects_object_event_get_icon_name (ObjectsObjectEvent* self);
VALA_EXTERN GDateTime* objects_object_event_get_datetime (ObjectsObjectEvent* self);
VALA_EXTERN GDateTime* objects_object_event_get_date (ObjectsObjectEvent* self);
VALA_EXTERN const gchar* objects_object_event_get_time (ObjectsObjectEvent* self);
VALA_EXTERN ObjectsSource* objects_source_new_from_import_json (JsonNode* node);
VALA_EXTERN ObjectsSource* objects_source_construct_from_import_json (GType object_type,
                                                          JsonNode* node);
VALA_EXTERN void objects_source_run_server (ObjectsSource* self,
                                gboolean skip_first_sync);
VALA_EXTERN void objects_source_remove_sync_server (ObjectsSource* self);
VALA_EXTERN void objects_source_save (ObjectsSource* self);
VALA_EXTERN void objects_source_delete_source (ObjectsSource* self,
                                   GAsyncReadyCallback _callback_,
                                   gpointer _user_data_);
VALA_EXTERN void objects_source_delete_source_finish (ObjectsSource* self,
                                          GAsyncResult* _res_);
VALA_EXTERN gchar* objects_source_to_string (ObjectsSource* self);
VALA_EXTERN gboolean objects_source_needs_migration (ObjectsSource* self);
VALA_EXTERN ObjectsSource* objects_source_new (void);
VALA_EXTERN ObjectsSource* objects_source_construct (GType object_type);
VALA_EXTERN SourceType objects_source_get_source_type (ObjectsSource* self);
VALA_EXTERN void objects_source_set_source_type (ObjectsSource* self,
                                     SourceType value);
VALA_EXTERN const gchar* objects_source_get_added_at (ObjectsSource* self);
VALA_EXTERN void objects_source_set_added_at (ObjectsSource* self,
                                  const gchar* value);
VALA_EXTERN const gchar* objects_source_get_updated_at (ObjectsSource* self);
VALA_EXTERN void objects_source_set_updated_at (ObjectsSource* self,
                                    const gchar* value);
VALA_EXTERN gboolean objects_source_get_is_visible (ObjectsSource* self);
VALA_EXTERN void objects_source_set_is_visible (ObjectsSource* self,
                                    gboolean value);
VALA_EXTERN gint objects_source_get_child_order (ObjectsSource* self);
VALA_EXTERN void objects_source_set_child_order (ObjectsSource* self,
                                     gint value);
VALA_EXTERN gboolean objects_source_get_sync_server (ObjectsSource* self);
VALA_EXTERN void objects_source_set_sync_server (ObjectsSource* self,
                                     gboolean value);
VALA_EXTERN const gchar* objects_source_get_last_sync (ObjectsSource* self);
VALA_EXTERN void objects_source_set_last_sync (ObjectsSource* self,
                                   const gchar* value);
VALA_EXTERN GType objects_source_data_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsSourceData, g_object_unref)
VALA_EXTERN ObjectsSourceData* objects_source_get_data (ObjectsSource* self);
VALA_EXTERN void objects_source_set_data (ObjectsSource* self,
                              ObjectsSourceData* value);
VALA_EXTERN const gchar* objects_source_get_display_name (ObjectsSource* self);
VALA_EXTERN void objects_source_set_display_name (ObjectsSource* self,
                                      const gchar* value);
VALA_EXTERN SyncStatus* objects_source_get_sync_status (ObjectsSource* self);
VALA_EXTERN void objects_source_set_sync_status (ObjectsSource* self,
                                     SyncStatus* value);
VALA_EXTERN GType objects_source_todoist_data_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsSourceTodoistData, g_object_unref)
VALA_EXTERN ObjectsSourceTodoistData* objects_source_get_todoist_data (ObjectsSource* self);
VALA_EXTERN GType objects_source_cal_dav_data_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsSourceCalDAVData, g_object_unref)
VALA_EXTERN ObjectsSourceCalDAVData* objects_source_get_caldav_data (ObjectsSource* self);
VALA_EXTERN const gchar* objects_source_get_header_text (ObjectsSource* self);
VALA_EXTERN const gchar* objects_source_get_subheader_text (ObjectsSource* self);
VALA_EXTERN const gchar* objects_source_get_avatar_path (ObjectsSource* self);
VALA_EXTERN const gchar* objects_source_get_user_displayname (ObjectsSource* self);
VALA_EXTERN const gchar* objects_source_get_user_email (ObjectsSource* self);
VALA_EXTERN gchar* objects_source_data_to_json (ObjectsSourceData* self);
VALA_EXTERN ObjectsSourceData* objects_source_data_new (void);
VALA_EXTERN ObjectsSourceData* objects_source_data_construct (GType object_type);
VALA_EXTERN JsonBuilder* objects_source_data_get_builder (ObjectsSourceData* self);
VALA_EXTERN ObjectsSourceTodoistData* objects_source_todoist_data_new_from_json (const gchar* json);
VALA_EXTERN ObjectsSourceTodoistData* objects_source_todoist_data_construct_from_json (GType object_type,
                                                                           const gchar* json);
VALA_EXTERN ObjectsSourceTodoistData* objects_source_todoist_data_new (void);
VALA_EXTERN ObjectsSourceTodoistData* objects_source_todoist_data_construct (GType object_type);
VALA_EXTERN const gchar* objects_source_todoist_data_get_access_token (ObjectsSourceTodoistData* self);
VALA_EXTERN void objects_source_todoist_data_set_access_token (ObjectsSourceTodoistData* self,
                                                   const gchar* value);
VALA_EXTERN const gchar* objects_source_todoist_data_get_sync_token (ObjectsSourceTodoistData* self);
VALA_EXTERN void objects_source_todoist_data_set_sync_token (ObjectsSourceTodoistData* self,
                                                 const gchar* value);
VALA_EXTERN const gchar* objects_source_todoist_data_get_user_id (ObjectsSourceTodoistData* self);
VALA_EXTERN void objects_source_todoist_data_set_user_id (ObjectsSourceTodoistData* self,
                                              const gchar* value);
VALA_EXTERN const gchar* objects_source_todoist_data_get_user_image_id (ObjectsSourceTodoistData* self);
VALA_EXTERN void objects_source_todoist_data_set_user_image_id (ObjectsSourceTodoistData* self,
                                                    const gchar* value);
VALA_EXTERN const gchar* objects_source_todoist_data_get_user_email (ObjectsSourceTodoistData* self);
VALA_EXTERN void objects_source_todoist_data_set_user_email (ObjectsSourceTodoistData* self,
                                                 const gchar* value);
VALA_EXTERN const gchar* objects_source_todoist_data_get_user_name (ObjectsSourceTodoistData* self);
VALA_EXTERN void objects_source_todoist_data_set_user_name (ObjectsSourceTodoistData* self,
                                                const gchar* value);
VALA_EXTERN const gchar* objects_source_todoist_data_get_user_avatar (ObjectsSourceTodoistData* self);
VALA_EXTERN void objects_source_todoist_data_set_user_avatar (ObjectsSourceTodoistData* self,
                                                  const gchar* value);
VALA_EXTERN gboolean objects_source_todoist_data_get_user_is_premium (ObjectsSourceTodoistData* self);
VALA_EXTERN void objects_source_todoist_data_set_user_is_premium (ObjectsSourceTodoistData* self,
                                                      gboolean value);
VALA_EXTERN const gchar* objects_source_todoist_data_get_api_version (ObjectsSourceTodoistData* self);
VALA_EXTERN void objects_source_todoist_data_set_api_version (ObjectsSourceTodoistData* self,
                                                  const gchar* value);
VALA_EXTERN ObjectsSourceCalDAVData* objects_source_cal_dav_data_new_from_json (const gchar* json);
VALA_EXTERN ObjectsSourceCalDAVData* objects_source_cal_dav_data_construct_from_json (GType object_type,
                                                                          const gchar* json);
VALA_EXTERN ObjectsSourceCalDAVData* objects_source_cal_dav_data_new (void);
VALA_EXTERN ObjectsSourceCalDAVData* objects_source_cal_dav_data_construct (GType object_type);
VALA_EXTERN const gchar* objects_source_cal_dav_data_get_server_url (ObjectsSourceCalDAVData* self);
VALA_EXTERN void objects_source_cal_dav_data_set_server_url (ObjectsSourceCalDAVData* self,
                                                 const gchar* value);
VALA_EXTERN const gchar* objects_source_cal_dav_data_get_username (ObjectsSourceCalDAVData* self);
VALA_EXTERN void objects_source_cal_dav_data_set_username (ObjectsSourceCalDAVData* self,
                                               const gchar* value);
VALA_EXTERN const gchar* objects_source_cal_dav_data_get_password (ObjectsSourceCalDAVData* self);
VALA_EXTERN void objects_source_cal_dav_data_set_password (ObjectsSourceCalDAVData* self,
                                               const gchar* value);
VALA_EXTERN const gchar* objects_source_cal_dav_data_get_user_displayname (ObjectsSourceCalDAVData* self);
VALA_EXTERN void objects_source_cal_dav_data_set_user_displayname (ObjectsSourceCalDAVData* self,
                                                       const gchar* value);
VALA_EXTERN const gchar* objects_source_cal_dav_data_get_user_email (ObjectsSourceCalDAVData* self);
VALA_EXTERN void objects_source_cal_dav_data_set_user_email (ObjectsSourceCalDAVData* self,
                                                 const gchar* value);
VALA_EXTERN const gchar* objects_source_cal_dav_data_get_calendar_home_url (ObjectsSourceCalDAVData* self);
VALA_EXTERN void objects_source_cal_dav_data_set_calendar_home_url (ObjectsSourceCalDAVData* self,
                                                        const gchar* value);
VALA_EXTERN CalDAVType objects_source_cal_dav_data_get_caldav_type (ObjectsSourceCalDAVData* self);
VALA_EXTERN void objects_source_cal_dav_data_set_caldav_type (ObjectsSourceCalDAVData* self,
                                                  CalDAVType value);
VALA_EXTERN gboolean objects_source_cal_dav_data_get_ignore_ssl (ObjectsSourceCalDAVData* self);
VALA_EXTERN void objects_source_cal_dav_data_set_ignore_ssl (ObjectsSourceCalDAVData* self,
                                                 gboolean value);
VALA_EXTERN GType objects_translation_metric_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsTranslationMetric, g_object_unref)
VALA_EXTERN ObjectsTranslationMetric* objects_translation_metric_new (void);
VALA_EXTERN ObjectsTranslationMetric* objects_translation_metric_construct (GType object_type);
VALA_EXTERN const gchar* objects_translation_metric_get_code (ObjectsTranslationMetric* self);
VALA_EXTERN void objects_translation_metric_set_code (ObjectsTranslationMetric* self,
                                          const gchar* value);
VALA_EXTERN const gchar* objects_translation_metric_get_language (ObjectsTranslationMetric* self);
VALA_EXTERN void objects_translation_metric_set_language (ObjectsTranslationMetric* self,
                                              const gchar* value);
VALA_EXTERN gint objects_translation_metric_get_total_strings (ObjectsTranslationMetric* self);
VALA_EXTERN void objects_translation_metric_set_total_strings (ObjectsTranslationMetric* self,
                                                   gint value);
VALA_EXTERN gint objects_translation_metric_get_translated_strings (ObjectsTranslationMetric* self);
VALA_EXTERN void objects_translation_metric_set_translated_strings (ObjectsTranslationMetric* self,
                                                        gint value);
VALA_EXTERN gdouble objects_translation_metric_get_translated_percent (ObjectsTranslationMetric* self);
VALA_EXTERN void objects_translation_metric_set_translated_percent (ObjectsTranslationMetric* self,
                                                        gdouble value);
VALA_EXTERN GType objects_release_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsRelease, g_object_unref)
VALA_EXTERN ObjectsRelease* objects_release_new_from_json (JsonObject* object);
VALA_EXTERN ObjectsRelease* objects_release_construct_from_json (GType object_type,
                                                     JsonObject* object);
VALA_EXTERN gchar* objects_release_get_release_message (ObjectsRelease* self);
VALA_EXTERN ObjectsRelease* objects_release_new (void);
VALA_EXTERN ObjectsRelease* objects_release_construct (GType object_type);
VALA_EXTERN const gchar* objects_release_get_release_type (ObjectsRelease* self);
VALA_EXTERN void objects_release_set_release_type (ObjectsRelease* self,
                                       const gchar* value);
VALA_EXTERN const gchar* objects_release_get_version (ObjectsRelease* self);
VALA_EXTERN void objects_release_set_version (ObjectsRelease* self,
                                  const gchar* value);
VALA_EXTERN gint64 objects_release_get_timestamp (ObjectsRelease* self);
VALA_EXTERN void objects_release_set_timestamp (ObjectsRelease* self,
                                    gint64 value);
VALA_EXTERN const gchar* objects_release_get_description (ObjectsRelease* self);
VALA_EXTERN void objects_release_set_description (ObjectsRelease* self,
                                      const gchar* value);
VALA_EXTERN GType objects_filters_inbox_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsFiltersInbox, g_object_unref)
VALA_EXTERN ObjectsFiltersInbox* objects_filters_inbox_get_default (void);
VALA_EXTERN ObjectsFiltersInbox* objects_filters_inbox_new (void);
VALA_EXTERN ObjectsFiltersInbox* objects_filters_inbox_construct (GType object_type);
VALA_EXTERN GType objects_filters_pinboard_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsFiltersPinboard, g_object_unref)
VALA_EXTERN ObjectsFiltersPinboard* objects_filters_pinboard_get_default (void);
VALA_EXTERN ObjectsFiltersPinboard* objects_filters_pinboard_new (void);
VALA_EXTERN ObjectsFiltersPinboard* objects_filters_pinboard_construct (GType object_type);
VALA_EXTERN GType objects_filters_scheduled_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsFiltersScheduled, g_object_unref)
VALA_EXTERN ObjectsFiltersScheduled* objects_filters_scheduled_get_default (void);
VALA_EXTERN ObjectsFiltersScheduled* objects_filters_scheduled_new (void);
VALA_EXTERN ObjectsFiltersScheduled* objects_filters_scheduled_construct (GType object_type);
VALA_EXTERN gint objects_filters_scheduled_get_scheduled_count (ObjectsFiltersScheduled* self);
VALA_EXTERN void objects_filters_scheduled_set_scheduled_count (ObjectsFiltersScheduled* self,
                                                    gint value);
VALA_EXTERN GType objects_filters_today_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsFiltersToday, g_object_unref)
VALA_EXTERN ObjectsFiltersToday* objects_filters_today_get_default (void);
VALA_EXTERN ObjectsFiltersToday* objects_filters_today_new (void);
VALA_EXTERN ObjectsFiltersToday* objects_filters_today_construct (GType object_type);
VALA_EXTERN gint objects_filters_today_get_overdeue_count (ObjectsFiltersToday* self);
VALA_EXTERN void objects_filters_today_set_overdeue_count (ObjectsFiltersToday* self,
                                               gint value);
VALA_EXTERN GType objects_filters_priority_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsFiltersPriority, g_object_unref)
VALA_EXTERN ObjectsFiltersPriority* objects_filters_priority_high (void);
VALA_EXTERN ObjectsFiltersPriority* objects_filters_priority_medium (void);
VALA_EXTERN ObjectsFiltersPriority* objects_filters_priority_low (void);
VALA_EXTERN ObjectsFiltersPriority* objects_filters_priority_none (void);
VALA_EXTERN ObjectsFiltersPriority* objects_filters_priority_get_default (gint priority);
VALA_EXTERN ObjectsFiltersPriority* objects_filters_priority_new (gint priority);
VALA_EXTERN ObjectsFiltersPriority* objects_filters_priority_construct (GType object_type,
                                                            gint priority);
VALA_EXTERN gint objects_filters_priority_get_priority (ObjectsFiltersPriority* self);
VALA_EXTERN gint objects_filters_priority_get_count (ObjectsFiltersPriority* self);
VALA_EXTERN void objects_filters_priority_set_count (ObjectsFiltersPriority* self,
                                         gint value);
VALA_EXTERN const gchar* objects_filters_priority_get_icon (ObjectsFiltersPriority* self);
VALA_EXTERN const gchar* objects_filters_priority_get_color (ObjectsFiltersPriority* self);
VALA_EXTERN const gchar* objects_filters_priority_get_title (ObjectsFiltersPriority* self);
VALA_EXTERN GType objects_filters_completed_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsFiltersCompleted, g_object_unref)
VALA_EXTERN ObjectsFiltersCompleted* objects_filters_completed_get_default (void);
VALA_EXTERN ObjectsFiltersCompleted* objects_filters_completed_new (void);
VALA_EXTERN ObjectsFiltersCompleted* objects_filters_completed_construct (GType object_type);
VALA_EXTERN GType objects_filters_labels_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsFiltersLabels, g_object_unref)
VALA_EXTERN ObjectsFiltersLabels* objects_filters_labels_get_default (void);
VALA_EXTERN ObjectsFiltersLabels* objects_filters_labels_new (void);
VALA_EXTERN ObjectsFiltersLabels* objects_filters_labels_construct (GType object_type);
VALA_EXTERN GType objects_filters_tomorrow_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsFiltersTomorrow, g_object_unref)
VALA_EXTERN ObjectsFiltersTomorrow* objects_filters_tomorrow_get_default (void);
VALA_EXTERN ObjectsFiltersTomorrow* objects_filters_tomorrow_new (void);
VALA_EXTERN ObjectsFiltersTomorrow* objects_filters_tomorrow_construct (GType object_type);
VALA_EXTERN GType objects_filters_anytime_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsFiltersAnytime, g_object_unref)
VALA_EXTERN ObjectsFiltersAnytime* objects_filters_anytime_get_default (void);
VALA_EXTERN ObjectsFiltersAnytime* objects_filters_anytime_new (void);
VALA_EXTERN ObjectsFiltersAnytime* objects_filters_anytime_construct (GType object_type);
VALA_EXTERN GType objects_filters_repeating_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsFiltersRepeating, g_object_unref)
VALA_EXTERN ObjectsFiltersRepeating* objects_filters_repeating_get_default (void);
VALA_EXTERN ObjectsFiltersRepeating* objects_filters_repeating_new (void);
VALA_EXTERN ObjectsFiltersRepeating* objects_filters_repeating_construct (GType object_type);
VALA_EXTERN GType objects_filters_unlabeled_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsFiltersUnlabeled, g_object_unref)
VALA_EXTERN ObjectsFiltersUnlabeled* objects_filters_unlabeled_get_default (void);
VALA_EXTERN ObjectsFiltersUnlabeled* objects_filters_unlabeled_new (void);
VALA_EXTERN ObjectsFiltersUnlabeled* objects_filters_unlabeled_construct (GType object_type);
VALA_EXTERN ObjectsFiltersFilterItem* objects_filters_filter_item_new (void);
VALA_EXTERN ObjectsFiltersFilterItem* objects_filters_filter_item_construct (GType object_type);
VALA_EXTERN FilterItemType objects_filters_filter_item_get_filter_type (ObjectsFiltersFilterItem* self);
VALA_EXTERN void objects_filters_filter_item_set_filter_type (ObjectsFiltersFilterItem* self,
                                                  FilterItemType value);
VALA_EXTERN const gchar* objects_filters_filter_item_get_name (ObjectsFiltersFilterItem* self);
VALA_EXTERN void objects_filters_filter_item_set_name (ObjectsFiltersFilterItem* self,
                                           const gchar* value);
VALA_EXTERN const gchar* objects_filters_filter_item_get_value (ObjectsFiltersFilterItem* self);
VALA_EXTERN void objects_filters_filter_item_set_value (ObjectsFiltersFilterItem* self,
                                            const gchar* value);
VALA_EXTERN const gchar* objects_filters_filter_item_get_id (ObjectsFiltersFilterItem* self);
VALA_EXTERN GType objects_filters_all_items_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ObjectsFiltersAllItems, g_object_unref)
VALA_EXTERN ObjectsFiltersAllItems* objects_filters_all_items_get_default (void);
VALA_EXTERN ObjectsFiltersAllItems* objects_filters_all_items_new (void);
VALA_EXTERN ObjectsFiltersAllItems* objects_filters_all_items_construct (GType object_type);
VALA_EXTERN GType services_calendar_events_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ServicesCalendarEvents, g_object_unref)
VALA_EXTERN ServicesCalendarEvents* services_calendar_events_get_default (void);
VALA_EXTERN ServicesCalendarEvents* services_calendar_events_new (GDateTime* month_start);
VALA_EXTERN ServicesCalendarEvents* services_calendar_events_construct (GType object_type,
                                                            GDateTime* month_start);
VALA_EXTERN GeeArrayList* services_calendar_events_get_all_sources (ServicesCalendarEvents* self);
VALA_EXTERN void services_calendar_events_create_event (ServicesCalendarEvents* self,
                                            const gchar* source_uid,
                                            ObjectsItem* item,
                                            GAsyncReadyCallback _callback_,
                                            gpointer _user_data_);
VALA_EXTERN gchar* services_calendar_events_create_event_finish (ServicesCalendarEvents* self,
                                                     GAsyncResult* _res_);
VALA_EXTERN void services_calendar_events_delete_event (ServicesCalendarEvents* self,
                                            const gchar* source_uid,
                                            const gchar* event_uid,
                                            GAsyncReadyCallback _callback_,
                                            gpointer _user_data_);
VALA_EXTERN gboolean services_calendar_events_delete_event_finish (ServicesCalendarEvents* self,
                                                       GAsyncResult* _res_);
VALA_EXTERN void services_calendar_events_update_event (ServicesCalendarEvents* self,
                                            const gchar* source_uid,
                                            const gchar* event_uid,
                                            ObjectsItem* item,
                                            GAsyncReadyCallback _callback_,
                                            gpointer _user_data_);
VALA_EXTERN gboolean services_calendar_events_update_event_finish (ServicesCalendarEvents* self,
                                                       GAsyncResult* _res_);
VALA_EXTERN GType calendar_events_util_date_range_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CalendarEventsUtilDateRange, g_object_unref)
VALA_EXTERN CalendarEventsUtilDateRange* services_calendar_events_get_data_range (ServicesCalendarEvents* self);
VALA_EXTERN GDateTime* services_calendar_events_get_month_start (ServicesCalendarEvents* self);
VALA_EXTERN gint services_calendar_events_get_num_weeks (ServicesCalendarEvents* self);
VALA_EXTERN GDateWeekday services_calendar_events_get_week_starts_on (ServicesCalendarEvents* self);
VALA_EXTERN void services_calendar_events_set_week_starts_on (ServicesCalendarEvents* self,
                                                  GDateWeekday value);
VALA_EXTERN GHashTable* services_calendar_events_get_source_components (ServicesCalendarEvents* self);
VALA_EXTERN ESourceRegistry* services_calendar_events_get_registry (ServicesCalendarEvents* self);
VALA_EXTERN GType calendar_events_util_date_iterator_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CalendarEventsUtilDateIterator, g_object_unref)
VALA_EXTERN CalendarEventsUtilDateIterator* calendar_events_util_date_iterator_new (CalendarEventsUtilDateRange* range);
VALA_EXTERN CalendarEventsUtilDateIterator* calendar_events_util_date_iterator_construct (GType object_type,
                                                                              CalendarEventsUtilDateRange* range);
VALA_EXTERN GDateTime* calendar_events_util_date_iterator_get_current (CalendarEventsUtilDateIterator* self);
VALA_EXTERN void calendar_events_util_date_iterator_set_current (CalendarEventsUtilDateIterator* self,
                                                     GDateTime* value);
VALA_EXTERN CalendarEventsUtilDateRange* calendar_events_util_date_iterator_get_range (CalendarEventsUtilDateIterator* self);
VALA_EXTERN CalendarEventsUtilDateRange* calendar_events_util_date_range_new (GDateTime* first,
                                                                  GDateTime* last);
VALA_EXTERN CalendarEventsUtilDateRange* calendar_events_util_date_range_construct (GType object_type,
                                                                        GDateTime* first,
                                                                        GDateTime* last);
VALA_EXTERN gboolean calendar_events_util_date_range_equals (CalendarEventsUtilDateRange* self,
                                                 CalendarEventsUtilDateRange* other);
VALA_EXTERN GeeList* calendar_events_util_date_range_to_list (CalendarEventsUtilDateRange* self);
VALA_EXTERN GDateTime* calendar_events_util_date_range_get_first_dt (CalendarEventsUtilDateRange* self);
VALA_EXTERN GDateTime* calendar_events_util_date_range_get_last_dt (CalendarEventsUtilDateRange* self);
VALA_EXTERN GDateTime* calendar_events_util_get_start_of_month (GDateTime* date);
VALA_EXTERN GDateTime* calendar_events_util_strip_time (GDateTime* datetime);
VALA_EXTERN GTimeZone* calendar_events_util_timezone_from_ical (ICalTime* date);
VALA_EXTERN GDateTime* calendar_events_util_ical_to_date_time (ICalTime* date);
VALA_EXTERN gboolean calendar_events_util_is_the_all_day (GDateTime* dtstart,
                                              GDateTime* dtend);
VALA_EXTERN guint calendar_events_util_source_hash_func (ESource* key);
VALA_EXTERN gboolean calendar_events_util_calcomponent_equal_func (ECalComponent* a,
                                                       ECalComponent* b);
VALA_EXTERN gint calendar_events_util_calcomponent_compare_func (ECalComponent* a,
                                                     ECalComponent* b);
VALA_EXTERN gboolean calendar_events_util_calcomp_is_on_day (ECalComponent* comp,
                                                 GDateTime* day);
VALA_EXTERN gboolean calendar_events_util_calcomp_is_on_month (ECalComponent* comp,
                                                   GDateTime* date);
VALA_EXTERN gboolean calendar_events_util_source_equal_func (ESource* a,
                                                 ESource* b);
VALA_EXTERN gchar* calendar_events_util_get_source_location (ESource* source);

G_END_DECLS

#endif
